@@ -35,12 +35,12 @@
 
 SbxObject* cloneTypeObjectImpl( const SbxObject& rTypeObj );
 
-// Deklaration einer Variablen
-// Bei Fehlern wird bis zum Komma oder Newline geparst.
-// Returnwert: eine neue Instanz, die eingefuegt und dann geloescht wird.
-// Array-Indexe werden als SbiDimList zurueckgegeben
+// Declaration of a variable
+// If there are errors it will be parsed up to the comma or the newline.
+// Return-value: a new instance, which were inserted and then deleted.
+// Array-Indexex were returned as SbiDimList
 
-SbiSymDef* SbiParser::VarDecl( SbiDimList** ppDim, BOOL bStatic, BOOL bConst )
+SbiSymDef* SbiParser::VarDecl( SbiDimList** ppDim, sal_Bool bStatic, sal_Bool bConst )
 {
     bool bWithEvents = false;
     if( Peek() == WITHEVENTS )
@@ -52,7 +52,7 @@ SbiSymDef* SbiParser::VarDecl( SbiDimList** ppDim, BOOL bStatic, BOOL bConst )
     SbxDataType t = eScanType;
     SbiSymDef* pDef = bConst ? new SbiConstDef( aSym ) : new SbiSymDef( aSym );
     SbiDimList* pDim = NULL;
-    // Klammern?
+    // Brackets?
     if( Peek() == LPAREN )
         pDim = new SbiDimList( this );
     pDef->SetType( t );
@@ -72,15 +72,15 @@ SbiSymDef* SbiParser::VarDecl( SbiDimList** ppDim, BOOL bStatic, BOOL bConst )
     return pDef;
 }
 
-// Aufloesen einer AS-Typdeklaration
-// Der Datentyp wird in die uebergebene Variable eingetragen
+// Resolving of a AS-Type-Declaration
+// The data type were inserted into the handed over variable
 
-void SbiParser::TypeDecl( SbiSymDef& rDef, BOOL bAsNewAlreadyParsed )
+void SbiParser::TypeDecl( SbiSymDef& rDef, sal_Bool bAsNewAlreadyParsed )
 {
     SbxDataType eType = rDef.GetType();
-    short nSize = 0;
     if( bAsNewAlreadyParsed || Peek() == AS )
     {
+        short nSize = 0;
         if( !bAsNewAlreadyParsed )
             Next();
         rDef.SetDefinedAs();
@@ -127,14 +127,14 @@ void SbiParser::TypeDecl( SbiSymDef& rDef, BOOL bAsNewAlreadyParsed )
                     }
                 }
                 break;
-            case SYMBOL: // kann nur ein TYPE oder eine Objektklasse sein!
+            case SYMBOL: // can only be a TYPE or a object class!
                 if( eScanType != SbxVARIANT )
                     Error( SbERR_SYNTAX );
                 else
                 {
                     String aCompleteName = aSym;
 
-                    // #52709 DIM AS NEW fuer Uno mit voll-qualifizierten Namen
+                    // #52709 DIM AS NEW for Uno with full-qualified name
                     if( Peek() == DOT )
                     {
                         String aDotStr( '.' );
@@ -162,7 +162,7 @@ void SbiParser::TypeDecl( SbiSymDef& rDef, BOOL bAsNewAlreadyParsed )
                         break;
                     }
 
-                    // In den String-Pool uebernehmen
+                    // Take over in the String pool
                     rDef.SetTypeId( aGblStrings.Add( aCompleteName ) );
 
                     if( rDef.IsNew() && pProc == NULL )
@@ -178,7 +178,7 @@ void SbiParser::TypeDecl( SbiSymDef& rDef, BOOL bAsNewAlreadyParsed )
                 Error( SbERR_UNEXPECTED, eTok );
                 Next();
         }
-        // Die Variable koennte mit Suffix deklariert sein
+        // The variable could have been declared with a suffix
         if( rDef.GetType() != SbxVARIANT )
         {
             if( rDef.GetType() != eType )
@@ -191,39 +191,39 @@ void SbiParser::TypeDecl( SbiSymDef& rDef, BOOL bAsNewAlreadyParsed )
     }
 }
 
-// Hier werden Variable, Arrays und Strukturen definiert.
+// Here variables, arrays and structures were definied.
 // DIM/PRIVATE/PUBLIC/GLOBAL
 
 void SbiParser::Dim()
 {
-    DefVar( _DIM, ( pProc && bVBASupportOn ) ? pProc->IsStatic() : FALSE );
+    DefVar( _DIM, ( pProc && bVBASupportOn ) ? pProc->IsStatic() : sal_False );
 }
 
-void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
+void SbiParser::DefVar( SbiOpcode eOp, sal_Bool bStatic )
 {
     SbiSymPool* pOldPool = pPool;
-    BOOL bSwitchPool = FALSE;
-    BOOL bPersistantGlobal = FALSE;
+    sal_Bool bSwitchPool = sal_False;
+    sal_Bool bPersistantGlobal = sal_False;
     SbiToken eFirstTok = eCurTok;
     if( pProc && ( eCurTok == GLOBAL || eCurTok == PUBLIC || eCurTok == PRIVATE ) )
         Error( SbERR_NOT_IN_SUBR, eCurTok );
     if( eCurTok == PUBLIC || eCurTok == GLOBAL )
     {
-        bSwitchPool = TRUE;		// im richtigen Moment auf globalen Pool schalten
+        bSwitchPool = sal_True;		// at the right moment switch to the global pool
         if( eCurTok == GLOBAL )
-            bPersistantGlobal = TRUE;
+            bPersistantGlobal = sal_True;
     }
     // behavior in VBA is that a module scope variable's lifetime is
     // tied to the document. e.g. a module scope variable is global
        if(  GetBasic()->IsDocBasic() && bVBASupportOn && !pProc )
-        bPersistantGlobal = TRUE;
-    // PRIVATE ist Synonym fuer DIM
+        bPersistantGlobal = sal_True;
+    // PRIVATE is a synonymous for DIM
     // _CONST_?
-    BOOL bConst = FALSE;
+    sal_Bool bConst = sal_False;
     if( eCurTok == _CONST_ )
-        bConst = TRUE;
+        bConst = sal_True;
     else if( Peek() == _CONST_ )
-        Next(), bConst = TRUE;
+        Next(), bConst = sal_True;
 
     // #110004 It can also be a sub/function
     if( !bConst && (eCurTok == SUB || eCurTok == FUNCTION || eCurTok == PROPERTY ||
@@ -244,10 +244,10 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
             if( bNewGblDefs && nGblChain == 0 )
             {
                 nGblChain = aGen.Gen( _JUMP, 0 );
-                bNewGblDefs = FALSE;
+                bNewGblDefs = sal_False;
             }
             Next();
-            DefProc( FALSE, bPrivate );
+            DefProc( sal_False, bPrivate );
             return;
         }
         else if( eCurTok == ENUM )
@@ -275,13 +275,13 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
 #define tmpSHARED
 #undef SHARED
 #endif
-    // SHARED wird ignoriert
+    // SHARED were ignored
     if( Peek() == SHARED ) Next();
 #ifdef tmpSHARED
 #define SHARED
 #undef tmpSHARED
 #endif
-    // PRESERVE nur bei REDIM
+    // PRESERVE only at REDIM
     if( Peek() == PRESERVE )
     {
         Next();
@@ -293,29 +293,29 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
     SbiSymDef* pDef;
     SbiDimList* pDim;
 
-    // AB 9.7.97, #40689, Statics -> Modul-Initialisierung, in Sub ueberspringen
-    UINT32 nEndOfStaticLbl = 0;
+    // #40689, Statics -> Modul-Initialising, skip in Sub
+    sal_uInt32 nEndOfStaticLbl = 0;
     if( !bVBASupportOn && bStatic )
     {
         nEndOfStaticLbl = aGen.Gen( _JUMP, 0 );
-        aGen.Statement();	// bei static hier nachholen
+        aGen.Statement();	// catch up on static here
     }
 
-    BOOL bDefined = FALSE;
+    sal_Bool bDefined = sal_False;
     while( ( pDef = VarDecl( &pDim, bStatic, bConst ) ) != NULL )
     {
         EnableErrors();
-        // Variable suchen:
+        // search variable:
         if( bSwitchPool )
             pPool = &aGlobals;
         SbiSymDef* pOld = pPool->Find( pDef->GetName() );
-        // AB 31.3.1996, #25651#, auch in Runtime-Library suchen
-        BOOL bRtlSym = FALSE;
+        // search also in the Runtime-Library
+        sal_Bool bRtlSym = sal_False;
         if( !pOld )
         {
             pOld = CheckRTLForSym( pDef->GetName(), SbxVARIANT );
             if( pOld )
-                bRtlSym = TRUE;
+                bRtlSym = sal_True;
         }
         if( pOld && !(eOp == _REDIM || eOp == _REDIMP) )
         {
@@ -324,11 +324,11 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
         }
         if( pOld )
         {
-            bDefined = TRUE;
-            // Bei RTL-Symbol immer Fehler
+            bDefined = sal_True;
+            // always an error at a RTL-S
             if( !bRtlSym && (eOp == _REDIM || eOp == _REDIMP) )
             {
-                // Bei REDIM die Attribute vergleichen
+                // compare the attributes at a REDIM
                 SbxDataType eDefType;
                 bool bError_ = false;
                 if( pOld->IsStatic() )
@@ -350,19 +350,19 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
         else
             pPool->Add( pDef );
 
-        // #36374: Variable vor Unterscheidung IsNew() anlegen
-        // Sonst Error bei Dim Identifier As New Type und option explicit
+        // #36374: Create the variable in front of the distinction IsNew()
+        // Otherwise error at Dim Identifier As New Type and option explicit
         if( !bDefined && !(eOp == _REDIM || eOp == _REDIMP)
                       && ( !bConst || pDef->GetScope() == SbGLOBAL ) )
         {
-            // Variable oder globale Konstante deklarieren
+            // Declare variable or global constant
             SbiOpcode eOp2;
             switch ( pDef->GetScope() )
             {
                 case SbGLOBAL:	eOp2 = bPersistantGlobal ? _GLOBAL_P : _GLOBAL;
                                 goto global;
                 case SbPUBLIC:	eOp2 = bPersistantGlobal ? _PUBLIC_P : _PUBLIC;
-                                // AB 9.7.97, #40689, kein eigener Opcode mehr
+                                // #40689, no own Opcode anymore
                                 if( bVBASupportOn && bStatic )
                                 {
                                     eOp2 = _STATIC;
@@ -370,23 +370,26 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
                                 }
                 global:			aGen.BackChain( nGblChain );
                                 nGblChain = 0;
-                                bGblDefs = bNewGblDefs = TRUE;
+                                bGblDefs = bNewGblDefs = sal_True;
                                 break;
                 default:		eOp2 = _LOCAL;
             }
-            UINT32 nOpnd2 = sal::static_int_cast< UINT16 >( pDef->GetType() );
+            sal_uInt32 nOpnd2 = sal::static_int_cast< sal_uInt16 >( pDef->GetType() );
             if( pDef->IsWithEvents() )
                 nOpnd2 |= SBX_TYPE_WITH_EVENTS_FLAG;
 
+            if( bCompatible && pDef->IsNew() )
+                nOpnd2 |= SBX_TYPE_DIM_AS_NEW_FLAG;
+
             short nFixedStringLength = pDef->GetFixedStringLength();
             if( nFixedStringLength >= 0 )
-                nOpnd2 |= (SBX_FIXED_LEN_STRING_FLAG + (UINT32(nFixedStringLength) << 17));		// len = all bits above 0x10000
+                nOpnd2 |= (SBX_FIXED_LEN_STRING_FLAG + (sal_uInt32(nFixedStringLength) << 17));		// len = all bits above 0x10000
 
             aGen.Gen( eOp2, pDef->GetId(), nOpnd2 );
         }
 
-        // Initialisierung fuer selbstdefinierte Datentypen
-        // und per NEW angelegte Variable
+        // Initialising for self-defined daty types
+        // and per NEW created variable
         if( pDef->GetType() == SbxOBJECT
          && pDef->GetTypeId() )
         {
@@ -439,7 +442,7 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
         {
             if( bConst )
             {
-                // Konstanten-Definition
+                // Definition of the constants
                 if( pDim )
                 {
                     Error( SbERR_SYNTAX );
@@ -447,13 +450,13 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
                 }
                 SbiExpression aVar( this, *pDef );
                 if( !TestToken( EQ ) )
-                    goto MyBreak;	// AB 24.6.1996 (s.u.)
+                    goto MyBreak;	// (see below)
                 SbiConstExpression aExpr( this );
                 if( !bDefined && aExpr.IsValid() )
                 {
                     if( pDef->GetScope() == SbGLOBAL )
                     {
-                        // Nur Code fuer globale Konstante erzeugen!
+                        // Create code only for the global constant!
                         aVar.Gen();
                         aExpr.Gen();
                         aGen.Gen( _PUTC );
@@ -467,8 +470,8 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
             }
             else if( pDim )
             {
-                // Die Variable dimensionieren
-                // Bei REDIM die Var vorher loeschen
+                // Dimension the variable
+                // Delete the var at REDIM beforehand
                 if( eOp == _REDIM )
                 {
                     SbiExpression aExpr( this, *pDef, NULL );
@@ -490,48 +493,46 @@ void SbiParser::DefVar( SbiOpcode eOp, BOOL bStatic )
                 }
                 pDef->SetDims( pDim->GetDims() );
                 if( bPersistantGlobal )
-                    pDef->SetGlobal( TRUE );
+                    pDef->SetGlobal( sal_True );
                 SbiExpression aExpr( this, *pDef, pDim );
                 aExpr.Gen();
-                pDef->SetGlobal( FALSE );
+                pDef->SetGlobal( sal_False );
                 aGen.Gen( (eOp == _STATIC) ? _DIM : eOp );
             }
         }
         if( !TestComma() )
-            goto MyBreak;	// AB 24.6.1996 (s.u.)
+            goto MyBreak;
 
-        // #27963# AB, 24.6.1996
-        // Einfuehrung bSwitchPool (s.o.): pPool darf beim VarDecl-Aufruf
-        // noch nicht auf &aGlobals gesetzt sein.
-        // Ansonsten soll das Verhalten aber absolut identisch bleiben,
-        // d.h. pPool muss immer am Schleifen-Ende zurueckgesetzt werden.
-        // auch bei break
+        // Implementation of bSwitchPool (see above): pPool must not be set to &aGlobals
+        // at the VarDecl-Call.
+        // Apart from that the behavior should be absolutely identical,
+        // i.e., pPool had to be reset always at the end of the loop.
+        // also at a break
         pPool = pOldPool;
-        continue;		// MyBreak berspingen
+        continue;		// Skip MyBreak
     MyBreak:
         pPool = pOldPool;
         break;
     }
 
-    // AB 9.7.97, #40689, Sprung ueber Statics-Deklaration abschliessen
+    // #40689, finalize the jump over statics declarations
     if( !bVBASupportOn && bStatic )
     {
-        // globalen Chain pflegen
+        // maintain the global chain
         nGblChain = aGen.Gen( _JUMP, 0 );
-        bGblDefs = bNewGblDefs = TRUE;
+        bGblDefs = bNewGblDefs = sal_True;
 
-        // fuer Sub Sprung auf Ende der statics eintragen
+        // Register for Sub a jump to the end of statics
         aGen.BackChain( nEndOfStaticLbl );
     }
 
-    //pPool = pOldPool;
 }
 
-// Hier werden Arrays redimensioniert.
+// Here were Arrays redimensioned.
 
 void SbiParser::ReDim()
 {
-    DefVar( _REDIM, (  pProc && bVBASupportOn ) ? pProc->IsStatic() : FALSE );
+    DefVar( _REDIM, (  pProc && bVBASupportOn ) ? pProc->IsStatic() : sal_False );
 }
 
 // ERASE array, ...
@@ -547,19 +548,19 @@ void SbiParser::Erase()
     }
 }
 
-// Deklaration eines Datentyps
+// Declaration of a data type
 
 void SbiParser::Type()
 {
-    DefType( FALSE );
+    DefType( sal_False );
 }
 
-void SbiParser::DefType( BOOL bPrivate )
+void SbiParser::DefType( sal_Bool bPrivate )
 {
     // TODO: Use bPrivate
     (void)bPrivate;
 
-    // Neues Token lesen, es muss ein Symbol sein
+    // Read the new Token lesen. It had to be a symbol
     if (!TestSymbol())
         return;
 
@@ -573,7 +574,7 @@ void SbiParser::DefType( BOOL bPrivate )
 
     SbiSymDef* pElem;
     SbiDimList* pDim = NULL;
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
 
     while( !bDone && !IsEof() )
     {
@@ -581,7 +582,7 @@ void SbiParser::DefType( BOOL bPrivate )
         {
             case ENDTYPE :
                 pElem = NULL;
-                bDone = TRUE;
+                bDone = sal_True;
                 Next();
             break;
 
@@ -593,9 +594,9 @@ void SbiParser::DefType( BOOL bPrivate )
 
             default:
                 pDim = NULL;
-                pElem = VarDecl(&pDim,FALSE,FALSE);
+                pElem = VarDecl(&pDim,sal_False,sal_False);
                 if( !pElem )
-                    bDone = TRUE;	// Error occured
+                    bDone = sal_True;	// Error occurred
         }
         if( pElem )
         {
@@ -616,8 +617,8 @@ void SbiParser::DefType( BOOL bPrivate )
 
                         for ( short i=0; i<pDim->GetSize();++i )
                         {
-                            INT32 ub = -1;
-                            INT32 lb = nBase;
+                            sal_Int32 ub = -1;
+                            sal_Int32 lb = nBase;
                             SbiExprNode* pNode =  pDim->Get(i)->GetExprNode();
                             ub = pNode->GetNumber();
                             if ( !pDim->Get( i )->IsBased() ) // each dim is low/up
@@ -636,7 +637,7 @@ void SbiParser::DefType( BOOL bPrivate )
                     }
                     else
                         pArray->unoAddDim( 0, -1 ); // variant array
-                    USHORT nSavFlags = pTypeElem->GetFlags();
+                    sal_uInt16 nSavFlags = pTypeElem->GetFlags();
                     // need to reset the FIXED flag
                     // when calling PutObject ( because the type will not match Object )
                     pTypeElem->ResetFlag( SBX_FIXED );
@@ -646,7 +647,7 @@ void SbiParser::DefType( BOOL bPrivate )
                 // Nested user type?
                 if( eElemType == SbxOBJECT )
                 {
-                    USHORT nElemTypeId = pElem->GetTypeId();
+                    sal_uInt16 nElemTypeId = pElem->GetTypeId();
                     if( nElemTypeId != 0 )
                     {
                         String aTypeName( aGblStrings.Find( nElemTypeId ) );
@@ -676,12 +677,12 @@ void SbiParser::DefType( BOOL bPrivate )
 
 void SbiParser::Enum()
 {
-    DefEnum( FALSE );
+    DefEnum( sal_False );
 }
 
-void SbiParser::DefEnum( BOOL bPrivate )
+void SbiParser::DefEnum( sal_Bool bPrivate )
 {
-    // Neues Token lesen, es muss ein Symbol sein
+    // Read a the new Token. It had to be a symbol
     if (!TestSymbol())
         return;
 
@@ -698,7 +699,7 @@ void SbiParser::DefEnum( BOOL bPrivate )
 
     SbiSymDef* pElem;
     SbiDimList* pDim;
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
 
     // Starting with -1 to make first default value 0 after ++
     sal_Int32 nCurrentEnumValue = -1;
@@ -708,7 +709,7 @@ void SbiParser::DefEnum( BOOL bPrivate )
         {
             case ENDENUM :
                 pElem = NULL;
-                bDone = TRUE;
+                bDone = sal_True;
                 Next();
             break;
 
@@ -721,20 +722,20 @@ void SbiParser::DefEnum( BOOL bPrivate )
             default:
             {
                 // TODO: Check existing!
-                BOOL bDefined = FALSE;
+                sal_Bool bDefined = sal_False;
 
                 pDim = NULL;
-                pElem = VarDecl( &pDim, FALSE, TRUE );
+                pElem = VarDecl( &pDim, sal_False, sal_True );
                 if( !pElem )
                 {
-                    bDone = TRUE;	// Error occured
+                    bDone = sal_True;	// Error occurred
                     break;
                 }
                 else if( pDim )
                 {
                     delete pDim;
                     Error( SbERR_SYNTAX );
-                    bDone = TRUE;	// Error occured
+                    bDone = sal_True;	// Error occurred
                     break;
                 }
 
@@ -764,7 +765,7 @@ void SbiParser::DefEnum( BOOL bPrivate )
                 if( pOld )
                 {
                     Error( SbERR_VAR_DEFINED, pElem->GetName() );
-                    bDone = TRUE;	// Error occured
+                    bDone = sal_True;	// Error occurred
                     break;
                 }
 
@@ -775,13 +776,13 @@ void SbiParser::DefEnum( BOOL bPrivate )
                     SbiOpcode eOp = _GLOBAL;
                     aGen.BackChain( nGblChain );
                     nGblChain = 0;
-                    bGblDefs = bNewGblDefs = TRUE;
+                    bGblDefs = bNewGblDefs = sal_True;
                     aGen.Gen(
                         eOp, pElem->GetId(),
-                        sal::static_int_cast< UINT16 >( pElem->GetType() ) );
+                        sal::static_int_cast< sal_uInt16 >( pElem->GetType() ) );
 
                     aVar.Gen();
-                    USHORT nStringId = aGen.GetParser()->aGblStrings.Add( nCurrentEnumValue, SbxLONG );
+                    sal_uInt16 nStringId = aGen.GetParser()->aGblStrings.Add( nCurrentEnumValue, SbxLONG );
                     aGen.Gen( _NUMBER, nStringId );
                     aGen.Gen( _PUTC );
                 }
@@ -808,14 +809,14 @@ void SbiParser::DefEnum( BOOL bPrivate )
 }
 
 
-// Prozedur-Deklaration
-// das erste Token ist bereits eingelesen (SUB/FUNCTION)
+// Procedure-Declaration
+// the first Token is already read in (SUB/FUNCTION)
 // xxx Name [LIB "name"[ALIAS "name"]][(Parameter)][AS TYPE]
 
-SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
+SbiProcDef* SbiParser::ProcDecl( sal_Bool bDecl )
 {
-    BOOL bFunc = BOOL( eCurTok == FUNCTION );
-    BOOL bProp = BOOL( eCurTok == GET || eCurTok == SET || eCurTok == LET );
+    sal_Bool bFunc = sal_Bool( eCurTok == FUNCTION );
+    sal_Bool bProp = sal_Bool( eCurTok == GET || eCurTok == SET || eCurTok == LET );
     if( !TestSymbol() ) return NULL;
     String aName( aSym );
     SbxDataType eType = eScanType;
@@ -843,28 +844,28 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
     }
     if( !bDecl )
     {
-        // CDECL, LIB und ALIAS sind unzulaessig
+        // CDECL, LIB and ALIAS are invalid
         if( pDef->GetLib().Len() )
             Error( SbERR_UNEXPECTED, LIB );
         if( pDef->GetAlias().Len() )
             Error( SbERR_UNEXPECTED, ALIAS );
         if( pDef->IsCdecl() )
             Error( SbERR_UNEXPECTED, _CDECL_ );
-        pDef->SetCdecl( FALSE );
+        pDef->SetCdecl( sal_False );
         pDef->GetLib().Erase();
         pDef->GetAlias().Erase();
     }
     else if( !pDef->GetLib().Len() )
     {
-        // ALIAS und CDECL nur zusammen mit LIB
+        // ALIAS and CDECL only together with LIB
         if( pDef->GetAlias().Len() )
             Error( SbERR_UNEXPECTED, ALIAS );
         if( pDef->IsCdecl() )
             Error( SbERR_UNEXPECTED, _CDECL_ );
-        pDef->SetCdecl( FALSE );
+        pDef->SetCdecl( sal_False );
         pDef->GetAlias().Erase();
     }
-    // Klammern?
+    // Brackets?
     if( Peek() == LPAREN )
     {
         Next();
@@ -872,23 +873,23 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
             Next();
         else
           for(;;) {
-            BOOL bByVal = FALSE;
-            BOOL bOptional = FALSE;
-            BOOL bParamArray = FALSE;
+            sal_Bool bByVal = sal_False;
+            sal_Bool bOptional = sal_False;
+            sal_Bool bParamArray = sal_False;
             while( Peek() == BYVAL || Peek() == BYREF || Peek() == _OPTIONAL_ )
             {
-                if		( Peek() == BYVAL )		Next(), bByVal = TRUE;
-                else if	( Peek() == BYREF )		Next(), bByVal = FALSE;
-                else if	( Peek() == _OPTIONAL_ )	Next(), bOptional = TRUE;
+                if		( Peek() == BYVAL )		Next(), bByVal = sal_True;
+                else if	( Peek() == BYREF )		Next(), bByVal = sal_False;
+                else if	( Peek() == _OPTIONAL_ )	Next(), bOptional = sal_True;
             }
             if( bCompatible && Peek() == PARAMARRAY )
             {
                 if( bByVal || bOptional )
                     Error( SbERR_UNEXPECTED, PARAMARRAY );
                 Next();
-                bParamArray = TRUE;
+                bParamArray = sal_True;
             }
-            SbiSymDef* pPar = VarDecl( NULL, FALSE, FALSE );
+            SbiSymDef* pPar = VarDecl( NULL, sal_False, sal_False );
             if( !pPar )
                 break;
             if( bByVal )
@@ -901,13 +902,13 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
             SbiToken eTok = Next();
             if( eTok != COMMA && eTok != RPAREN )
             {
-                BOOL bError2 = TRUE;
+                sal_Bool bError2 = sal_True;
                 if( bOptional && bCompatible && eTok == EQ )
                 {
                     SbiConstExpression* pDefaultExpr = new SbiConstExpression( this );
                     SbxDataType eType2 = pDefaultExpr->GetType();
 
-                    USHORT nStringId;
+                    sal_uInt16 nStringId;
                     if( eType2 == SbxSTRING )
                         nStringId = aGblStrings.Add( pDefaultExpr->GetString() );
                     else
@@ -918,7 +919,7 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
 
                     eTok = Next();
                     if( eTok == COMMA || eTok == RPAREN )
-                        bError2 = FALSE;
+                        bError2 = sal_False;
                 }
                 if( bError2 )
                 {
@@ -933,9 +934,6 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
     TypeDecl( *pDef );
     if( eType != SbxVARIANT && pDef->GetType() != eType )
         Error( SbERR_BAD_DECLARATION, aName );
-//	if( pDef->GetType() == SbxOBJECT )
-//		pDef->SetType( SbxVARIANT ),
-//		Error( SbERR_SYNTAX );
     if( pDef->GetType() == SbxVARIANT && !( bFunc || bProp ) )
         pDef->SetType( SbxEMPTY );
     return pDef;
@@ -945,10 +943,10 @@ SbiProcDef* SbiParser::ProcDecl( BOOL bDecl )
 
 void SbiParser::Declare()
 {
-    DefDeclare( FALSE );
+    DefDeclare( sal_False );
 }
 
-void SbiParser::DefDeclare( BOOL bPrivate )
+void SbiParser::DefDeclare( sal_Bool bPrivate )
 {
     Next();
     if( eCurTok != SUB && eCurTok != FUNCTION )
@@ -957,19 +955,19 @@ void SbiParser::DefDeclare( BOOL bPrivate )
     {
         bool bFunction = (eCurTok == FUNCTION);
 
-        SbiProcDef* pDef = ProcDecl( TRUE );
+        SbiProcDef* pDef = ProcDecl( sal_True );
         if( pDef )
         {
             if( !pDef->GetLib().Len() )
                 Error( SbERR_EXPECTED, LIB );
-            // gibts den schon?
+            // Is it already there?
             SbiSymDef* pOld = aPublics.Find( pDef->GetName() );
             if( pOld )
             {
                 SbiProcDef* p = pOld->GetProcDef();
                 if( !p )
                 {
-                    // Als Variable deklariert
+                    // Declared as a variable
                     Error( SbERR_BAD_DECLARATION, pDef->GetName() );
                     delete pDef;
                     pDef = NULL;
@@ -990,39 +988,39 @@ void SbiParser::DefDeclare( BOOL bPrivate )
                     if( bNewGblDefs && nGblChain == 0 )
                     {
                         nGblChain = aGen.Gen( _JUMP, 0 );
-                        bNewGblDefs = FALSE;
+                        bNewGblDefs = sal_False;
                     }
 
-                    USHORT nSavLine = nLine;
+                    sal_uInt16 nSavLine = nLine;
                     aGen.Statement();
                     pDef->Define();
                     pDef->SetLine1( nSavLine );
                     pDef->SetLine2( nSavLine );
 
                     SbiSymPool& rPool = pDef->GetParams();
-                    USHORT nParCount = rPool.GetSize();
+                    sal_uInt16 nParCount = rPool.GetSize();
 
                     SbxDataType eType = pDef->GetType();
                     if( bFunction )
-                        aGen.Gen( _PARAM, 0, sal::static_int_cast< UINT16 >( eType ) );
+                        aGen.Gen( _PARAM, 0, sal::static_int_cast< sal_uInt16 >( eType ) );
 
                     if( nParCount > 1 )
                     {
                         aGen.Gen( _ARGC );
 
-                        for( USHORT i = 1 ; i < nParCount ; ++i )
+                        for( sal_uInt16 i = 1 ; i < nParCount ; ++i )
                         {
                             SbiSymDef* pParDef = rPool.Get( i );
                             SbxDataType eParType = pParDef->GetType();
 
-                            aGen.Gen( _PARAM, i, sal::static_int_cast< UINT16 >( eParType ) );
+                            aGen.Gen( _PARAM, i, sal::static_int_cast< sal_uInt16 >( eParType ) );
                             aGen.Gen( _ARGV );
 
-                            USHORT nTyp = sal::static_int_cast< USHORT >( pParDef->GetType() );
+                            sal_uInt16 nTyp = sal::static_int_cast< sal_uInt16 >( pParDef->GetType() );
                             if( pParDef->IsByVal() )
                             {
                                 // Reset to avoid additional byval in call to wrapper function
-                                pParDef->SetByVal( FALSE );
+                                pParDef->SetByVal( sal_False );
                                 nTyp |= 0x8000;
                             }
                             aGen.Gen( _ARGTYP, nTyp );
@@ -1032,12 +1030,12 @@ void SbiParser::DefDeclare( BOOL bPrivate )
                     aGen.Gen( _LIB, aGblStrings.Add( pDef->GetLib() ) );
 
                     SbiOpcode eOp = pDef->IsCdecl() ? _CALLC : _CALL;
-                    USHORT nId = pDef->GetId();
+                    sal_uInt16 nId = pDef->GetId();
                     if( pDef->GetAlias().Len() )
                         nId = ( nId & 0x8000 ) | aGblStrings.Add( pDef->GetAlias() );
                     if( nParCount > 1 )
                         nId |= 0x8000;
-                    aGen.Gen( eOp, nId, sal::static_int_cast< UINT16 >( eType ) );
+                    aGen.Gen( eOp, nId, sal::static_int_cast< sal_uInt16 >( eType ) );
 
                     if( bFunction )
                         aGen.Gen( _PUT );
@@ -1066,7 +1064,7 @@ void SbiParser::Attribute()
     // Don't generate any code - just discard it.
 }
 
-// Aufruf einer SUB oder FUNCTION
+// Call of a SUB or a FUNCTION
 
 void SbiParser::Call()
 {
@@ -1079,18 +1077,18 @@ void SbiParser::Call()
 
 void SbiParser::SubFunc()
 {
-    DefProc( FALSE, FALSE );
+    DefProc( sal_False, sal_False );
 }
 
-// Einlesen einer Prozedur
+// Read in of a procedure
 
-BOOL runsInSetup( void );
+sal_Bool runsInSetup( void );
 
-void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
+void SbiParser::DefProc( sal_Bool bStatic, sal_Bool bPrivate )
 {
-    USHORT l1 = nLine, l2 = nLine;
-    BOOL bSub = BOOL( eCurTok == SUB );
-    BOOL bProperty = BOOL( eCurTok == PROPERTY );
+    sal_uInt16 l1 = nLine, l2 = nLine;
+    sal_Bool bSub = sal_Bool( eCurTok == SUB );
+    sal_Bool bProperty = sal_Bool( eCurTok == PROPERTY );
     PropertyMode ePropertyMode = PROPERTY_MODE_NONE;
     if( bProperty )
     {
@@ -1106,12 +1104,12 @@ void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
     }
 
     SbiToken eExit = eCurTok;
-    SbiProcDef* pDef = ProcDecl( FALSE );
+    SbiProcDef* pDef = ProcDecl( sal_False );
     if( !pDef )
         return;
     pDef->setPropertyMode( ePropertyMode );
 
-    // Ist die Proc bereits deklariert?
+    // Is the Proc already declared?
     SbiSymDef* pOld = aPublics.Find( pDef->GetName() );
     if( pOld )
     {
@@ -1120,7 +1118,7 @@ void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
         pProc = pOld->GetProcDef();
         if( !pProc )
         {
-            // Als Variable deklariert
+            // Declared as a variable
             Error( SbERR_BAD_DECLARATION, pDef->GetName() );
             delete pDef;
             pProc = NULL;
@@ -1153,22 +1151,22 @@ void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
         return;
     pProc->SetPublic( !bPrivate );
 
-    // Nun setzen wir die Suchhierarchie fuer Symbole sowie die aktuelle
-    // Prozedur.
+    // Now we set the search hierarchy for symbols as well as the
+    // current procedure.
     aPublics.SetProcId( pProc->GetId() );
     pProc->GetParams().SetParent( &aPublics );
     if( bStatic )
         {
         if ( bVBASupportOn )
-            pProc->SetStatic( TRUE );
+            pProc->SetStatic( sal_True );
         else
             Error( SbERR_NOT_IMPLEMENTED ); // STATIC SUB ...
         }
      else
     {
-        pProc->SetStatic( FALSE );
+        pProc->SetStatic( sal_False );
         }
-    // Normalfall: Lokale Variable->Parameter->Globale Variable
+    // Normal case: Local variable->parameter->global variable
     pProc->GetLocals().SetParent( &pProc->GetParams() );
     pPool = &pProc->GetLocals();
 
@@ -1180,7 +1178,7 @@ void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
     pProc->SetLine2( l2 );
     pPool = &aPublics;
     aPublics.SetProcId( 0 );
-    // Offene Labels?
+    // Open labels?
     pProc->GetLabels().CheckRefs();
     CloseBlock();
     aGen.Gen( _LEAVE );
@@ -1191,10 +1189,10 @@ void SbiParser::DefProc( BOOL bStatic, BOOL bPrivate )
 
 void SbiParser::Static()
 {
-    DefStatic( FALSE );
+    DefStatic( sal_False );
 }
 
-void SbiParser::DefStatic( BOOL bPrivate )
+void SbiParser::DefStatic( sal_Bool bPrivate )
 {
     switch( Peek() )
     {
@@ -1206,18 +1204,18 @@ void SbiParser::DefStatic( BOOL bPrivate )
             if( bNewGblDefs && nGblChain == 0 )
             {
                 nGblChain = aGen.Gen( _JUMP, 0 );
-                bNewGblDefs = FALSE;
+                bNewGblDefs = sal_False;
             }
             Next();
-            DefProc( TRUE, bPrivate );
+            DefProc( sal_True, bPrivate );
             break;
         default: {
             if( !pProc )
                 Error( SbERR_NOT_IN_SUBR );
-            // Pool umsetzen, damit STATIC-Deklarationen im globalen
-            // Pool landen
+            // Reset the Pool, so that STATIC-Declarations go into the
+            // global Pool
             SbiSymPool* p = pPool; pPool = &aPublics;
-            DefVar( _STATIC, TRUE );
+            DefVar( _STATIC, sal_True );
             pPool = p;
             } break;
     }
