@@ -40,9 +40,6 @@
 
 #include "runtime.hxx"
 
-#ifdef _USE_UNO
-
-// <-- encoding
 #include <sal/alloca.h>
 
 #include <ctype.h>
@@ -51,7 +48,7 @@
 #include <rtl/ustrbuf.hxx>
 #include <rtl/textenc.h>
 #include <rtl/ustrbuf.hxx>
-// encoding -->
+
 #include <comphelper/processfactory.hxx>
 
 #include <com/sun/star/uno/Sequence.hxx>
@@ -73,8 +70,6 @@ using namespace com::sun::star::ucb;
 using namespace com::sun::star::io;
 using namespace com::sun::star::bridge;
 
-#endif /* _USE_UNO */
-
 #include "iosys.hxx"
 #include "sbintern.hxx"
 
@@ -139,7 +134,6 @@ IMPL_LINK_INLINE_START( SbiInputDialog, Cancel, Window *, pWindow )
 }
 IMPL_LINK_INLINE_END( SbiInputDialog, Cancel, Window *, pWindow )
 
-//////////////////////////////////////////////////////////////////////////
 
 SbiStream::SbiStream()
     : pStrm( 0 )
@@ -177,8 +171,6 @@ void SbiStream::MapError()
     }
 }
 
-#ifdef _USE_UNO
-
 // TODO: Code is copied from daemons2/source/uno/asciiEncoder.cxx
 
 ::rtl::OUString findUserInDescription( const ::rtl::OUString& aDescription )
@@ -211,17 +203,15 @@ void SbiStream::MapError()
     return user;
 }
 
-#endif
 
 
 // Hack for #83750
-BOOL runsInSetup( void );
+sal_Bool runsInSetup( void );
 
-BOOL needSecurityRestrictions( void )
+sal_Bool needSecurityRestrictions( void )
 {
-#ifdef _USE_UNO
-    static BOOL bNeedInit = TRUE;
-    static BOOL bRetVal = TRUE;
+    static sal_Bool bNeedInit = sal_True;
+    static sal_Bool bRetVal = sal_True;
 
     if( bNeedInit )
     {
@@ -230,11 +220,11 @@ BOOL needSecurityRestrictions( void )
         if( runsInSetup() )
         {
             // Setup is not critical
-            bRetVal = FALSE;
+            bRetVal = sal_False;
             return bRetVal;
         }
 
-        bNeedInit = FALSE;
+        bNeedInit = sal_False;
 
         // Get system user to compare to portal user
         oslSecurity aSecurity = osl_getCurrentSecurity();
@@ -243,14 +233,14 @@ BOOL needSecurityRestrictions( void )
         if( !bRet )
         {
             // No valid security! -> Secure mode!
-            return TRUE;
+            return sal_True;
         }
 
         Reference< XMultiServiceFactory > xSMgr = getProcessServiceFactory();
         if( !xSMgr.is() )
-            return TRUE;
+            return sal_True;
         Reference< XBridgeFactory > xBridgeFac( xSMgr->createInstance
-            ( ::rtl::OUString::createFromAscii( "com.sun.star.bridge.BridgeFactory" ) ), UNO_QUERY );
+            ( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.bridge.BridgeFactory" )) ), UNO_QUERY );
 
         Sequence< Reference< XBridge > > aBridgeSeq;
         sal_Int32 nBridgeCount = 0;
@@ -263,13 +253,13 @@ BOOL needSecurityRestrictions( void )
         if( nBridgeCount == 0 )
         {
             // No bridges -> local
-            bRetVal = FALSE;
+            bRetVal = sal_False;
             return bRetVal;
         }
 
         // Iterate through all bridges to find (portal) user property
         const Reference< XBridge >* pBridges = aBridgeSeq.getConstArray();
-        bRetVal = FALSE;	// Now only TRUE if user different from portal user is found
+        bRetVal = sal_False;	// Now only sal_True if user different from portal user is found
         sal_Int32 i;
         for( i = 0 ; i < nBridgeCount ; i++ )
         {
@@ -287,7 +277,7 @@ BOOL needSecurityRestrictions( void )
                 else
                 {
                     // Different user -> Secure mode!
-                    bRetVal = TRUE;
+                    bRetVal = sal_True;
                     break;
                 }
             }
@@ -296,51 +286,42 @@ BOOL needSecurityRestrictions( void )
     }
 
     return bRetVal;
-#else
-    return FALSE;
-#endif
 }
 
-// Returns TRUE if UNO is available, otherwise the old file
+// Returns sal_True if UNO is available, otherwise the old file
 // system implementation has to be used
 // #89378 New semantic: Don't just ask for UNO but for UCB
-BOOL hasUno( void )
+sal_Bool hasUno( void )
 {
-#ifdef _USE_UNO
-    static BOOL bNeedInit = TRUE;
-    static BOOL bRetVal = TRUE;
+    static sal_Bool bNeedInit = sal_True;
+    static sal_Bool bRetVal = sal_True;
 
     if( bNeedInit )
     {
-        bNeedInit = FALSE;
+        bNeedInit = sal_False;
         Reference< XMultiServiceFactory > xSMgr = getProcessServiceFactory();
         if( !xSMgr.is() )
         {
             // No service manager at all
-            bRetVal = FALSE;
+            bRetVal = sal_False;
         }
         else
         {
-            Reference< XContentProviderManager > xManager( xSMgr->createInstance( ::rtl::OUString::createFromAscii
-                    ( "com.sun.star.ucb.UniversalContentBroker" ) ), UNO_QUERY );
+            Reference< XContentProviderManager > xManager( xSMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM
+                    ( "com.sun.star.ucb.UniversalContentBroker" )) ), UNO_QUERY );
 
-            if ( !( xManager.is() && xManager->queryContentProvider( ::rtl::OUString::createFromAscii( "file:///" ) ).is() ) )
+            if ( !( xManager.is() && xManager->queryContentProvider( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "file:///" )) ).is() ) )
             {
                 // No UCB
-                bRetVal = FALSE;
+                bRetVal = sal_False;
             }
         }
     }
     return bRetVal;
-#else
-    return FALSE;
-#endif
 }
 
 
 
-#ifndef _OLD_FILE_IMPL
-
 class OslStream : public SvStream
 {
     osl::File maFile;
@@ -349,11 +330,11 @@ class OslStream : public SvStream
 public:
                     OslStream( const String& rName, short nStrmMode );
                     ~OslStream();
-    virtual ULONG	GetData( void* pData, ULONG nSize );
-    virtual ULONG	PutData( const void* pData, ULONG nSize );
-    virtual ULONG	SeekPos( ULONG nPos );
+    virtual sal_uIntPtr	GetData( void* pData, sal_uIntPtr nSize );
+    virtual sal_uIntPtr	PutData( const void* pData, sal_uIntPtr nSize );
+    virtual sal_uIntPtr	SeekPos( sal_uIntPtr nPos );
     virtual void	FlushData();
-    virtual void	SetSize( ULONG nSize );
+    virtual void	SetSize( sal_uIntPtr nSize );
 };
 
 OslStream::OslStream( const String& rName, short nStrmMode )
@@ -364,21 +345,21 @@ OslStream::OslStream( const String& rName, short nStrmMode )
 
     if( (nStrmMode & (STREAM_READ | STREAM_WRITE)) == (STREAM_READ | STREAM_WRITE) )
     {
-        nFlags = OpenFlag_Read | OpenFlag_Write;
+        nFlags = osl_File_OpenFlag_Read | osl_File_OpenFlag_Write;
     }
     else if( nStrmMode & STREAM_WRITE )
     {
-        nFlags = OpenFlag_Write;
+        nFlags = osl_File_OpenFlag_Write;
     }
     else //if( nStrmMode & STREAM_READ )
     {
-        nFlags = OpenFlag_Read;
+        nFlags = osl_File_OpenFlag_Read;
     }
 
     osl::FileBase::RC nRet = maFile.open( nFlags );
-    if( nRet == osl::FileBase::E_NOENT && nFlags != OpenFlag_Read )
+    if( nRet == osl::FileBase::E_NOENT && nFlags != osl_File_OpenFlag_Read )
     {
-        nFlags |= OpenFlag_Create;
+        nFlags |= osl_File_OpenFlag_Create;
         nRet = maFile.open( nFlags );
     }
 
@@ -394,53 +375,42 @@ OslStream::~OslStream()
     maFile.close();
 }
 
-ULONG OslStream::GetData( void* pData, ULONG nSize )
+sal_uIntPtr OslStream::GetData( void* pData, sal_uIntPtr nSize )
 {
     sal_uInt64 nBytesRead = nSize;
-    osl::FileBase::RC nRet = osl::FileBase::E_None;
-    nRet = maFile.read( pData, nBytesRead, nBytesRead );
-    return (ULONG)nBytesRead;
+    maFile.read( pData, nBytesRead, nBytesRead );
+    return (sal_uIntPtr)nBytesRead;
 }
 
-ULONG OslStream::PutData( const void* pData, ULONG nSize )
+sal_uIntPtr OslStream::PutData( const void* pData, sal_uIntPtr nSize )
 {
     sal_uInt64 nBytesWritten;
-    osl::FileBase::RC nRet = osl::FileBase::E_None;
-    nRet = maFile.write( pData, (sal_uInt64)nSize, nBytesWritten );
-    return (ULONG)nBytesWritten;
+    maFile.write( pData, (sal_uInt64)nSize, nBytesWritten );
+    return (sal_uIntPtr)nBytesWritten;
 }
 
-ULONG OslStream::SeekPos( ULONG nPos )
+sal_uIntPtr OslStream::SeekPos( sal_uIntPtr nPos )
 {
-    osl::FileBase::RC nRet;
     if( nPos == STREAM_SEEK_TO_END )
-    {
-        nRet = maFile.setPos( Pos_End, 0 );
-    }
+        maFile.setPos( Pos_End, 0 );
     else
-    {
-        nRet = maFile.setPos( Pos_Absolut, (sal_uInt64)nPos );
-    }
-    sal_uInt64 nRealPos;
-    nRet = maFile.getPos( nRealPos );
-    return sal::static_int_cast<ULONG>(nRealPos);
+        maFile.setPos( Pos_Absolut, (sal_uInt64)nPos );
+    sal_uInt64 nRealPos(0);
+    maFile.getPos( nRealPos );
+    return sal::static_int_cast<sal_uIntPtr>(nRealPos);
 }
 
 void OslStream::FlushData()
 {
 }
 
-void OslStream::SetSize( ULONG nSize )
+void OslStream::SetSize( sal_uIntPtr nSize )
 {
-    osl::FileBase::RC nRet = osl::FileBase::E_None;
-    nRet = maFile.setSize( (sal_uInt64)nSize );
+    maFile.setSize( (sal_uInt64)nSize );
 }
 
-#endif
 
 
-#ifdef _USE_UNO
-
 class UCBStream : public SvStream
 {
     Reference< XInputStream >	xIS;
@@ -452,47 +422,13 @@ public:
                     UCBStream( Reference< XOutputStream > & xOS );
                     UCBStream( Reference< XStream > & xS );
                     ~UCBStream();
-    virtual ULONG	GetData( void* pData, ULONG nSize );
-    virtual ULONG	PutData( const void* pData, ULONG nSize );
-    virtual ULONG	SeekPos( ULONG nPos );
+    virtual sal_uIntPtr	GetData( void* pData, sal_uIntPtr nSize );
+    virtual sal_uIntPtr	PutData( const void* pData, sal_uIntPtr nSize );
+    virtual sal_uIntPtr	SeekPos( sal_uIntPtr nPos );
     virtual void	FlushData();
-    virtual void	SetSize( ULONG nSize );
+    virtual void	SetSize( sal_uIntPtr nSize );
 };
 
-/*
-ULONG UCBErrorToSvStramError( ucb::IOErrorCode nError )
-{
-    ULONG eReturn = ERRCODE_IO_GENERAL;
-    switch( nError )
-    {
-        case ucb::IOErrorCode_ABORT:				eReturn = SVSTREAM_GENERALERROR; break;
-        case ucb::IOErrorCode_NOT_EXISTING:			eReturn = SVSTREAM_FILE_NOT_FOUND; break;
-        case ucb::IOErrorCode_NOT_EXISTING_PATH:	eReturn = SVSTREAM_PATH_NOT_FOUND; break;
-        case ucb::IOErrorCode_OUT_OF_FILE_HANDLES:	eReturn = SVSTREAM_TOO_MANY_OPEN_FILES; break;
-        case ucb::IOErrorCode_ACCESS_DENIED:		eReturn = SVSTREAM_ACCESS_DENIED; break;
-        case ucb::IOErrorCode_LOCKING_VIOLATION:	eReturn = SVSTREAM_SHARING_VIOLATION; break;
-
-        case ucb::IOErrorCode_INVALID_ACCESS:		eReturn = SVSTREAM_INVALID_ACCESS; break;
-        case ucb::IOErrorCode_CANT_CREATE:			eReturn = SVSTREAM_CANNOT_MAKE; break;
-        case ucb::IOErrorCode_INVALID_PARAMETER:	eReturn = SVSTREAM_INVALID_PARAMETER; break;
-
-        case ucb::IOErrorCode_CANT_READ:			eReturn = SVSTREAM_READ_ERROR; break;
-        case ucb::IOErrorCode_CANT_WRITE:			eReturn = SVSTREAM_WRITE_ERROR; break;
-        case ucb::IOErrorCode_CANT_SEEK:			eReturn = SVSTREAM_SEEK_ERROR; break;
-        case ucb::IOErrorCode_CANT_TELL:			eReturn = SVSTREAM_TELL_ERROR; break;
-
-        case ucb::IOErrorCode_OUT_OF_MEMORY:		eReturn = SVSTREAM_OUTOFMEMORY; break;
-
-        case SVSTREAM_FILEFORMAT_ERROR:				eReturn = SVSTREAM_FILEFORMAT_ERROR; break;
-        case ucb::IOErrorCode_WRONG_VERSION:		eReturn = SVSTREAM_WRONGVERSION;
-        case ucb::IOErrorCode_OUT_OF_DISK_SPACE:	eReturn = SVSTREAM_DISK_FULL; break;
-
-        case ucb::IOErrorCode_BAD_CRC:				eReturn = ERRCODE_IO_BADCRC; break;
-    }
-    return eReturn;
-}
-*/
-
 UCBStream::UCBStream( Reference< XInputStream > & rStm )
     : xIS( rStm )
     , xSeek( rStm, UNO_QUERY )
@@ -533,7 +469,7 @@ UCBStream::~UCBStream()
     }
 }
 
-ULONG	UCBStream::GetData( void* pData, ULONG nSize )
+sal_uIntPtr	UCBStream::GetData( void* pData, sal_uIntPtr nSize )
 {
     try
     {
@@ -562,7 +498,7 @@ ULONG	UCBStream::GetData( void* pData, ULONG nSize )
     return 0;
 }
 
-ULONG	UCBStream::PutData( const void* pData, ULONG nSize )
+sal_uIntPtr	UCBStream::PutData( const void* pData, sal_uIntPtr nSize )
 {
     try
     {
@@ -589,13 +525,13 @@ ULONG	UCBStream::PutData( const void* pData, ULONG nSize )
     return 0;
 }
 
-ULONG	UCBStream::SeekPos( ULONG nPos )
+sal_uIntPtr	UCBStream::SeekPos( sal_uIntPtr nPos )
 {
     try
     {
         if( xSeek.is() )
         {
-            ULONG nLen = sal::static_int_cast<ULONG>( xSeek->getLength() );
+            sal_uIntPtr nLen = sal::static_int_cast<sal_uIntPtr>( xSeek->getLength() );
             if( nPos > nLen )
                 nPos = nLen;
             xSeek->seek( nPos );
@@ -629,16 +565,14 @@ void	UCBStream::FlushData()
     }
 }
 
-void	UCBStream::SetSize( ULONG nSize )
+void	UCBStream::SetSize( sal_uIntPtr nSize )
 {
     (void)nSize;
 
-    DBG_ERROR( "not allowed to call from basic" );
+    OSL_FAIL( "not allowed to call from basic" );
     SetError( ERRCODE_IO_GENERAL );
 }
 
-#endif
-
 // Oeffnen eines Streams
 SbError SbiStream::Open
 ( short nCh, const ByteString& rName, short nStrmMode, short nFlags, short nL )
@@ -653,14 +587,13 @@ SbError SbiStream::Open
     String aStr( rName, gsl_getSystemTextEncoding() );
     String aNameStr = getFullPath( aStr );
 
-#ifdef _USE_UNO
     if( hasUno() )
     {
         Reference< XMultiServiceFactory > xSMgr = getProcessServiceFactory();
         if( xSMgr.is() )
         {
             Reference< XSimpleFileAccess >
-                xSFI( xSMgr->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.ucb.SimpleFileAccess" ) ), UNO_QUERY );
+                xSFI( xSMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.ucb.SimpleFileAccess" )) ), UNO_QUERY );
             if( xSFI.is() )
             {
                 try
@@ -682,9 +615,6 @@ SbError SbiStream::Open
                 {
                     Reference< XStream > xIS = xSFI->openFileReadWrite( aNameStr );
                     pStrm = new UCBStream( xIS );
-                    // Open for writing is not implemented in ucb yet!!!
-                    //Reference< XOutputStream > xIS = xSFI->openFileWrite( aNameStr );
-                    //pStrm = new UCBStream( xIS );
                 }
                 else //if( nStrmMode & STREAM_READ )
                 {
@@ -701,14 +631,9 @@ SbError SbiStream::Open
         }
     }
 
-#endif
     if( !pStrm )
     {
-#ifdef _OLD_FILE_IMPL
-        pStrm = new SvFileStream( aNameStr, nStrmMode );
-#else
         pStrm = new OslStream( aNameStr, nStrmMode );
-#endif
     }
     if( IsAppend() )
         pStrm->Seek( STREAM_SEEK_TO_END );
@@ -722,12 +647,6 @@ SbError SbiStream::Close()
 {
     if(	pStrm )
     {
-        if( !hasUno() )
-        {
-#ifdef _OLD_FILE_IMPL
-            ((SvFileStream *)pStrm)->Close();
-#endif
-        }
         MapError();
         delete pStrm;
         pStrm = NULL;
@@ -736,7 +655,7 @@ SbError SbiStream::Close()
     return nError;
 }
 
-SbError SbiStream::Read( ByteString& rBuf, USHORT n, bool bForceReadingPerByte )
+SbError SbiStream::Read( ByteString& rBuf, sal_uInt16 n, bool bForceReadingPerByte )
 {
     nExpandOnWriteTo = 0;
     if( !bForceReadingPerByte && IsText() )
@@ -775,10 +694,10 @@ void SbiStream::ExpandFile()
 {
     if ( nExpandOnWriteTo )
     {
-        ULONG nCur = pStrm->Seek(STREAM_SEEK_TO_END);
+        sal_uIntPtr nCur = pStrm->Seek(STREAM_SEEK_TO_END);
         if( nCur < nExpandOnWriteTo )
         {
-            ULONG nDiff = nExpandOnWriteTo - nCur;
+            sal_uIntPtr nDiff = nExpandOnWriteTo - nCur;
             char c = 0;
             while( nDiff-- )
                 *pStrm << c;
@@ -791,7 +710,7 @@ void SbiStream::ExpandFile()
     }
 }
 
-SbError SbiStream::Write( const ByteString& rBuf, USHORT n )
+SbError SbiStream::Write( const ByteString& rBuf, sal_uInt16 n )
 {
     ExpandFile();
     if( IsAppend() )
@@ -802,7 +721,7 @@ SbError SbiStream::Write( const ByteString& rBuf, USHORT n )
         aLine += rBuf;
         // Raus damit, wenn das Ende ein LF ist, aber CRLF vorher
         // strippen, da der SvStrm ein CRLF anfuegt!
-        USHORT nLineLen = aLine.Len();
+        sal_uInt16 nLineLen = aLine.Len();
         if( nLineLen && aLine.GetBuffer()[ --nLineLen ] == 0x0A )
         {
             aLine.Erase( nLineLen );
@@ -823,7 +742,6 @@ SbError SbiStream::Write( const ByteString& rBuf, USHORT n )
     return nError;
 }
 
-//////////////////////////////////////////////////////////////////////////
 
 // Zugriff auf das aktuelle I/O-System:
 
@@ -833,7 +751,6 @@ SbiIoSystem* SbGetIoSystem()
     return pInst ? pInst->GetIoSystem() : NULL;
 }
 
-//////////////////////////////////////////////////////////////////////////
 
 SbiIoSystem::SbiIoSystem()
 {
@@ -1021,8 +938,8 @@ void SbiIoSystem::ReadCon( ByteString& rIn )
 void SbiIoSystem::WriteCon( const ByteString& rText )
 {
     aOut += rText;
-    USHORT n1 = aOut.Search( '\n' );
-    USHORT n2 = aOut.Search( '\r' );
+    sal_uInt16 n1 = aOut.Search( '\n' );
+    sal_uInt16 n2 = aOut.Search( '\r' );
     if( n1 != STRING_NOTFOUND || n2 != STRING_NOTFOUND )
     {
         if( n1 == STRING_NOTFOUND ) n1 = n2;
