@@ -102,8 +102,8 @@ const StringSequence& getColumnTypes()
 //------------------------------------------------------------------------------
 sal_Int32 getColumnTypeByModelName(const ::rtl::OUString& aModelName)
 {
-    const ::rtl::OUString aModelPrefix = ::rtl::OUString::createFromAscii("com.sun.star.form.component.");
-    const ::rtl::OUString aCompatibleModelPrefix = ::rtl::OUString::createFromAscii("stardiv.one.form.component.");
+    const ::rtl::OUString aModelPrefix( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.form.component." ));
+    const ::rtl::OUString aCompatibleModelPrefix( RTL_CONSTASCII_USTRINGPARAM( "stardiv.one.form.component." ));
 
     sal_Int32 nTypeId = -1;
     if (aModelName == FRM_COMPONENT_EDIT)
@@ -111,16 +111,17 @@ sal_Int32 getColumnTypeByModelName(const ::rtl::OUString& aModelName)
     else
     {
         sal_Int32 nPrefixPos = aModelName.indexOf(aModelPrefix);
-        sal_Int32 nCampatiblePrefixPos = aModelName.indexOf(aCompatibleModelPrefix);
-        DBG_ASSERT( (nPrefixPos != -1) ||   (nCampatiblePrefixPos != -1),
+        sal_Int32 nCompatiblePrefixPos = aModelName.indexOf(aCompatibleModelPrefix);
+        DBG_ASSERT( (nPrefixPos != -1) || (nCompatiblePrefixPos != -1),
                 "::getColumnTypeByModelName() : wrong servivce !");
+        (void)nCompatiblePrefixPos;
 
         ::rtl::OUString aColumnType = (nPrefixPos != -1)
             ? aModelName.copy(aModelPrefix.getLength())
             : aModelName.copy(aCompatibleModelPrefix.getLength());
 
         const StringSequence& rColumnTypes = getColumnTypes();
-        nTypeId = ::binfilter::internal::findPos(aColumnType, rColumnTypes);//STRIP008         nTypeId = ::internal::findPos(aColumnType, rColumnTypes);
+        nTypeId = ::binfilter::internal::findPos(aColumnType, rColumnTypes);
     }
     return nTypeId;
 }
@@ -206,8 +207,8 @@ DBG_NAME(OGridColumn)
 OGridColumn::OGridColumn(const Reference<XMultiServiceFactory>& _rxFactory, const ::rtl::OUString& _sModelName)
     :OGridColumn_BASE(m_aMutex)
     ,OPropertySetAggregationHelper(OGridColumn_BASE::rBHelper)
-    ,m_aModelName(_sModelName)
     ,m_aHidden( makeAny( sal_False ) )
+    ,m_aModelName(_sModelName)
 {
     DBG_CTOR(OGridColumn,NULL);
 
@@ -353,14 +354,14 @@ void OGridColumn::setOwnProperties(Sequence<Property>& aDescriptor)
 //------------------------------------------------------------------------------
 Reference<XPropertySetInfo> SAL_CALL OGridColumn::getPropertySetInfo() throw(RuntimeException)
 {
-    DBG_ERROR("OGridColumn::getPropertySetInfo() : Dummy Called");
+    OSL_FAIL("OGridColumn::getPropertySetInfo() : Dummy Called");
     return Reference<XPropertySetInfo> ();
 }
 
 //------------------------------------------------------------------------------
 ::cppu::IPropertyArrayHelper& OGridColumn::getInfoHelper()
 {
-    DBG_ERROR("OGridColumn::getInfoHelper() : Dummy Called");
+    OSL_FAIL("OGridColumn::getInfoHelper() : Dummy Called");
 
     Sequence<Property> aDescriptor, aAggProperties;
     static OPropertyArrayAggregationHelper aDescAry(aDescriptor, aAggProperties);
@@ -412,7 +413,7 @@ sal_Bool OGridColumn::convertFastPropertyValue( Any& rConvertedValue, Any& rOldV
             }
             catch(starlang::IllegalArgumentException&)
             {
-                OSL_ENSURE(0,"OGridColumn::convertFastPropertyValue: TextAlign must be casted to sal_Int16!");
+                OSL_FAIL("OGridColumn::convertFastPropertyValue: TextAlign must be casted to sal_Int16!");
                 throw;
             }
             break;
@@ -577,7 +578,7 @@ void SAL_CALL OGridColumn::read(const Reference<XObjectInputStream>& _rxInStream
     }
 
     // 2. Lesen des Versionsnummer
-    sal_uInt16 nVersion = _rxInStream->readShort();
+    /*sal_uInt16 nVersion =*/ _rxInStream->readShort();
     sal_uInt16 nAnyMask = _rxInStream->readShort();
 
     if (nAnyMask & WIDTH)
