@@ -131,7 +131,7 @@ OEditControl::OEditControl(const Reference<XMultiServiceFactory>& _rxFactory)
         }
     }
     // Refcount wieder bei 2 fuer beide Listener
-    sal_Int32 n = decrement(m_refCount);
+    /*sal_Int32 n =*/ decrement(m_refCount);
 }
 
 //------------------------------------------------------------------------------
@@ -193,7 +193,7 @@ void OEditControl::disposing(const EventObject& Source) throw( RuntimeException
 
 // XFocusListener
 //------------------------------------------------------------------------------
-void OEditControl::focusGained( const FocusEvent& e ) throw ( ::com::sun::star::uno::RuntimeException)
+void OEditControl::focusGained( const FocusEvent& /*e*/ ) throw ( ::com::sun::star::uno::RuntimeException)
 {
     Reference<XPropertySet>  xSet(getModel(), UNO_QUERY);
     if (xSet.is())
@@ -201,7 +201,7 @@ void OEditControl::focusGained( const FocusEvent& e ) throw ( ::com::sun::star::
 }
 
 //------------------------------------------------------------------------------
-void OEditControl::focusLost( const FocusEvent& e ) throw ( ::com::sun::star::uno::RuntimeException)
+void OEditControl::focusLost( const FocusEvent& /*e*/ ) throw ( ::com::sun::star::uno::RuntimeException)
 {
     Reference<XPropertySet>  xSet(getModel(), UNO_QUERY);
     if (xSet.is())
@@ -276,7 +276,7 @@ void OEditControl::keyPressed(const ::com::sun::star::awt::KeyEvent& e) throw (
 }
 
 //------------------------------------------------------------------------------
-void OEditControl::keyReleased(const ::com::sun::star::awt::KeyEvent& e) throw ( ::com::sun::star::uno::RuntimeException)
+void OEditControl::keyReleased(const ::com::sun::star::awt::KeyEvent& /*e*/) throw ( ::com::sun::star::uno::RuntimeException)
 {
 }
 
@@ -314,11 +314,11 @@ DBG_NAME(OEditModel)
 OEditModel::OEditModel(const Reference<XMultiServiceFactory>& _rxFactory)
              :OEditBaseModel( _rxFactory, VCL_CONTROLMODEL_EDIT, FRM_CONTROL_EDIT )
                                     // use the old control name for compytibility reasons
-    ,m_bMaxTextLenModified(sal_False)
-    ,m_nKeyType(NumberFormat::UNDEFINED)
-    ,m_aNullDate(DBTypeConversion::getStandardDate())
     ,m_nFormatKey(0)
+    ,m_aNullDate(DBTypeConversion::getStandardDate())
     ,m_nFieldType(DataType::OTHER)
+    ,m_nKeyType(NumberFormat::UNDEFINED)
+    ,m_bMaxTextLenModified(sal_False)
     ,m_bWritingFormattedFake(sal_False)
     ,m_bNumericField(sal_False)
 {
@@ -333,11 +333,11 @@ OEditModel::OEditModel(const Reference<XMultiServiceFactory>& _rxFactory)
 //------------------------------------------------------------------
 OEditModel::OEditModel( const OEditModel* _pOriginal, const Reference<XMultiServiceFactory>& _rxFactory )
         :OEditBaseModel( _pOriginal, _rxFactory )
-    ,m_bMaxTextLenModified(sal_False)
-    ,m_nKeyType(NumberFormat::UNDEFINED)
-    ,m_aNullDate(DBTypeConversion::getStandardDate())
     ,m_nFormatKey(0)
+    ,m_aNullDate(DBTypeConversion::getStandardDate())
     ,m_nFieldType(DataType::OTHER)
+    ,m_nKeyType(NumberFormat::UNDEFINED)
+    ,m_bMaxTextLenModified(sal_False)
     ,m_bWritingFormattedFake(sal_False)
     ,m_bNumericField(sal_False)
 {
@@ -455,7 +455,6 @@ void OEditModel::write(const Reference<XObjectOutputStream>& _rxOutStream) throw
     {	// -> fuer die Dauer des Speicherns meinem aggregierten Model die alte TextLen einreden
 
         // before doing this we have to save the current text value of the aggregate, as this may be affected by resetting the text len
-        // FS - 08.12.99 - 70606
         aCurrentText = m_xAggregateSet->getPropertyValue(PROPERTY_TEXT);
 
         m_xAggregateSet->getPropertyValue(PROPERTY_MAXTEXTLEN) >>= nOldTextLen;
@@ -509,170 +508,6 @@ sal_Int16 OEditModel::getPersistenceFlags() const
     return nFlags;
 }
 
-// XLoadListener
-//------------------------------------------------------------------------------
-void OEditModel::_loaded(const EventObject& rEvent)
-{
-    m_bNumericField = sal_False;
-    Reference<XPropertySet> xField = getField();
-    if (xField.is())
-    {
-        // jetzt den Key und typ ermitteln
-        m_nFieldType  = getINT32(xField->getPropertyValue(PROPERTY_FIELDTYPE));
-        m_nFormatKey = getINT32(xField->getPropertyValue(PROPERTY_FORMATKEY));
-
-        switch (m_nFieldType)
-        {
-            case ::com::sun::star::sdbc::DataType::DATE:
-            case ::com::sun::star::sdbc::DataType::TIME:
-            case ::com::sun::star::sdbc::DataType::TIMESTAMP:
-            case ::com::sun::star::sdbc::DataType::BIT:
-            case ::com::sun::star::sdbc::DataType::TINYINT:
-            case ::com::sun::star::sdbc::DataType::SMALLINT:
-            case ::com::sun::star::sdbc::DataType::INTEGER:
-            case ::com::sun::star::sdbc::DataType::REAL:
-            case ::com::sun::star::sdbc::DataType::BIGINT:
-            case ::com::sun::star::sdbc::DataType::DOUBLE:
-            case ::com::sun::star::sdbc::DataType::NUMERIC:
-            case ::com::sun::star::sdbc::DataType::DECIMAL:
-                m_bNumericField = sal_True;
-                break;
-            default:
-                m_bNumericField = sal_False;
-                break;
-        }
-
-        // XNumberFormatter besorgen
-        Reference<XRowSet>  xRowSet(rEvent.Source, UNO_QUERY);
-        DBG_ASSERT(xRowSet.is(), "OEditModel::_loaded : source is not a row set ?");
-        Reference<XNumberFormatsSupplier>  xSupplier = getNumberFormats(getConnection(xRowSet), sal_False, m_xServiceFactory);
-        if (xSupplier.is())
-        {
-            m_xFormatter =	Reference<XNumberFormatter>(m_xServiceFactory
-                                ->createInstance(FRM_NUMBER_FORMATTER), UNO_QUERY);
-            if (m_xFormatter.is())
-                m_xFormatter->attachNumberFormatsSupplier(xSupplier);
-
-            m_nKeyType  = getNumberFormatType(xSupplier->getNumberFormats(), m_nFormatKey);
-            xSupplier->getNumberFormatSettings()->getPropertyValue(::rtl::OUString::createFromAscii("NullDate"))
-                >>= m_aNullDate;
-        }
-
-        if (m_nKeyType != NumberFormat::SCIENTIFIC)
-        {
-            m_bMaxTextLenModified =	getINT16(m_xAggregateSet->getPropertyValue(PROPERTY_MAXTEXTLEN)) != 0;
-            if ( !m_bMaxTextLenModified )
-            {
-                sal_Int32 nFieldLen;
-                xField->getPropertyValue(::rtl::OUString::createFromAscii("Precision")) >>= nFieldLen;
-
-                if (nFieldLen && nFieldLen <= USHRT_MAX)
-                {
-                    Any aVal;
-                    aVal <<= (sal_Int16)nFieldLen;
-                    m_xAggregateSet->setPropertyValue(PROPERTY_MAXTEXTLEN, aVal);
-
-                    m_bMaxTextLenModified = sal_True;
-                }
-            }
-            else
-                m_bMaxTextLenModified = sal_False; // to get sure that the text len won't be set in unloaded
-        }
-    }
-}
-
-//------------------------------------------------------------------------------
-void OEditModel::_unloaded()
-{
-    OEditBaseModel::_unloaded();
-    if (getField().is())
-    {
-        if ( m_bMaxTextLenModified )
-        {
-            Any aVal;
-            aVal <<= (sal_Int16)0;	// nur wenn es 0 war, habe ich es in _loaded umgesetzt
-            m_xAggregateSet->setPropertyValue(PROPERTY_MAXTEXTLEN, aVal);
-            m_bMaxTextLenModified = sal_False;
-        }
-
-        m_xFormatter = 0;
-        m_nFieldType = DataType::OTHER;
-        m_nFormatKey = 0;
-        m_nKeyType	 = NumberFormat::UNDEFINED;
-        m_aNullDate	 = DBTypeConversion::getStandardDate();
-    }
-}
-
-//------------------------------------------------------------------------------
-sal_Bool OEditModel::_commit()
-{
-    ::rtl::OUString sNewValue;
-    m_xAggregateFastSet->getFastPropertyValue(OEditModel::nTextHandle) >>= sNewValue;
-    if (sNewValue != m_aSaveValue)
-    {
-        if (!sNewValue.getLength() && !m_bRequired && m_bEmptyIsNull)
-            m_xColumnUpdate->updateNull();
-        else
-        {
-            try
-            {
-                if ( m_bNumericField )
-                    DBTypeConversion::setValue(m_xColumnUpdate, m_xFormatter, m_aNullDate, sNewValue, m_nFormatKey, m_nFieldType, m_nKeyType);
-                else
-                    m_xColumnUpdate->updateString(sNewValue);
-            }
-            catch(Exception&)
-            {
-                return sal_False;
-            }
-        }
-        m_aSaveValue = sNewValue;
-    }
-    return sal_True;
-}
-
-// XPropertyChangeListener
-//------------------------------------------------------------------------------
-void OEditModel::_onValueChanged()
-{
-
-    // release our mutex once (it's acquired in the calling method !), as setting aggregate properties
-    // may cause any uno controls belonging to us to lock the solar mutex, which is potentially dangerous with
-    // our own mutex locked
-    // and in this special case do it before calling DBTypeConversion::getValue, as this uses the number formatter
-    // which's implementation locks the SM, too :(
-    // FS - 72451 - 31.01.00
-    MutexRelease aRelease(m_aMutex);
-    m_aSaveValue = DBTypeConversion::getValue(m_xColumn,
-                                              m_xFormatter,
-                                              m_aNullDate,
-                                              m_nFormatKey,
-                                              m_nKeyType);
-
-    // #i2817# OJ
-    sal_uInt16 nMaxTextLen = getINT16(m_xAggregateSet->getPropertyValue(PROPERTY_MAXTEXTLEN));
-    if ( nMaxTextLen && m_aSaveValue.getLength() > nMaxTextLen )
-    {
-        sal_Int32 nDiff = m_aSaveValue.getLength() - nMaxTextLen;
-        m_aSaveValue = m_aSaveValue.replaceAt(nMaxTextLen,nDiff,::rtl::OUString());
-    }
-
-    m_xAggregateFastSet->setFastPropertyValue(OEditModel::nTextHandle, makeAny(m_aSaveValue));
-}
-
-// XReset
-//------------------------------------------------------------------------------
-void OEditModel::_reset()
-{
-    {	// release our mutex once (it's acquired in the calling method !), as setting aggregate properties
-        // may cause any uno controls belonging to us to lock the solar mutex, which is potentially dangerous with
-        // our own mutex locked
-        // FS - 72451 - 31.01.00
-        MutexRelease aRelease(m_aMutex);
-        m_xAggregateFastSet->setFastPropertyValue(OEditModel::nTextHandle, makeAny(m_aDefaultText));
-    }
-}
-
 //.........................................................................
 }
 //.........................................................................
