@@ -26,10 +26,10 @@
  *
  ************************************************************************/
 
+#include <bf_svtools/bf_solar.h>
+
 #include "FormComponent.hxx"
 
-
-
 #include <com/sun/star/awt/XTextComponent.hpp>
 #include <com/sun/star/awt/XWindow.hpp>
 #include <com/sun/star/io/XMarkableStream.hpp>
@@ -100,7 +100,7 @@ OControl::OControl(const Reference<com::sun::star::lang::XMultiServiceFactory>&
     }
 
     // Refcount wieder bei NULL
-    sal_Int32 n = decrement(m_refCount);
+    /*sal_Int32 n =*/ decrement(m_refCount);
 }
 
 //------------------------------------------------------------------------------
@@ -417,7 +417,7 @@ void OControlModel::readHelpTextCompatibly(const staruno::Reference< stario::XOb
     }
     catch(const Exception&)
     {
-        OSL_ENSURE(sal_False, "OControlModel::readHelpTextCompatibly: could not forward the property value to the aggregate!");
+        OSL_FAIL("OControlModel::readHelpTextCompatibly: could not forward the property value to the aggregate!");
     }
 }
 
@@ -432,7 +432,7 @@ void OControlModel::writeHelpTextCompatibly(const staruno::Reference< stario::XO
     }
     catch(const Exception&)
     {
-        OSL_ENSURE(sal_False, "OControlModel::writeHelpTextCompatibly: could not retrieve the property value from the aggregate!");
+        OSL_FAIL("OControlModel::writeHelpTextCompatibly: could not retrieve the property value from the aggregate!");
     }
     ::comphelper::operator<<( _rxOutStream, sHelpText);
 }
@@ -444,9 +444,9 @@ OControlModel::OControlModel(
             const ::rtl::OUString& rDefault, const sal_Bool _bSetDelegator)
     :OComponentHelper(m_aMutex)
     ,OPropertySetAggregationHelper(OComponentHelper::rBHelper)
+    ,m_xServiceFactory(_rxFactory)
     ,m_nTabIndex(FRM_DEFAULT_TABINDEX)
     ,m_nClassId(FormComponentType::CONTROL)
-    ,m_xServiceFactory(_rxFactory)
 {
     DBG_CTOR(OControlModel, NULL);
     if (_rUnoControlModelTypeName.getLength())	// the is a model we have to aggregate
@@ -473,9 +473,9 @@ OControlModel::OControlModel(
 OControlModel::OControlModel( const OControlModel* _pOriginal, const Reference< XMultiServiceFactory>& _rxFactory, const sal_Bool _bSetDelegator )
     :OComponentHelper( m_aMutex )
     ,OPropertySetAggregationHelper( OComponentHelper::rBHelper )
+    ,m_xServiceFactory( _rxFactory )
     ,m_nTabIndex( FRM_DEFAULT_TABINDEX )
     ,m_nClassId( FormComponentType::CONTROL )
-    ,m_xServiceFactory( _rxFactory )
 {
     DBG_CTOR( OControlModel, NULL );
     DBG_ASSERT( _pOriginal, "OControlModel::OControlModel: invalid original!" );
@@ -598,7 +598,7 @@ Sequence<rtl::OUString> SAL_CALL OControlModel::getSupportedServiceNames() throw
     aSupported.realloc(aSupported.getLength() + 2);
     ::rtl::OUString* pArray = aSupported.getArray();
     pArray[aSupported.getLength()-2] = FRM_SUN_FORMCOMPONENT;
-    pArray[aSupported.getLength()-1] = ::rtl::OUString::createFromAscii("com.sun.star.form.FormControlModel");
+    pArray[aSupported.getLength()-1] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.form.FormControlModel" ));
 
     return aSupported;
 }
@@ -876,12 +876,12 @@ OBoundControlModel::OBoundControlModel(
     :OControlModel(_rxFactory, _rUnoControlModelTypeName, _rDefault, _bSetDelegator)
     ,m_aUpdateListeners(m_aMutex)
     ,m_aResetListeners(m_aMutex)
+    ,m_aLabelServiceName(FRM_SUN_COMPONENT_FIXEDTEXT)
     ,m_bLoaded(sal_False)
     ,m_bRequired(sal_False)
     ,m_bCommitable(_bCommitable)
-    ,m_aLabelServiceName(FRM_SUN_COMPONENT_FIXEDTEXT)
-    ,m_bResetting(sal_False)
     ,m_bForwardValueChanges(sal_True)
+    ,m_bResetting(sal_False)
 {
     DBG_CTOR(frm_OBoundControlModel, NULL);
 }
@@ -896,8 +896,8 @@ OBoundControlModel::OBoundControlModel(
     ,m_bLoaded( sal_False )
     ,m_bRequired( sal_False )
     ,m_bCommitable( _bCommitable )
-    ,m_bResetting( sal_False )
     ,m_bForwardValueChanges( sal_True )
+    ,m_bResetting( sal_False )
 {
     DBG_CTOR(frm_OBoundControlModel, NULL);
 
@@ -1003,7 +1003,7 @@ StringSequence SAL_CALL OBoundControlModel::getSupportedServiceNames() throw(Run
     aSupported.realloc(aSupported.getLength() + 1);
 
     ::rtl::OUString* pArray = aSupported.getArray();
-    pArray[aSupported.getLength()-1] = ::rtl::OUString::createFromAscii("com.sun.star.form.DataAwareControlModel");
+    pArray[aSupported.getLength()-1] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.form.DataAwareControlModel" ));
     return aSupported;
 }
 
@@ -1029,7 +1029,6 @@ void SAL_CALL OBoundControlModel::write( const Reference<stario::XObjectOutputSt
     // in anything from data loss to crash.
     // (use writeCommonProperties instead, this is called in derived classes write-method)
     // !!! EOIN !!!
-    // FS - 68876 - 28.09.1999
 }
 
 //------------------------------------------------------------------------------
@@ -1105,7 +1104,7 @@ void SAL_CALL OBoundControlModel::read( const Reference< stario::XObjectInputStr
     OControlModel::read(_rxInStream);
 
     osl::MutexGuard aGuard(m_aMutex);
-    UINT16 nVersion = _rxInStream->readShort();
+    /*UINT16 nVersion =*/ _rxInStream->readShort();
     ::comphelper::operator>>( _rxInStream, m_aControlSource);
 }
 
@@ -1181,7 +1180,7 @@ void OBoundControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, co
             rValue >>= m_aControlSource;
             break;
         case PROPERTY_ID_BOUNDFIELD:
-            DBG_ERROR("OBoundControlModel::setFastPropertyValue_NoBroadcast : BoundField should be a read-only property !");
+            OSL_FAIL("OBoundControlModel::setFastPropertyValue_NoBroadcast : BoundField should be a read-only property !");
                 throw com::sun::star::lang::IllegalArgumentException();
             break;
         case PROPERTY_ID_CONTROLLABEL:
@@ -1225,8 +1224,8 @@ void OBoundControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, co
                     // found my root
                     break;
 
-                Reference<XChild> xAsChild(xMyTopLevel, UNO_QUERY);
-                xMyTopLevel = xAsChild.is() ? xAsChild->getParent() : InterfaceRef();
+                Reference<XChild> xLclAsChild(xMyTopLevel, UNO_QUERY);
+                xMyTopLevel = xLclAsChild.is() ? xLclAsChild->getParent() : InterfaceRef();
             }
             InterfaceRef xNewTopLevel = xAsChild->getParent();
             while (xNewTopLevel.is())
@@ -1235,8 +1234,8 @@ void OBoundControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, co
                 if (!xAsForm.is())
                     break;
 
-                Reference<XChild> xAsChild(xNewTopLevel, UNO_QUERY);
-                xNewTopLevel = xAsChild.is() ? xAsChild->getParent() : InterfaceRef();
+                Reference<XChild> xLclAsChild(xNewTopLevel, UNO_QUERY);
+                xNewTopLevel = xLclAsChild.is() ? xLclAsChild->getParent() : InterfaceRef();
             }
             if (xNewTopLevel != xMyTopLevel)
             {
@@ -1263,8 +1262,8 @@ void SAL_CALL OBoundControlModel::propertyChange( const PropertyChangeEvent& evt
     if (evt.PropertyName.equals(PROPERTY_VALUE))
     {
         osl::MutexGuard aGuard(m_aMutex);
-        if (m_bForwardValueChanges && m_xColumn.is())
-            _onValueChanged();
+//		if (m_bForwardValueChanges && m_xColumn.is())
+//			_onValueChanged();
     }
 }
 
@@ -1301,21 +1300,21 @@ sal_Bool SAL_CALL OBoundControlModel::commit() throw(RuntimeException)
     if (bSucceed)
     {
         osl::MutexGuard aGuard(m_aMutex);
-        try
-        {
-            bSucceed = _commit();
-        }
-        catch(Exception&)
-        {
-            bSucceed = sal_False;
-        }
+//		try
+//		{
+//			bSucceed = _commit();
+//		}
+//		catch(Exception&)
+//		{
+//			bSucceed = sal_False;
+//		}
     }
 
     if (bSucceed)
     {
-        cppu::OInterfaceIteratorHelper aIter(m_aUpdateListeners);
-        while (aIter.hasMoreElements())
-            ((XUpdateListener*)aIter.next())->updated(aEvt);
+        cppu::OInterfaceIteratorHelper aLclIter(m_aUpdateListeners);
+        while (aLclIter.hasMoreElements())
+            ((XUpdateListener*)aLclIter.next())->updated(aEvt);
     }
 
     return bSucceed;
@@ -1352,7 +1351,7 @@ sal_Bool OBoundControlModel::connectToField(const Reference<XRowSet>& rForm)
         // darf ich mich ueberhaupt an dieses Feld binden (Typ-Check)
         if (xFieldCandidate.is())
         {
-            sal_Int32 nFieldType;
+            sal_Int32 nFieldType(0);
             xFieldCandidate->getPropertyValue(PROPERTY_FIELDTYPE) >>= nFieldType;
             if (_approve(nFieldType))
                 setField(xFieldCandidate,sal_False);
@@ -1368,13 +1367,14 @@ sal_Bool OBoundControlModel::connectToField(const Reference<XRowSet>& rForm)
                 m_xField->addPropertyChangeListener(PROPERTY_VALUE, this);
                                 m_xColumnUpdate = Reference<XColumnUpdate>(m_xField, UNO_QUERY);
                                 m_xColumn = Reference<XColumn>(m_xField, UNO_QUERY);
-                INT32 nNullableFlag; m_xField->getPropertyValue(PROPERTY_ISNULLABLE) >>= nNullableFlag;
+                INT32 nNullableFlag(0);
+                m_xField->getPropertyValue(PROPERTY_ISNULLABLE) >>= nNullableFlag;
                 m_bRequired = (ColumnValue::NO_NULLS == nNullableFlag);
                     // we're optimistic : in case of ColumnValue_NULLABLE_UNKNOWN we assume nullability ....
             }
             else
             {
-                OSL_ENSURE(sal_False, "OBoundControlModel::connectToField: property NAME not supported!");
+                OSL_FAIL("OBoundControlModel::connectToField: property NAME not supported!");
                 setField(NULL,sal_False);
             }
         }
@@ -1398,56 +1398,28 @@ sal_Bool OBoundControlModel::_approve(sal_Int32 _nColumnType)
 
 // XLoadListener
 //------------------------------------------------------------------------------
-void SAL_CALL OBoundControlModel::loaded(const com::sun::star::lang::EventObject& _rEvent) throw(RuntimeException)
+void SAL_CALL OBoundControlModel::loaded(const com::sun::star::lang::EventObject& /*rEvent*/) throw(RuntimeException)
 {
-    osl::MutexGuard aGuard(m_aMutex);
-    Reference<XRowSet> xForm(_rEvent.Source, UNO_QUERY);
-    Reference<XPropertySet> xOldField = m_xField;
-    connectToField(xForm);
-
-    m_bLoaded = sal_True;
-    _loaded(_rEvent);
-
-    if (m_xField.is())
-    {
-        // initially call _onValueChanged
-        // but only if the rowset if posisitioned on a valid record
-        Reference< XRowSet > xRowset( _rEvent.Source, UNO_QUERY );
-        OSL_ENSURE( xRowset.is(), "OBoundControlModel::loaded: invalid event source (no rowset)!" );
-        if ( xRowset.is() )
-        {
-            if ( !xRowset->isBeforeFirst() && !xRowset->isAfterLast() )
-                _onValueChanged();
-        }
-    }
-
-    if ( xOldField != m_xField )
-    {
-        Any aNewValue; aNewValue <<= m_xField;
-        Any aOldValue; aOldValue <<= xOldField;
-        sal_Int32 nHandle = PROPERTY_ID_BOUNDFIELD;
-        OPropertySetHelper::fire(&nHandle, &aNewValue, &aOldValue, 1, sal_False);
-    }
+    OSL_ENSURE( false, "OBoundControlModel::loaded: dead code!?" );
 }
 
 
 //------------------------------------------------------------------------------
-void SAL_CALL OBoundControlModel::unloaded( const com::sun::star::lang::EventObject& aEvent ) throw(RuntimeException)
+void SAL_CALL OBoundControlModel::unloaded( const com::sun::star::lang::EventObject& ) throw(RuntimeException)
 {
 }
 
 //------------------------------------------------------------------------------
-void SAL_CALL OBoundControlModel::reloading( const com::sun::star::lang::EventObject& aEvent ) throw(RuntimeException)
+void SAL_CALL OBoundControlModel::reloading( const com::sun::star::lang::EventObject& ) throw(RuntimeException)
 {
     osl::MutexGuard aGuard(m_aMutex);
     m_bForwardValueChanges = sal_False;
 }
 
 //------------------------------------------------------------------------------
-void SAL_CALL OBoundControlModel::unloading(const com::sun::star::lang::EventObject& aEvent) throw(RuntimeException)
+void SAL_CALL OBoundControlModel::unloading(const com::sun::star::lang::EventObject& ) throw(RuntimeException)
 {
     osl::MutexGuard aGuard(m_aMutex);
-    _unloaded();
 
     if (m_xField.is())
     {
@@ -1459,47 +1431,9 @@ void SAL_CALL OBoundControlModel::unloading(const com::sun::star::lang::EventObj
 }
 
 //------------------------------------------------------------------------------
-void SAL_CALL OBoundControlModel::reloaded(const com::sun::star::lang::EventObject& aEvent) throw(RuntimeException)
-{
-    osl::MutexGuard aGuard(m_aMutex);
-    Reference<XPropertySet> xOldField = m_xField;
-    // did we lost the connection to the field because there was a new created?
-    if (!m_xField.is())
-    {
-        Reference<XRowSet> xForm(aEvent.Source, UNO_QUERY);
-        connectToField(xForm);
-    }
-
-    m_bForwardValueChanges = sal_True;
-    _loaded(aEvent);
-
-    // do we have a field, than get the new value
-    if (m_xField.is())
-        _onValueChanged();
-
-    if ( xOldField != m_xField )
-    {
-        Any aNewValue; aNewValue <<= m_xField;
-        Any aOldValue; aOldValue <<= xOldField;
-        sal_Int32 nHandle = PROPERTY_ID_BOUNDFIELD;
-        OPropertySetHelper::fire(&nHandle, &aNewValue, &aOldValue, 1, sal_False);
-    }
-}
-
-//------------------------------------------------------------------------------
-void OBoundControlModel::_loaded(const com::sun::star::lang::EventObject& rEvent)
-{
-}
-
-//------------------------------------------------------------------------------
-void OBoundControlModel::_unloaded()
-{
-}
-
-// XReset
-//-----------------------------------------------------------------------------
-void OBoundControlModel::_reset()
+void SAL_CALL OBoundControlModel::reloaded(const com::sun::star::lang::EventObject& /*rEvent*/) throw(RuntimeException)
 {
+    OSL_ENSURE( false, "OBoundControlModel::reloaded: dead code!?" );
 }
 
 //-----------------------------------------------------------------------------
@@ -1517,72 +1451,7 @@ void OBoundControlModel::removeResetListener(const Reference<XResetListener>& l)
 //-----------------------------------------------------------------------------
 void OBoundControlModel::reset() throw (RuntimeException)
 {
-    cppu::OInterfaceIteratorHelper aIter(m_aResetListeners);
-        com::sun::star::lang::EventObject aResetEvent(static_cast<XWeak*>(this));
-    sal_Bool bContinue = sal_True;
-    while (aIter.hasMoreElements() && bContinue)
-        bContinue = reinterpret_cast<XResetListener*>(aIter.next())->approveReset(aResetEvent);
-
-    if (!bContinue)
-        return;
-
-    osl::ClearableMutexGuard aGuard(m_aMutex);
-    m_bResetting = sal_True;
-
-    sal_Bool bSimpleReset = !m_xField.is()						// no connection to a database field
-                        ||	(	m_xCursor.is()					// OR	we have an improperly positioned cursor
-                            &&	(	m_xCursor->isAfterLast()
-                                ||	m_xCursor->isBeforeFirst()
-                                )
-                            );
-
-    if ( !bSimpleReset )
-    {
-        // The default values will be set if and only if the current value of the field which we're bound
-        // to is NULL.
-        // Else, the current field value should be refreshed
-        // This behaviour is not completely ... "matured": What should happen if the field as well as the
-        // control have a default value?
-
-        sal_Bool bIsNull = sal_True;
-        // we have to access the field content at least once to get a reliable result by XColumn::wasNull
-        try
-        {
-            m_xColumn->getString();
-            bIsNull = m_xColumn->wasNull();
-        }
-        catch(Exception&)
-        {
-            DBG_ERROR("OBoundControlModel::reset : XColumn::getString and wasNull are expected to always succeed !");
-        }
-
-        if (bIsNull)
-        {
-            sal_Bool bIsNewRecord = sal_False;
-            Reference<XPropertySet> xSet(m_xCursor, UNO_QUERY);
-            if (xSet.is())
-                xSet->getPropertyValue(PROPERTY_ISNEW) >>= bIsNewRecord;
-            if (bIsNewRecord)
-            {
-                _reset();	// setzen der Werte,
-                _commit();	// uebertragen der Werte ins Feld
-                            // fuer das zuruecksetzen des modifyflags ist das Formular zustaendig
-            }
-            else
-                _onValueChanged();
-        }
-        else
-            _onValueChanged();
-    }
-    else
-        _reset();
-
-    m_bResetting = sal_False;
-    aGuard.clear();
-
-    cppu::OInterfaceIteratorHelper aIterDone(m_aResetListeners);
-    while (aIterDone.hasMoreElements())
-        reinterpret_cast<XResetListener*>(aIterDone.next())->resetted(aResetEvent);
+    OSL_ENSURE( false, "OBoundControlModel::reset: dead code!?" );
 }
 // -----------------------------------------------------------------------------
 void OBoundControlModel::setField( const Reference< XPropertySet>& _rxField,sal_Bool _bFire)
