@@ -67,7 +67,7 @@ using namespace ::com::sun::star;
 
 #define SC_FUNCGROUP_COUNT  ID_FUNCTION_GRP_ADDINS
 
-static const sal_Char* __FAR_DATA aFuncNames[SC_FUNCGROUP_COUNT] =
+static const sal_Char* aFuncNames[SC_FUNCGROUP_COUNT] =
     {
         //  array index = ID - 1 (ID starts at 1)
         //  all upper case
@@ -150,16 +150,16 @@ public:
 /*N*/                                         long nAC, const ScAddInArgDesc* pAD,
 /*N*/                                         long nCP ) :
 /*N*/     aOriginalName( rNam ),
-/*N*/     aUpperName( rNam ),
 /*N*/     aLocalName( rLoc ),
+/*N*/     aUpperName( rNam ),
 /*N*/     aUpperLocal( rLoc ),
 /*N*/     aDescription( rDesc ),
-/*N*/     nCategory( nCat ),
-/*N*/     nHelpId( nHelp ),
 /*N*/     xFunction( rFunc ),
 /*N*/     aObject( rO ),
 /*N*/     nArgCount( nAC ),
 /*N*/     nCallerPos( nCP ),
+/*N*/     nCategory( nCat ),
+/*N*/     nHelpId( nHelp ),
 /*N*/     bCompInitialized( FALSE )
 /*N*/ {
 /*N*/     if ( nArgCount )
@@ -201,11 +201,11 @@ public:
 /*N*/         case uno::TypeClass_FLOAT:
 /*N*/         case uno::TypeClass_DOUBLE:
 /*N*/             rAny >>= rOut;
-/*N*/             bRet = TRUE;
 /*N*/             break;
+              default:
+                  rOut = 0.0;
+                  break;
 /*N*/     }
-/*N*/     if (!bRet)
-/*N*/         rOut = 0.0;
 /*N*/     return bRet;
 /*N*/ }
 
@@ -244,7 +244,7 @@ public:
 /*N*/     {
 /*N*/         uno::Reference<container::XEnumeration> xEnum =
 /*N*/                         xEnAc->createContentEnumeration(
-/*N*/                             ::rtl::OUString::createFromAscii(SCADDINSUPPLIER_SERVICE) );
+/*N*/                             ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(SCADDINSUPPLIER_SERVICE)) );
 /*N*/         if ( xEnum.is() )
 /*N*/         {
 /*N*/             //  loop through all AddIns
@@ -407,8 +407,8 @@ public:
 /*N*/         if ( xManager.is() )
 /*N*/         {
 /*N*/             uno::Reference<beans::XIntrospection> xIntro(
-/*N*/                                     xManager->createInstance(::rtl::OUString::createFromAscii(
-/*N*/                                         "com.sun.star.beans.Introspection" )),
+/*N*/                                     xManager->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+/*N*/                                         "com.sun.star.beans.Introspection" ))),
 /*N*/                                     uno::UNO_QUERY );
 /*N*/             if ( xIntro.is() )
 /*N*/             {
@@ -527,7 +527,7 @@ public:
 /*N*/                                         }
 /*N*/                                         catch(uno::Exception&)
 /*N*/                                         {
-/*N*/                                             aLocalU = ::rtl::OUString::createFromAscii( "###" );
+/*N*/                                             aLocalU = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "###" ));
 /*N*/                                         }
 /*N*/                                         String aLocalName = String( aLocalU );
 /*N*/ 
@@ -539,7 +539,7 @@ public:
 /*N*/                                         }
 /*N*/                                         catch(uno::Exception&)
 /*N*/                                         {
-/*N*/                                             aDescU = ::rtl::OUString::createFromAscii( "###" );
+/*N*/                                             aDescU = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "###" ));
 /*N*/                                         }
 /*N*/                                         String aDescription = String( aDescU );
 /*N*/ 
@@ -564,7 +564,7 @@ public:
 /*N*/                                                     }
 /*N*/                                                     catch(uno::Exception&)
 /*N*/                                                     {
-/*N*/                                                         aArgName = ::rtl::OUString::createFromAscii( "###" );
+/*N*/                                                         aArgName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "###" ));
 /*N*/                                                     }
 /*N*/                                                     ::rtl::OUString aArgDesc;
 /*N*/                                                     try
@@ -574,7 +574,7 @@ public:
 /*N*/                                                     }
 /*N*/                                                     catch(uno::Exception&)
 /*N*/                                                     {
-/*N*/                                                         aArgName = ::rtl::OUString::createFromAscii( "###" );
+/*N*/                                                         aArgName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "###" ));
 /*N*/                                                     }
 /*N*/ 
 /*N*/                                                     BOOL bOptional =
@@ -641,13 +641,6 @@ public:
 /*N*/         if ( iLook != pLocalHashMap->end() )
 /*?*/             return iLook->second->GetOriginalName();
 /*N*/ 
-/*N*/ #if 0
-/*N*/         //  after that, scan international names (really?)
-/*N*/ 
-/*N*/         iLook = pNameHashMap->find( rUpperName );
-/*N*/         if ( iLook != pNameHashMap->end() )
-/*N*/             return iLook->second->GetOriginalName();
-/*N*/ #endif
 /*N*/     }
 /*N*/     else
 /*N*/     {
@@ -691,11 +684,11 @@ public:
 
 /*N*/ ScUnoAddInCall::ScUnoAddInCall( ScUnoAddInCollection& rColl, const String& rName,
 /*N*/                                 long nParamCount ) :
+/*N*/     bValidCount( FALSE ),
 /*N*/     nErrCode( errNoCode ),      // before function was called
 /*N*/     bHasString( TRUE ),
 /*N*/     fValue( 0.0 ),
-/*N*/     pMatrix( NULL ),
-/*N*/     bValidCount( FALSE )
+/*N*/     pMatrix( NULL )
 /*N*/ {
 /*N*/	pFuncData = rColl.GetFuncData( rName );
 /*N*/     DBG_ASSERT( pFuncData, "Function Data missing" );
@@ -703,13 +696,12 @@ public:
 /*N*/     {
 /*N*/         long nDescCount = pFuncData->GetArgumentCount();
 /*N*/         const ScAddInArgDesc* pArgs = pFuncData->GetArguments();
-/*N*/         long nVarCount = 0;
 /*N*/ 
 /*N*/         //  is aVarArg sequence needed?
 /*N*/         if ( nParamCount >= nDescCount && nDescCount > 0 &&
 /*N*/              pArgs[nDescCount-1].eType == SC_ADDINARG_VARARGS )
 /*N*/         {
-/*?*/ 					{DBG_BF_ASSERT(0, "STRIP");} //STRIP001             long nVarCount = nParamCount - ( nDescCount - 1 );  // size of last argument
+/*?*/ 			{DBG_BF_ASSERT(0, "STRIP");}
 /*N*/         }
 /*N*/         else if ( nParamCount <= nDescCount )
 /*N*/         {
@@ -786,12 +778,12 @@ public:
 /*N*/             if ( nVarPos < aVarArg.getLength() )
 /*N*/                 aVarArg.getArray()[nVarPos] = rValue;
 /*N*/             else
-/*N*/                 DBG_ERROR("wrong argument number");
+/*N*/                 OSL_FAIL("wrong argument number");
 /*N*/         }
 /*N*/         else if ( nPos < aArgs.getLength() )
 /*N*/             aArgs.getArray()[nPos] = rValue;
 /*N*/         else
-/*N*/             DBG_ERROR("wrong argument number");
+/*N*/             OSL_FAIL("wrong argument number");
 /*N*/     }
 /*N*/ }
 
@@ -820,7 +812,7 @@ public:
 /*N*/         long nCallPos = pFuncData->GetCallerPos();
 /*N*/         if (nCallPos>nUserLen)                          // should not happen
 /*N*/         {
-/*N*/             DBG_ERROR("wrong CallPos");
+/*N*/             OSL_FAIL("wrong CallPos");
 /*N*/             nCallPos = nUserLen;
 /*N*/         }
 /*N*/ 
@@ -870,12 +862,6 @@ public:
 /*N*/         {
 /*N*/             nErrCode = errIllegalArgument;
 /*N*/         }
-/*N*/ #if 0
-/*N*/         catch(FloatingPointException&)
-/*N*/         {
-/*N*/             nErrCode = errIllegalFPOperation;
-/*N*/         }
-/*N*/ #endif
 /*N*/ 		catch(reflection::InvocationTargetException& rWrapped)
 /*N*/ 		{
 /*N*/ 			if ( rWrapped.TargetException.getValueType().equals(
