@@ -85,16 +85,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 
 //------------------------------------------------------------------------
 
-//-/class ScPublicAttrObj : public SdrAttrObj
-//-/{
-//-/private:
-//-/	ScPublicAttrObj() {}						// wird nicht angelegt
-//-/public:
-//-/	const XLineAttrSetItem* GetLineAttr()		{ return pLineAttr; }
-//-/};
-
-//------------------------------------------------------------------------
-
 /*N*/ class ScDetectiveData
 /*N*/ {
 /*N*/ private:
@@ -281,12 +271,12 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 	//	MAXCOL/ROW+1 ist erlaubt fuer Ende von Rahmen
 /*N*/ 	if (nCol > MAXCOL+1)
 /*N*/ 	{
-/*N*/ 		DBG_ERROR("falsche Col in ScDetectiveFunc::GetDrawPos");
+/*N*/ 		OSL_FAIL("falsche Col in ScDetectiveFunc::GetDrawPos");
 /*N*/ 		nCol = MAXCOL+1;
 /*N*/ 	}
 /*N*/ 	if (nRow > MAXROW+1)
 /*N*/ 	{
-/*N*/ 		DBG_ERROR("falsche Row in ScDetectiveFunc::GetDrawPos");
+/*N*/ 		OSL_FAIL("falsche Row in ScDetectiveFunc::GetDrawPos");
 /*N*/ 		nRow = MAXROW+1;
 /*N*/ 	}
 /*N*/ 
@@ -341,7 +331,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	if (bStartAlien && bEndAlien)
 /*N*/ 	{
-/*N*/ 		DBG_ERROR("bStartAlien && bEndAlien");
+/*N*/ 		OSL_FAIL("bStartAlien && bEndAlien");
 /*N*/ 		return TRUE;
 /*N*/ 	}
 /*N*/ 
@@ -381,19 +371,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 			BOOL bObjEndAlien =
 /*N*/ 				lcl_IsOtherTab( ((const XLineEndItem&)pObject->GetItem(XATTR_LINEEND)).GetValue() );
 /*N*/ 			
-/*N*/ //-/			BOOL bObjStartAlien = FALSE;
-/*N*/ //-/			BOOL bObjEndAlien = FALSE;
-/*N*/ //-/			const XLineAttrSetItem* pLineAttrs =
-/*N*/ //-/				((ScPublicAttrObj*)(SdrAttrObj*)pObject)->GetLineAttr();
-/*N*/ //-/			if (pLineAttrs)
-/*N*/ //-/			{
-/*N*/ //-/				const SfxItemSet& rSet = pLineAttrs->GetItemSet();
-/*N*/ //-/				bObjStartAlien = (((const XLineStartItem&)rSet.Get(XATTR_LINESTART)).
-/*N*/ //-/										GetValue().GetPointCount() == 4 );
-/*N*/ //-/				bObjEndAlien   = (((const XLineEndItem&)rSet.Get(XATTR_LINEEND)).
-/*N*/ //-/										GetValue().GetPointCount() == 4 );
-/*N*/ //-/			}
-/*N*/ 
 /*N*/ 			BOOL bStartHit = bStartAlien ? bObjStartAlien :
 /*N*/ 								( !bObjStartAlien && aStartRect.IsInside(pObject->GetPoint(0)) );
 /*N*/ 			BOOL bEndHit = bEndAlien ? bObjEndAlien :
@@ -424,7 +401,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	BOOL bArea = ( nRefStartCol != nRefEndCol || nRefStartRow != nRefEndRow );
 /*N*/ 	if (bArea && !bFromOtherTab)
-/*N*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ 	{DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 
 /*N*/ 	Point aStartPos	= GetDrawPos( nRefStartCol, nRefStartRow, TRUE );
@@ -454,7 +431,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	pArrow->NbcSetLogicRect(Rectangle(aStartPos,aEndPos));	//! noetig ???
 /*N*/ 
-/*N*/ //-/	pArrow->SetAttributes( rAttrSet, FALSE );
 /*N*/ 	pArrow->SetItemSetAndBroadcast(rAttrSet);
 /*N*/ 
 /*N*/ 	ScDrawLayer::SetAnchor( pArrow, SCA_CELL );
@@ -496,7 +472,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 		SdrRectObj* pBox = new SdrRectObj(Rectangle(aStartCorner,aEndCorner));
 /*N*/ 		
-/*N*/ //-/		pBox->SetAttributes( rData.GetBoxSet(), FALSE );
 /*N*/ 		pBox->SetItemSetAndBroadcast(rData.GetBoxSet());
 /*N*/ 
 /*N*/ 		ScDrawLayer::SetAnchor( pBox, SCA_CELL );
@@ -534,7 +509,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	pArrow->NbcSetLogicRect(Rectangle(aStartPos,aEndPos));	//! noetig ???
 /*N*/ 
-/*N*/ //-/	pArrow->SetAttributes( rAttrSet, FALSE );
 /*N*/ 	pArrow->SetItemSetAndBroadcast(rAttrSet);
 /*N*/ 
 /*N*/ 	ScDrawLayer::SetAnchor( pArrow, SCA_CELL );
@@ -611,7 +585,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 	SdrCircObj* pCircle = new SdrCircObj( OBJ_CIRC, aRect );
 /*N*/ 	SfxItemSet& rAttrSet = rData.GetCircleSet();
 /*N*/ 
-/*N*/ //-/	pCircle->SetAttributes( rAttrSet, FALSE );
 /*N*/ 	pCircle->SetItemSetAndBroadcast(rAttrSet);
 /*N*/ 
 /*N*/ 	ScDrawLayer::SetAnchor( pCircle, SCA_CELL );
@@ -692,17 +665,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 
 /*N*/ void ScDetectiveFunc::DeleteBox( USHORT nCol1, USHORT nRow1, USHORT nCol2, USHORT nRow2 )
 /*N*/ {
-/*	String aStr;
-    aStr += nCol1;
-    aStr += '/';
-    aStr += nRow1;
-    aStr += '/';
-    aStr += nCol2;
-    aStr += '/';
-    aStr += nRow2;
-    InfoBox(0,aStr).Execute();
-*/
-/*N*/ 
 /*N*/ 	Point aStartCorner = GetDrawPos( nCol1, nRow1, FALSE );
 /*N*/ 	Point aEndCorner = GetDrawPos( nCol2+1, nRow2+1, FALSE );
 /*N*/ 	Rectangle aObjRect;
@@ -1161,6 +1123,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	SdrPage* pPage = pModel->GetPage(nTab);
 /*N*/ 	DBG_ASSERT(pPage,"Page ?");
+/*N*/ 	(void)pPage;
 /*N*/ 
 /*N*/ 	ScDetectiveData aData( pModel );
 /*N*/ 
@@ -1184,6 +1147,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	SdrPage* pPage = pModel->GetPage(nTab);
 /*N*/ 	DBG_ASSERT(pPage,"Page ?");
+/*N*/ 	(void)pPage;
 /*N*/ 
 /*N*/ 	ScDetectiveData aData( pModel );
 /*N*/ 
@@ -1207,6 +1171,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	SdrPage* pPage = pModel->GetPage(nTab);
 /*N*/ 	DBG_ASSERT(pPage,"Page ?");
+/*N*/ 	(void)pPage;
 /*N*/ 
 /*N*/ 	ScTripel aPos( nCol, nRow, nTab );
 /*N*/ 	ScTripel aErrPos;
@@ -1229,6 +1194,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	SdrPage* pPage = pModel->GetPage(nTab);
 /*N*/ 	DBG_ASSERT(pPage,"Page ?");
+/*N*/ 	(void)pPage;
 /*N*/ 
 /*N*/ 	USHORT nLevelCount = FindSuccLevel( nCol, nRow, nCol, nRow, 0, 0 );
 /*N*/ 	if ( nLevelCount )
@@ -1245,6 +1211,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 
 /*N*/ 	SdrPage* pPage = pModel->GetPage(nTab);
 /*N*/ 	DBG_ASSERT(pPage,"Page ?");
+/*N*/ 	(void)pPage;
 /*N*/ 
 /*N*/ 	USHORT nLevelCount = FindPredLevel( nCol, nRow, 0, 0 );
 /*N*/ 	if ( nLevelCount )
@@ -1290,7 +1257,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 					else if ( eWhat == SC_DET_ARROWS )		// DetectiveRefresh
 /*N*/ 						bDoThis = !bCaption && !bCircle;	// don't include circles
 /*N*/ 					else
-/*N*/ 						DBG_ERROR("wat?");
+/*N*/ 						OSL_FAIL("wat?");
 /*N*/ 				}
 /*N*/ 				if ( bDoThis )
 /*N*/ 					ppObj[nDelCount++] = pObject;
@@ -1380,7 +1347,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ }
 
 /*N*/ SdrObject* ScDetectiveFunc::ShowCommentUser( USHORT nCol, USHORT nRow, const String& rUserText,
-/*N*/ 											const Rectangle& rVisible, BOOL bLeft, BOOL bForce,
+/*N*/ 											const Rectangle& /*rVisible*/, BOOL /*bLeft*/, BOOL bForce,
 /*N*/ 											SdrPage* pDestPage )
 /*N*/ {
 /*N*/ 	ScDrawLayer* pModel = pDoc->GetDrawLayer();
@@ -1392,7 +1359,7 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 	BOOL bFound = pDoc->GetNote( nCol, nRow, nTab, aNote );
 /*N*/ 	if ( bFound || bForce || rUserText.Len() )
 /*N*/ 	{
-        DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SdrModel* pDestModel = pModel;
+        DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 
 /*N*/ 	return pObject;
@@ -1465,7 +1432,6 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*?*/ 
 /*?*/ 					SfxItemSet& rAttrSet = aData.GetCaptionSet();
 /*?*/ 
-/*?*/ //-/					pCaption->SetAttributes( rAttrSet, FALSE );
 /*?*/ 					pCaption->SetItemSetAndBroadcast(rAttrSet);
 /*?*/ 
 /*?*/ 					pCaption->SetSpecialTextBoxShadow();
@@ -1644,11 +1610,11 @@ enum DetInsertResult {				// Return-Werte beim Einfuegen in einen Level
 /*N*/ 	return eType;
 /*N*/ }
 
-/*N*/ void ScDetectiveFunc::InsertObject( ScDetectiveObjType eType,
-/*N*/ 							const ScAddress& rPosition, const ScRange& rSource,
-/*N*/ 							BOOL bRedLine )
+/*N*/ void ScDetectiveFunc::InsertObject( ScDetectiveObjType /*eType*/,
+/*N*/ 							const ScAddress& /*rPosition*/, const ScRange& /*rSource*/,
+/*N*/ 							BOOL /*bRedLine*/ )
 /*N*/ {
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	ScDrawLayer* pModel = pDoc->GetDrawLayer();
+        DBG_BF_ASSERT(0, "STRIP"); 
 /*N*/ }
 
 // static
