@@ -40,9 +40,10 @@
 namespace binfilter {
 
 using namespace utl;
-using namespace rtl;
 using namespace ::com::sun::star::uno;
 
+using ::rtl::OUString;
+
 //------------------------------------------------------------------
 
 
@@ -171,7 +172,7 @@ using namespace ::com::sun::star::uno;
 
 //------------------------------------------------------------------------
 
-/*N*/ __EXPORT ScViewOptions::~ScViewOptions()
+/*N*/ ScViewOptions::~ScViewOptions()
 /*N*/ {
 /*N*/ }
 
@@ -475,10 +476,10 @@ using namespace ::com::sun::star::uno;
 /*N*/ 	//	adjust for metric system
 /*N*/ 	if (ScOptionsUtil::IsMetricSystem())
 /*N*/ 	{
-/*N*/ 		pNames[SCGRIDOPT_RESOLU_X] = OUString::createFromAscii( "Resolution/XAxis/Metric" );
-/*N*/ 		pNames[SCGRIDOPT_RESOLU_Y] = OUString::createFromAscii( "Resolution/YAxis/Metric" );
-/*N*/ 		pNames[SCGRIDOPT_OPTION_X] = OUString::createFromAscii( "Option/XAxis/Metric" );
-/*N*/ 		pNames[SCGRIDOPT_OPTION_Y] = OUString::createFromAscii( "Option/YAxis/Metric" );
+/*N*/ 		pNames[SCGRIDOPT_RESOLU_X] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Resolution/XAxis/Metric" ));
+/*N*/ 		pNames[SCGRIDOPT_RESOLU_Y] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Resolution/YAxis/Metric" ));
+/*N*/ 		pNames[SCGRIDOPT_OPTION_X] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Option/XAxis/Metric" ));
+/*N*/ 		pNames[SCGRIDOPT_OPTION_Y] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Option/YAxis/Metric" ));
 /*N*/ 	}
 /*N*/ 
 /*N*/ 	return aNames;
@@ -486,11 +487,11 @@ using namespace ::com::sun::star::uno;
 
 
 /*N*/ ScViewCfg::ScViewCfg() :
-/*N*/ 	aLayoutItem( OUString::createFromAscii( CFGPATH_LAYOUT ) ),
-/*N*/ 	aDisplayItem( OUString::createFromAscii( CFGPATH_DISPLAY ) ),
-/*N*/ 	aGridItem( OUString::createFromAscii( CFGPATH_GRID ) )
+/*N*/ 	aLayoutItem( OUString(RTL_CONSTASCII_USTRINGPARAM( CFGPATH_LAYOUT )) ),
+/*N*/ 	aDisplayItem( OUString(RTL_CONSTASCII_USTRINGPARAM( CFGPATH_DISPLAY )) ),
+/*N*/ 	aGridItem( OUString(RTL_CONSTASCII_USTRINGPARAM( CFGPATH_GRID )) )
 /*N*/ {
-/*N*/ 	sal_Int32 nIntVal;
+/*N*/ 	sal_Int32 nIntVal = 0;
 /*N*/ 
 /*N*/ 	Sequence<OUString> aNames = GetLayoutPropertyNames();
 /*N*/ 	Sequence<Any> aValues = aLayoutItem.GetProperties(aNames);
@@ -652,19 +653,19 @@ using namespace ::com::sun::star::uno;
 
 /*N*/ IMPL_LINK( ScViewCfg, LayoutCommitHdl, void *, EMPTYARG )
 /*N*/ {
-    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 Sequence<OUString> aNames = GetLayoutPropertyNames();
+    DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	return 0;
 /*N*/ }
 
 /*N*/ IMPL_LINK( ScViewCfg, DisplayCommitHdl, void *, EMPTYARG )
 /*N*/ {
-    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 Sequence<OUString> aNames = GetDisplayPropertyNames();
+    DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	return 0;
 /*N*/ }
 
 /*N*/ IMPL_LINK( ScViewCfg, GridCommitHdl, void *, EMPTYARG )
 /*N*/ {
-    DBG_BF_ASSERT(0, "STRIP"); //STRIP001 const ScGridOptions& rGrid = GetGridOptions();
+    DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	return 0;
 /*N*/ }
 
