@@ -69,7 +69,7 @@ const SfxItemPropertyMap* lcl_GetAutoFormatMap()
         {MAP_CHAR_LEN(SC_UNONAME_INCJUST),	0,	&::getBooleanCppuType(),	0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_INCNUM),	0,	&::getBooleanCppuType(),	0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_INCWIDTH),	0,	&::getBooleanCppuType(),	0, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aAutoFormatMap_Impl;
 }
@@ -124,7 +124,7 @@ const SfxItemPropertyMap* lcl_GetAutoFieldMap()
         {MAP_CHAR_LEN(SC_UNONAME_ROTANG),   ATTR_ROTATE_VALUE,      &::getCppuType((const sal_Int32*)0),        0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_ROTREF),   ATTR_ROTATE_MODE,       &::getCppuType((const table::CellVertJustify*)0),   0, 0 },
         {MAP_CHAR_LEN(SC_UNONAME_CELLVJUS), ATTR_VER_JUSTIFY,       &::getCppuType((const table::CellVertJustify*)0),   0, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aAutoFieldMap_Impl;
 }
@@ -181,14 +181,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScAutoFormatsObj_CreateInstance(
 
 ::rtl::OUString ScAutoFormatsObj::getImplementationName_Static()
 {
-    return ::rtl::OUString::createFromAscii( "stardiv.StarCalc.ScAutoFormatsObj" );
+    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScAutoFormatsObj" ));
 }
 
 uno::Sequence< ::rtl::OUString> ScAutoFormatsObj::getSupportedServiceNames_Static()
 {
     uno::Sequence< ::rtl::OUString> aRet(1);
     ::rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = ::rtl::OUString::createFromAscii( SCAUTOFORMATSOBJ_SERVICE );
+    pArray[0] = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCAUTOFORMATSOBJ_SERVICE ));
     return aRet;
 }
 
@@ -255,7 +255,7 @@ void SAL_CALL ScAutoFormatsObj::insertByName( const ::rtl::OUString& aName, cons
                 else
                 {
                     delete pNew;
-                    DBG_ERROR("AutoFormat konnte nicht eingefuegt werden");
+                    OSL_FAIL("AutoFormat konnte nicht eingefuegt werden");
                     throw uno::RuntimeException();
                 }
             }
@@ -476,7 +476,7 @@ ScAutoFormatObj* ScAutoFormatObj::getImplementation(
     return pRet;
 }
 
-void ScAutoFormatObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScAutoFormatObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& /*rHint*/ )
 {
     //	spaeter...
 }
@@ -584,7 +584,7 @@ void SAL_CALL ScAutoFormatObj::setName( const ::rtl::OUString& aNewName )
         else
         {
             delete pNew;
-            DBG_ERROR("AutoFormat konnte nicht eingefuegt werden");
+            OSL_FAIL("AutoFormat konnte nicht eingefuegt werden");
             nFormatIndex = 0;		//! alter Index ist ungueltig
         }
     }
@@ -619,7 +619,7 @@ void SAL_CALL ScAutoFormatObj::setPropertyValue(
         DBG_ASSERT(pData,"AutoFormat Daten nicht da");
 
         String aPropString = aPropertyName;
-        sal_Bool bBool;
+        sal_Bool bBool = sal_False;
         if (aPropString.EqualsAscii( SC_UNONAME_INCBACK ) && (aValue >>= bBool))
             pData->SetIncludeBackground( bBool );
         else if (aPropString.EqualsAscii( SC_UNONAME_INCBORD ) && (aValue >>= bBool))
@@ -681,7 +681,6 @@ uno::Any SAL_CALL ScAutoFormatObj::getPropertyValue( const ::rtl::OUString& aPro
 
 SC_IMPL_DUMMY_PROPERTY_LISTENER( ScAutoFormatObj )
 
-//------------------------------------------------------------------------
 
 ScAutoFormatFieldObj::ScAutoFormatFieldObj(sal_uInt16 nFormat, sal_uInt16 nField) :
     aPropSet( lcl_GetAutoFieldMap() ),
@@ -695,7 +694,7 @@ ScAutoFormatFieldObj::~ScAutoFormatFieldObj()
 {
 }
 
-void ScAutoFormatFieldObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
+void ScAutoFormatFieldObj::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& /*rHint*/ )
 {
     //	spaeter...
 }
@@ -816,8 +815,6 @@ uno::Any SAL_CALL ScAutoFormatFieldObj::getPropertyValue( const ::rtl::OUString&
 
 SC_IMPL_DUMMY_PROPERTY_LISTENER( ScAutoFormatFieldObj )
 
-//------------------------------------------------------------------------
-
 
 
 }
