@@ -64,7 +64,7 @@ const SfxItemPropertyMap* lcl_GetShapeMap()
     static SfxItemPropertyMap aShapeMap_Impl[] =
     {
         {MAP_CHAR_LEN(SC_UNONAME_IMAGEMAP),	0, &getCppuType((uno::Reference<container::XIndexContainer>*)0), 0, 0 },
-        {0,0,0,0}
+        {0,0,0,0,0,0}
     };
     return aShapeMap_Impl;
 }
@@ -436,7 +436,7 @@ uno::Any SAL_CALL ScShapeObj::getPropertyDefault( const ::rtl::OUString& aProper
 
 // XTextContent
 
-void SAL_CALL ScShapeObj::attach( const uno::Reference<text::XTextRange>& xTextRange )
+void SAL_CALL ScShapeObj::attach( const uno::Reference<text::XTextRange>& /*xTextRange*/ )
                                 throw(lang::IllegalArgumentException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
@@ -542,7 +542,7 @@ void lcl_CopyOneProperty( beans::XPropertySet& rDest, beans::XPropertySet& rSour
     }
     catch (uno::Exception&)
     {
-        DBG_ERROR("Exception in text field");
+        OSL_FAIL("Exception in text field");
     }
 }
 
@@ -774,7 +774,7 @@ uno::Sequence<sal_Int8> SAL_CALL ScShapeObj::getImplementationId()
     }
     if( NULL == pImplementationId )
     {
-        DBG_ERROR( "Could not create an implementation id for a ScXShape!" );
+        OSL_FAIL( "Could not create an implementation id for a ScXShape!" );
         return uno::Sequence< sal_Int8 > ();
     }
     else
