@@ -212,7 +212,7 @@ void SvEmbeddedObject::TestMemberObjRef( BOOL /*bFree*/ )
     {
         ByteString aTest = "\t\tGetClient() == ";
         aTest.Append( ByteString::CreateFromInt32( (ULONG)(SvObject *)GetClient() ) );
-        DBG_TRACE( aTest.GetBuffer() );
+        OSL_TRACE( "%s", aTest.GetBuffer() );
     }
 #endif
 }
@@ -301,27 +301,6 @@ BOOL SvEmbeddedObject::Save()
     return SvPersist::Save();
 }
 
-BOOL SvEmbeddedObject::SaveAs( SvStorage * pNewStor )
-{
-    BOOL bRet = FALSE;
-    if( SvPersist::SaveAs( pNewStor ) )
-    {
-        bRet = TRUE;
-        if( bRet && Owner() && GetParent()
-          && SOFFICE_FILEFORMAT_31 == pNewStor->GetVersion() )
-        {
-            ULONG n = pNewStor->GetFormat();
-            if( n == SOT_FORMATSTR_ID_STARWRITER_30 || n == SOT_FORMATSTR_ID_STARDRAW
-              || n == SOT_FORMATSTR_ID_STARCALC )
-            {
-                // empty MTF for 3.1 formats
-                GDIMetaFile aMtf;
-                MakeContentStream( pNewStor, aMtf );
-            }
-        }
-    }
-    return bRet;
-}
 
 /*************************************************************************
 |*    SvEmbeddedObject::LoadContent()
@@ -547,7 +526,7 @@ void SvEmbeddedObject::Embed( BOOL )
     String aTest( "Object---Embed---" );
     aTest += Owner() ? "Intern" : "Extern: ";
     aTest += bEmbed ? "TRUE" : "FALSE";
-    DBG_TRACE( aTest )
+    OSL_TRACE( "%s", aTest.GetBuffer() )
 #endif
 }
 
@@ -595,7 +574,7 @@ void SvEmbeddedObject::PlugIn( BOOL )
     String aTest( "Object---PlugIn---" );
     aTest += Owner() ? "Intern" : "Extern: ";
     aTest += bPlugIn ? "TRUE" : "FALSE";
-    DBG_TRACE( aTest )
+    OSL_TRACE( "%s", aTest.GetBuffer() )
 #endif
 }
 
@@ -712,7 +691,7 @@ void SvEmbeddedObject::Open( BOOL bOpen )
     String aTest( "Object---Open---" );
     aTest += Owner() ? "Intern" : "Extern: ";
     aTest += bOpen ? "TRUE" : "FALSE";
-    DBG_TRACE( aTest )
+    OSL_TRACE( "%s", aTest.GetBuffer() )
 #endif
 
     SendViewChanged();
