@@ -28,6 +28,7 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
+#include <bf_svtools/bf_solar.h>
 #include <bf_svtools/saveopt.hxx>
 
 #include "rtl/instance.hxx"
@@ -45,10 +46,11 @@
 #include "itemholder1.hxx"
 
 using namespace utl;
-using namespace rtl;
 using namespace com::sun::star::uno;
 namespace css = ::com::sun::star;
 
+using ::rtl::OUString;
+
 namespace binfilter
 {
 
@@ -75,7 +77,6 @@ class SvtSaveOptions_Impl : public utl::ConfigItem
                                         bAutoSavePrompt,
                                         bDocInfSave,
                                         bSaveWorkingSet,
-                                        bSaveDocWins,
                                         bSaveDocView,
                                         bSaveRelINet,
                                         bSaveRelFSys,
@@ -91,7 +92,6 @@ class SvtSaveOptions_Impl : public utl::ConfigItem
                                         bROAutoSavePrompt,
                                         bRODocInfSave,
                                         bROSaveWorkingSet,
-                                        bROSaveDocWins,
                                         bROSaveDocView,
                                         bROSaveRelINet,
                                         bROSaveRelFSys,
@@ -113,7 +113,6 @@ public:
     BOOL                    IsAutoSavePrompt() const            { return bAutoSavePrompt; }
     BOOL                    IsDocInfoSave() const               { return bDocInfSave; }
     BOOL                    IsSaveWorkingSet() const            { return bSaveWorkingSet;         }
-    BOOL                    IsSaveDocWins() const               { return bSaveDocWins; }
     BOOL                    IsSaveDocView() const               { return bSaveDocView; }
     BOOL                    IsSaveRelINet() const               { return bSaveRelINet; }
     BOOL                    IsSaveRelFSys() const               { return bSaveRelFSys; }
@@ -130,15 +129,14 @@ public:
 #define AUTOSAVE		 4
 #define PROMPT			 5
 #define EDITPROPERTY	 6
-#define SAVEDOCWINS		 7
-#define SAVEVIEWINFO	 8
-#define UNPACKED		 9
-#define PRETTYPRINTING	10
-#define WARNALIENFORMAT 11
-#define LOADDOCPRINTER  12
-#define FILESYSTEM      13
-#define INTERNET        14
-#define SAVEWORKINGSET  15
+#define SAVEVIEWINFO	 7
+#define UNPACKED		 8
+#define PRETTYPRINTING	 9
+#define WARNALIENFORMAT 10
+#define LOADDOCPRINTER  11
+#define FILESYSTEM      12
+#define INTERNET        13
+#define SAVEWORKINGSET  14
 
 Sequence< OUString > GetPropertyNames()
 {
@@ -151,7 +149,6 @@ Sequence< OUString > GetPropertyNames()
         "Document/AutoSave",
         "Document/AutoSavePrompt",
         "Document/EditProperty",
-        "Document/DocumentWindows",
         "Document/ViewInfo",
         "Document/Unpacked",
         "Document/PrettyPrinting",
@@ -174,7 +171,7 @@ Sequence< OUString > GetPropertyNames()
 // -----------------------------------------------------------------------
 
 SvtSaveOptions_Impl::SvtSaveOptions_Impl()
-    : ConfigItem( OUString::createFromAscii("Office.Common/Save") )
+    : ConfigItem( OUString( RTL_CONSTASCII_USTRINGPARAM( "Office.Common/Save" )) )
     , nAutoSaveTime( 0 )
     , bUseUserData( sal_False )
     , bBackup( sal_False )
@@ -182,7 +179,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
     , bAutoSavePrompt( sal_False )
     , bDocInfSave( sal_False )
     , bSaveWorkingSet( sal_False )
-    , bSaveDocWins( sal_False )
     , bSaveDocView( sal_False )
     , bSaveRelINet( sal_False )
     , bSaveRelFSys( sal_False )
@@ -197,7 +193,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
     , bROAutoSavePrompt( CFG_READONLY_DEFAULT )
     , bRODocInfSave( CFG_READONLY_DEFAULT )
     , bROSaveWorkingSet( CFG_READONLY_DEFAULT )
-    , bROSaveDocWins( CFG_READONLY_DEFAULT )
     , bROSaveDocView( CFG_READONLY_DEFAULT )
     , bROSaveRelINet( CFG_READONLY_DEFAULT )
     , bROSaveRelFSys( CFG_READONLY_DEFAULT )
@@ -229,7 +224,7 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
                             nAutoSaveTime = nTemp;
                         else 
                         {
-                            DBG_ERROR( "Wrong Type!" );
+                            OSL_FAIL( "Wrong Type!" );
                         }
                         bROAutoSaveTime = pROStates[nProp];
                         break;
@@ -269,10 +264,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
                                     bSaveWorkingSet = bTemp;
                                     bROSaveWorkingSet = pROStates[nProp];
                                     break;
-                                case SAVEDOCWINS :
-                                    bSaveDocWins = bTemp;
-                                    bROSaveDocWins = pROStates[nProp];
-                                    break;
                                 case SAVEVIEWINFO :
                                     bSaveDocView = bTemp;
                                     bROSaveDocView = pROStates[nProp];
@@ -311,7 +302,7 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
                         }
                         else
                         {
-                            DBG_ERROR( "Wrong Type!" );
+                            OSL_FAIL( "Wrong Type!" );
                         }
                     }
                 }
@@ -323,21 +314,21 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
     {
     css::uno::Reference< css::uno::XInterface > xCFG = ::comphelper::ConfigurationHelper::openConfig(
         ::utl::getProcessServiceFactory(),
-        ::rtl::OUString::createFromAscii("org.openoffice.Office.Recovery"),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "org.openoffice.Office.Recovery" )),
         ::comphelper::ConfigurationHelper::E_READONLY);
 
     ::comphelper::ConfigurationHelper::readRelativeKey(
         xCFG,
-        ::rtl::OUString::createFromAscii("AutoSave"),
-        ::rtl::OUString::createFromAscii("Enabled")) >>= bAutoSave;
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AutoSave" )),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Enabled" ))) >>= bAutoSave;
 
     ::comphelper::ConfigurationHelper::readRelativeKey(
         xCFG,
-        ::rtl::OUString::createFromAscii("AutoSave"),
-        ::rtl::OUString::createFromAscii("TimeIntervall")) >>= nAutoSaveTime;
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AutoSave" )),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "TimeIntervall" ))) >>= nAutoSaveTime;
     }
     catch(const css::uno::Exception&)
-        { DBG_ERROR("Could not find needed informations for AutoSave feature."); }
+        { OSL_FAIL("Could not find needed informations for AutoSave feature."); }
 }
 
 SvtSaveOptions_Impl::~SvtSaveOptions_Impl()
@@ -415,14 +406,6 @@ void SvtSaveOptions_Impl::Commit()
                     ++nRealCount;
                 }
                 break;
-            case SAVEDOCWINS :
-                if (!bROSaveDocWins)
-                {
-                    pValues[nRealCount] <<= bSaveDocWins;
-                    pNames[nRealCount] = pOrgNames[i];
-                    ++nRealCount;
-                }
-                break;
             case SAVEVIEWINFO :
                 if (!bROSaveDocView)
                 {
@@ -493,19 +476,19 @@ void SvtSaveOptions_Impl::Commit()
 
     css::uno::Reference< css::uno::XInterface > xCFG = ::comphelper::ConfigurationHelper::openConfig(
         ::utl::getProcessServiceFactory(),
-        ::rtl::OUString::createFromAscii("org.openoffice.Office.Recovery"),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "org.openoffice.Office.Recovery" )),
         ::comphelper::ConfigurationHelper::E_STANDARD);
 
     ::comphelper::ConfigurationHelper::writeRelativeKey(
         xCFG,
-        ::rtl::OUString::createFromAscii("AutoSave"),
-        ::rtl::OUString::createFromAscii("TimeIntervall"),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AutoSave" )),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "TimeIntervall" )),
         css::uno::makeAny(nAutoSaveTime));
 
     ::comphelper::ConfigurationHelper::writeRelativeKey(
         xCFG,
-        ::rtl::OUString::createFromAscii("AutoSave"),
-        ::rtl::OUString::createFromAscii("Enabled"),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AutoSave" )),
+        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Enabled" )),
         css::uno::makeAny(bAutoSave));
 
     ::comphelper::ConfigurationHelper::flush(xCFG);
@@ -537,7 +520,7 @@ public:
 const sal_Char cUserDefinedSettings[] = "UserDefinedSettings";
 
 SvtLoadOptions_Impl::SvtLoadOptions_Impl()
-    : ConfigItem( OUString::createFromAscii("Office.Common/Load") )
+    : ConfigItem( OUString( RTL_CONSTASCII_USTRINGPARAM( "Office.Common/Load" )) )
     , bLoadUserDefinedSettings( sal_False )
 {
     Sequence< OUString > aNames(1);
