@@ -49,10 +49,6 @@ namespace binfilter
 |*
 |*    operator>>( SvStream&, SgfHeader& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator>>(SvStream& rIStream, SgfHeader& rHead)
 {
@@ -78,10 +74,6 @@ SvStream& operator>>(SvStream& rIStream, SgfHeader& rHead)
 |*
 |*    SgfHeader::ChkMagic()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfHeader::ChkMagic()
 { return Magic=='J'*256+'J'; }
@@ -94,10 +86,6 @@ UINT32 SgfHeader::GetOffset()
 |*
 |*    operator>>( SvStream&, SgfEntry& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator>>(SvStream& rIStream, SgfEntry& rEntr)
 {
@@ -121,10 +109,6 @@ UINT32 SgfEntry::GetOffset()
 |*
 |*    operator>>( SvStream&, SgfVector& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator>>(SvStream& rIStream, SgfVector& rVect)
 {
@@ -144,10 +128,6 @@ SvStream& operator>>(SvStream& rIStream, SgfVector& rVect)
 |*
 |*    operator<<( SvStream&, BmpFileHeader& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator<<(SvStream& rOStream, BmpFileHeader& rHead)
 {
@@ -194,10 +174,6 @@ UINT32 BmpFileHeader::GetOfs()
 |*
 |*    operator<<( SvStream&, BmpInfoHeader& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator<<(SvStream& rOStream, BmpInfoHeader& rInfo)
 {
@@ -236,10 +212,6 @@ SvStream& operator<<(SvStream& rOStream, BmpInfoHeader& rInfo)
 |*
 |*    operator<<( SvStream&, RGBQuad& )
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 SvStream& operator<<(SvStream& rOStream, const RGBQuad& rQuad)
 {
@@ -285,10 +257,6 @@ BYTE PcxExpand::GetByte(SvStream& rInp)
 |*
 |*    SgfFilterBmp()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfFilterBMap(SvStream& rInp, SvStream& rOut, SgfHeader& rHead, SgfEntry&)
 {
@@ -422,10 +390,6 @@ BOOL SgfFilterBMap(SvStream& rInp, SvStream& rOut, SgfHeader& rHead, SgfEntry&)
 |*
 |*    SgfBMapFilter()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfBMapFilter(SvStream& rInp, SvStream& rOut)
 {
@@ -500,10 +464,6 @@ Color Hpgl2SvFarbe( BYTE nFarb )
 |*
 |*    SgfFilterVect()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfFilterVect(SvStream& rInp, SgfHeader& rHead, SgfEntry&, GDIMetaFile& rMtf)
 {
@@ -577,10 +537,6 @@ BOOL SgfFilterVect(SvStream& rInp, SgfHeader& rHead, SgfEntry&, GDIMetaFile& rMt
 |*
 |*    SgfVectFilter()
 |*
-|*    Beschreibung
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
-|*
 *************************************************************************/
 BOOL SgfVectFilter(SvStream& rInp, GDIMetaFile& rMtf)
 {
@@ -616,8 +572,6 @@ BOOL SgfVectFilter(SvStream& rInp, GDIMetaFile& rMtf)
 |*    CheckSgfTyp()
 |*
 |*    Beschreibung      Feststellen, um was fuer ein SGF/SGV es sich handelt.
-|*    Ersterstellung    JOE 23.06.93
-|*    Letzte Aenderung  JOE 23.06.93
 |*
 *************************************************************************/
 BYTE CheckSgfTyp(SvStream& rInp, USHORT& nVersion)
