@@ -738,7 +738,7 @@ UniString INetContentTypes::GetContentType(INetContentType eTypeID)
                               Registration::GetContentType(eTypeID);
     if (aTypeName.Len() == 0)
     {
-        DBG_ERROR("INetContentTypes::GetContentType(): Bad ID");
+        OSL_FAIL("INetContentTypes::GetContentType(): Bad ID");
         return
             UniString::CreateFromAscii(RTL_CONSTASCII_STRINGPARAM(
                                            CONTENT_TYPE_STR_APP_OCTSTREAM));
