@@ -93,12 +93,16 @@ public:
 };
 
 SvxUnoXPropertyTable::SvxUnoXPropertyTable( sal_Int16 nWhich, XPropertyTable* pTable ) throw()
-: mpTable( pTable ), mpList( NULL ), mnWhich( nWhich )
+    : mnWhich( nWhich )
+    , mpList( NULL )
+    , mpTable( pTable )
 {
 }
 
 SvxUnoXPropertyTable::SvxUnoXPropertyTable( sal_Int16 nWhich, XPropertyList* pList ) throw()
-: mpTable( NULL ), mpList( pList ), mnWhich( nWhich )
+    : mnWhich( nWhich )
+    , mpList( pList )
+    , mpTable( NULL )
 {
 }
 
@@ -328,7 +332,7 @@ Any SvxUnoXColorTable::getAny( const XPropertyEntry* pEntry ) const throw()
 
 XPropertyEntry* SvxUnoXColorTable::getEntry( const OUString& rName, const Any& rAny ) const throw()
 {
-    sal_Int32 nColor;
+    sal_Int32 nColor = 0;
     if( !(rAny >>= nColor) )
         return NULL;
 
