@@ -117,11 +117,11 @@ using namespace ::com::sun::star::util;
 
 // gebe den aktuellen zurueck
 
-/*N*/ SwPaM* SwCrsrShell::GetCrsr( FASTBOOL bMakeTblCrsr ) const
+/*N*/ SwPaM* SwCrsrShell::GetCrsr( bool /*bMakeTblCrsr*/ ) const
 /*N*/ {
 /*N*/ 	if( pTblCrsr )
 /*N*/ 	{
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 		if( bMakeTblCrsr && pTblCrsr->IsCrsrMovedUpdt() )
+        DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 	return pCurCrsr;
 /*N*/ }
@@ -148,19 +148,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 		if( bMakeTblCrsr && pTblCrsr->IsC
 
 /*N*/ void SwCrsrShell::EndAction( const BOOL bIdleEnd )
 /*N*/ {
-/*
-//OS: Wird z.B. eine Basic-Action im Hintergrund ausgefuehrt, geht es so nicht
-    if( !bHasFocus )
-    {
-        // hat die Shell nicht den Focus, dann nur das EndAction an
-        // die ViewShell weitergeben.
-        ViewShell::EndAction( bIdleEnd );
-        return;
-    }
-*/
-
-/*N*/ 	FASTBOOL bVis = bSVCrsrVis;
-
+/*N*/ 	bool bVis = bSVCrsrVis;
     // Idle-Formatierung ?
 /*N*/ 	if( bIdleEnd && Imp()->GetRegion() )
 /*N*/ 	{
@@ -209,7 +197,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 		if( bMakeTblCrsr && pTblCrsr->IsC
 /*?*/ 			//				der Cursor geupdatet werden; um z.B. den
 /*?*/ 			//				TabellenCursor zu erzeugen. Im UpdateCrsr wird
 /*?*/ 			//				das jetzt beruecksichtigt!
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANGE, bIdleEnd );
+                DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		return;
 /*N*/ 	}
@@ -243,14 +231,14 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*?*/ 
 /*?*/ void SwCrsrShell::SttCrsrMove()
 /*?*/ {
-/*?*/ 	ASSERT( nCrsrMove < USHRT_MAX, "To many nested CrsrMoves." );
+/*?*/ 	OSL_ENSURE( nCrsrMove < USHRT_MAX, "To many nested CrsrMoves." );
 /*?*/ 	++nCrsrMove;
 /*?*/ 	StartAction();
 /*?*/ }
 /*?*/ 
 /*?*/ void SwCrsrShell::EndCrsrMove( const BOOL bIdleEnd )
 /*?*/ {
-/*?*/ 	ASSERT( nCrsrMove, "EndCrsrMove() ohne SttCrsrMove()." );
+/*?*/ 	OSL_ENSURE( nCrsrMove, "EndCrsrMove() ohne SttCrsrMove()." );
 /*?*/ 	EndAction( bIdleEnd );
 /*?*/ 	if( !--nCrsrMove )
 /*?*/ 		bInCMvVisportChgd = FALSE;
@@ -294,7 +282,6 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 
 /*M*/ 	// erfrage den Count fuer die Start-/End-Actions und ob die Shell
 /*M*/ 	// ueberhaupt den Focus hat
-/*M*/ //	if( ActionPend() /*|| !bHasFocus*/ )
 /*M*/ 	//JP 12.01.98: Bug #46496# - es muss innerhalb einer BasicAction der
 /*M*/ 	//				Cursor geupdatet werden; um z.B. den TabellenCursor zu
 /*M*/ 	//				erzeugen. Im EndAction wird jetzt das UpdateCrsr gerufen!
@@ -324,9 +311,8 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 		  pDoc->IsIdxInTbl( pTstCrsr->GetPoint()->nNode ) &&
 /*M*/ 		  ( pTblCrsr ||
 /*M*/ 			pTstCrsr->GetNode( TRUE )->FindStartNode() !=
-/*M*/ 			pTstCrsr->GetNode( FALSE )->FindStartNode() ))
-/*M*/ 		/*|| ( !pTblCrsr && lcl_IsInValueBox( *pTstCrsr, *this ) )*/ )
-/*M*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*M*/ 			pTstCrsr->GetNode( FALSE )->FindStartNode() )) )
+/*M*/ 	{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 	}
 /*M*/ 
 /*M*/ 	if( pTblCrsr )
@@ -351,7 +337,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 			  pSectNd->GetSection().IsProtectFlag() &&
 /*M*/ 			 ( !pDoc->GetDocShell() ||
 /*M*/ 			   !pDoc->GetDocShell()->IsReadOnly() || bAllProtect )) ) )
-/*M*/ 		{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*M*/ 		{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 		}
 /*M*/ 		if( bChgState )
 /*M*/ 		{
@@ -359,7 +345,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 			bAllProtect = FALSE;
 /*M*/ 			if( bWasAllProtect && GetDoc()->GetDocShell() &&
 /*M*/ 				GetDoc()->GetDocShell()->IsReadOnlyUI() )
-/*M*/ 			{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*M*/ 			{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 			}
 /*M*/ 		}
 /*M*/ 	}
@@ -402,7 +388,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 
 /*M*/ 
 /*M*/ 	SwRect aOld( aCharRect );
-/*M*/ 	FASTBOOL bFirst = TRUE;
+/*M*/ 	bool bFirst = TRUE;
 /*M*/ 	SwCntntFrm *pFrm;
 /*M*/ 	int nLoopCnt = 100;
 /*M*/ 
@@ -425,7 +411,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 			}
 /*M*/ 			else if ( Imp()->IsIdleAction() )
 /*M*/ 				//Wir stellen sicher, dass anstaendig Formatiert wurde #42224#
-/*?*/ 				{DBG_BF_ASSERT(0, "STRIP"); }//STRIP001 pFrm->PrepareCrsr();
+/*?*/ 				{DBG_BF_ASSERT(0, "STRIP"); }
 /*M*/ 
 /*M*/ 			// im geschuetzten Fly? aber bei Rahmenselektion ignorieren
 /*M*/ 			if( !IsReadOnlyAvailable() && pFrm->IsProtected() &&
@@ -433,7 +419,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 				  !Imp()->GetDrawView()->GetMarkList().GetMarkCount() ) &&
 /*M*/ 				(!pDoc->GetDocShell() ||
 /*M*/ 				 !pDoc->GetDocShell()->IsReadOnly() || bAllProtect ) )
-/*M*/ 			{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*M*/ 			{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 			}
 /*M*/ 		} while( bAgainst );
 /*M*/ 
@@ -451,7 +437,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*N*/ 				pFrm->GetCrsrOfst( pCurCrsr->GetPoint(), rPt, &aTmpState );
 /*N*/ #ifndef VERTICAL_LAYOUT
 /*N*/                 if ( !pFrm->GetCharRect(aCharRect, *pCurCrsr->GetPoint(), &aTmpState) )
-/*N*/ 					ASSERT( !this, "GetCharRect failed." );
+/*N*/ 					OSL_ENSURE( !this, "GetCharRect failed." );
 /*N*/ #endif
 /*M*/ 			}
 /*M*/ //			ALIGNRECT( aCharRect );
@@ -479,7 +465,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 		// siehe Bug: 29658
 /*M*/ 		if( !--nLoopCnt )
 /*M*/ 		{
-/*M*/ 			ASSERT( !this, "Endlosschleife? CharRect != OldCharRect ");
+/*M*/ 			OSL_ENSURE( !this, "Endlosschleife? CharRect != OldCharRect ");
 /*M*/ 			break;
 /*M*/ 		}
 /*M*/ 		aOld = aCharRect;
@@ -523,7 +509,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 	//Nur wenn gescrollt wurde, und wenn keine Selektion existiert.
 /*M*/ 	if( pFrm && Imp()->IsScrolled() &&
 /*M*/ 			pCurCrsr->GetNext() == pCurCrsr && !pCurCrsr->HasMark() )
-/*?*/ 		{DBG_BF_ASSERT(0, "STRIP"); }//STRIP001 Imp()->RefreshScrolledArea( aCharRect );
+/*?*/ 		{DBG_BF_ASSERT(0, "STRIP"); }
 /*M*/ 
 /*M*/ 
 /*M*/ 	eMvState = MV_NONE;		// Status fuers Crsr-Travelling - GetCrsrOfst
@@ -557,12 +543,8 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*M*/ 		pVisCrsr->Show();           // wieder anzeigen
 /*M*/ }
 
-
-
 // erzeuge eine Kopie vom Cursor und speicher diese im Stack
 
-
-
 /*
  *  Loescht einen Cursor (gesteuert durch bOldCrsr)
  *      - vom Stack oder    ( bOldCrsr = TRUE )
@@ -572,18 +554,12 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
  */
 
 
-
 /*
  * Verbinde zwei Cursor miteinander.
  * Loesche vom Stack den obersten und setzen dessen GetMark im Aktuellen.
  */
 
 
-
-
-
-
-
 /*N*/ void SwCrsrShell::ShowCrsrs( BOOL bCrsrVis )
 /*N*/ {
 /*N*/ 	if( !bHasFocus || bAllProtect || bBasicHideCrsr )
@@ -630,7 +606,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*N*/ {
 /*N*/ 	USHORT nWhich = pOld ? pOld->Which()
 /*N*/ 						 : pNew ? pNew->Which()
-/*N*/ 						 		: RES_MSG_BEGIN;
+/*N*/ 						 		: sal::static_int_cast<USHORT>(RES_MSG_BEGIN);
 /*N*/ 	if( bCallChgLnk &&
 /*N*/ 		( nWhich < RES_MSG_BEGIN || nWhich >= RES_MSG_END ||
 /*N*/ 			nWhich == RES_FMT_CHG || nWhich == RES_UPDATE_ATTR ||
@@ -651,7 +627,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 // also, ob GetMark gesetzt und SPoint und GetMark unterschiedlich sind.
 
 
-/*N*/ FASTBOOL SwCrsrShell::HasSelection() const
+/*N*/ bool SwCrsrShell::HasSelection() const
 /*N*/ {
 /*N*/ 	SwPaM* pCrsr = IsTableMode() ? pTblCrsr : pCurCrsr;
 /*N*/ 	return( IsTableMode() || ( pCurCrsr->HasMark() &&
@@ -728,7 +704,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 // zeige das akt. selektierte "Object" an
 /*N*/ void SwCrsrShell::MakeSelVisible()
 /*N*/ {
-/*N*/ 	ASSERT( bHasFocus, "kein Focus aber Cursor sichtbar machen?" );
+/*N*/ 	OSL_ENSURE( bHasFocus, "kein Focus aber Cursor sichtbar machen?" );
 /*N*/ 	if( aCrsrHeight.Y() < aCharRect.Height() && aCharRect.Height() > VisArea().Height() )
 /*N*/ 	{
 /*N*/ 		SwRect aTmp( aCharRect );
@@ -766,7 +742,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 
 
 
-/*N*/ FASTBOOL SwCrsrShell::IsCrsrReadonly() const
+/*N*/ bool SwCrsrShell::IsCrsrReadonly() const
 /*N*/ {
 /*N*/ 	if ( GetViewOptions()->IsReadonly() )
 /*N*/ 	{
@@ -786,7 +762,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*N*/ }
 
 // SwCursor - Methode !!!!
-/*N*/ FASTBOOL SwCursor::IsReadOnlyAvailable() const
+/*N*/ bool SwCursor::IsReadOnlyAvailable() const
 /*N*/ {
 /*N*/ 	const SwShellCrsr* pShCrsr = *this;
 /*N*/ 	const SwUnoCrsr* pUnoCrsr = *this;
@@ -797,9 +773,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 
 #if defined(DBG_UTIL) || defined(WIN)
 
-
-
-/*N*/ SwCursor* SwCrsrShell::GetSwCrsr( FASTBOOL bMakeTblCrsr ) const
+/*N*/ SwCursor* SwCrsrShell::GetSwCrsr( bool bMakeTblCrsr ) const
 /*N*/ {
 /*N*/ 	return (SwCursor*)GetCrsr( bMakeTblCrsr );
 /*N*/ }
@@ -814,13 +788,13 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 // Abfrage, ob ueberhaupt eine Selektion existiert, sprich der akt. Cursor
 // aufgespannt oder nicht der einzigste ist.
 
-/*N*/ FASTBOOL SwCrsrShell::IsSelection() const
+/*N*/ bool SwCrsrShell::IsSelection() const
 /*N*/ {
 /*N*/ 	return IsTableMode() || pCurCrsr->HasMark() ||
 /*N*/ 			pCurCrsr->GetNext() != pCurCrsr;
 /*N*/ }
 // returns if multiple cursors are available
-/*N*/ FASTBOOL SwCrsrShell::IsMultiSelection() const
+/*N*/ bool SwCrsrShell::IsMultiSelection() const
 /*N*/ {
 /*N*/     return pCurCrsr->GetNext() != pCurCrsr;
 /*N*/ }        
@@ -832,7 +806,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*N*/ }
 
 
-/*?*/ FASTBOOL SwCrsrShell::IsCrsrPtAtEnd() const
+/*?*/ bool SwCrsrShell::IsCrsrPtAtEnd() const
 /*?*/ {
 /*?*/ 	return pCurCrsr->End() == pCurCrsr->GetPoint();
 /*?*/ }
@@ -851,7 +825,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*?*/ }
 
 
-/*?*/ FASTBOOL SwCrsrShell::IsSelOnePara() const
+/*?*/ bool SwCrsrShell::IsSelOnePara() const
 /*?*/ {
 /*?*/ 	return pCurCrsr == pCurCrsr->GetNext() &&
 /*?*/ 		   pCurCrsr->GetPoint()->nNode ==
@@ -861,7 +835,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*?*/ SwMoveFnCollection* SwCrsrShell::MakeFindRange(
 /*?*/ 							USHORT nStt, USHORT nEnd, SwPaM* pPam ) const
 /*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return NULL;//STRIP001 	return pCurCrsr->MakeFindRange( (SwDocPositions)nStt,
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return NULL;
 /*?*/ }
 #endif
 
@@ -936,7 +910,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
 /*?*/         SwNode * pNode = aNodes.GoNext(&aIdx);
 /*?*/         bool bFound = (pNode != NULL);
 /*?*/ 
-/*?*/         ASSERT(bFound, "no content node found");
+/*?*/         OSL_ENSURE(bFound, "no content node found");
 /*?*/ 
 /*?*/         if (bFound)
 /*?*/         {
@@ -952,7 +926,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001  /*?*/ 			UpdateCrsr( SwCrsrShell::CHKRANG
       replaced, remove the table cursor.
     */
 /*N*/     if (pTblCrsr != NULL && bChanged)
-/*?*/         {DBG_BF_ASSERT(0, "STRIP"); }//STRIP001 TblCrsrToCursor();
+/*?*/         {DBG_BF_ASSERT(0, "STRIP"); }
 /*N*/ }
 
 }
