@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -189,7 +189,7 @@ namespace binfilter {
 /*N*/
 /*N*/ 		if( IsRedlineOn() || (!IsIgnoreRedline() && pRedlineTbl->Count() ))
 /*N*/ 		{
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwPaM aPam( rPos );
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 	}
 /*N*/
@@ -218,7 +218,7 @@ namespace binfilter {
 /*N*/
 /*N*/ 	if( IsRedlineOn() || (!IsIgnoreRedline() && pRedlineTbl->Count() ))
 /*N*/ 	{
-/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwPaM aPam( rPos );
+/*?*/ 		DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/
 /*N*/ 	SetModified();
@@ -241,7 +241,7 @@ namespace binfilter {
 /*N*/
 /*N*/ 	if( IsRedlineOn() || (!IsIgnoreRedline() && pRedlineTbl->Count() ))
 /*N*/ 	{
-/*?*/ 		DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwPaM aPam( pPos->nNode, aTmp.GetCntnt(),
+/*?*/ 		DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/
 /*N*/ 	SetModified();
@@ -302,7 +302,7 @@ namespace binfilter {
 /*N*/ 	{
 /*N*/ 		USHORT nId = RES_POOLFRM_OLE;
 /*N*/
-/*N*/ 		FASTBOOL bMath = SmModuleDummy::HasID( *pObj->GetSvFactory() );
+/*N*/ 		bool bMath = SmModuleDummy::HasID( *pObj->GetSvFactory() );
 /*N*/         if ( bMath )
 /*?*/ 			nId = RES_POOLFRM_FORMEL;
 /*N*/
@@ -487,9 +487,9 @@ void SwDoc::SetGlobalMacro( USHORT nEvent, const SvxMacro& rMacro )
     //JP 24.06.96: Ist der ArrayPointer 0 dann returne nur, ob im Doc. eine
     //				RefMark gesetzt ist
     // OS 25.06.96: ab jetzt wird immer die Anzahl der Referenzen returnt
-/*N*/ USHORT SwDoc::GetRefMarks( SvStringsDtor* pNames ) const
+/*N*/ USHORT SwDoc::GetRefMarks( SvStringsDtor* /*pNames*/ ) const
 /*N*/ {
-/*N*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 	const SfxPoolItem* pItem;
+/*N*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*N*/ }
 
 /*N*/ void SwDoc::SetModified()
@@ -524,11 +524,11 @@ void SwDoc::SetGlobalMacro( USHORT nEvent, const SvxMacro& rMacro )
 /*N*/ }
 
 
-/*N*/ void SwDoc::ReRead( SwPaM& rPam, const String& rGrfName,
-/*N*/ 					const String& rFltName, const Graphic* pGraphic,
-/*N*/ 					const BfGraphicObject* pGrafObj )
+/*N*/ void SwDoc::ReRead( SwPaM& /*rPam*/, const String& /*rGrfName*/,
+/*N*/ 					const String& /*rFltName*/, const Graphic* /*pGraphic*/,
+/*N*/ 					const BfGraphicObject* /*pGrafObj*/ )
 /*N*/ {
-DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	SwGrfNode *pGrfNd;
+DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 /*--------------------------------------------------------------------
