@@ -71,7 +71,7 @@
 #include <txtinet.hxx>
 #include <fmtinfmt.hxx>
 #include <SwStyleNameMapper.hxx>
-#include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002
+#include <legacysmgr/legacy_binfilters_smgr.hxx>
 namespace binfilter {
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::lang;
@@ -164,7 +164,7 @@ struct ParaRstFmt
 /*N*/ 							0 );
 /*N*/ 		SwAttrSet* pSet = pNode->GetpSwAttrSet();
 /*N*/
-/*N*/ 		USHORT __READONLY_DATA aSavIds[ 3 ] = { RES_PAGEDESC, RES_BREAK,
+/*N*/ 		USHORT const aSavIds[ 3 ] = { RES_PAGEDESC, RES_BREAK,
 /*N*/ 												RES_PARATR_NUMRULE };
 /*N*/
 /*N*/ 		const SfxPoolItem* pItem;
@@ -233,7 +233,6 @@ struct ParaRstFmt
 /*M*/ 						const SvUShortsSort* pAttrs )
 /*M*/ {
 /*M*/ 	SwPaM* pPam = (SwPaM*)&rRg;
-/*M*/ 	BOOL bStopAttr = FALSE;
 /*M*/ 	if( !bTxtAttr && pAttrs && pAttrs->Count() &&
 /*M*/ 		RES_TXTATR_END > (*pAttrs)[ 0 ] )
 /*M*/ 		bTxtAttr = TRUE;
@@ -248,7 +247,7 @@ struct ParaRstFmt
 /*M*/
 /*M*/ 		SwIndex& rSt = pPam->GetPoint()->nContent;
 /*M*/ 		USHORT nMkPos = 0, nPtPos = rSt.GetIndex();
-/*M*/ 		const String& rStr = pTxtNd->GetTxt();
+/*M*/ 		pTxtNd->GetTxt();
 /*M*/
 /*M*/ 		// JP 22.08.96: Sonderfall: steht der Crsr in einem URL-Attribut
 /*M*/ 		//				dann wird dessen Bereich genommen
@@ -261,7 +260,7 @@ struct ParaRstFmt
 /*M*/ 			nPtPos = *pURLAttr->GetEnd();
 /*M*/ 		}
 /*M*/ 		else
-/*M*/ 		{DBG_BF_ASSERT(0, "STRIP"); //STRIP001
+/*M*/ 		{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 		}
 /*M*/
 /*M*/ 		rSt = nMkPos;
@@ -274,7 +273,7 @@ struct ParaRstFmt
 /*M*/ 	const SwPosition *pStt = pPam->Start(), *pEnd = pPam->End();
 /*M*/   ParaRstFmt aPara( pStt, pEnd );
 /*M*/
-/*N*/     USHORT __FAR_DATA aResetableSetRange[] = {
+/*N*/     USHORT aResetableSetRange[] = {
 /*N*/         RES_FRMATR_BEGIN, RES_FRMATR_END-1,
 /*N*/         RES_CHRATR_BEGIN, RES_CHRATR_END-1,
 /*N*/         RES_PARATR_BEGIN, RES_PARATR_END-1,
@@ -300,7 +299,7 @@ struct ParaRstFmt
 /*M*/ 	SwNodeIndex aTmpStt( pStt->nNode );
 /*M*/ 	SwNodeIndex aTmpEnd( pEnd->nNode );
 /*M*/ 	if( pStt->nContent.GetIndex() )		// nur ein Teil
-/*M*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001
+/*M*/ 	{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 	}
 /*M*/ 	if( pEnd->nContent.GetIndex() == pEnd->nNode.GetNode().GetCntntNode()->Len() )
 /*M*/ 		// dann spaeter aufsetzen und alle CharFmtAttr -> TxtFmtAttr
@@ -398,7 +397,7 @@ struct ParaRstFmt
 /*N*/ 				if( pDoc->IsRedlineOn() || (!pDoc->IsIgnoreRedline() &&
 /*N*/ 					pDoc->GetRedlineTbl().Count() ))
 /*N*/ 				{
-/*?*/ 					DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwPaM aPam( pStt->nNode, pStt->nContent.GetIndex()-1,
+/*?*/ 					DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 				}
 /*N*/ 			}
 /*N*/ 		}
@@ -425,7 +424,7 @@ struct ParaRstFmt
 /*N*/ 				if( pDoc->IsRedlineOn() || (!pDoc->IsIgnoreRedline() &&
 /*N*/ 					 pDoc->GetRedlineTbl().Count() ) )
 /*N*/ 				{
-/*?*/ 					DBG_BF_ASSERT(0, "STRIP"); //STRIP001 // wurde Text-Inhalt eingefuegt? (RefMark/TOXMarks ohne Ende)
+/*?*/ 					DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 				}
 /*N*/ 			}
 /*N*/ 		}
@@ -507,7 +506,7 @@ struct ParaRstFmt
 /*N*/
 /*N*/ 		if( pNode->IsTxtNode() && aCharSet.Count() )
 /*N*/ 		{
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 SwTxtNode* pTxtNd = (SwTxtNode*)pNode;
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		if( aOtherSet.Count() )
 /*N*/ 		{
@@ -519,7 +518,7 @@ struct ParaRstFmt
 /*N*/
 /*N*/ 	if( pDoc->IsRedlineOn() && aCharSet.Count() )
 /*N*/ 	{
-/*?*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	if( pUndo )
+/*?*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 
     /* jetzt wenn Bereich */
@@ -604,11 +603,10 @@ struct ParaRstFmt
 /*N*/ 	const SfxPoolItem* pChrFmtItem = 0;
 /*N*/ 	aCharSet.GetItemState( RES_TXTATR_CHARFMT, FALSE, &pChrFmtItem );
 /*N*/ #endif
-/*N*/ 	BOOL bCreateSwpHints =
 /*N*/ 		SFX_ITEM_SET == aCharSet.GetItemState( RES_TXTATR_CHARFMT, FALSE ) ||
 /*N*/ 		SFX_ITEM_SET == aCharSet.GetItemState( RES_TXTATR_INETFMT, FALSE );
 /*N*/
-/*N*/ 	for(; aSt < aEnd; aSt++ )
+/*N*/ 	for(; aSt < aEnd; ++aSt )
 /*N*/ 	{
 /*N*/ 		pNode = aSt.GetNode().GetCntntNode();
 /*N*/ 		if( !pNode )
@@ -637,29 +635,6 @@ struct ParaRstFmt
 /*N*/ 	aSet.Put( rHt );
 /*N*/   bRet = InsAttr( this, rRg, aSet, nFlags );
 
-/*	if( INSATTR_DONTEXPAND & nFlags )
-    {
-        USHORT nWhich = rHt.Which();
-        const SwPosition* pPos = rRg.End();
-        SwTxtNode* pTxtNd = GetNodes()[ pPos->nNode ]->GetTxtNode();
-        SwpHints* pHts;
-        if( pTxtNd && 0 != ( pHts = pTxtNd->GetpSwpHints()) )
-        {
-            USHORT nPos = pHts->GetEndCount();
-            while( nPos )
-            {
-                SwTxtAttr *pTmp = pHts->GetEnd( --nPos );
-                USHORT *pEnd = pTmp->GetEnd();
-                if( !pEnd || *pEnd > nEnd )
-                    continue;
-                if( nEnd != *pEnd )
-                    nPos = 0;
-                else if( nWhich == pTmp->Which() )
-                    pTmp->SetDontExpand( TRUE );
-            }
-        }
-    }
-*/
 /*N*/ 	if( bRet )
 /*N*/ 		SetModified();
 /*N*/ 	return bRet;
@@ -859,7 +834,7 @@ void SwDoc::DelCharFmt(USHORT nFmt)
 void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 {
     USHORT nFmt = pCharFmtTbl->GetPos( pFmt );
-    ASSERT( USHRT_MAX != nFmt, "Fmt not found," );
+    OSL_ENSURE( USHRT_MAX != nFmt, "Fmt not found," );
     DelCharFmt( nFmt );
 }
 
@@ -867,7 +842,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*N*/ {
 /*N*/ 	if( pFmt->ISA( SwTableBoxFmt ) || pFmt->ISA( SwTableLineFmt ))
 /*N*/ 	{
-/*?*/ 		ASSERT( !this, "Format steht nicht mehr im DocArray, "
+/*?*/ 		OSL_ENSURE( !this, "Format steht nicht mehr im DocArray, "
 /*?*/ 					   "kann per delete geloescht werden" );
 /*?*/ 		delete pFmt;
 /*N*/ 	}
@@ -881,7 +856,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*N*/ 		else
 /*N*/ 		{
 /*N*/ 			nPos = GetSpzFrmFmts()->GetPos( pFmt );
-/*N*/ 			ASSERT( nPos != USHRT_MAX, "FrmFmt not found." );
+/*N*/ 			OSL_ENSURE( nPos != USHRT_MAX, "FrmFmt not found." );
 /*N*/ 			if( USHRT_MAX != nPos )
 /*N*/ 				GetSpzFrmFmts()->DeleteAndDestroy( nPos );
 /*N*/ 		}
@@ -891,7 +866,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*N*/ void SwDoc::DelTblFrmFmt( SwTableFmt *pFmt )
 /*N*/ {
 /*N*/ 	USHORT nPos = pTblFrmFmtTbl->GetPos( pFmt );
-/*N*/ 	ASSERT( USHRT_MAX != nPos, "Fmt not found," );
+/*N*/ 	OSL_ENSURE( USHRT_MAX != nPos, "Fmt not found," );
 /*N*/ 	pTblFrmFmtTbl->DeleteAndDestroy( nPos );
 /*N*/ }
 
@@ -917,9 +892,9 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*N*/ }
 
 
-/*N*/ USHORT SwDoc::GetTblFrmFmtCount(BOOL bUsed) const
+/*N*/ USHORT SwDoc::GetTblFrmFmtCount(BOOL /*bUsed*/) const
 /*N*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;//STRIP001 	USHORT nCount = pTblFrmFmtTbl->Count();
+/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
 /*N*/ }
 
 
@@ -1134,7 +1109,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 //FEATURE::CONDCOLL
 /*?*/ 	if( RES_CONDTXTFMTCOLL == rColl.Which() )
 /*?*/ 	{
-/*?*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	pNewColl = new SwConditionTxtFmtColl( GetAttrPool(), rColl.GetName(),
+/*?*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*?*/ 	}
 /*?*/ 	else
 /*?*/ //FEATURE::CONDCOLL
@@ -1194,7 +1169,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*?*/ 		pParent = CopyGrfColl( *(SwGrfFmtColl*)rColl.DerivedFrom() );
 /*?*/
 /*?*/ 	// falls nicht, so kopiere sie
-/*?*/ 	DBG_BF_ASSERT(0, "STRIP"); //STRIP001 pNewColl = MakeGrfFmtColl( rColl.GetName(), pParent );
+/*?*/ 	DBG_BF_ASSERT(0, "STRIP");
 /*?*/
 /*?*/ 	// noch die Attribute kopieren
 /*?*/ 	pNewColl->CopyAttrs( rColl );
@@ -1247,7 +1222,7 @@ void SwDoc::DelCharFmt( SwCharFmt *pFmt )
 /*N*/ {
 /*N*/ 	RTL_LOGFILE_CONTEXT_AUTHOR( aLog, "SW", "JP93722",  "SwDoc::_CreateNumberFormatter" );
 /*N*/
-/*N*/ 	ASSERT( !pNumberFormatter, "ist doch schon vorhanden" );
+/*N*/ 	OSL_ENSURE( !pNumberFormatter, "ist doch schon vorhanden" );
 /*N*/
 /*N*/
 /*N*/ 	LanguageType eLang = LANGUAGE_SYSTEM; //System::GetLanguage();
