@@ -62,10 +62,8 @@
 #include <editsh.hxx>
 #include <docary.hxx>
 
-// #108784#
 #include <bf_svx/xoutx.hxx>
 
-// OD 18.06.2003 #108784#
 #include <algorithm>
 namespace binfilter {
 
@@ -174,9 +172,6 @@ namespace binfilter {
 |*
 |*	SwContact, Ctor und Dtor
 |*
-|*	Ersterstellung		AMA 27.Sep.96 18:13
-|*	Letzte Aenderung	AMA 27.Sep.96
-|*
 |*************************************************************************/
 
 /*N*/ SwContact::SwContact( SwFrmFmt *pToRegisterIn, SdrObject *pObj ) :
@@ -197,8 +192,7 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ }
 
-// OD 13.05.2003 #108784# - copied inline-implementation of <GetMaster()> and
-// <SetMaster()>
+// copied inline-implementation of <GetMaster()> and <SetMaster()>
 /*N*/ const SdrObject* SwContact::GetMaster() const
 /*N*/ {
 /*N*/     return pMasterObj;
@@ -216,12 +210,9 @@ namespace binfilter {
 |*
 |*	SwFlyDrawContact, Ctor und Dtor
 |*
-|*	Ersterstellung		OK 23.11.94 18:13
-|*	Letzte Aenderung	MA 06. Apr. 95
-|*
 |*************************************************************************/
 
-/*N*/ SwFlyDrawContact::SwFlyDrawContact( SwFlyFrmFmt *pToRegisterIn, SdrModel *pMod ) :
+/*N*/ SwFlyDrawContact::SwFlyDrawContact( SwFlyFrmFmt *pToRegisterIn, SdrModel* /*pMod*/ ) :
 /*N*/ 	SwContact( pToRegisterIn )
 /*N*/ {
 /*N*/ 	SetMaster( new SwFlyDrawObj() );
@@ -233,9 +224,6 @@ namespace binfilter {
 |*
 |*	SwFlyDrawContact::CreateNewRef()
 |*
-|*	Ersterstellung		MA 14. Dec. 94
-|*	Letzte Aenderung	MA 24. Apr. 95
-|*
 |*************************************************************************/
 
 /*N*/ SwVirtFlyDrawObj *SwFlyDrawContact::CreateNewRef( SwFlyFrm *pFly )
@@ -261,12 +249,9 @@ namespace binfilter {
 |*
 |*	SwFlyDrawContact::Modify()
 |*
-|*	Ersterstellung		OK 08.11.94 10:21
-|*	Letzte Aenderung	MA 06. Dec. 94
-|*
 |*************************************************************************/
 
-/*N*/ void SwFlyDrawContact::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
+/*N*/ void SwFlyDrawContact::Modify( SfxPoolItem* /*pOld*/, SfxPoolItem* /*pNew*/ )
 /*N*/ {
 /*N*/ }
 
@@ -274,9 +259,6 @@ namespace binfilter {
 |*
 |*	SwDrawContact, Ctor+Dtor
 |*
-|*	Ersterstellung		MA 09. Jan. 95
-|*	Letzte Aenderung	MA 22. Jul. 98
-|*
 |*************************************************************************/
 /*N*/ bool CheckControlLayer( const SdrObject *pObj )
 /*N*/ {
@@ -304,7 +286,7 @@ namespace binfilter {
 /*N*/ 	//Gruppenobjekte, wenn diese Controls enthalten.
 /*N*/     if ( ::binfilter::CheckControlLayer( pObj ) )
 /*N*/     {
-/*N*/         // OD 25.06.2003 #108784# - set layer of object to corresponding invisible layer.
+/*N*/         // set layer of object to corresponding invisible layer.
 /*N*/         pObj->SetLayer( pToRegisterIn->GetDoc()->GetInvisibleControlsId() );
 /*N*/     }
 /*N*/ }
@@ -313,14 +295,14 @@ namespace binfilter {
 /*N*/ {
 /*N*/     DisconnectFromLayout();
 /*N*/ 
-/*N*/     // OD 25.06.2003 #108784# - remove 'master' from drawing page
+/*N*/     // remove 'master' from drawing page
 /*N*/     RemoveMasterFromDrawPage();
 /*N*/ 
 /*N*/     // remove and destroy 'virtual' drawing objects.
 /*N*/     RemoveAllVirtObjs();
 /*N*/ }
 
-// OD 23.06.2003 #108784# - method to create a new 'virtual' drawing object.
+// method to create a new 'virtual' drawing object.
 /*N*/ SwDrawVirtObj* SwDrawContact::CreateVirtObj()
 /*N*/ {
 /*N*/     // determine 'master'
@@ -335,7 +317,7 @@ namespace binfilter {
 /*N*/     return pNewDrawVirtObj;
 /*N*/ }
 
-// OD 23.06.2003 #108784# - destroys a given 'virtual' drawing object.
+// destroys a given 'virtual' drawing object.
 // side effect: 'virtual' drawing object is removed from data structure
 //              <maDrawVirtObjs>.
 /*N*/ void SwDrawContact::DestroyVirtObj( SwDrawVirtObj* _pVirtObj )
@@ -347,7 +329,7 @@ namespace binfilter {
 /*N*/     }
 /*N*/ }
 
-// OD 16.05.2003 #108784# - add a 'virtual' drawing object to drawing page.
+// add a 'virtual' drawing object to drawing page.
 // Use an already created one, which isn't used, or create a new one.
 /*N*/ SwDrawVirtObj* SwDrawContact::AddVirtObj()
 /*N*/ {
@@ -373,7 +355,7 @@ namespace binfilter {
 /*N*/     return pAddedDrawVirtObj;
 /*N*/ }
 
-// OD 16.05.2003 #108784# - remove 'virtual' drawing objects and destroy them.
+// remove 'virtual' drawing objects and destroy them.
 /*N*/ void SwDrawContact::RemoveAllVirtObjs()
 /*N*/ {
 /*N*/     for ( std::list<SwDrawVirtObj*>::iterator aDrawVirtObjsIter = maDrawVirtObjs.begin();
@@ -389,20 +371,20 @@ namespace binfilter {
 /*N*/     maDrawVirtObjs.clear();
 /*N*/ }
 
-// OD 16.05.2003 #108784# - overload <SwContact::SetMaster(..)> in order to
+// overload <SwContact::SetMaster(..)> in order to
 // assert, if the 'master' drawing object is replaced.
-// OD 10.07.2003 #110742# - replace of master object correctly handled, if
+// replace of master object correctly handled, if
 // handled by method <SwDrawContact::ChangeMasterObject(..)>. Thus, assert
 // only, if a debug level is given.
 /*N*/ void SwDrawContact::SetMaster( SdrObject* pNew )
 /*N*/ {
 /*N*/ #if OSL_DEBUG_LEVEL > 1
-/*N*/     ASSERT( !pNew, "debug notification - master replaced!" );
+/*N*/     OSL_ENSURE( !pNew, "debug notification - master replaced!" );
 /*N*/ #endif
 /*N*/     SwContact::SetMaster( pNew );
 /*N*/ }
 
-// OD 19.06.2003 #108784# - get drawing object ('master' or 'virtual') by frame.
+// get drawing object ('master' or 'virtual') by frame.
 /*N*/ SdrObject* SwDrawContact::GetDrawObjectByAnchorFrm( const SwFrm& _rAnchorFrm )
 /*N*/ {
 /*N*/     SdrObject* pRetDrawObj = 0L;
@@ -430,9 +412,6 @@ namespace binfilter {
 |*
 |*	SwDrawContact::Changed
 |*
-|*	Ersterstellung		MA 09. Jan. 95
-|*	Letzte Aenderung	MA 29. May. 96
-|*
 |*************************************************************************/
 
 /*N*/ void lcl_Notify( SwDrawContact* pThis, const Rectangle* pOldBoundRect )
@@ -441,7 +420,7 @@ namespace binfilter {
 /*N*/ 	if( pAnch )
 /*N*/ 	{
 /*N*/ 		SwPageFrm *pPage = pAnch->FindPageFrm();
-/*N*/ 		ASSERT( GetUserCall(pThis->GetMaster()) == pThis, "Wrong Master" );
+/*N*/ 		OSL_ENSURE( GetUserCall(pThis->GetMaster()) == pThis, "Wrong Master" );
 /*N*/ 		if( pOldBoundRect && pPage )
 /*N*/ 		{
 /*N*/ 			SwRect aOldRect( *pOldBoundRect );
@@ -459,12 +438,11 @@ namespace binfilter {
 /*N*/ 		}
 /*N*/ 		ClrContourCache( pThis->GetMaster() );
 /*N*/ 
-/*N*/         // OD 03.07.2003 #108784# - notify background of all 'virtual' drawing objects
+/*N*/         // snotify background of all 'virtual' drawing objects
 /*N*/         pThis->NotifyBackgrdOfAllVirtObjs( pOldBoundRect );
 /*N*/ 	}
 /*N*/ }
 
-// OD 03.07.2003 #108784#
 /*N*/ void SwDrawContact::NotifyBackgrdOfAllVirtObjs( const Rectangle* pOldBoundRect )
 /*N*/ {
 /*N*/     for ( std::list<SwDrawVirtObj*>::iterator aDrawVirtObjIter = maDrawVirtObjs.begin();
@@ -536,7 +514,7 @@ namespace binfilter {
 /*N*/                               const Rectangle* pOldBoundRect )
 /*N*/ {
 /*N*/ 	BOOL bInCntnt = FLY_IN_CNTNT == GetFmt()->GetAnchor().GetAnchorId();
-/*N*/     /// OD 05.08.2002 #100843# - do *not* notify, if document is destructing
+/*N*/     /// do *not* notify, if document is destructing
 /*N*/     BOOL bNotify = !bInCntnt &&
 /*N*/                    !(GetFmt()->GetDoc()->IsInDtor()) &&
 /*N*/                    ( SURROUND_THROUGHT != GetFmt()->GetSurround().GetSurround() );
@@ -623,12 +601,9 @@ namespace binfilter {
 |*
 |*	SwDrawContact::Modify()
 |*
-|*	Ersterstellung		MA 09. Jan. 95
-|*	Letzte Aenderung	MA 03. Dec. 95
-|*
 |*************************************************************************/
 
-/*N*/ void SwDrawContact::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
+/*N*/ void SwDrawContact::Modify( SfxPoolItem* /*pOld*/, SfxPoolItem* pNew )
 /*N*/ {
 /*N*/ 	//Es kommen immer Sets herein.
 /*N*/ 	//MA 03. Dec. 95: Falsch es kommen nicht immer Sets herein
@@ -705,15 +680,11 @@ namespace binfilter {
 |*
 |*	SwDrawContact::DisconnectFromLayout()
 |*
-|*	Ersterstellung		MA 09. Jan. 95
-|*	Letzte Aenderung	MA 25. Mar. 99
-|*
 |*************************************************************************/
 
 void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
 {
-    // OD 16.05.2003 #108784# - remove 'virtual' drawing objects from writer
-    // layout and from drawing page
+    // remove 'virtual' drawing objects from writer layout and from drawing page
     for ( std::list<SwDrawVirtObj*>::iterator aDisconnectIter = maDrawVirtObjs.begin();
           aDisconnectIter != maDrawVirtObjs.end();
           ++aDisconnectIter )
@@ -737,9 +708,8 @@ void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
             pView->MarkObj( GetMaster(), pView->GetPageViewPvNum(0), TRUE );
         }
 
-        // OD 25.06.2003 #108784# - Instead of removing 'master' object from
-        // drawing page, move the 'master' drawing object into the corresponding
-        // invisible layer.
+        // Instead of removing 'master' object from drawing page, move
+        // the 'master' drawing object into the corresponding invisible layer.
         {
             //((SwFrmFmt*)pRegisteredIn)->GetDoc()->GetDrawModel()->GetPage(0)->
             //                            RemoveObject( GetMaster()->GetOrdNum() );
@@ -754,8 +724,7 @@ void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
     }
 }
 
-// OD 26.06.2003 #108784# - method to remove 'master' drawing object
-// from drawing page.
+// method to remove 'master' drawing object from drawing page.
 void SwDrawContact::RemoveMasterFromDrawPage()
 {
     if ( GetMaster() )
@@ -769,8 +738,7 @@ void SwDrawContact::RemoveMasterFromDrawPage()
     }
 }
 
-// OD 19.06.2003 #108784# - disconnect for a dedicated drawing object -
-// could be 'master' or 'virtual'.
+// disconnect for a dedicated drawing object - could be 'master' or 'virtual'.
 // a 'master' drawing object will disconnect a 'virtual' drawing object
 // in order to take its place.
 /*N*/ void SwDrawContact::DisconnectObjFromLayout( SdrObject* _pDrawObj )
@@ -828,9 +796,6 @@ void SwDrawContact::RemoveMasterFromDrawPage()
 |*
 |*	SwDrawContact::ConnectToLayout()
 |*
-|*	Ersterstellung		MA 09. Jan. 95
-|*	Letzte Aenderung	MA 25. Mar. 99
-|*
 |*************************************************************************/
 
 void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
@@ -843,7 +808,7 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
         return;
     }
 
-    // OD 16.05.2003 #108784# - remove 'virtual' drawing objects from writer
+    // remove 'virtual' drawing objects from writer
     // layout and from drawing page, and remove 'master' drawing object from
     // writer layout - 'master' object will remain in drawing page.
     DisconnectFromLayout( false );
@@ -887,9 +852,8 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
                 {
                     ClrContourCache( GetMaster() );
                 }
-                // OD 16.05.2003 #108784# - support drawing objects in header/footer,
-                // but not control objects:
-                // anchor at first found frame the 'master' object and
+                // support drawing objects in header/footer, but not control
+                // objects: anchor at first found frame the 'master' object and
                 // at the following frames 'virtual' drawing objects.
                 // Note: method is similar to <SwFlyFrmFmt::MakeFrms(..)>
                 SwModify *pModify = 0;
@@ -947,13 +911,13 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
 
                         if ( !pAnchorFrmOfMaster )
                         {
-                            // OD 02.07.2003 #108784# - check, if 'master' drawing
+                            // check, if 'master' drawing
                             // objects is inserted into drawing page. If not,
                             // assert and insert 'master' drawing object.
                             if ( !GetMaster()->IsInserted() )
                             {
-                                // OD 25.06.2003 #108784# - debug assert
-                                ASSERT( false, "<SwDrawContact::ConnectToLayout(..)> - master drawing object not inserted!?" );
+                                // debug assert
+                                OSL_FAIL( "<SwDrawContact::ConnectToLayout(..)> - master drawing object not inserted!?" );
 
                                 pDrawFrmFmt->GetDoc()->GetDrawModel()->GetPage(0)->
                                     InsertObject( GetMaster(), GetMaster()->GetOrdNumDirect() );
@@ -984,73 +948,15 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
                 }
             }
             break;
-/*
-        case FLY_AT_FLY:
-            {
-                if( pAnch->GetCntntAnchor() ) // LAYER_IMPL
-                {
-                    SwFrm *pAnchor = 0;
-                    //Erst einmal ueber den Inhalt suchen, weil konstant schnell. Kann
-                    //Bei verketteten Rahmen aber auch schief gehen, weil dann evtl.
-                    //niemals ein Frame zu dem Inhalt existiert. Dann muss leider noch
-                    //die Suche vom StartNode zum FrameFormat sein.
-                    SwNodeIndex aIdx( pAnch->GetCntntAnchor()->nNode );
-                    SwCntntNode *pCNd = pFmt->GetDoc()->GetNodes().GoNext( &aIdx );
-                    if ( pCNd && 0 != (pAnchor = pCNd->GetFrm( 0, 0, FALSE ) ) )
-                        pAnchor = pAnchor->FindFlyFrm();
-                    else
-                    {
-                        const SwNodeIndex &rIdx = pAnch->GetCntntAnchor()->nNode;
-                        SwSpzFrmFmts& rFmts = *pFmt->GetDoc()->GetSpzFrmFmts();
-                        for( USHORT i = 0; i < rFmts.Count(); ++i )
-                        {
-                            SwFrmFmt *pFmt = rFmts[i];
-                            SwFlyFrmFmt* pFlyFmt;
-                            if( 0 != (pFlyFmt = PTR_CAST( SwFlyFrmFmt, pFmt )) &&
-                                pFlyFmt->GetCntnt().GetCntntIdx() && //#57390#, Reader
-                                rIdx == *pFlyFmt->GetCntnt().GetCntntIdx() )
-                            {
-                                pAnchor = pFlyFmt->GetFrm( 0, FALSE );
-                                break;
-                            }
-                        }
-                    }
-                    if ( pAnchor )	//Kann sein, dass der Anker noch nicht existiert
-                    {
-                        pAnchor->FindFlyFrm()->AppendDrawObj( this );
-                        bSetAnchorPos = false;
-                    }
-                }
-            }
+        default:
             break;
-*/
-/*
-        case FLY_IN_CNTNT:
-            {
-                ClrContourCache( GetMaster() );
-                SwCntntNode *pNode = GetFmt()->GetDoc()->
-                        GetNodes()[pAnch->GetCntntAnchor()->nNode]->GetCntntNode();
-                SwCntntFrm *pCntnt = pNode->GetFrm( 0, 0, FALSE );
-                if ( pCntnt )
-                {
-                    //Kann sein, dass der Anker noch nicht existiert
-                    pCntnt->AppendDrawObj( this );
-                    pCntnt->InvalidatePrt();
-                }
-                bSetAnchorPos = false;
-            }
-            break;
-*/
-#ifdef DBG_UTIL
-        default:	ASSERT( FALSE, "Unknown Anchor." );
-#endif
     }
     if ( GetAnchor() )
     {
         if( bSetAnchorPos )
         {
             GetMaster()->SetAnchorPos( GetAnchor()->GetFrmAnchorPos( ::binfilter::HasWrap( GetMaster() ) ) );
-    }
+        }
         if ( !pDrawFrmFmt->GetDoc()->IsVisibleLayerId( GetMaster()->GetLayer() ) )
         {
             SdrLayerID nVisibleLayerId =
@@ -1060,7 +966,7 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
     }
 }
 
-// OD 20.06.2003 #108784# - method in order to correct relative positioning of
+// method in order to correct relative positioning of
 // 'virtual' drawing objects, e.g. caused by a <NbcSetAnchorPos(..)> at the
 // 'master' drawing object.
 void SwDrawContact::CorrectRelativePosOfVirtObjs()
@@ -1074,8 +980,8 @@ void SwDrawContact::CorrectRelativePosOfVirtObjs()
     }
 }
 
-// OD 20.06.2003 #108784# - correct in-direct movements of the 'virtual'
-// drawing objects, e.g. caused by a <NbcMove(..)> at the 'master' drawing object
+// correct in-direct movements of the 'virtual' drawing objects,
+// e.g. caused by a <NbcMove(..)> at the 'master' drawing object
 void SwDrawContact::MoveOffsetOfVirtObjs( const Size& _rMoveSize )
 {
     for ( std::list<SwDrawVirtObj*>::iterator aDrawVirtObjIter = maDrawVirtObjs.begin();
@@ -1087,7 +993,7 @@ void SwDrawContact::MoveOffsetOfVirtObjs( const Size& _rMoveSize )
     }
 }
 
-// OD 26.06.2003 #108784# - invalidate anchor frames of 'virtual' drawing objects.
+// invalidate anchor frames of 'virtual' drawing objects.
 // Needed for, e.g., 'as character' anchored drawing objects and a change of the
 // 'master' drawing object.
 void SwDrawContact::InvalidateAnchorOfVirtObjs()
@@ -1108,9 +1014,6 @@ void SwDrawContact::InvalidateAnchorOfVirtObjs()
 |*
 |*	SwDrawContact::FindPage(), ChkPage()
 |*
-|*	Ersterstellung		MA 21. Mar. 95
-|*	Letzte Aenderung	MA 19. Jul. 96
-|*
 |*************************************************************************/
 
 SwPageFrm* SwDrawContact::FindPage( const SwRect &rRect )
@@ -1129,9 +1032,8 @@ void SwDrawContact::ChkPage()
         pPage : FindPage( GetMaster()->GetBoundRect() );
     if ( pPage != pPg )
     {
-        // OD 27.06.2003 #108784# - if drawing object is anchor in header/footer
-        // a change of the page is a dramatic change. Thus, completely re-connect
-        // to the layout
+        // if drawing object is anchor in header/footer a change of the page
+        // is a dramatic change. Thus, completely re-connect to the layout
         if ( pAnchor && pAnchor->FindFooterOrHeader() )
         {
             ConnectToLayout();
@@ -1150,12 +1052,9 @@ void SwDrawContact::ChkPage()
 |*
 |*	SwDrawContact::ChangeMasterObject()
 |*
-|*	Ersterstellung		MA 07. Aug. 95
-|*	Letzte Aenderung	MA 20. Apr. 99
-|*
 |*************************************************************************/
 
-// OD 10.07.2003 #110742# - Important note:
+// Important note:
 // method is called by method <SwDPage::ReplaceObject(..)>, which called its
 // corresponding superclass method <FmFormPage::ReplaceObject(..)>.
 // Note: 'master' drawing object *has* to be connected to layout (GetAnchor()
@@ -1164,14 +1063,11 @@ void SwDrawContact::ChkPage()
 // =============================================================================
 /** implementation of class <SwDrawVirtObj>
 
-    OD 14.05.2003 #108784#
-
     @author OD
 */
 
 TYPEINIT1(SwDrawVirtObj,SdrVirtObj);
 
-// #108784#
 // implemetation of SwDrawVirtObj
 SwDrawVirtObj::SwDrawVirtObj( SdrObject&        _rNewObj,
                               SwDrawContact&    _rDrawContact )
@@ -1195,9 +1091,9 @@ const Point SwDrawVirtObj::GetOffset() const
     return maOffset;
 }
 
-void SwDrawVirtObj::operator=( const SdrObject& rObj )
+void SwDrawVirtObj::operator=( const SdrObject& /*rObj*/ )
 {
-DBG_BF_ASSERT(0, "STRIP");//STRIP001 
+DBG_BF_ASSERT(0, "STRIP");
 }
 
 SdrObject* SwDrawVirtObj::Clone() const
@@ -1283,7 +1179,7 @@ bool SwDrawVirtObj::IsConnected() const
     return bRetVal;
 }
 
-// OD 19.06.2003 #108784# - adjust the relative postion of the 'virtual'
+// adjust the relative postion of the 'virtual'
 // drawing object to the reference object
 void SwDrawVirtObj::AdjustRelativePosToReference()
 {
@@ -1296,7 +1192,6 @@ void SwDrawVirtObj::AdjustRelativePosToReference()
     }
 }
 
-// #108784#
 // All AnchorPos influencing methods which shall not change the
 // original object positions.
 
@@ -1332,9 +1227,9 @@ void SwDrawVirtObj::RecalcBoundRect()
     aOutRect += maOffset;
 }
 
-FASTBOOL SwDrawVirtObj::Paint(ExtOutputDevice& rOut, const SdrPaintInfoRec& rInfoRec) const
+bool SwDrawVirtObj::Paint(ExtOutputDevice& rOut, const SdrPaintInfoRec& rInfoRec) const
 {
-    FASTBOOL bRet;
+    bool bRet = FALSE;
 
     Point aOfs(rOut.GetOffset());
     rOut.SetOffset(aOfs + maOffset);
@@ -1357,12 +1252,12 @@ FASTBOOL SwDrawVirtObj::Paint(ExtOutputDevice& rOut, const SdrPaintInfoRec& rInf
 SdrObject* SwDrawVirtObj::CheckHit(const Point& rPnt, USHORT nTol, const SetOfByte* pVisiLayer) const
 {
     Point aPnt(rPnt - maOffset);
-    FASTBOOL bRet = rRefObj.CheckHit(aPnt, nTol, pVisiLayer) != NULL;
+    bool bRet = rRefObj.CheckHit(aPnt, nTol, pVisiLayer) != NULL;
 
     return bRet ? (SdrObject*)this : NULL;
 }
 
-void SwDrawVirtObj::TakeXorPoly(XPolyPolygon& rPoly, FASTBOOL bDetail) const
+void SwDrawVirtObj::TakeXorPoly(XPolyPolygon& rPoly, bool bDetail) const
 {
     rRefObj.TakeXorPoly(rPoly, bDetail);
     rPoly.Move(maOffset.X(), maOffset.Y());
@@ -1374,12 +1269,12 @@ void SwDrawVirtObj::TakeContour(XPolyPolygon& rPoly) const
     rPoly.Move(maOffset.X(), maOffset.Y());
 }
 
-SdrHdl* SwDrawVirtObj::GetHdl(USHORT nHdlNum) const
-{DBG_BF_ASSERT(0, "STRIP");return NULL;//STRIP001 
+SdrHdl* SwDrawVirtObj::GetHdl(USHORT /*nHdlNum*/) const
+{DBG_BF_ASSERT(0, "STRIP");return NULL;
 }
 
-SdrHdl* SwDrawVirtObj::GetPlusHdl(const SdrHdl& rHdl, USHORT nPlNum) const
-{DBG_BF_ASSERT(0, "STRIP");return NULL;//STRIP001 
+SdrHdl* SwDrawVirtObj::GetPlusHdl(const SdrHdl& /*rHdl*/, USHORT /*nPlNum*/) const
+{DBG_BF_ASSERT(0, "STRIP");return NULL;
 }
 
 void SwDrawVirtObj::NbcMove(const Size& rSiz)
@@ -1406,7 +1301,7 @@ void SwDrawVirtObj::NbcMirror(const Point& rRef1, const Point& rRef2)
     SetRectsDirty();
 }
 
-void SwDrawVirtObj::NbcShear(const Point& rRef, long nWink, double tn, FASTBOOL bVShear)
+void SwDrawVirtObj::NbcShear(const Point& rRef, long nWink, double tn, bool bVShear)
 {
     rRefObj.NbcShear(rRef - maOffset, nWink, tn, bVShear);
     SetRectsDirty();
@@ -1442,11 +1337,11 @@ void SwDrawVirtObj::Rotate(const Point& rRef, long nWink, double sn, double cs)
     }
 }
 
-void SwDrawVirtObj::Mirror(const Point& rRef1, const Point& rRef2)
-{DBG_BF_ASSERT(0, "STRIP");//STRIP001 
+void SwDrawVirtObj::Mirror(const Point& /*rRef1*/, const Point& /*rRef2*/)
+{DBG_BF_ASSERT(0, "STRIP");
 }
 
-void SwDrawVirtObj::Shear(const Point& rRef, long nWink, double tn, FASTBOOL bVShear)
+void SwDrawVirtObj::Shear(const Point& rRef, long nWink, double tn, bool bVShear)
 {
     if(nWink)
     {
@@ -1515,8 +1410,8 @@ void SwDrawVirtObj::NbcSetLogicRect(const Rectangle& rRect)
     SetRectsDirty();
 }
 
-Point SwDrawVirtObj::GetSnapPoint(USHORT i) const
-{DBG_BF_ASSERT(0, "STRIP");Point ap; return ap;//STRIP001 
+Point SwDrawVirtObj::GetSnapPoint(USHORT /*i*/) const
+{DBG_BF_ASSERT(0, "STRIP");Point ap; return ap;
 }
 
 const Point& SwDrawVirtObj::GetPoint(USHORT i) const
@@ -1536,14 +1431,13 @@ void SwDrawVirtObj::NbcSetPoint(const Point& rPnt, USHORT i)
 }
 
 // #108784#
-FASTBOOL SwDrawVirtObj::HasTextEdit() const
+bool SwDrawVirtObj::HasTextEdit() const
 {
     return rRefObj.HasTextEdit();
 }
 
-// OD 18.06.2003 #108784# - overloaded 'layer' methods for 'virtual' drawing
-// object to assure, that layer of 'virtual' object is the layer of the referenced
-// object.
+// overloaded 'layer' methods for 'virtual' drawin object to assure,
+// that layer of 'virtual' object is the layer of the referenced object.
 // NOTE: member <
 SdrLayerID SwDrawVirtObj::GetLayer() const
 {
