@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -58,7 +58,7 @@
 #include <grfatr.hxx>
 #include <swtypes.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <ndgrf.hxx>
 #include <fmtcol.hxx>
@@ -82,7 +82,7 @@ namespace binfilter {
 /*N*/ 	: SwNoTxtNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr )
 /*N*/ {
 /*N*/ 	aGrfObj.SetSwapStreamHdl( LINK( this, SwGrfNode, SwapGraphic ) );
-/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf = 
+/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf =
 /*N*/ 		bFrameInPaint = bScaleImageMap = FALSE;
 /*N*/ 	bGrafikArrived = TRUE;
 /*N*/ 	ReRead( rGrfName, rFltName, pGraphic, 0, FALSE );
@@ -97,7 +97,7 @@ namespace binfilter {
 /*N*/ 	aGrfObj.SetSwapStreamHdl( LINK( this, SwGrfNode, SwapGraphic ) );
 /*N*/ 	if( rGrfObj.HasUserData() && rGrfObj.IsSwappedOut() )
 /*?*/ 		aGrfObj.SetSwapState();
-/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel= bLoadLowResGrf = 
+/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel= bLoadLowResGrf =
 /*N*/ 		bFrameInPaint = bScaleImageMap = FALSE;
 /*N*/ 	bGrafikArrived = TRUE;
 /*N*/ }
@@ -113,14 +113,14 @@ namespace binfilter {
 /*N*/ 	: SwNoTxtNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr )
 /*N*/ {
 /*N*/ 	aGrfObj.SetSwapStreamHdl( LINK( this, SwGrfNode, SwapGraphic ) );
-/*N*/ 
+/*N*/
 /*N*/ 	Graphic aGrf; aGrf.SetDefaultType();
 /*N*/ 	aGrfObj.SetGraphic( aGrf, rGrfName );
-/*N*/ 
-/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf = 
+/*N*/
+/*N*/ 	bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf =
 /*N*/ 		bFrameInPaint = bScaleImageMap = FALSE;
 /*N*/ 	bGrafikArrived = TRUE;
-/*N*/ 
+/*N*/
 /*N*/ 	InsertLink( rGrfName, rFltName );
 /*N*/ 	if( IsLinkedFile() )
 /*N*/ 	{
@@ -143,14 +143,14 @@ namespace binfilter {
 /*N*/ 						BOOL bNewGrf )
 /*N*/ {
 /*N*/ 	BOOL bReadGrf = FALSE, bSetTwipSize = TRUE;
-/*N*/ 
-/*N*/ 	ASSERT( pGraphic || pGrfObj || rGrfName.Len(),
+/*N*/
+/*N*/ 	OSL_ENSURE( pGraphic || pGrfObj || rGrfName.Len(),
 /*N*/ 			"GraphicNode without a name, Graphic or GraphicObject" );
-/*N*/ 
+/*N*/
 /*N*/ 	// ReadRead mit Namen
 /*N*/ 	if( refLink.Is() )
 /*N*/ 	{
-/*?*/ 		ASSERT( !bInSwapIn, "ReRead: stehe noch im SwapIn" );
+/*?*/ 		OSL_ENSURE( !bInSwapIn, "ReRead: stehe noch im SwapIn" );
 /*?*/ 		if( rGrfName.Len() )
 /*?*/ 		{
 /*?*/ 			// Besonderheit: steht im FltNamen DDE, handelt es sich um eine
@@ -166,14 +166,14 @@ namespace binfilter {
 /*?*/                     ::binfilter::MakeLnkName( sCmd, 0, rGrfName, aEmptyStr, &rFltName );
 /*?*/ 					nNewType = OBJECT_CLIENT_GRF;
 /*?*/ 				}
-/*?*/ 
+/*?*/
 /*?*/ 				if( nNewType != refLink->GetObjType() )
 /*?*/ 				{
 /*?*/ 					refLink->Disconnect();
 /*?*/ 					((SwBaseLink*)&refLink)->SetObjType( nNewType );
 /*?*/ 				}
 /*?*/ 			}
-/*?*/ 
+/*?*/
 /*?*/ 			refLink->SetLinkSourceName( sCmd );
 /*?*/ 		}
 /*?*/ 		else		// kein Name mehr, Link aufheben
@@ -181,7 +181,7 @@ namespace binfilter {
 /*?*/ 			GetDoc()->GetLinkManager().Remove( refLink );
 /*?*/ 			refLink.Clear();
 /*?*/ 		}
-/*?*/ 
+/*?*/
 /*?*/ 		if( pGraphic )
 /*?*/ 		{
 /*?*/ 			aGrfObj.SetGraphic( *pGraphic, rGrfName );
@@ -202,7 +202,7 @@ namespace binfilter {
 /*?*/ 			// der neue Link nicht geladen werden konnte.
 /*?*/ 			Graphic aGrf; aGrf.SetDefaultType();
 /*?*/ 			aGrfObj.SetGraphic( aGrf, rGrfName );
-/*?*/ 
+/*?*/
 /*?*/ 			if( refLink.Is() )
 /*?*/ 			{
 /*?*/ 				if( GetFrm() )
@@ -218,19 +218,19 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ 	else if( pGraphic && !rGrfName.Len() )
 /*N*/ 	{
-/*N*/ 		// MIB 27.02.2001: Old stream must be deleted before the new one is set.
+/*N*/ 		// Old stream must be deleted before the new one is set.
 /*N*/ 		if( HasStreamName() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 			DelStreamName();
-/*N*/ 
+                {DBG_BF_ASSERT(0, "STRIP");}
+/*N*/
 /*N*/ 		aGrfObj.SetGraphic( *pGraphic );
 /*N*/ 		bReadGrf = TRUE;
 /*N*/ 	}
 /*N*/ 	else if( pGrfObj && !rGrfName.Len() )
 /*N*/ 	{
-/*N*/ 		// MIB 27.02.2001: Old stream must be deleted before the new one is set.
+/*N*/ 		// Old stream must be deleted before the new one is set.
 /*?*/ 		if( HasStreamName() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 			DelStreamName();
-/*?*/ 
+                {DBG_BF_ASSERT(0, "STRIP");}
+/*?*/
 /*?*/ 		aGrfObj = *pGrfObj;
 /*?*/ 		if( pGrfObj->HasUserData() && pGrfObj->IsSwappedOut() )
 /*?*/ 			aGrfObj.SetSwapState();
@@ -240,15 +240,15 @@ namespace binfilter {
 /*N*/ 		// Ist die Grafik bereits geladen?
 /*N*/ 	else if( !bNewGrf && GRAPHIC_NONE != aGrfObj.GetType() )
 /*N*/ 		return TRUE;
-/*N*/ 
+/*N*/
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		if( HasStreamName() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 			DelStreamName();
-/*N*/ 
+                {DBG_BF_ASSERT(0, "STRIP");}
+/*N*/
 /*N*/ 		// einen neuen Grafik-Link anlegen
 /*N*/ 		InsertLink( rGrfName, rFltName );
-/*N*/ 
+/*N*/
 /*N*/ 		if( GetNodes().IsDocNodes() )
 /*N*/ 		{
 /*N*/ 			if( pGraphic )
@@ -277,19 +277,19 @@ namespace binfilter {
 /*N*/ 			}
 /*N*/ 		}
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	// Bug 39281: Size nicht sofort loeschen - Events auf ImageMaps
 /*N*/ 	//			  sollten nicht beim Austauschen nicht ins "leere greifen"
 /*N*/ 	if( bSetTwipSize )
 /*N*/ 		SetTwipSize( ::binfilter::GetGraphicSizeTwip( aGrfObj.GetGraphic(), 0 ) );
-/*N*/ 
+/*N*/
 /*N*/ 	// erzeuge noch einen Update auf die Frames
 /*N*/ 	if( bReadGrf && bNewGrf )
 /*N*/ 	{
 /*?*/ 		SwMsgPoolItem aMsgHint( RES_UPDATE_ATTR );
 /*?*/ 		Modify( &aMsgHint, &aMsgHint );
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	return bReadGrf;
 /*N*/ }
 
@@ -299,14 +299,14 @@ namespace binfilter {
 /*N*/ 	SwDoc* pDoc = GetDoc();
 /*N*/ 	if( refLink.Is() )
 /*N*/ 	{
-/*N*/ 		ASSERT( !bInSwapIn, "DTOR: stehe noch im SwapIn" );
+/*N*/ 		OSL_ENSURE( !bInSwapIn, "DTOR: stehe noch im SwapIn" );
 /*N*/ 		pDoc->GetLinkManager().Remove( refLink );
 /*N*/ 		refLink->Disconnect();
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		if( !pDoc->IsInDtor() && HasStreamName() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 			DelStreamName();
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 	}
 /*N*/ 	//#39289# Die Frames muessen hier bereits geloescht weil der DTor der
 /*N*/ 	//Frms die Grafik noch fuer StopAnimation braucht.
@@ -315,7 +315,7 @@ namespace binfilter {
 /*N*/ }
 
 
-/*N*/ SwCntntNode *SwGrfNode::SplitNode( const SwPosition &rPos )
+/*N*/ SwCntntNode *SwGrfNode::SplitNode( const SwPosition& /*rPos*/ )
 /*N*/ {
 /*?*/ 	return this;
 /*N*/ }
@@ -329,7 +329,7 @@ namespace binfilter {
 /*N*/ 								SwAttrSet* pAutoAttr,
 /*N*/ 								BOOL bDelayed )
 /*N*/ {
-/*N*/ 	ASSERT( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
+/*N*/ 	OSL_ENSURE( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
 /*N*/ 	SwGrfNode *pNode;
 /*N*/ 	// Delayed erzeugen nur aus dem SW/G-Reader
 /*N*/ 	if( bDelayed )
@@ -346,7 +346,7 @@ namespace binfilter {
 /*N*/ 								SwGrfFmtColl* pGrfColl,
 /*N*/ 								SwAttrSet* pAutoAttr )
 /*N*/ {
-/*N*/ 	ASSERT( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
+/*N*/ 	OSL_ENSURE( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
 /*N*/ 	return new SwGrfNode( rWhere, rGrfObj, pGrfColl, pAutoAttr );
 /*N*/ }
 
@@ -402,7 +402,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
         else
         {
             SvStorageRef refRoot = GetDoc()->GetDocStorage();
-            ASSERT( refRoot.Is(), "Kein Storage am Doc" );
+            OSL_ENSURE( refRoot.Is(), "Kein Storage am Doc" );
             if( refRoot.Is() )
             {
                 String aStrmName, aPicStgName;
@@ -469,12 +469,12 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 // Streamnamen abgelegt (SaveAs). nach einem SaveAs wird
 // vom SW3-I/O-System noch SaveCompleted() aufgerufen,
 // da nun der Doc-Storage dem neuen Storage entspricht.
-// MIB 02/28/2001: This method is called only to store graphics
+// This method is called only to store graphics
 // in the 3.1 to 5.0 formats. For the 6.0 format, graphics
 // are exported using the SvXMLGraphicObjectHelper class.
 
 
-/*N*/ BOOL SwGrfNode::StoreGraphics( SvStorage* pRoot )
+/*N*/ BOOL SwGrfNode::StoreGraphics( SvStorage* pInRoot )
 /*N*/ {
 /*N*/ 	if( !refLink.Is() )
 /*N*/ 	{
@@ -485,19 +485,19 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 		if( HasStreamName() )
 /*N*/ 			bGraphic = GetStreamStorageNames( aSrcStrmName, aSrcPicStgName );
 /*N*/ 		SvStorage* pDocStg = GetDoc()->GetDocStorage();
-/*N*/ 		if( !pRoot )
-/*N*/ 			pRoot = pDocStg;
-/*N*/ 		ASSERT( SOFFICE_FILEFORMAT_60 > pRoot->GetVersion(),
+/*N*/ 		if( !pInRoot )
+/*N*/ 			pInRoot = pDocStg;
+/*N*/ 		OSL_ENSURE( SOFFICE_FILEFORMAT_60 > pInRoot->GetVersion(),
 /*N*/ 				"SwGrfNode::StoreGraphic called for 6.0+ file format" );
-/*N*/ 
+/*N*/
 /*N*/ 		String aDstPicStgName(
-/*N*/ 				RTL_CONSTASCII_STRINGPARAM( "EmbeddedPictures" ) );
+/*N*/ 				RTL_CONSTASCII_USTRINGPARAM( "EmbeddedPictures" ) );
 /*N*/ 		String aDstStrmName( aSrcStrmName );
-/*N*/ 		if( pRoot != pDocStg || !bGraphic )
+/*N*/ 		if( pInRoot != pDocStg || !bGraphic )
 /*N*/ 		{
 /*N*/ 			// If the stream does not contain a streamed graphic object,
 /*N*/ 			// the graphic has to be stored again.
-/*N*/ 			ASSERT( pRoot != pDocStg || aSrcStrmName.Len(),
+/*N*/ 			OSL_ENSURE( pInRoot != pDocStg || aSrcStrmName.Len(),
 /*N*/ 					"raw image data stream but no stream name" );
 /*N*/ 			// Neuer Storage. Wenn die Grafik im DocStg drin ist,
 /*N*/ 			// kann sie bequem per CopyTo() kopiert werden.
@@ -507,13 +507,13 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 					? pDocStg->OpenStorage( aSrcPicStgName,
 /*N*/ 						STREAM_READ | STREAM_SHARE_DENYWRITE )
 /*N*/ 					: pDocStg;
-/*N*/ 
+/*N*/
 /*N*/ 				SvStorageStreamRef refStrm;
-/*N*/ 
-/*N*/ 				BOOL bWriteNew = pDocStg->GetVersion() != pRoot->GetVersion() ||
+/*N*/
+/*N*/ 				BOOL bWriteNew = pDocStg->GetVersion() != pInRoot->GetVersion() ||
 /*N*/ 								 !bGraphic;
 /*N*/ 				if( !bWriteNew &&
-/*N*/ 					SOFFICE_FILEFORMAT_40 <= pRoot->GetVersion() )
+/*N*/ 					SOFFICE_FILEFORMAT_40 <= pInRoot->GetVersion() )
 /*N*/ 				{
 /*N*/ 					refStrm = refSrcPics->OpenStream( aSrcStrmName,
 /*N*/ 									STREAM_READ | STREAM_SHARE_DENYWRITE );
@@ -527,10 +527,10 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 						if( GRAPHIC_BITMAP == aGrfObj.GetType() &&
 /*N*/ 							GetDoc()->GetInfo()->IsSaveGraphicsCompressed() )
 /*N*/ 							nNewCmprsMode |= COMPRESSMODE_ZBITMAP;
-/*N*/ 						if( SOFFICE_FILEFORMAT_40 < pRoot->GetVersion() &&
+/*N*/ 						if( SOFFICE_FILEFORMAT_40 < pInRoot->GetVersion() &&
 /*N*/ 							GetDoc()->GetInfo()->IsSaveOriginalGraphics() )
 /*N*/ 							nNewCmprsMode |= COMPRESSMODE_NATIVE;
-/*N*/ 
+/*N*/
 /*N*/ 						if( nCmprsMode != nNewCmprsMode )
 /*N*/ 						{
 /*N*/ 							// der Kompressedmode stimmt nicht, also muss
@@ -541,7 +541,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 						}
 /*N*/ 					}
 /*N*/ 				}
-/*N*/ 
+/*N*/
 /*N*/ 				if( bWriteNew )
 /*N*/ 				{
 /*N*/ 					if( aGrfObj.IsSwappedOut() &&
@@ -560,21 +560,21 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 					}
 /*N*/ 					// If the graphic is restored within the same storage,
 /*N*/ 					// its storage has to be removed.
-/*N*/ 					if( pRoot == pDocStg )
+/*N*/ 					if( pInRoot == pDocStg )
 /*N*/ 					{
-                            {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 						refStrm.Clear();
+                            {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 					}
 /*N*/ 					aDstStrmName.Erase();
 /*N*/ 				}
 /*N*/ 				else
 /*N*/ 				{
 /*N*/ 					SvStorageRef refDstPics =
-/*N*/ 						pRoot->OpenStorage( aDstPicStgName,
+/*N*/ 						pInRoot->OpenStorage( aDstPicStgName,
 /*N*/ 							STREAM_READWRITE | STREAM_SHARE_DENYALL );
 /*N*/ 					if( refDstPics->IsContained( aDstStrmName ) )
 /*N*/ 						// nur neu erzeugen, wenn Name schon vorhanden ist!
 /*?*/ 						aDstStrmName = Sw3Io::UniqueName( refDstPics, "Pic" );
-/*N*/ 
+/*N*/
 /*N*/ 					if( refSrcPics->CopyTo( aSrcStrmName, refDstPics,
 /*N*/ 											aDstStrmName )
 /*N*/ 						&& refDstPics->Commit() )
@@ -584,14 +584,14 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 				}
 /*N*/ 			}
 /*N*/ 		}
-/*N*/ 
+/*N*/
 /*N*/ 		if( !aDstStrmName.Len() )
 /*N*/ 		{
-/*N*/ 			ASSERT( pRoot, "Kein Storage gegeben" );
-/*N*/ 			if( pRoot )
+/*N*/ 			OSL_ENSURE( pInRoot, "Kein Storage gegeben" );
+/*N*/ 			if( pInRoot )
 /*N*/ 			{
 /*N*/ 				SvStorageRef refPics =
-/*N*/ 					pRoot->OpenStorage( aDstPicStgName,
+/*N*/ 					pInRoot->OpenStorage( aDstPicStgName,
 /*N*/ 						STREAM_READWRITE | STREAM_SHARE_DENYALL );
 /*N*/ 				if( SVSTREAM_OK == refPics->GetError() )
 /*N*/ 				{
@@ -604,12 +604,12 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 						// HACK bis die Grafik als Portable markiert
 /*N*/ 						// werden kann!!!
 /*N*/ 						// Die Grafik kann in einer TempFile sein!
-/*N*/ 						FASTBOOL bIsSwapOut = aGrfObj.IsSwappedOut();
+/*N*/ 						bool bIsSwapOut = aGrfObj.IsSwappedOut();
 /*N*/ 						if( bIsSwapOut && !aGrfObj.SwapIn() )
 /*N*/ 							return FALSE;
-/*N*/ 
-/*N*/ 						refStrm->SetVersion( pRoot->GetVersion() );
-/*N*/ 
+/*N*/
+/*N*/ 						refStrm->SetVersion( pInRoot->GetVersion() );
+/*N*/
 /*N*/ 						//JP 04.05.98: laut ChangesMail vom KA und Bug 49617
 /*N*/ 						//JP 21.06.98: laut ChangesMail vom KA, natives Save
 /*N*/ 						USHORT nComprMode = refStrm->GetCompressMode();
@@ -619,7 +619,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 							nComprMode |= COMPRESSMODE_ZBITMAP;
 /*N*/ 						else
 /*N*/ 							nComprMode &= ~COMPRESSMODE_ZBITMAP;
-/*N*/ 
+/*N*/
 /*N*/ 						//JP 21.06.98: laut ChangesMail vom KA, natives Save
 /*N*/ 						if( SOFFICE_FILEFORMAT_40 < refStrm->GetVersion() &&
 /*N*/ 							GetDoc()->GetInfo()->IsSaveOriginalGraphics() )
@@ -627,13 +627,13 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 						else
 /*N*/ 							nComprMode &= ~COMPRESSMODE_NATIVE;
 /*N*/ 						refStrm->SetCompressMode( nComprMode );
-/*N*/ 
+/*N*/
 /*N*/ 						BOOL bRes = FALSE;
-/*N*/ 						if( pRoot == pDocStg )
+/*N*/ 						if( pInRoot == pDocStg )
 /*N*/ 						{
 /*?*/ 							if( aGrfObj.SwapOut( refStrm ) &&
 /*?*/ 								( refStrm->Commit() | refPics->Commit()
-/*?*/ 								  /*| pRoot->Commit()*/ ))
+/*?*/ 								  /*| pInRoot->Commit()*/ ))
 /*?*/ 							{
 /*?*/ 								SetStreamName( aDstStrmName );
 /*?*/ 								bRes = TRUE;
@@ -642,7 +642,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 						else if( ((Graphic&)aGrfObj.GetGraphic()).
 /*N*/ 												WriteEmbedded( *refStrm )
 /*N*/ 								&& ( refStrm->Commit() | refPics->Commit()
-/*N*/ 								  /*| pRoot->Commit()*/ ))
+/*N*/ 								  /*| pInRoot->Commit()*/ ))
 /*N*/ 						{
 /*N*/ 							if( bIsSwapOut )
 /*?*/ 								aGrfObj.SwapOut();
@@ -725,7 +725,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 			BOOL bSync = rFltName.EqualsAscii( "SYNCHRON" );
 /*N*/ 			refLink->SetSynchron( bSync );
 /*N*/             refLink->SetContentType( SOT_FORMATSTR_ID_SVXB );
-/*N*/ 
+/*N*/
 /*N*/ 			pDoc->GetLinkManager().InsertFileLink( *refLink,
 /*N*/ 											OBJECT_CLIENT_GRF, rGrfName,
 /*N*/ 								(!bSync && rFltName.Len() ? &rFltName : 0) );
@@ -743,7 +743,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 	if( IsScaleImageMap() && nGrfSize.Width() && nGrfSize.Height() )
 /*N*/ 	{
 /*N*/ 		// Image-Map an Grafik-Groesse anpassen
-            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/ 		ScaleImageMap();
+            DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ }
 
@@ -760,12 +760,12 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 	BOOL bGraphic = FALSE;
 /*N*/ 	rStorName.Erase();
 /*N*/ 	rStrmName.Erase();
-/*N*/ 
+/*N*/
 /*N*/ 	String aUserData( aGrfObj.GetUserData() );
 /*N*/ 	if( !aUserData.Len() )
 /*N*/ 		return FALSE;
-/*N*/ 
-/*N*/ 	String aProt( RTL_CONSTASCII_STRINGPARAM( "vnd.sun.star.Package:" ) );
+/*N*/
+/*N*/ 	String aProt( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.Package:" ) );
 /*N*/ 	if( 0 == aUserData.CompareTo( aProt, aProt.Len() ) )
 /*N*/ 	{
 /*N*/ 		// 6.0 (XML) Package
@@ -783,13 +783,13 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		// 3.1 - 5.2
-/*N*/ 		rStorName = String( RTL_CONSTASCII_STRINGPARAM( "EmbeddedPictures" ) );
+/*N*/ 		rStorName = String( RTL_CONSTASCII_USTRINGPARAM( "EmbeddedPictures" ) );
 /*N*/ 		rStrmName = aUserData;
 /*N*/ 		bGraphic = TRUE;
 /*N*/ 	}
-/*N*/ 	ASSERT( STRING_NOTFOUND == rStrmName.Search( '/' ),
+/*N*/ 	OSL_ENSURE( STRING_NOTFOUND == rStrmName.Search( '/' ),
 /*N*/ 			"invalid graphic stream name" );
-/*N*/ 
+/*N*/
 /*N*/ 	return bGraphic;
 /*N*/ }
 
@@ -797,15 +797,15 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ {
 /*N*/ 	// kopiere die Formate in das andere Dokument:
 /*N*/ 	SwGrfFmtColl* pColl = pDoc->CopyGrfColl( *GetGrfColl() );
-/*N*/ 
+/*N*/
 /*N*/ 	SwGrfNode* pThis = (SwGrfNode*)this;
-/*N*/ 
+/*N*/
 /*N*/ 	Graphic aTmpGrf;
 /*N*/ 	SwBaseLink* pLink = (SwBaseLink*)(::binfilter::SvBaseLink*) refLink;
 /*N*/ 	if( !pLink && HasStreamName() )
 /*N*/ 	{
 /*?*/ 		SvStorageRef refRoot = pThis->GetDoc()->GetDocStorage();
-/*?*/ 		ASSERT( refRoot.Is(), "Kein Storage am Doc" );
+/*?*/ 		OSL_ENSURE( refRoot.Is(), "Kein Storage am Doc" );
 /*?*/ 		if( refRoot.Is() )
 /*?*/ 		{
 /*?*/ 			String aStrmName, aPicStgName;
@@ -833,10 +833,10 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		if( aGrfObj.IsSwappedOut() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/ 			pThis->SwapIn();
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 		aTmpGrf = aGrfObj.GetGraphic();
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	const ::binfilter::SvLinkManager& rMgr = GetDoc()->GetLinkManager();
 /*N*/ 	String sFile, sFilter;
 /*N*/ 	if( IsLinkedFile() )
@@ -848,7 +848,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*?*/         ::binfilter::MakeLnkName( sFile, &sTmp1, sTmp2, sFilter );
 /*?*/ 		sFilter.AssignAscii( RTL_CONSTASCII_STRINGPARAM( "DDE" ));
 /*N*/ 	}
-/*N*/ 
+/*N*/
 /*N*/ 	SwGrfNode* pGrfNd = pDoc->GetNodes().MakeGrfNode( rIdx, sFile, sFilter,
 /*N*/ 													&aTmpGrf, pColl,
 /*N*/ 											(SwAttrSet*)GetpSwAttrSet() );
@@ -860,23 +860,23 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*M*/ IMPL_LINK( SwGrfNode, SwapGraphic, BfGraphicObject*, pGrfObj )
 /*M*/ {
 /*M*/ 	SvStream* pRet = NULL;
-/*M*/ 
+/*M*/
 /*M*/ 	// #101174#: Keep graphic while in swap in. That's at least important
 /*M*/ 	// when breaking links, because in this situation a reschedule call and
-/*M*/ 	// a DataChanged call lead to a paint of the graphic. 
+/*M*/ 	// a DataChanged call lead to a paint of the graphic.
 /*M*/ 	if( pGrfObj->IsInSwapOut() && (IsSelected() || bInSwapIn) )
 /*M*/ 		pRet = GRFMGR_AUTOSWAPSTREAM_NONE;
 /*M*/ 	else if( refLink.Is() )
-/*M*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*M*/ 	{DBG_BF_ASSERT(0, "STRIP");
 /*M*/ 	}
 /*M*/ 	else
 /*M*/ 	{
 /*M*/ 		pRet = GRFMGR_AUTOSWAPSTREAM_TEMP;
-/*M*/ 
+/*M*/
 /*M*/ 		if( HasStreamName() )
 /*M*/ 		{
 /*M*/ 			SvStorageRef refRoot = GetDoc()->GetDocStorage();
-/*M*/ 			ASSERT( refRoot.Is(), "Kein Storage am Doc" );
+/*M*/ 			OSL_ENSURE( refRoot.Is(), "Kein Storage am Doc" );
 /*M*/ 			if( refRoot.Is() )
 /*M*/ 			{
 /*M*/ 				String aStrmName, aPicStgName;
@@ -915,7 +915,7 @@ short SwGrfNode::SwapIn( BOOL bWaitForData )
 /*M*/ 			}
 /*M*/ 		}
 /*M*/ 	}
-/*M*/ 
+/*M*/
 /*M*/ 	return (long)pRet;
 /*M*/ }
 
