@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -37,10 +37,10 @@
 #include <horiornt.hxx>
 
 #include <doc.hxx>
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 #include <swtable.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <pam.hxx>
 #include <cntfrm.hxx>
@@ -67,7 +67,6 @@
 #include <fmtruby.hxx>
 #include <tgrditem.hxx>
 
-#include <error.h>
 #include "bf_so3/staticbaseurl.hxx"
 namespace binfilter {
 
@@ -97,7 +96,7 @@ namespace binfilter {
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		UINT32 nIndex32 = Sw3IoImp::InULong( rStrm );
-/*N*/ 		ASSERT( nIndex32 <= USHRT_MAX,
+/*N*/ 		OSL_ENSURE( nIndex32 <= USHRT_MAX,
 /*N*/ 				"SwFmtAnchor: Index/Seitenzahl > USHRT_MAX" );
 /*N*/ 		nIndex = (USHORT)nIndex32;
 /*N*/ 	}
@@ -115,7 +114,7 @@ namespace binfilter {
 /*N*/ 	if( nIVer < IVER_FMTANCHOR_LONGIDX )
 /*N*/ 	{
 /*N*/ 		// Nur 3.1/4.0-Export
-/*N*/ 		ASSERT( SOFFICE_FILEFORMAT_40 >= rStrm.GetVersion(),
+/*N*/ 		OSL_ENSURE( SOFFICE_FILEFORMAT_40 >= rStrm.GetVersion(),
 /*N*/ 				"SwFmtAnchor:: FF-Version und Item-Version passen nicht" );
 /*N*/
 /*N*/ 		Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
@@ -132,11 +131,11 @@ namespace binfilter {
 /*N*/ 		else if( FLY_AT_FLY == GetAnchorId() ||
 /*N*/ 				 FLY_AUTO_CNTNT == GetAnchorId() )
 /*N*/ 		{
-/*?*/ 			BYTE nAnchorId = GetAnchorId();
+/*?*/ 			BYTE nAnchorId2 = GetAnchorId();
 /*?*/ 			USHORT nIndex;
-/*?*/ 			if( FLY_AT_FLY == nAnchorId )
+/*?*/ 			if( FLY_AT_FLY == nAnchorId2 )
 /*?*/ 			{
-/*?*/ 				nAnchorId = FLY_PAGE;
+/*?*/ 				nAnchorId2 = FLY_PAGE;
 /*?*/ 				SwNodeIndex aIdx( pPos->nNode );
 /*?*/ 				const SwNodes& rNds = aIdx.GetNodes();
 /*?*/ 				const SwCntntNode* pCNd = rNds.GoNext( &aIdx );
@@ -148,12 +147,12 @@ namespace binfilter {
 /*?*/ 			}
 /*?*/ 			else
 /*?*/ 			{
-/*?*/ 				nAnchorId = FLY_AT_CNTNT;
+/*?*/ 				nAnchorId2 = FLY_AT_CNTNT;
 /*?*/ 				xub_StrLen nCntntIdx = pPos->nContent.GetIndex();
 /*?*/ 				nIndex = nCntntIdx <= STRING_MAXLEN52 ? nCntntIdx
 /*?*/ 													  : STRING_MAXLEN52;
 /*?*/ 			}
-/*?*/ 			rStrm << (BYTE) nAnchorId
+/*?*/ 			rStrm << (BYTE) nAnchorId2
 /*?*/ 				  << (USHORT) nIndex;
 /*N*/ 		}
 /*N*/ 		else
@@ -173,7 +172,7 @@ namespace binfilter {
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
-/*N*/ 		ASSERT( SOFFICE_FILEFORMAT_40 < rStrm.GetVersion(),
+/*N*/ 		OSL_ENSURE( SOFFICE_FILEFORMAT_40 < rStrm.GetVersion(),
 /*N*/ 				"SwFmtAnchor:: FF-Version und Item-Version passen nicht" );
 /*N*/ 		ULONG nIndex = pPos ? pPos->nContent.GetIndex() : GetPageNum();
 /*N*/ 		if( nIndex > STRING_MAXLEN52 )
@@ -187,7 +186,7 @@ namespace binfilter {
 
 /*N*/ USHORT SwFmtAnchor::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtAnchor: Gibt es ein neues Fileformat?" );
@@ -197,8 +196,8 @@ namespace binfilter {
 
 /*N*/ SfxPoolItem* SwFmtHeader::Create( SvStream& rStrm, USHORT ) const
 /*N*/ {
-/*N*/ 	BYTE bActive;
-/*N*/ 	rStrm >> bActive;
+/*N*/ 	BYTE bActive2;
+/*N*/ 	rStrm >> bActive2;
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 	SvStream* p = pIo->pStrm;
 /*N*/ 	pIo->pStrm = (SvStorageStream*) &rStrm;
@@ -213,7 +212,7 @@ namespace binfilter {
 /*N*/ 		if( pFmt )
 /*N*/ 		{
 /*N*/ 			pAttr = new SwFmtHeader( pFmt );
-/*N*/ 			pAttr->SetActive( BOOL( bActive ) );
+/*N*/ 			pAttr->SetActive( BOOL( bActive2 ) );
 /*N*/ 		}
 /*N*/ 		else
 /*?*/ 			pIo->Error();
@@ -230,7 +229,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	rStrm << (BYTE) IsActive();
 /*N*/ 	const SwFrmFmt* pFmt = GetHeaderFmt();
-/*N*/ 	ASSERT( !IsActive() || pFmt, "Aktiver Header ohne Format" );
+/*N*/ 	OSL_ENSURE( !IsActive() || pFmt, "Aktiver Header ohne Format" );
 /*N*/ 	if( pFmt )
 /*N*/ 	{
 /*N*/ 		Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
@@ -244,8 +243,8 @@ namespace binfilter {
 
 /*N*/ SfxPoolItem* SwFmtFooter::Create( SvStream& rStrm, USHORT ) const
 /*N*/ {
-/*N*/ 	BYTE bActive;
-/*N*/ 	rStrm >> bActive;
+/*N*/ 	BYTE bActive3;
+/*N*/ 	rStrm >> bActive3;
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 	SvStream* p = pIo->pStrm;
 /*N*/ 	pIo->pStrm = (SvStorageStream*) &rStrm;
@@ -259,7 +258,6 @@ namespace binfilter {
 /*N*/ 		SwFrmFmt* pFmt = (SwFrmFmt*) pIo->InFormat( SWG_FREEFMT, NULL );
 /*N*/ 		if( pFmt )
 /*N*/ 		{
-/*N*/           // --> FME 2005-01-18 #b6218408#
 /*N*/           // Emulate 5.2 footer size bug:
 /*N*/           if ( pIo->IsVersion( SWG_MAJORVERSION_50 ) )
 /*N*/           {
@@ -270,9 +268,8 @@ namespace binfilter {
 /*N*/                   pFmt->SetAttr( aSize );
 /*N*/               }
 /*N*/           }
-/*N*/           // <--
 /*N*/           pAttr = new SwFmtFooter( pFmt );
-/*N*/ 			pAttr->SetActive( BOOL( bActive ) );
+/*N*/ 			pAttr->SetActive( BOOL( bActive3 ) );
 /*N*/ 		}
 /*N*/ 		else
 /*?*/ 			pIo->Error();
@@ -289,7 +286,7 @@ namespace binfilter {
 /*N*/ {
 /*N*/ 	rStrm << (BYTE) IsActive();
 /*N*/ 	const SwFrmFmt* pFmt = GetFooterFmt();
-/*N*/ 	ASSERT( !IsActive() || pFmt, "Aktiver Footer ohne Format" );
+/*N*/ 	OSL_ENSURE( !IsActive() || pFmt, "Aktiver Footer ohne Format" );
 /*N*/ 	if( pFmt )
 /*N*/ 	{
 /*N*/ 		Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
@@ -315,8 +312,8 @@ namespace binfilter {
 /*N*/ 	SwStartNode* pSttNd = &pIo->InContents();
 /*N*/ 	if( pIo->bInsert )
 /*N*/ 	{
-/*?*/ 		ASSERT( pIo->pSectionDepths, "There is the section depth stack?" );
-/*?*/ 		ASSERT( pIo->pSectionDepths->Count() > 0U,
+/*?*/ 		OSL_ENSURE( pIo->pSectionDepths, "There is the section depth stack?" );
+/*?*/ 		OSL_ENSURE( pIo->pSectionDepths->Count() > 0U,
 /*?*/ 				"section depth stack is empty" );
 /*?*/ 		pIo->pSectionDepths->Remove( pIo->pSectionDepths->Count() - 1U );
 /*N*/ 	}
@@ -350,7 +347,7 @@ namespace binfilter {
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		ULONG nOff32 = Sw3IoImp::InULong( rStrm );
-/*N*/ 		ASSERT( nOff32 <= USHRT_MAX, "SwFmtPageDesc: Seitenzahl > USHRT_MAX" );
+/*N*/ 		OSL_ENSURE( nOff32 <= USHRT_MAX, "SwFmtPageDesc: Seitenzahl > USHRT_MAX" );
 /*N*/ 		nOff = (USHORT)nOff32;
 /*N*/ 		rStrm >> nIdx;
 /*N*/ 	}
@@ -362,7 +359,7 @@ namespace binfilter {
 
 /*N*/ USHORT SwFmtPageDesc::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtPageDesc: Gibt es ein neues Fileformat?" );
@@ -372,7 +369,7 @@ namespace binfilter {
 
 /*N*/ SvStream& SwFmtPageDesc::Store( SvStream& rStrm, USHORT nVersion) const
 /*N*/ {
-/*N*/ 	ASSERT( IVER_FMTPAGEDESC_NOAUTO != nVersion,
+/*N*/ 	OSL_ENSURE( IVER_FMTPAGEDESC_NOAUTO != nVersion,
 /*N*/ 			"SwFmtPageDesc: Export der Item-Version wird nicht unterstuetzt" );
 /*N*/
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
@@ -460,16 +457,16 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ SvStream& SwFmtFlyCnt::Store( SvStream& rStrm, USHORT ) const
 /*N*/ {
-/*N*/ 	SwFrmFmt* pFmt = GetFrmFmt();
-/*N*/ 	if( pFmt )
+/*N*/ 	SwFrmFmt* pFmt1 = GetFrmFmt();
+/*N*/ 	if( pFmt1 )
 /*N*/ 	{
 /*N*/ 		Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 		SvStream* p = pIo->pStrm;
 /*N*/ 		pIo->pStrm = (SvStorageStream*) &rStrm;
-/*N*/ 		if( RES_DRAWFRMFMT == pFmt->Which() )
-/*N*/ 			pIo->OutFormat( SWG_SDRFMT, *pFmt );
+/*N*/ 		if( RES_DRAWFRMFMT == pFmt1->Which() )
+/*N*/ 			pIo->OutFormat( SWG_SDRFMT, *pFmt1 );
 /*N*/ 		else
-/*N*/ 			pIo->OutFormat( SWG_FLYFMT, *pFmt );
+/*N*/ 			pIo->OutFormat( SWG_FLYFMT, *pFmt1 );
 /*N*/ 		pIo->pStrm = p;
 /*N*/ 	}
 /*N*/ 	return rStrm;
@@ -511,13 +508,13 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ SfxPoolItem* SwFmtINetFmt::Create( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
 /*N*/ 	UINT16 nId1, nId2;
-/*N*/ 	String aURL, aTarget;
-/*N*/ 	rStrm.ReadByteString( aURL, rStrm.GetStreamCharSet() );
+/*N*/ 	String aURL1, aTarget;
+/*N*/ 	rStrm.ReadByteString( aURL1, rStrm.GetStreamCharSet() );
 /*N*/ 	rStrm.ReadByteString( aTarget, rStrm.GetStreamCharSet() );
 /*N*/ 	rStrm >> nId1 >> nId2;
-/*N*/ 
-/*N*/ 	aURL = ::binfilter::StaticBaseUrl::SmartRelToAbs( aURL );
-/*N*/ 	SwFmtINetFmt *pNew = new SwFmtINetFmt( aURL, aTarget );
+/*N*/
+/*N*/ 	aURL1 = ::binfilter::StaticBaseUrl::SmartRelToAbs( aURL1 );
+/*N*/ 	SwFmtINetFmt *pNew = new SwFmtINetFmt( aURL1, aTarget );
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 	if( nId1 != IDX_NO_VALUE )
 /*N*/ 	{
@@ -550,9 +547,9 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 	}
 /*N*/ 	if( nIVer >= 1 )
 /*N*/ 	{
-/*N*/ 		String aName;
-/*N*/ 		rStrm.ReadByteString( aName, rStrm.GetStreamCharSet() );;
-/*N*/ 		pNew->SetName( aName );
+/*N*/ 		String aName1;
+/*N*/ 		rStrm.ReadByteString( aName1, rStrm.GetStreamCharSet() );;
+/*N*/ 		pNew->SetName( aName1 );
 /*N*/ 	}
 /*N*/ 	if( nIVer >= 2 )
 /*N*/ 	{
@@ -575,7 +572,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ SvStream& SwFmtINetFmt::Store( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( nIVer != USHRT_MAX,
+/*N*/ 	OSL_ENSURE( nIVer != USHRT_MAX,
 /*N*/ 			"SwFmtINetFmt: Wer faengt da Version USHRT_MAX nicht ab?" );
 /*N*/
 /*N*/ 	UINT16 nId1 = IDX_NO_VALUE;
@@ -585,8 +582,8 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*?*/ 		nId1 = (UINT16) pIo->aStringPool.Find( aINetFmt, nINetId );
 /*N*/ 	if( aVisitedFmt.Len() )
 /*?*/ 		nId2 = (UINT16) pIo->aStringPool.Find( aVisitedFmt, nVisitedId );
-/*N*/ 	String aURL( GetValue() );
-/*N*/ 	lcl_sw3io__ConvertMarkToOutline( aURL );
+/*N*/ 	String aURL2( GetValue() );
+/*N*/ 	lcl_sw3io__ConvertMarkToOutline( aURL2 );
 /*N*/ 	rStrm.WriteByteString( ::binfilter::StaticBaseUrl::AbsToRel( aURL URL_DECODE ),
 /*N*/ 						   rStrm.GetStreamCharSet() );
 /*N*/   	rStrm.WriteByteString( aTargetFrame, rStrm.GetStreamCharSet() );
@@ -646,7 +643,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ USHORT SwFmtINetFmt::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtINetFmr: Gibt es ein neues Fileformat?" );
@@ -656,20 +653,15 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ SfxPoolItem* SwFmtFtn::Create( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
-/*N*/ 	String aNumber;
-/*N*/ 	UINT16 nNumber;
-/*N*/ 	rStrm >> nNumber;
-/*N*/ 	rStrm.ReadByteString( aNumber, rStrm.GetStreamCharSet() );
+/*N*/ 	String aNumber1;
+/*N*/ 	UINT16 nNumber1;
+/*N*/ 	rStrm >> nNumber1;
+/*N*/ 	rStrm.ReadByteString( aNumber1, rStrm.GetStreamCharSet() );
 /*N*/
 /*N*/ 	// Die Section fuer den Text erzeugen
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 	SwNodes& rNodes = pIo->pDoc->GetNodes();
 /*N*/ 	SwNodeIndex aStart( rNodes.GetEndOfInserts() );
-/*N*/ #if 0
-/*N*/ 	SwStartNode* pSttNd = rNodes.MakeTextSection( aStart, SwFootnoteStartNode,
-/*N*/ 										pIo->FindTxtColl( IDX_DFLT_VALUE ) );
-/*N*/ 	aStart = *pSttNd;
-/*N*/ #endif
 /*N*/ 	SwStartNode* pSttNd = rNodes.MakeEmptySection( aStart,SwFootnoteStartNode );
 /*N*/ 	aStart = *pSttNd->EndOfSectionNode();
 /*N*/
@@ -679,19 +671,18 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*?*/ 			pIo->pSectionDepths = new SvUShorts;
 /*?*/ 		pIo->pSectionDepths->Insert( (USHORT)0U, pIo->pSectionDepths->Count() );
 /*N*/ 	}
-/*N*/ //	pIo->InContents( aStart );
 /*N*/ 	pIo->InContents( aStart, 0, FALSE );
 /*N*/ 	if( pIo->bInsert )
 /*N*/ 	{
-/*?*/ 		ASSERT( pIo->pSectionDepths, "There is the section depth stack?" );
-/*?*/ 		ASSERT( pIo->pSectionDepths->Count() > 0U,
+/*?*/ 		OSL_ENSURE( pIo->pSectionDepths, "There is the section depth stack?" );
+/*?*/ 		OSL_ENSURE( pIo->pSectionDepths->Count() > 0U,
 /*?*/ 				"section depth stack is empty" );
 /*?*/ 		pIo->pSectionDepths->Remove( pIo->pSectionDepths->Count() - 1U );
 /*N*/ 	}
 /*N*/
 /*N*/ 	// die Seq-Nummer einlesen - fuer die Querverweise auf Fussnoten
 /*N*/ 	USHORT nSeqNo;
-/*N*/ 	BOOL bEndNote = FALSE;
+/*N*/ 	BOOL bEndNote1 = FALSE;
 /*N*/ 	if( 1 <= nIVer )
 /*N*/ 	{
 /*N*/ 		rStrm >> nSeqNo;
@@ -700,12 +691,12 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 	{
 /*N*/ 		BYTE nFlags;
 /*N*/ 		rStrm >> nFlags;
-/*N*/ 		bEndNote = (nFlags & 0x01) != 0;
+/*N*/ 		bEndNote1 = (nFlags & 0x01) != 0;
 /*N*/ 	}
 /*N*/
-/*N*/ 	SwFmtFtn aFtn( bEndNote );
-/*N*/ 	aFtn.SetNumStr( aNumber );
-/*N*/ 	aFtn.SetNumber( nNumber );
+/*N*/ 	SwFmtFtn aFtn( bEndNote1 );
+/*N*/ 	aFtn.SetNumStr( aNumber1 );
+/*N*/ 	aFtn.SetNumber( nNumber1 );
 /*N*/
 /*N*/ 	// Das Fussnoten-Attribut liest seine Section "auf der Wiese" ein.
 /*N*/ 	// Hier muss also der Start errechnet und eingetragen werden.
@@ -749,7 +740,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 	SwNodeIndex* pStart = GetTxtFtn()->GetStartNode();
 /*N*/ 	if( pStart )
 /*N*/ 	{
-/*N*/ 		ASSERT( pIo, "SwFmtFtn: kein Sw3Io" );
+/*N*/ 		OSL_ENSURE( pIo, "SwFmtFtn: kein Sw3Io" );
 /*N*/ 		SvStream* p = pIo->pStrm;
 /*N*/ 		pIo->pStrm = (SvStorageStream*) &rStrm;
 /*N*/ 		pIo->OutContents( *pStart );
@@ -765,7 +756,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ USHORT SwFmtFtn::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtINetFmr: Gibt es ein neues Fileformat?" );
@@ -802,18 +793,18 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ SfxPoolItem* SwTOXMark::Create( SvStream& rStrm, USHORT nIVer ) const
 /*N*/ {
 /*N*/ 	BYTE cType;
-/*N*/ 	UINT16 nLevel, nStrIdx = IDX_NO_VALUE;
-/*N*/ 	String aTypeName, aAltText, aPrimKey, aSecKey;
+/*N*/ 	UINT16 nLevel1, nStrIdx = IDX_NO_VALUE;
+/*N*/ 	String aTypeName, aAltText1, aPrimKey, aSecKey;
 /*N*/ 	Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
 /*N*/ 	rStrm >> cType
-/*N*/ 		  >> nLevel;
+/*N*/ 		  >> nLevel1;
 /*N*/
 /*N*/ 	if( nIVer < IVER_TOXMARK_STRPOOL )
 /*N*/ 		rStrm.ReadByteString( aTypeName, rStrm.GetStreamCharSet() );
 /*N*/ 	else
 /*N*/ 		rStrm >> nStrIdx;
 /*N*/
-/*N*/ 	rStrm.ReadByteString( aAltText, rStrm.GetStreamCharSet() );
+/*N*/ 	rStrm.ReadByteString( aAltText1, rStrm.GetStreamCharSet() );
 /*N*/ 	rStrm.ReadByteString( aPrimKey, rStrm.GetStreamCharSet() );
 /*N*/ 	rStrm.ReadByteString( aSecKey, rStrm.GetStreamCharSet() );
 /*N*/
@@ -852,7 +843,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 		pIo->pDoc->InsertTOXType( SwTOXType( eType, aTypeName ) );
 /*N*/ 		pType = pIo->pDoc->GetTOXType( eType, n );
 /*N*/ 	}
-/*N*/ 	ASSERT( pType, "unknown tox type" );
+/*N*/ 	OSL_ENSURE( pType, "unknown tox type" );
 /*N*/ 	if( !pType )
 /*N*/ 	{
 /*?*/ 		pIo->Error();
@@ -860,7 +851,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 	}
 /*N*/
 /*N*/ 	SwTOXMark* pMark = new SwTOXMark( pType );
-/*N*/ 	pMark->SetAlternativeText( aAltText );
+/*N*/ 	pMark->SetAlternativeText( aAltText1 );
 /*N*/ 	switch( eType )
 /*N*/ 	{
 /*N*/ 		case TOX_INDEX:
@@ -875,7 +866,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 		case TOX_OBJECTS:
 /*N*/ 		case TOX_TABLES:
 /*N*/ 		case TOX_AUTHORITIES:
-/*N*/ 			pMark->SetLevel( nLevel );
+/*N*/ 			pMark->SetLevel( nLevel1 );
 /*N*/ 			break;
 /*N*/ 		default:
 /*?*/ 			pIo->Error();
@@ -907,14 +898,14 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 	if( nIVer < IVER_TOXMARK_STRPOOL )
 /*N*/ 	{
 /*N*/ 		// Nur 3.1/4.0-Export
-/*N*/ 		ASSERT( SOFFICE_FILEFORMAT_40 >= rStrm.GetVersion(),
+/*N*/ 		OSL_ENSURE( SOFFICE_FILEFORMAT_40 >= rStrm.GetVersion(),
 /*N*/ 				"SwToxMark: FF-Version und Item-Version passen nicht" );
 /*N*/ 		rStrm.WriteByteString( rTypeName, rStrm.GetStreamCharSet() );
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		// Nur 5.0 und folgende
-/*N*/ 		ASSERT( SOFFICE_FILEFORMAT_40 < rStrm.GetVersion(),
+/*N*/ 		OSL_ENSURE( SOFFICE_FILEFORMAT_40 < rStrm.GetVersion(),
 /*N*/ 				"SwToxMark: FF-Version und Item-Version passen nicht" );
 /*N*/ 		UINT16 nStrIdx =
 /*N*/ 			( eType >= TOX_ILLUSTRATIONS ||
@@ -944,7 +935,7 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 
 /*N*/ USHORT SwTOXMark::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwTOXMark: Gibt es ein neues Fileformat?" );
@@ -952,10 +943,10 @@ bool SwFmtFlyCnt::Sw3ioExportAllowed() const
 /*N*/ 			 SOFFICE_FILEFORMAT_40==nFFVer ) ? 0 : IVER_TOXMARK_NEWTOX;
 /*N*/ }
 
-SfxPoolItem* SwFmtRuby::Create(SvStream & rStrm, USHORT nVer) const
+SfxPoolItem* SwFmtRuby::Create(SvStream & rStrm, USHORT /*nVer*/) const
 {
-    String sRubyTxt;
-    SwFmtRuby* pRet = new SwFmtRuby( sRubyTxt );
+    String sRubyTxt1;
+    SwFmtRuby* pRet = new SwFmtRuby( sRubyTxt1 );
 
     BOOL bVal;
     rStrm >> bVal;
@@ -963,19 +954,18 @@ SfxPoolItem* SwFmtRuby::Create(SvStream & rStrm, USHORT nVer) const
     return pRet;
 }
 
-SvStream& SwFmtRuby::Store( SvStream & rStrm, USHORT nIVer ) const
+SvStream& SwFmtRuby::Store( SvStream & rStrm, USHORT /*nIVer*/ ) const
 {
     BOOL bVal = 0;
     rStrm << bVal;
 
-    ASSERT( FALSE, "Ruby atribute stored in old format" )
-
+    OSL_ENSURE( FALSE, "Ruby atribute stored in old format" );
     return rStrm;
 }
 
 /*N*/ USHORT SwFmtRuby::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtRuby: Gibt es ein neues Fileformat?" );
@@ -1008,7 +998,7 @@ SvStream& SwTblBoxFormula::Store( SvStream & rStrm, USHORT ) const
 
 /*N*/ USHORT SwTblBoxFormula::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwTblBoxFormula: Gibt es ein neues Fileformat?" );
@@ -1026,7 +1016,7 @@ SfxPoolItem* SwFmtChain::Create(SvStream& rStrm, USHORT nIVer) const
                 >> nNextIdx;
 
         Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
-        ASSERT( pIo || nPrevIdx != IDX_NO_VALUE || nNextIdx != IDX_NO_VALUE,
+        OSL_ENSURE( pIo || nPrevIdx != IDX_NO_VALUE || nNextIdx != IDX_NO_VALUE,
                 "SwFmtChain: kein sw3io: Verkettung nicht moeglich" );
         if( pIo )
         {
@@ -1039,7 +1029,7 @@ SfxPoolItem* SwFmtChain::Create(SvStream& rStrm, USHORT nIVer) const
             {
                 SwFlyFrmFmt *pPrevFlyFmt =
                     (SwFlyFrmFmt *)pIo->aStringPool.FindCachedFmt( nPrevIdx );
-                ASSERT( pIo->bInsert ||
+                OSL_ENSURE( pIo->bInsert ||
                         (SwFlyFrmFmt *)pIo->pDoc->FindSpzFrmFmtByName(
                         pIo->aStringPool.Find( nPrevIdx ) ) == pPrevFlyFmt,
                         "falsches Prev-Format gechached?" );
@@ -1049,7 +1039,7 @@ SfxPoolItem* SwFmtChain::Create(SvStream& rStrm, USHORT nIVer) const
             {
                 SwFlyFrmFmt *pNextFlyFmt =
                     (SwFlyFrmFmt *)pIo->aStringPool.FindCachedFmt( nNextIdx );
-                ASSERT( pIo->bInsert ||
+                OSL_ENSURE( pIo->bInsert ||
                         (SwFlyFrmFmt *)pIo->pDoc->FindSpzFrmFmtByName(
                         pIo->aStringPool.Find( nNextIdx ) ) == pNextFlyFmt,
                         "falsches Prev-Format gechached?" );
@@ -1063,7 +1053,7 @@ SfxPoolItem* SwFmtChain::Create(SvStream& rStrm, USHORT nIVer) const
 
 /*N*/ SvStream& SwFmtChain::Store(SvStream &rStrm, USHORT nIVer) const
 /*N*/ {
-        ASSERT( nIVer != USHRT_MAX,
+        OSL_ENSURE( nIVer != USHRT_MAX,
                 "SwFmtChain: Wer faengt da Version USHRT_MAX nicht ab?" );
 
         Sw3IoImp* pIo = Sw3IoImp::GetCurrentIo();
@@ -1090,14 +1080,14 @@ SfxPoolItem* SwFmtChain::Create(SvStream& rStrm, USHORT nIVer) const
 
 /*N*/ USHORT SwFmtChain::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/ 			"SwFmtChain: Gibt es ein neues Fileformat?" );
 /*N*/ 	return SOFFICE_FILEFORMAT_40 < nFFVer ? 1 : USHRT_MAX;
 /*N*/ }
 
-SfxPoolItem* SwTextGridItem::Create(SvStream& rStrm, USHORT nIVer) const
+SfxPoolItem* SwTextGridItem::Create(SvStream& rStrm, USHORT /*nIVer*/) const
 {
     SwTextGridItem* pRet = new SwTextGridItem;
     BOOL bVal;
@@ -1106,7 +1096,7 @@ SfxPoolItem* SwTextGridItem::Create(SvStream& rStrm, USHORT nIVer) const
     return pRet;
 }
 
-SvStream& SwTextGridItem::Store( SvStream & rStrm, USHORT nIVer ) const
+SvStream& SwTextGridItem::Store( SvStream & rStrm, USHORT /*nIVer*/ ) const
 {
     BOOL bVal = 0;
     rStrm << bVal;
@@ -1116,7 +1106,7 @@ SvStream& SwTextGridItem::Store( SvStream & rStrm, USHORT nIVer ) const
 
 /*N*/ USHORT SwTextGridItem::GetVersion( USHORT nFFVer ) const
 /*N*/ {
-/*N*/ 	ASSERT( SOFFICE_FILEFORMAT_31==nFFVer ||
+/*N*/ 	OSL_ENSURE( SOFFICE_FILEFORMAT_31==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_40==nFFVer ||
 /*N*/ 			SOFFICE_FILEFORMAT_50==nFFVer,
 /*N*/             "SwTextGridItem: Gibt es ein neues Fileformat?" );
