@@ -38,7 +38,7 @@
 #error Wer fummelt denn an den makefiles?
 #endif
 
-#define CONSTCHAR( name, string ) static const sal_Char __FAR_DATA name[] = string
+#define CONSTCHAR( name, string ) static const sal_Char name[] = string
 
 #include <horiornt.hxx>
 
@@ -265,7 +265,7 @@ namespace binfilter {
 /*N*/ }
 } //namespace binfilter
 /*N*/ #endif
-namespace binfilter {//STRIP009
+namespace binfilter {
 /*N*/ SvStream &operator<<( SvStream &rOs, const SwpHints &rHints ) //$ ostream
 /*N*/ {
 /*N*/ 	rOs << " {HINTS:";
@@ -329,12 +329,12 @@ namespace binfilter {//STRIP009
 } //namespace binfilter
 
 /*N*/ #if OSL_DEBUG_LEVEL < 2
-namespace binfilter {//STRIP009
+namespace binfilter {
 /*N*/ static void Error()
 /*N*/ {
 /*N*/ 	// wegen PM und BCC
 /*N*/ 	sal_Bool bFalse = sal_False;
-/*N*/ 	ASSERT( bFalse, "txtio: No debug version" );
+/*N*/ 	OSL_ENSURE( bFalse, "txtio: No debug version" );
 /*N*/ }
 
 #define IMPL_OUTOP(class) \
@@ -409,7 +409,7 @@ namespace binfilter {//STRIP009
 # include <stdlib.h>
 # include "swtypes.hxx"      // ZTCCONST
 # include "swfont.hxx"     // SwDropPortion
-namespace binfilter {//STRIP009
+namespace binfilter {
 /*N*/ CONSTCHAR( pClose, "} " );
 
 /*************************************************************************
@@ -472,7 +472,7 @@ namespace binfilter {//STRIP009
 /*N*/ 	  pPOR_HIDDEN, pPOR_QUOVADIS, pPOR_ERGOSUM,
 /*N*/ 	  pPOR_NUMBER, pPOR_BULLET, pPOR_UNKW, pPOR_PAR
 /*N*/ 	};
-/*N*/ 	ASSERT( eType < PORTYPE_END, "GetPortionName: bad type" );
+/*N*/ 	OSL_ENSURE( eType < PORTYPE_END, "GetPortionName: bad type" );
 /*N*/ 	return( ppNameArr[eType] );
 /*N*/ #else
 /*N*/ 	return 0;
@@ -510,7 +510,7 @@ namespace binfilter {//STRIP009
 /*N*/ 		pPREP_UL_SPACE, pPREP_MUST_FIT, pPREP_WIDOWS, pPREP_QUOVADIS,
 /*N*/ 		pPREP_PAGE
 /*N*/ 	};
-/*N*/ 	ASSERT( ePrep < PREP_END, "GetPrepName: unknown PrepareHint" );
+/*N*/ 	OSL_ENSURE( ePrep < PREP_END, "GetPrepName: unknown PrepareHint" );
 /*N*/ 	return( ppNameArr[ePrep] );
 /*N*/ }
 
