@@ -60,7 +60,7 @@ namespace binfilter {
 // Ein Follow, der auf der selben Seite steht, wie sein Master ist nasty.
 /*N*/ inline sal_Bool IsNastyFollow( const SwTxtFrm *pFrm )
 /*N*/ {
-/*N*/ 	ASSERT(	!pFrm->IsFollow() || !pFrm->GetPrev() ||
+/*N*/ 	OSL_ENSURE(	!pFrm->IsFollow() || !pFrm->GetPrev() ||
 /*N*/ 			((const SwTxtFrm*)pFrm->GetPrev())->GetFollow() == pFrm,
 /*N*/ 			"IsNastyFollow: Was ist denn hier los?" );
 /*N*/ 	return	pFrm->IsFollow() && pFrm->GetPrev();
@@ -71,7 +71,8 @@ namespace binfilter {
  *************************************************************************/
 
 /*N*/ SwTxtFrmBreak::SwTxtFrmBreak( SwTxtFrm *pFrm, const SwTwips nRst )
-/*N*/     : pFrm(pFrm), nRstHeight(nRst)
+/*N*/     : nRstHeight(nRst)
+/*N*/     , pFrm(pFrm)
 /*N*/ {
 /*N*/     SWAP_IF_SWAPPED( pFrm )
 /*N*/     SWRECTFN( pFrm )
@@ -134,7 +135,7 @@ namespace binfilter {
 /*N*/ 
 /*N*/     SwTwips nTmpY;
 /*N*/     if ( pFrm->IsVertical() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*?*/         nTmpY = pFrm->SwitchHorizontalToVertical( rLine.Y() + rLine.GetLineHeight() );
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/     else
 /*N*/         nTmpY = rLine.Y() + rLine.GetLineHeight();
 /*N*/ 
@@ -246,7 +247,9 @@ sal_Bool SwTxtFrmBreak::WouldFit( SwTxtMargin &rLine )
 
 /*N*/ WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pFrm, const SwTwips nRst,
 /*N*/ 	sal_Bool bChkKeep	)
-/*N*/ 	: SwTxtFrmBreak( pFrm, nRst ), nOrphLines( 0 ), nWidLines( 0 )
+/*N*/ 	: SwTxtFrmBreak( pFrm, nRst )
+/*N*/ 	, nWidLines( 0 )
+/*N*/ 	, nOrphLines( 0 )
 /*N*/ {
 /*N*/     SWAP_IF_SWAPPED( pFrm )
 /*N*/     SWRECTFN( pFrm )
@@ -359,8 +362,8 @@ sal_Bool SwTxtFrmBreak::WouldFit( SwTxtMargin &rLine )
 
 /*N*/ sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrm, SwTxtMargin &rLine )
 /*N*/ {
-/*N*/     ASSERT( ! pFrm->IsVertical() || ! pFrm->IsSwapped(),
-/*N*/             "WidowsAndOrphans::FindWidows with swapped frame" )
+/*N*/     OSL_ENSURE( ! pFrm->IsVertical() || ! pFrm->IsSwapped(),
+/*N*/             "WidowsAndOrphans::FindWidows with swapped frame" );
 /*N*/ 
 /*N*/ 	if( !nWidLines || !pFrm->IsFollow() )
 /*N*/ 		return sal_False;
@@ -369,7 +372,7 @@ sal_Bool SwTxtFrmBreak::WouldFit( SwTxtMargin &rLine )
 /*N*/ 
 /*N*/ 	// Wir koennen noch was abzwacken
 /*N*/ 	SwTxtFrm *pMaster = pFrm->FindMaster();
-/*N*/ 	ASSERT(pMaster, "+WidowsAndOrphans::FindWidows: Widows in a master?");
+/*N*/ 	OSL_ENSURE(pMaster, "+WidowsAndOrphans::FindWidows: Widows in a master?");
 /*N*/ 	if( !pMaster )
 /*N*/ 		return sal_False;
 /*N*/ 
@@ -387,7 +390,7 @@ sal_Bool SwTxtFrmBreak::WouldFit( SwTxtMargin &rLine )
 /*N*/ 
 /*N*/     if ( bVert )
 /*N*/     {
-            DBG_BF_ASSERT(0, "STRIP"); //STRIP001 /*?*/         nTmpY = pFrm->SwitchHorizontalToVertical( nTmpY );
+            DBG_BF_ASSERT(0, "STRIP");
 /*N*/     }
 /*N*/     else
 /*N*/         nOldHeight = (pFrm->Prt().*fnRect->fnGetHeight)();
@@ -481,7 +484,7 @@ sal_Bool SwTxtFrmBreak::WouldFit( SwTxtMargin &rLine )
 /*N*/     // IsInside() takes care for itself
 /*N*/ 
 /*N*/ 	// Wir erwarten, dass rLine auf der letzten Zeile steht!!
-/*N*/ 	ASSERT( !rLine.GetNext(), "WouldFit: aLine::Bottom missed!" );
+/*N*/ 	OSL_ENSURE( !rLine.GetNext(), "WouldFit: aLine::Bottom missed!" );
 /*N*/ 	MSHORT nLineCnt = rLine.GetLineNr();
 /*N*/ 
 /*N*/ 	// Erstmal die Orphansregel und den Initialenwunsch erfuellen ...
