@@ -79,9 +79,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 |*
 |*	SwFntCache::Flush()
 |*
-|*	Ersterstellung		AMA 16. Dez. 94
-|*	Letzte Aenderung	AMA 16. Dez. 94
-|*
 |*************************************************************************/
 
 /*N*/ void SwFntCache::Flush( )
@@ -98,9 +95,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 |*
 |*	SwFntObj::SwFntObj(), ~SwFntObj()
 |*
-|*	Ersterstellung		AMA 7. Nov. 94
-|*	Letzte Aenderung	AMA 7. Nov. 94
-|*
 |*************************************************************************/
 
 /*N*/ SwFntObj::SwFntObj( const SwSubFont &rFont, const void *pOwner, ViewShell *pSh ) :
@@ -155,9 +149,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *
  *  USHORT SwFntObj::GetAscent( const OutputDevice *pOut )
  *
- *	Ersterstellung		AMA 7. Nov. 94
- *	Letzte Aenderung	AMA 7. Nov. 94
- *
  *  Beschreibung: liefern den Ascent des Fonts auf dem
  * 	gewuenschten Outputdevice zurueck, ggf. muss der Bildschirmfont erst
  *  erzeugt werden.
@@ -229,15 +220,12 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *
  *  SwFntObj::CreateScrFont( const ViewShell *pSh, const OutputDevice& rOut )
  *
- *	Ersterstellung		AMA 7. Nov. 94
- *	Letzte Aenderung	AMA 7. Nov. 94
- *
  *  pOut is the output device, not the reference device
  *
  *************************************************************************/
 
-/*N*/ void SwFntObj::CreateScrFont( const ViewShell *pSh, const OutputDevice& rOut )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SwFntObj::CreateScrFont( const ViewShell* /*pSh*/, const OutputDevice& /*rOut*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 
@@ -284,7 +272,7 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 /*?*/ 					aWinMet.GetAscent() - rMet.GetAscent() - nTmpLeading );
 /*?*/ 				if( nDiff > 0 )
 /*?*/ 				{
-/*?*/ 					ASSERT( nPrtAscent < USHRT_MAX, "GuessLeading: PrtAscent-Fault" );
+/*?*/ 					OSL_ENSURE( nPrtAscent < USHRT_MAX, "GuessLeading: PrtAscent-Fault" );
 /*?*/                   nPrtAscent += (USHORT)(( 2 * nDiff ) / 5);
 /*?*/ 				}
 /*N*/ 			}
@@ -311,9 +299,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *
  *	void SwFntObj::SetDeviceFont( const OutputDevice *pOut ),
  *
- *	Ersterstellung		AMA 7. Nov. 94
- *	Letzte Aenderung	AMA 7. Nov. 94
- *
  *  Beschreibung: stellt den Font am gewuenschten OutputDevice ein,
  *  am Bildschirm muss eventuell erst den Abgleich durchgefuehrt werden.
  *
@@ -366,9 +351,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *
  * void SwFntObj::DrawText( ... )
  *
- *	Ersterstellung		AMA 16. Dez. 94
- *	Letzte Aenderung	AMA 16. Dez. 94
- *
  *  Beschreibung: Textausgabe
  * 					auf dem Bildschirm 			=> DrawTextArray
  * 					auf dem Drucker, !Kerning 	=> DrawText
@@ -377,8 +359,8 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *************************************************************************/
 
 
-/*N*/ sal_Bool lcl_IsMonoSpaceFont( const OutputDevice* pOut )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return sal_False; //STRIP001 
+/*N*/ sal_Bool lcl_IsMonoSpaceFont( const OutputDevice* /*pOut*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP"); return sal_False;
 /*N*/ }
 
 // ER 09.07.95 20:34
@@ -402,9 +384,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
  *	Size SwFntObj::GetTextSize( const OutputDevice *pOut, const String &rTxt,
  *			 const USHORT nIdx, const USHORT nLen, const short nKern = 0 );
  *
- *	Ersterstellung		AMA 16. Dez. 94
- *	Letzte Aenderung	AMA 16. Dez. 94
- *
  *  Beschreibung: ermittelt die TextSize (des Druckers)
  *
  *************************************************************************/
@@ -465,20 +444,20 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 /*N*/                            rInf.GetScriptInfo()->CountCompChg() &&
 /*N*/                      lcl_IsMonoSpaceFont( rInf.GetpOut() );
 /*N*/ 
-/*N*/ 	ASSERT(	!bCompress || ( rInf.GetScriptInfo() && rInf.GetScriptInfo()->
+/*N*/ 	OSL_ENSURE(	!bCompress || ( rInf.GetScriptInfo() && rInf.GetScriptInfo()->
 /*N*/ 			CountCompChg()), "Compression without info" );
 /*N*/ 
 /*N*/     // This is the part used e.g., for cursor travelling
 /*N*/     // See condition for DrawText or DrawTextArray (bDirectPrint)
 /*N*/     if ( pPrinter && pPrinter != rInf.GetpOut() )
-/*N*/ 	{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ 	{DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 	}
 /*N*/ 	else
 /*N*/ 	{
 /*N*/         if( !pPrtFont->IsSameInstance( rInf.GetpOut()->GetFont() ) )
 /*N*/             rInf.GetpOut()->SetFont( *pPrtFont );
 /*N*/ 		if( bCompress )
-/*N*/ 		{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ 		{DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		else
 /*N*/ 		{
@@ -504,9 +483,6 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 |*
 |*	SwFntAccess::SwFntAccess()
 |*
-|*	Ersterstellung		AMA 9. Nov. 94
-|*	Letzte Aenderung	AMA 9. Nov. 94
-|*
 |*************************************************************************/
 
 /*N*/ SwFntAccess::SwFntAccess( const void* &rMagic,
@@ -585,14 +561,14 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 /*N*/ 			// SwFont sein, spaeter wird als Owner die "MagicNumber" gehalten.
 /*N*/ 			SwCacheAccess::pOwner = pOwner;
 /*N*/ 			pFntObj = Get(); // hier wird via NewObj() angelegt und gelockt.
-/*N*/ 			ASSERT(pFntObj, "No Font, no Fun.");
+/*N*/ 			OSL_ENSURE(pFntObj, "No Font, no Fun.");
 /*N*/ 		}
 /*N*/         else  // Font has been found, so we lock it.
 /*N*/ 		{
 /*N*/ 			pFntObj->Lock();
 /*N*/ 			if( pFntObj->pPrinter != pOut ) // Falls bis dato kein Drucker bekannt
 /*N*/ 			{
-/*N*/ 				ASSERT( !pFntObj->pPrinter, "SwFntAccess: Printer Changed" );
+/*N*/ 				OSL_ENSURE( !pFntObj->pPrinter, "SwFntAccess: Printer Changed" );
 /*N*/                 pFntObj->CreatePrtFont( *pOut );
 /*N*/ 				pFntObj->pPrinter = pOut;
 /*N*/ 				pFntObj->pScrFont = NULL;
@@ -634,7 +610,7 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 /*N*/                            rInf.GetScriptInfo()->CountCompChg() &&
 /*N*/                      lcl_IsMonoSpaceFont( rInf.GetpOut() );
 /*N*/ 
-/*N*/     ASSERT( !bCompress || ( rInf.GetScriptInfo() && rInf.GetScriptInfo()->
+/*N*/     OSL_ENSURE( !bCompress || ( rInf.GetScriptInfo() && rInf.GetScriptInfo()->
 /*N*/             CountCompChg()), "Compression without info" );
 /*N*/ 
 /*N*/ 	USHORT nTxtBreak = 0;
@@ -676,7 +652,7 @@ extern USHORT UnMapDirection( USHORT nDir, const BOOL bVertFormat );
 /*N*/     }
 /*N*/ 
 /*N*/     if( aSub[nActual].IsCapital() && nLn )
-/*?*/ 		{DBG_BF_ASSERT(0, "STRIP");} //STRIP001 nTxtBreak = GetCapitalBreak( rInf.GetShell(), rInf.GetpOut(),
+/*?*/ 		{DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 	else
 /*N*/ 	{
 /*N*/ 		nKern = CheckKerning();
