@@ -26,20 +26,16 @@
  *
  ************************************************************************/
 
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
 
-
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include "XMLRedlineImportHelper.hxx"
-
 #include "unoobj.hxx"
 
 #include <unocrsr.hxx>
-
 #include <horiornt.hxx>
 
 #include "doc.hxx"
@@ -47,19 +43,13 @@
 #include <tools/datetime.hxx>
 
 #include "poolfmt.hxx"
-
 #include "unoredline.hxx"
 
 #include <bf_xmloff/xmltoken.hxx>
-
 #include <com/sun/star/lang/XUnoTunnel.hpp>
-
 #include <com/sun/star/text/XWordCursor.hpp>
-
 #include <com/sun/star/frame/XModel.hpp>
-
 #include <com/sun/star/beans/XPropertySet.hpp>
-
 #include <com/sun/star/beans/XPropertySetInfo.hpp>
 
 // for locking SolarMutex: svapp + mutex
@@ -181,6 +171,7 @@ void XTextRangeOrNodeIndexPosition::SetAsNodeIndex(
     SwUnoInternalPaM aPaM(*pDoc);
     sal_Bool bSuccess = SwXTextRange::XTextRangeToSwPaM( aPaM, rRange);
     DBG_ASSERT(bSuccess, "illegal range");
+    (void)bSuccess;
 
     // PaM -> Index
     Set(aPaM.GetPoint()->nNode);
@@ -196,6 +187,7 @@ void XTextRangeOrNodeIndexPosition::CopyPositionInto(SwPosition& rPos)
         SwUnoInternalPaM aUnoPaM(*GetDoc());
         sal_Bool bSuccess = SwXTextRange::XTextRangeToSwPaM(aUnoPaM, xRange);
         DBG_ASSERT(bSuccess, "illegal range");
+        (void)bSuccess;
 
         rPos = *aUnoPaM.GetPoint();
     }
@@ -262,12 +254,12 @@ RedlineInfo::RedlineInfo() :
     sAuthor(),
     sComment(),
     aDateTime(),
+    bMergeLastParagraph( sal_False ),
     aAnchorStart(),
     aAnchorEnd(),
     pContentIndex(NULL),
     pNextRedline(NULL),
-    bNeedsAdjustment( sal_False ),
-    bMergeLastParagraph( sal_False )
+    bNeedsAdjustment( sal_False )
 {
 }
 
@@ -332,7 +324,7 @@ XMLRedlineImportHelper::~XMLRedlineImportHelper()
 {
     // delete all left over (and obviously incomplete) RedlineInfos (and map)
     RedlineMapType::iterator aFind = aRedlineMap.begin();
-    for( ; aRedlineMap.end() != aFind; aFind++ )
+    for( ; aRedlineMap.end() != aFind; ++aFind )
     {
         RedlineInfo* pInfo = aFind->second;
 
@@ -340,7 +332,7 @@ XMLRedlineImportHelper::~XMLRedlineImportHelper()
         // and delete the incomplete ones. Finally, delete it.
         if( IsReady(pInfo) )
         {
-            DBG_ERROR("forgotten RedlineInfo; now inserted");
+            OSL_FAIL("forgotten RedlineInfo; now inserted");
             InsertIntoDocument( pInfo );
         }
         else 
@@ -349,7 +341,7 @@ XMLRedlineImportHelper::~XMLRedlineImportHelper()
             pInfo->bNeedsAdjustment = sal_False;
             if( IsReady(pInfo) )
             {
-                DBG_ERROR("RedlineInfo without adjustment; now inserted");
+                OSL_FAIL("RedlineInfo without adjustment; now inserted");
                 InsertIntoDocument( pInfo );
             }
             else
@@ -358,7 +350,7 @@ XMLRedlineImportHelper::~XMLRedlineImportHelper()
                 // (i.e. end without start, or start without
                 // end). This may well be a problem in the file,
                 // rather than the code.
-                DBG_ERROR("incomplete redline (maybe file was corrupt); "
+                OSL_FAIL("incomplete redline (maybe file was corrupt); "
                           "now deleted");
             }
         }
@@ -567,8 +559,8 @@ void XMLRedlineImportHelper::SetCursor(
 
 void XMLRedlineImportHelper::AdjustStartNodeCursor(
     const OUString& rId,		/// ID used in RedlineAdd() call
-    sal_Bool bStart,
-    Reference<XTextRange> & rRange)
+    sal_Bool /*bStart*/,
+    Reference<XTextRange> & /*rRange*/)
 {
     // this method will modify the document directly -> lock SolarMutex
     SolarMutexGuard aGuard;
