@@ -53,7 +53,7 @@
 
 #include <doc.hxx>
 
-#include <errhdl.hxx>
+#include <osl/diagnose.h>
 
 #include <viscrs.hxx>
 #include <unoobj.hxx>
@@ -121,7 +121,7 @@ enum SwXMLDocTokens
     XML_TOK_OFFICE_END=XML_TOK_UNKNOWN
 };
 
-static __FAR_DATA SvXMLTokenMapEntry aDocTokenMap[] =
+static SvXMLTokenMapEntry aDocTokenMap[] =
 {
     { XML_NAMESPACE_OFFICE, XML_FONT_DECLS,     XML_TOK_DOC_FONTDECLS	},
     { XML_NAMESPACE_OFFICE, XML_STYLES,	        XML_TOK_DOC_STYLES		},
@@ -142,20 +142,20 @@ class SwXMLDocContext_Impl : public SvXMLImportContext
 
 public:
 
-    SwXMLDocContext_Impl( SwXMLImport& rImport, sal_uInt16 nPrfx,
+    SwXMLDocContext_Impl( SwXMLImport& rInImport, sal_uInt16 nPrfx,
                 const OUString& rLName,
                 const Reference< xml::sax::XAttributeList > & xAttrList );
     virtual ~SwXMLDocContext_Impl();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nInPrefix,
                 const OUString& rLocalName,
                 const Reference< xml::sax::XAttributeList > & xAttrList );
 };
 
-SwXMLDocContext_Impl::SwXMLDocContext_Impl( SwXMLImport& rImport,
+SwXMLDocContext_Impl::SwXMLDocContext_Impl( SwXMLImport& rInImport,
                 sal_uInt16 nPrfx, const OUString& rLName,
                 const Reference< xml::sax::XAttributeList > & xAttrList ) :
-    SvXMLImportContext( rImport, nPrfx, rLName )
+    SvXMLImportContext( rInImport, nPrfx, rLName )
 {
     // process document class
     // global-text is handled via document shell;
@@ -164,11 +164,11 @@ SwXMLDocContext_Impl::SwXMLDocContext_Impl( SwXMLImport& rImport,
     for(sal_Int16 nAttr = 0; nAttr < nLength; nAttr++)
     {
         OUString sLocalName;
-        sal_uInt16 nPrefix = GetImport().GetNamespaceMap().
+        sal_uInt16 nLclPrefix = GetImport().GetNamespaceMap().
             GetKeyByAttrName( xAttrList->getNameByIndex(nAttr),
                               &sLocalName );
 
-        if ( (XML_NAMESPACE_OFFICE == nPrefix) &&
+        if ( (XML_NAMESPACE_OFFICE == nLclPrefix) &&
              IsXMLToken( sLocalName, XML_CLASS ) )
         {
             if ( IsXMLToken( xAttrList->getValueByIndex(nAttr), XML_LABEL ) )
@@ -198,14 +198,14 @@ SwXMLDocContext_Impl::~SwXMLDocContext_Impl()
 }
 
 SvXMLImportContext *SwXMLDocContext_Impl::CreateChildContext(
-        sal_uInt16 nPrefix,
+        sal_uInt16 nInPrefix,
         const OUString& rLocalName,
         const Reference< xml::sax::XAttributeList > & xAttrList )
 {
     SvXMLImportContext *pContext = 0;
 
     const SvXMLTokenMap& rTokenMap = GetSwImport().GetDocElemTokenMap();
-    switch( rTokenMap.Get( nPrefix, rLocalName ) )
+    switch( rTokenMap.Get( nInPrefix, rLocalName ) )
     {
     case XML_TOK_DOC_FONTDECLS:
         pContext = GetSwImport().CreateFontDeclsContext( rLocalName,
@@ -243,12 +243,12 @@ SvXMLImportContext *SwXMLDocContext_Impl::CreateChildContext(
         pContext = GetSwImport().CreateBodyContext( rLocalName );
         break;
     case XML_TOK_DOC_SETTINGS:
-        pContext = new XMLDocumentSettingsContext ( GetImport(), nPrefix, rLocalName, xAttrList );
+        pContext = new XMLDocumentSettingsContext ( GetImport(), nInPrefix, rLocalName, xAttrList );
         break;
     }
 
     if( !pContext )
-        pContext = new SvXMLImportContext( GetImport(), nPrefix, rLocalName );
+        pContext = new SvXMLImportContext( GetImport(), nInPrefix, rLocalName );
 
 
     return pContext;
@@ -265,22 +265,22 @@ const SvXMLTokenMap& SwXMLImport::GetDocElemTokenMap()
 }
 
 SvXMLImportContext *SwXMLImport::CreateContext(
-        sal_uInt16 nPrefix,
+        sal_uInt16 nInPrefix,
         const OUString& rLocalName,
         const Reference< xml::sax::XAttributeList > & xAttrList )
 {
     SvXMLImportContext *pContext = 0;
 
-    if( XML_NAMESPACE_OFFICE==nPrefix &&
+    if( XML_NAMESPACE_OFFICE==nInPrefix &&
         ( IsXMLToken( rLocalName, XML_DOCUMENT ) ||
           IsXMLToken( rLocalName, XML_DOCUMENT_META ) ||
           IsXMLToken( rLocalName, XML_DOCUMENT_SETTINGS ) ||
           IsXMLToken( rLocalName, XML_DOCUMENT_STYLES ) ||
           IsXMLToken( rLocalName, XML_DOCUMENT_CONTENT ) ))
-        pContext = new SwXMLDocContext_Impl( *this, nPrefix, rLocalName,
+        pContext = new SwXMLDocContext_Impl( *this, nInPrefix, rLocalName,
                                              xAttrList );
     else
-        pContext = SvXMLImport::CreateContext( nPrefix, rLocalName, xAttrList );
+        pContext = SvXMLImport::CreateContext( nInPrefix, rLocalName, xAttrList );
 
     return pContext;
 }
@@ -290,20 +290,20 @@ SwXMLImport::SwXMLImport(
     const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > xServiceFactory,
     sal_uInt16 nImportFlags) 
 :	SvXMLImport( xServiceFactory, nImportFlags ),
-    bLoadDoc( sal_True ),
-    bInsert( sal_False ),
-    bBlock( sal_False ),
-    bOrganizerMode( sal_False ),
-    nStyleFamilyMask( SFX_STYLE_FAMILY_ALL ),
+    pSttNdIdx( 0 ),
+    pTableItemMapper( 0 ),
     pDocElemTokenMap( 0 ),
     pTableElemTokenMap( 0 ),
     pTableCellAttrTokenMap( 0 ),
-    pTableItemMapper( 0 ),
-    pSttNdIdx( 0 ),
-    bShowProgress( sal_True ),
-    bPreserveRedlineMode( sal_True ),
     pGraphicResolver( 0 ),
-    pEmbeddedResolver( 0 )
+    pEmbeddedResolver( 0 ),
+    nStyleFamilyMask( SFX_STYLE_FAMILY_ALL ),
+    bLoadDoc( sal_True ),
+    bInsert( sal_False ),
+    bBlock( sal_False ),
+    bShowProgress( sal_True ),
+    bOrganizerMode( sal_False ),
+    bPreserveRedlineMode( sal_True )
 {
     _InitItemImport();
 
@@ -403,13 +403,13 @@ sal_Int64 SAL_CALL SwXMLImport::getSomething( const Sequence< sal_Int8 >& rId )
 OTextCursorHelper *lcl_xml_GetSwXTextCursor( const Reference < XTextCursor >& rTextCursor )
 {
     Reference<XUnoTunnel> xCrsrTunnel( rTextCursor, UNO_QUERY );
-    ASSERT( xCrsrTunnel.is(), "missing XUnoTunnel for Cursor" );
+    OSL_ENSURE( xCrsrTunnel.is(), "missing XUnoTunnel for Cursor" );
     if( !xCrsrTunnel.is() )
         return 0;
     OTextCursorHelper *pTxtCrsr =
         (OTextCursorHelper *)xCrsrTunnel->getSomething(
                                             OTextCursorHelper::getUnoTunnelId() );
-    ASSERT( pTxtCrsr, "SwXTextCursor missing" );
+    OSL_ENSURE( pTxtCrsr, "SwXTextCursor missing" );
     return pTxtCrsr;
 }
 
@@ -445,12 +445,12 @@ void SwXMLImport::startDocument( void )
         if( IMPORT_ALL == getImportFlags() )
         {
             pTxtCrsr = lcl_xml_GetSwXTextCursor( xTextCursor );
-            ASSERT( pTxtCrsr, "SwXTextCursor missing" );
+            OSL_ENSURE( pTxtCrsr, "SwXTextCursor missing" );
             if( !pTxtCrsr )
                 return;
 
             pDoc = pTxtCrsr->GetDoc();
-            ASSERT( pDoc, "SwDoc missing" );
+            OSL_ENSURE( pDoc, "SwDoc missing" );
             if( !pDoc )
                 return;
 
@@ -478,12 +478,12 @@ void SwXMLImport::startDocument( void )
 
     if( !pTxtCrsr  )
         pTxtCrsr = lcl_xml_GetSwXTextCursor( xTextCursor );
-    ASSERT( pTxtCrsr, "SwXTextCursor missing" );
+    OSL_ENSURE( pTxtCrsr, "SwXTextCursor missing" );
     if( !pTxtCrsr )
         return;
 
     SwDoc *pDoc = pTxtCrsr->GetDoc();
-    ASSERT( pDoc, "SwDoc missing" );
+    OSL_ENSURE( pDoc, "SwDoc missing" );
     if( !pDoc )
         return;
 
@@ -516,8 +516,8 @@ void SwXMLImport::startDocument( void )
     if( !GetGraphicResolver().is() )
     {
         pGraphicResolver = SvXMLGraphicHelper::Create( GRAPHICHELPER_MODE_READ );
-        Reference< document::XGraphicObjectResolver > xGraphicResolver( pGraphicResolver );
-        SetGraphicResolver( xGraphicResolver );
+        Reference< document::XGraphicObjectResolver > xLclGraphicResolver( pGraphicResolver );
+        SetGraphicResolver( xLclGraphicResolver );
     }
 
     if( !GetEmbeddedResolver().is() )
@@ -528,8 +528,8 @@ void SwXMLImport::startDocument( void )
             pEmbeddedResolver = SvXMLEmbeddedObjectHelper::Create(
                                             *pPersist,
                                             EMBEDDEDOBJECTHELPER_MODE_READ );
-            Reference< document::XEmbeddedObjectResolver > xEmbeddedResolver( pEmbeddedResolver );
-            SetEmbeddedResolver( xEmbeddedResolver );
+            Reference< document::XEmbeddedObjectResolver > xLclEmbeddedResolver( pEmbeddedResolver );
+            SetEmbeddedResolver( xLclEmbeddedResolver );
         }
     }
 }
@@ -560,11 +560,11 @@ void SwXMLImport::endDocument( void )
     {
         Reference<XUnoTunnel> xCrsrTunnel( GetTextImport()->GetCursor(),
                                               UNO_QUERY);
-        ASSERT( xCrsrTunnel.is(), "missing XUnoTunnel for Cursor" );
+        OSL_ENSURE( xCrsrTunnel.is(), "missing XUnoTunnel for Cursor" );
         OTextCursorHelper *pTxtCrsr =
                 (OTextCursorHelper*)xCrsrTunnel->getSomething(
                                             OTextCursorHelper::getUnoTunnelId() );
-        ASSERT( pTxtCrsr, "SwXTextCursor missing" );
+        OSL_ENSURE( pTxtCrsr, "SwXTextCursor missing" );
         SwPaM *pPaM = pTxtCrsr->GetPaM();
         if( IsInsertMode() && pSttNdIdx->GetIndex() )
         {
@@ -587,10 +587,10 @@ void SwXMLImport::endDocument( void )
 
 #ifdef DBG_UTIL
                 // !!! This should be impossible !!!!
-                ASSERT( pSttNdIdx->GetIndex()+1 !=
+                OSL_ENSURE( pSttNdIdx->GetIndex()+1 !=
                                         pPaM->GetBound( sal_True ).nNode.GetIndex(),
                         "PaM.Bound1 point to new node " );
-                ASSERT( pSttNdIdx->GetIndex()+1 !=
+                OSL_ENSURE( pSttNdIdx->GetIndex()+1 !=
                                         pPaM->GetBound( sal_False ).nNode.GetIndex(),
                         "PaM.Bound2 points to new node" );
 
@@ -797,13 +797,13 @@ void SwXMLImport::SetViewSettings(const Sequence < PropertyValue > & aViewProps)
     Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
     Reference < XText > xText = xTextDoc->getText();
     Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-    ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+    OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
     if( !xTextTunnel.is() )
         return;
 
     SwXText *pText = (SwXText *)xTextTunnel->getSomething(
                                         SwXText::getUnoTunnelId() );
-    ASSERT( pText, "SwXText missing" );
+    OSL_ENSURE( pText, "SwXText missing" );
     if( !pText )
         return;
 
@@ -815,7 +815,7 @@ void SwXMLImport::SetViewSettings(const Sequence < PropertyValue > & aViewProps)
     sal_Int32 nCount = aViewProps.getLength();
     const PropertyValue *pValue = aViewProps.getConstArray();
 
-    long nTmp;
+    long nTmp(0);
     sal_Bool bShowRedlineChanges = sal_False, bBrowseMode = sal_False,
              bShowFooter = sal_False, bShowHeader = sal_False;
     sal_Bool bChangeShowRedline = sal_False, bChangeBrowseMode = sal_False,
@@ -1069,7 +1069,7 @@ void main()
         if( !bIsUserSetting )
         {
             // test over the hash value if the entry is in the table.
-            const sal_Unicode* p = pValues->Name;
+            const sal_Unicode* p = pValues->Name.getStr();
             for( ULONG nLen = pValues->Name.getLength(); nLen; --nLen, ++p )
                 nHash = (nHash * nPrime) ^ ( *p - nSub );
             nHash %= SAL_N_ELEMENTS( aNotSetArr );
@@ -1095,7 +1095,7 @@ void main()
             }
             catch( Exception& )
             {
-                DBG_ERROR( "SwXMLImport::SetConfigurationSettings: Exception!" );
+                OSL_FAIL( "SwXMLImport::SetConfigurationSettings: Exception!" );
             }
         }
         pValues++;
@@ -1115,12 +1115,12 @@ void main()
     Reference < XTextDocument > xTextDoc( GetModel(), UNO_QUERY );
     Reference < XText > xText = xTextDoc->getText();
     Reference<XUnoTunnel> xTextTunnel( xText, UNO_QUERY);
-    ASSERT( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
+    OSL_ENSURE( xTextTunnel.is(), "missing XUnoTunnel for Cursor" );
     if( xTextTunnel.is() )
     {
         SwXText *pText = (SwXText *)xTextTunnel->getSomething(
                                         SwXText::getUnoTunnelId() );
-        ASSERT( pText, "SwXText missing" );
+        OSL_ENSURE( pText, "SwXText missing" );
         if( pText )
         {
             SwDoc *pDoc = pText->GetDoc();
