@@ -31,81 +31,44 @@
 #endif
 
 #include <com/sun/star/ucb/XAnyCompareFactory.hpp>
-
 #include <com/sun/star/container/XIndexReplace.hpp>
-
 #include <com/sun/star/drawing/LineStyle.hpp>
-
 #include <com/sun/star/drawing/LineJoint.hpp>
-
 #include <com/sun/star/drawing/FillStyle.hpp>
-
 #include <com/sun/star/presentation/AnimationSpeed.hpp>
-
 #include <com/sun/star/presentation/FadeEffect.hpp>
-
 #include <com/sun/star/drawing/ConnectorType.hpp>
-
 #include <com/sun/star/drawing/RectanglePoint.hpp>
-
 #include <com/sun/star/drawing/CircleKind.hpp>
-
 #include <com/sun/star/drawing/BitmapMode.hpp>
-
 #include <com/sun/star/text/WritingMode.hpp>
-
 #include <EnumPropertyHdl.hxx>
-
 #include <NamedBoolPropertyHdl.hxx>
-
 #include "numithdl.hxx"
-
 #include "XMLBitmapRepeatOffsetPropertyHandler.hxx"
-
 #include "XMLFillBitmapSizePropertyHandler.hxx"
-
 #include "XMLBitmapLogicalSizePropertyHandler.hxx"
-
 #include <com/sun/star/drawing/TextAnimationKind.hpp>
-
 #include <com/sun/star/drawing/TextAnimationDirection.hpp>
-
 #include <com/sun/star/drawing/TextHorizontalAdjust.hpp>
-
 #include <com/sun/star/drawing/TextVerticalAdjust.hpp>
-
 #include <com/sun/star/drawing/TextFitToSizeType.hpp>
-
 #include <com/sun/star/drawing/MeasureTextHorzPos.hpp>
-
 #include <com/sun/star/drawing/MeasureTextVertPos.hpp>
-
 #include "ControlBorderHandler.hxx"
-
-
 #include "sdpropls.hxx"
-
 #include "propimp0.hxx"
-
 #include "xmlexp.hxx"
-
 #include <xmlnmspe.hxx>
-
 #include <com/sun/star/drawing/NormalsKind.hpp>
-
 #include <com/sun/star/drawing/TextureProjectionMode.hpp>
-
 #include <com/sun/star/drawing/TextureKind.hpp>
-
 #include <com/sun/star/drawing/TextureMode.hpp>
-
 #include "txtprmap.hxx"
-
 #include "XMLClipPropertyHandler.hxx"
-
 #include "XMLIsPercentagePropertyHandler.hxx"
-
 #include "XMLPercentOrMeasurePropertyHandler.hxx"
+
 namespace binfilter {
 
 using namespace ::rtl;
@@ -113,6 +76,7 @@ using namespace ::com::sun::star;
 using namespace ::binfilter::xmloff::token;
 
 #define MAP(name,prefix,token,type,context)  { name, sizeof(name)-1, prefix, token, type, context }
+#define MAP_ENTRY_END { 0,0,0,xmloff::token::XML_TOKEN_INVALID,0,0 }
 
 //////////////////////////////////////////////////////////////////////////////
 // entry list for graphic properties
@@ -307,7 +271,7 @@ const XMLPropertyMapEntry aXMLSDProperties[] =
     // misc object properties
     MAP( "MoveProtect",			    	XML_NAMESPACE_DRAW, XML_MOVE_PROTECT,				XML_TYPE_BOOL, CTF_SD_MOVE_PROTECT ),
     MAP( "SizeProtect",			    	XML_NAMESPACE_DRAW, XML_SIZE_PROTECT,				XML_TYPE_BOOL, CTF_SD_SIZE_PROTECT ),
-    { 0L }
+    MAP_ENTRY_END
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -346,7 +310,7 @@ const XMLPropertyMapEntry aXMLSDPresPageProps[] =
     MAP( "FillBitmapOffsetX",			XML_NAMESPACE_DRAW,	XML_TILE_REPEAT_OFFSET,	    XML_SD_TYPE_BITMAPREPOFFSETX|MID_FLAG_MULTI_PROPERTY, CTF_REPEAT_OFFSET_X ),
     MAP( "FillBitmapOffsetY",			XML_NAMESPACE_DRAW,	XML_TILE_REPEAT_OFFSET,	XML_SD_TYPE_BITMAPREPOFFSETY|MID_FLAG_MULTI_PROPERTY, CTF_REPEAT_OFFSET_Y ),
 
-    { 0L }
+    MAP_ENTRY_END
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -548,7 +512,7 @@ SvXMLEnumMapEntry aXML_WritingMode_EnumMap[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimation_Enum[] =
+SvXMLEnumMapEntry const pXML_TextAnimation_Enum[] =
 {
     { XML_NONE, 		drawing::TextAnimationKind_NONE	},
     { XML_BLINKING,	    drawing::TextAnimationKind_BLINK },	// will be filtered
@@ -558,7 +522,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimation_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimation_Blinking_Enum[] =
+SvXMLEnumMapEntry const pXML_TextAnimation_Blinking_Enum[] =
 {
     { XML_FALSE,		drawing::TextAnimationKind_NONE	},
     { XML_TRUE, 		drawing::TextAnimationKind_BLINK },
@@ -568,7 +532,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimation_Blinking_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimationDirection_Enum[] =
+SvXMLEnumMapEntry const pXML_TextAnimationDirection_Enum[] =
 {
     { XML_LEFT,	    	drawing::TextAnimationDirection_LEFT },
     { XML_RIGHT,		drawing::TextAnimationDirection_RIGHT },	// will be filtered
@@ -577,7 +541,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_TextAnimationDirection_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_TextAlign_Enum[] =
+SvXMLEnumMapEntry const pXML_TextAlign_Enum[] =
 {
     { XML_LEFT,		    drawing::TextHorizontalAdjust_LEFT },
     { XML_CENTER,		drawing::TextHorizontalAdjust_CENTER },
@@ -586,7 +550,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_TextAlign_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VerticalAlign_Enum[] =
+SvXMLEnumMapEntry const pXML_VerticalAlign_Enum[] =
 {
     { XML_TOP,			drawing::TextVerticalAdjust_TOP },
     { XML_MIDDLE,		drawing::TextVerticalAdjust_CENTER },
@@ -595,7 +559,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VerticalAlign_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_FitToSize_Enum[] =
+SvXMLEnumMapEntry const pXML_FitToSize_Enum[] =
 {
     { XML_FALSE,		drawing::TextFitToSizeType_NONE },
     { XML_TRUE, 		drawing::TextFitToSizeType_PROPORTIONAL },
@@ -604,7 +568,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_FitToSize_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_MeasureUnit_Enum[] =
+SvXMLEnumMapEntry const pXML_MeasureUnit_Enum[] =
 {
     { XML_AUTOMATIC,	0 },
     { XML_UNIT_MM,		1 },
@@ -619,7 +583,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_MeasureUnit_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Measure_HAlign_Enum[] =
+SvXMLEnumMapEntry const pXML_Measure_HAlign_Enum[] =
 {
     { XML_AUTOMATIC,		drawing::MeasureTextHorzPos_AUTO },
     { XML_LEFT_OUTSIDE, 	drawing::MeasureTextHorzPos_LEFTOUTSIDE },
@@ -628,7 +592,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Measure_HAlign_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Measure_VAlign_Enum[] =
+SvXMLEnumMapEntry const pXML_Measure_VAlign_Enum[] =
 {
     { XML_AUTOMATIC,	drawing::MeasureTextVertPos_AUTO },
     { XML_ABOVE,		drawing::MeasureTextVertPos_EAST },
@@ -638,7 +602,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Measure_VAlign_Enum[] =
 };
 
 // #FontWork#
-SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Style_Enum[] =
+SvXMLEnumMapEntry const pXML_Fontwork_Style_Enum[] =
 {
     { XML_ROTATE,		0 }, //XFT_ROTATE, 
     { XML_UPRIGHT,		1 }, //XFT_UPRIGHT, 
@@ -648,7 +612,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Style_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Adjust_Enum[] =
+SvXMLEnumMapEntry const pXML_Fontwork_Adjust_Enum[] =
 {
     { XML_LEFT, 		0 }, //XFT_LEFT, 
     { XML_RIGHT,		1 }, //XFT_RIGHT, 
@@ -657,7 +621,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Adjust_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Shadow_Enum[] =
+SvXMLEnumMapEntry const pXML_Fontwork_Shadow_Enum[] =
 {
     { XML_NORMAL,		0 }, //XFTSHADOW_NORMAL, 
     { XML_SLANT,		1 }, //XFTSHADOW_SLANT, 
@@ -665,7 +629,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Shadow_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Form_Enum[] =
+SvXMLEnumMapEntry const pXML_Fontwork_Form_Enum[] =
 {
     { XML_NONE,			    0 }, //XFTFORM_NONE, 
     { XML_TOPCIRCLE,		1 }, //XFTFORM_TOPCIRC, 
@@ -683,7 +647,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Fontwork_Form_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Caption_Esc_Dir_Enum[] =
+SvXMLEnumMapEntry const pXML_Caption_Esc_Dir_Enum[] =
 {
     { XML_HORIZONTAL,		0 }, //SDRCAPT_ESCHORIZONTAL, 
     { XML_VERTICAL,		    1 }, //SDRCAPT_ESCVERTICAL, 
@@ -691,7 +655,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_Caption_Esc_Dir_Enum[] =
     { XML_TOKEN_INVALID,0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Caption_Type_Enum[] =
+SvXMLEnumMapEntry const pXML_Caption_Type_Enum[] =
 {
     { XML_STRAIGHT_LINE,			0 }, //SDRCAPT_TYPE1, 
     { XML_ANGLED_LINE,				1 }, //SDRCAPT_TYPE2, 
@@ -969,10 +933,10 @@ XMLShapeExportPropertyMapper::XMLShapeExportPropertyMapper( const UniReference<
         mpListAutoPool( pListAutoPool ),
         mrExport( rExport ),
         maNumRuleExp( rExport ),
+        mbIsInAutoStyles( sal_True ),
         msCDATA( GetXMLToken(XML_CDATA)),
         msTrue( GetXMLToken(XML_TRUE)),
-        msFalse( GetXMLToken(XML_FALSE)),
-        mbIsInAutoStyles( sal_True )
+        msFalse( GetXMLToken(XML_FALSE))
 {
 }
 
@@ -1115,7 +1079,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
                 break;
             case CTF_SD_MOVE_PROTECT:
                 {
-                    sal_Bool bProtected;
+                    sal_Bool bProtected(sal_False);
                     property->maValue >>= bProtected;
                     if( !bProtected )
                         property->mnIndex = -1;
@@ -1123,7 +1087,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
                 break;
             case CTF_SD_SIZE_PROTECT:
                 {
-                    sal_Bool bProtected;
+                    sal_Bool bProtected(sal_False);
                     property->maValue >>= bProtected;
                     if( !bProtected )
                         property->mnIndex = -1;
@@ -1138,7 +1102,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
     // do not export visual area for internal ole objects
     if( pOLEIsInternal )
     {
-        sal_Bool bInternal;
+        sal_Bool bInternal sal_False;
         if( (pOLEIsInternal->maValue >>= bInternal) && bInternal )
         {
             if( pOLEVisAreaLeft ) pOLEVisAreaLeft->mnIndex = -1;
@@ -1165,7 +1129,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
 
     if( pRepeatOffsetX && pRepeatOffsetY )
     {
-        sal_Int32 nOffset;
+        sal_Int32 nOffset = 0;
         if( ( pRepeatOffsetX->maValue >>= nOffset ) && ( nOffset == 0 ) )
             pRepeatOffsetX->mnIndex = -1;
         else
@@ -1175,7 +1139,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
     if(pFontWorkStyle)
     {
         // #FontWork#
-        sal_Int32 nStyle;
+        sal_Int32 nStyle = 0;
 
         if(pFontWorkStyle->maValue >>= nStyle)
         {
@@ -1212,7 +1176,7 @@ void XMLShapeExportPropertyMapper::ContextFilter(
 
     if( pCaptionIsEscRel )
     {
-        sal_Bool bIsRel;
+        sal_Bool bIsRel(sal_False);
         pCaptionIsEscRel->maValue >>= bIsRel;
         
         if( bIsRel )
@@ -1338,7 +1302,7 @@ void XMLPageExportPropertyMapper::ContextFilter(
                 break;
             case CTF_PAGE_VISIBLE:
                 {
-                    sal_Bool bVisible;
+                    sal_Bool bVisible(sal_False);
                     (*property).maValue >>= bVisible;
                     if( bVisible )
                         (*property).mnIndex = -1;
@@ -1352,7 +1316,7 @@ void XMLPageExportPropertyMapper::ContextFilter(
 
     if( pRepeatOffsetX && pRepeatOffsetY )
     {
-        sal_Int32 nOffset;
+        sal_Int32 nOffset = 0;
         if( ( pRepeatOffsetX->maValue >>= nOffset ) && ( nOffset == 0 ) )
             pRepeatOffsetX->mnIndex = -1;
         else
