@@ -128,7 +128,7 @@ sal_Bool getBOOL(const Any& _rAny)
     if (_rAny.getValueType() == ::getCppuBooleanType())
         nReturn = *(sal_Bool*)_rAny.getValue();
     else
-        OSL_ENSURE(sal_False, "comphelper::getBOOL : invalid argument !");
+        OSL_FAIL("comphelper::getBOOL : invalid argument !");
     return nReturn;
 }
 
