@@ -217,7 +217,7 @@ void Components::WriteThread::run() {
     reference_->clear();
 }
 
-void Components::initSingleton(
+Components & Components::getSingleton(
     css::uno::Reference< css::uno::XComponentContext > const & context)
 {
     OSL_ASSERT(context.is());
@@ -226,10 +226,6 @@ void Components::initSingleton(
         singleton = &theSingleton;
         singletonCreated = true;
     }
-}
-
-Components & Components::getSingleton() {
-    OSL_ASSERT(singletonCreated);
     if (singleton == 0) {
         throw css::uno::RuntimeException(
             rtl::OUString(
@@ -514,12 +510,16 @@ css::beans::Optional< css::uno::Any > Components::getExternalValue(
     return value;
 }
 
+int tempHACK = 0;
+
 Components::Components(
     css::uno::Reference< css::uno::XComponentContext > const & context):
     context_(context)
 {
     lock_ = lock();
 
+    tempHACK = 1;
+
     OSL_ASSERT(context.is());
     RTL_LOGFILE_TRACE_AUTHOR("configmgr", "sb", "begin parsing");
     parseXcsXcuLayer(
@@ -598,6 +598,7 @@ Components::Components(
 Components::~Components()
 {
     flushModifications();
+    tempHACK = 0;
 }
 
 void Components::parseFileLeniently(
@@ -869,7 +870,7 @@ void Components::parseModificationLayer() {
             "configmgr user registrymodifications.xcu does not (yet) exist");
         // Migrate old user layer data (can be removed once migration is no
         // longer relevant, probably OOo 4; also see hack for xsi namespace in
-        // XmlReader constructor):
+        // xmlreader::XmlReader::registerNamespaceIri):
         parseFiles(
             Data::NO_LAYER, rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".xcu")),
             &parseXcuFile,
