@@ -31,7 +31,7 @@
 
 #include "IdentityMapping.hxx"
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <set>
 #include <algorithm>
 
@@ -57,9 +57,11 @@
 
 using namespace std;
 using namespace osl;
-using namespace rtl;
 using namespace com::sun::star::uno;
-
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+using ::rtl::OUStringToOString;
+using ::rtl::OString;
 
 namespace cppu
 {
@@ -69,7 +71,7 @@ class Mapping
     uno_Mapping * _pMapping;
 
 public:
-    inline Mapping( uno_Mapping * pMapping = 0 ) SAL_THROW( () );
+    inline explicit Mapping( uno_Mapping * pMapping = 0 ) SAL_THROW( () );
     inline Mapping( const Mapping & rMapping ) SAL_THROW( () );
     inline ~Mapping() SAL_THROW( () );
     inline Mapping & SAL_CALL operator = ( uno_Mapping * pMapping ) SAL_THROW( () );
@@ -142,9 +144,9 @@ struct FctPtrHash : public std::unary_function< uno_Mapping *, size_t >
         { return (size_t)pKey; }
 };
 
-typedef hash_map<
+typedef boost::unordered_map<
     OUString, MappingEntry *, FctOUStringHash, equal_to< OUString > > t_OUString2Entry;
-typedef hash_map<
+typedef boost::unordered_map<
     uno_Mapping *, MappingEntry *, FctPtrHash, equal_to< uno_Mapping * > > t_Mapping2Entry;
 
 typedef set< uno_getMappingFunc > t_CallbackSet;
