@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include "align.hxx" //add for SvxAlignmentTabPage
 #include "dlgfact.hxx"
 
@@ -104,6 +101,8 @@
 #include "passwdomdlg.hxx"
 #include "hyphen.hxx"
 #include "thesdlg.hxx"
+#include "about.hxx"
+#include "dialmgr.hxx"
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::frame;
@@ -132,7 +131,6 @@ short AbstractSvxZoomDialog_Impl::Execute()
     return pDlg->Execute();
 }
 
-//IMPL_ABSTDLG_BASE(AbstractSvxZoomDialog_Impl);
 IMPL_ABSTDLG_BASE(AbstractSearchProgress_Impl);
 IMPL_ABSTDLG_BASE(AbstractTakeProgress_Impl);
 IMPL_ABSTDLG_BASE(AbstractTitleDialog_Impl);
@@ -205,7 +203,7 @@ IMPL_LINK( VclAbstractDialog2_Impl, EndDialogHdl, Dialog*, pDlg )
 
 //////////////////////////////////////////////////////////////////////////
 
-void AbstractTabDialog_Impl::SetCurPageId( USHORT nId )
+void AbstractTabDialog_Impl::SetCurPageId( sal_uInt16 nId )
 {
     pDlg->SetCurPageId( nId );
 }
@@ -215,7 +213,7 @@ const SfxItemSet* AbstractTabDialog_Impl::GetOutputItemSet() const
     return pDlg->GetOutputItemSet();
 }
 
-const USHORT* AbstractTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
+const sal_uInt16* AbstractTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
 {
     return pDlg->GetInputRanges( pItem );
 }
@@ -395,7 +393,7 @@ Reference < com::sun::star::embed::XEmbeddedObject > AbstractInsertObjectDialog_
    return pDlg->GetObject();
 }
 
-BOOL AbstractInsertObjectDialog_Impl::IsCreateNew()
+sal_Bool AbstractInsertObjectDialog_Impl::IsCreateNew()
 {
     return pDlg->IsCreateNew();
 }
@@ -415,7 +413,7 @@ void AbstractPasteDialog_Impl::SetObjName( const SvGlobalName & rClass, const St
     pDlg->SetObjName( rClass, rObjName );
 }
 
-ULONG AbstractPasteDialog_Impl::GetFormat( const TransferableDataHelper& aHelper,
+sal_uLong AbstractPasteDialog_Impl::GetFormat( const TransferableDataHelper& aHelper,
                         const DataFlavorExVector* pFormats,
                         const TransferableObjectDescriptor* pDesc )
 {
@@ -427,12 +425,12 @@ void  AbstractFmShowColsDialog_Impl::SetColumns(const ::Reference< ::com::sun::s
      pDlg->SetColumns(xCols);
 }
 
-void AbstractSvxZoomDialog_Impl::SetLimits( USHORT nMin, USHORT nMax )
+void AbstractSvxZoomDialog_Impl::SetLimits( sal_uInt16 nMin, sal_uInt16 nMax )
 {
     pDlg->SetLimits( nMin, nMax );
 }
 
-void AbstractSvxZoomDialog_Impl::HideButton( USHORT nBtnId )
+void AbstractSvxZoomDialog_Impl::HideButton( sal_uInt16 nBtnId )
 {
     pDlg->HideButton( nBtnId );
 }
@@ -516,7 +514,7 @@ String AbstractTitleDialog_Impl::GetTitle() const
     return pDlg->GetTitle();
 }
 
-ULONG AbstractGalleryIdDialog_Impl::GetId() const
+sal_uLong AbstractGalleryIdDialog_Impl::GetId() const
 {
     return pDlg->GetId();
 }
@@ -556,7 +554,7 @@ String AbstractURLDlg_Impl::GetName() const
     return pDlg->GetName();
 }
 
-void AbstractSvxHlinkDlgMarkWnd_Impl::Hide( USHORT nFlags )
+void AbstractSvxHlinkDlgMarkWnd_Impl::Hide( sal_uInt16 nFlags )
 {
     ((Window*)pDlg)->Hide( nFlags );
 }
@@ -571,22 +569,22 @@ Size AbstractSvxHlinkDlgMarkWnd_Impl::GetSizePixel() const
     return pDlg->GetSizePixel();
 }
 
-BOOL AbstractSvxHlinkDlgMarkWnd_Impl::IsVisible( ) const
+sal_Bool AbstractSvxHlinkDlgMarkWnd_Impl::IsVisible( ) const
 {
     return (( Window* )pDlg)->IsVisible();
 }
 
-void AbstractSvxHlinkDlgMarkWnd_Impl::Invalidate( USHORT nFlags )
+void AbstractSvxHlinkDlgMarkWnd_Impl::Invalidate( sal_uInt16 nFlags )
 {
     (( Window* )pDlg)->Invalidate(nFlags);
 }
 
-BOOL AbstractSvxHlinkDlgMarkWnd_Impl::MoveTo( Point aNewPos )const
+sal_Bool AbstractSvxHlinkDlgMarkWnd_Impl::MoveTo( Point aNewPos )const
 {
     return pDlg->MoveTo(aNewPos);
 }
 
-BOOL AbstractSvxHlinkDlgMarkWnd_Impl::ConnectToDialog( BOOL bDoit  )const
+sal_Bool AbstractSvxHlinkDlgMarkWnd_Impl::ConnectToDialog( sal_Bool bDoit  )const
 {
     return pDlg->ConnectToDialog(bDoit);
 }
@@ -601,33 +599,33 @@ void AbstractSvxHlinkDlgMarkWnd_Impl::SelectEntry ( String aStrMark )
     pDlg->SelectEntry(aStrMark);
 }
 
-USHORT AbstractSvxHlinkDlgMarkWnd_Impl::SetError( USHORT nError)
+sal_uInt16 AbstractSvxHlinkDlgMarkWnd_Impl::SetError( sal_uInt16 nError)
 {
     return pDlg->SetError(nError);
 }
 
-USHORT AbstractSvxSearchSimilarityDialog_Impl::GetOther()
+sal_uInt16 AbstractSvxSearchSimilarityDialog_Impl::GetOther()
 {
     return pDlg->GetOther();
 }
 
-USHORT AbstractSvxSearchSimilarityDialog_Impl::GetShorter()
+sal_uInt16 AbstractSvxSearchSimilarityDialog_Impl::GetShorter()
 {
     return pDlg->GetShorter();
 }
 
-USHORT AbstractSvxSearchSimilarityDialog_Impl::GetLonger()
+sal_uInt16 AbstractSvxSearchSimilarityDialog_Impl::GetLonger()
 {
     return pDlg-> GetLonger();
 }
 
-BOOL AbstractSvxSearchSimilarityDialog_Impl::IsRelaxed()
+sal_Bool AbstractSvxSearchSimilarityDialog_Impl::IsRelaxed()
 {
     return pDlg-> IsRelaxed();
 }
 
 // AbstractSvxTransformTabDialog implementations just forwards everything to the dialog
-void AbstractSvxTransformTabDialog_Impl::SetCurPageId( USHORT nId )
+void AbstractSvxTransformTabDialog_Impl::SetCurPageId( sal_uInt16 nId )
 {
     pDlg->SetCurPageId( nId );
 }
@@ -636,7 +634,7 @@ const SfxItemSet* AbstractSvxTransformTabDialog_Impl::GetOutputItemSet() const
     return pDlg->GetOutputItemSet();
 }
 //
-const USHORT* AbstractSvxTransformTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
+const sal_uInt16* AbstractSvxTransformTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
 {
     return pDlg->GetInputRanges( pItem );
 }
@@ -660,7 +658,7 @@ void AbstractSvxTransformTabDialog_Impl::SetValidateFramePosLink( const Link& rL
 }
 
 // AbstractSvxCaptionDialog implementations just forwards everything to the dialog
-void AbstractSvxCaptionDialog_Impl::SetCurPageId( USHORT nId )
+void AbstractSvxCaptionDialog_Impl::SetCurPageId( sal_uInt16 nId )
 {
     pDlg->SetCurPageId( nId );
 }
@@ -669,7 +667,7 @@ const SfxItemSet* AbstractSvxCaptionDialog_Impl::GetOutputItemSet() const
     return pDlg->GetOutputItemSet();
 }
 //
-const USHORT* AbstractSvxCaptionDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
+const sal_uInt16* AbstractSvxCaptionDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
 {
     return pDlg->GetInputRanges( pItem );
 }
@@ -692,7 +690,7 @@ void AbstractSvxCaptionDialog_Impl::SetValidateFramePosLink( const Link& rLink )
     pDlg->SetValidateFramePosLink( rLink );
 }
 
-INT32 AbstractSvxJSearchOptionsDialog_Impl::GetTransliterationFlags() const
+sal_Int32 AbstractSvxJSearchOptionsDialog_Impl::GetTransliterationFlags() const
 {
     return pDlg->GetTransliterationFlags();
 }
@@ -726,13 +724,13 @@ void AbstractSvxNameDialog_Impl::SetCheckNameHdl( const Link& rLink, bool bCheck
     else
         pDlg->SetCheckNameHdl( Link(), bCheckImmediately );
 }
-void AbstractSvxNameDialog_Impl::SetEditHelpId(ULONG nHelpId)
+void AbstractSvxNameDialog_Impl::SetEditHelpId(const rtl::OString& aHelpId)
 {
-    pDlg->SetEditHelpId( nHelpId );
+    pDlg->SetEditHelpId( aHelpId );
 }
-void AbstractSvxNameDialog_Impl::SetHelpId( ULONG nHelpId )
+void AbstractSvxNameDialog_Impl::SetHelpId( const rtl::OString& aHelpId )
 {
-    pDlg->SetHelpId( nHelpId );
+    pDlg->SetHelpId( aHelpId );
 }
 void AbstractSvxNameDialog_Impl::SetText( const XubString& rStr )
 {
@@ -784,7 +782,7 @@ void AbstractSvxObjectTitleDescDialog_Impl::GetDescription(String& rDescription)
     pDlg->GetDescription(rDescription);
 }
 
-void AbstractSvxMessDialog_Impl::SetButtonText( USHORT nBtnId, const String& rNewTxt )
+void AbstractSvxMessDialog_Impl::SetButtonText( sal_uInt16 nBtnId, const String& rNewTxt )
 {
     pDlg->SetButtonText( nBtnId, rNewTxt );
 }
@@ -844,9 +842,9 @@ void AbstractSvxMultiFileDialog_Impl::SetTitle( const String& rNewTitle )
     pDlg->SetText( rNewTitle );
 }
 
-void AbstractSvxMultiFileDialog_Impl::SetHelpId( ULONG nHelpId )
+void AbstractSvxMultiFileDialog_Impl::SetHelpId( const rtl::OString& aHelpId )
 {
-    pDlg->SetHelpId( nHelpId );
+    pDlg->SetHelpId( aHelpId );
 }
 
 Window * AbstractSvxHpLinkDlg_Impl::GetWindow()
@@ -879,7 +877,7 @@ Graphic AbstractGraphicFilterDialog_Impl::GetFilteredGraphic( const Graphic& rGr
 }
 
 // AbstractSvxAreaTabDialog implementations just forwards everything to the dialog
-void AbstractSvxAreaTabDialog_Impl::SetCurPageId( USHORT nId )
+void AbstractSvxAreaTabDialog_Impl::SetCurPageId( sal_uInt16 nId )
 {
     pDlg->SetCurPageId( nId );
 }
@@ -889,7 +887,7 @@ const SfxItemSet* AbstractSvxAreaTabDialog_Impl::GetOutputItemSet() const
     return pDlg->GetOutputItemSet();
 }
 
-const USHORT* AbstractSvxAreaTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
+const sal_uInt16* AbstractSvxAreaTabDialog_Impl::GetInputRanges(const SfxItemPool& pItem )
 {
     return pDlg->GetInputRanges( pItem );
 }
@@ -921,7 +919,7 @@ const SfxItemSet* AbstractSvxPostItDialog_Impl::GetOutputItemSet() const
 {
     return pDlg->GetOutputItemSet();
 }
-void AbstractSvxPostItDialog_Impl::EnableTravel(BOOL bNext, BOOL bPrev)
+void AbstractSvxPostItDialog_Impl::EnableTravel(sal_Bool bNext, sal_Bool bPrev)
 {
     pDlg->EnableTravel( bNext, bPrev );
 }
@@ -945,11 +943,11 @@ void AbstractSvxPostItDialog_Impl::HideAuthor()
 {
     pDlg->HideAuthor();
 }
-void AbstractSvxPostItDialog_Impl::SetReadonlyPostIt(BOOL bDisable)
+void AbstractSvxPostItDialog_Impl::SetReadonlyPostIt(sal_Bool bDisable)
 {
     pDlg->SetReadonlyPostIt( bDisable );
 }
-BOOL AbstractSvxPostItDialog_Impl::IsOkEnabled() const
+sal_Bool AbstractSvxPostItDialog_Impl::IsOkEnabled() const
 {
     return pDlg->IsOkEnabled();
 }
@@ -989,7 +987,7 @@ Window * AbstractSvxPostItDialog_Impl::GetWindow()
 String AbstractPasswordToOpenModifyDialog_Impl::GetPasswordToOpen() const
 {
     return pDlg->GetPasswordToOpen();
-}    
+}
 String AbstractPasswordToOpenModifyDialog_Impl::GetPasswordToModify() const
 {
     return pDlg->GetPasswordToModify();
@@ -1005,6 +1003,11 @@ VclAbstractDialog* AbstractDialogFactory_Impl::CreateVclDialog( Window* pParent,
     Dialog* pDlg=NULL;
     switch ( nResId )
     {
+        case RID_DEFAULTABOUT:
+        {   
+            pDlg = new AboutDialog( pParent, CUI_RES( (sal_uInt16) nResId ) );
+            break;
+        }
         case SID_OPTIONS_TREEDIALOG :
         case SID_OPTIONS_DATABASES :
         case SID_LANGUAGE_OPTIONS :
@@ -1129,10 +1132,10 @@ SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateTextTabDialog( Window* p
     return new AbstractTabDialog_Impl( pDlg );
 }
 
-//TabDialog that use functionality of the drawing layer and add AnchorTypes  -- for SvxCaptionTabDialog CHINA001
+// TabDialog that use functionality of the drawing layer and add AnchorTypes -- for SvxCaptionTabDialog
 AbstractSvxCaptionDialog*       AbstractDialogFactory_Impl::CreateCaptionDialog( Window* pParent,
                                             const SdrView* pView,
-                                            USHORT nAnchorTypes )
+                                            sal_uInt16 nAnchorTypes )
 {
     SvxCaptionTabDialog* pDlg = new SvxCaptionTabDialog( pParent, pView, nAnchorTypes );
     return new AbstractSvxCaptionDialog_Impl( pDlg );
@@ -1154,7 +1157,7 @@ AbstractHangulHanjaConversionDialog* AbstractDialogFactory_Impl::CreateHangulHan
     return new AbstractHangulHanjaConversionDialog_Impl( pDlg );
 }
 
-AbstractThesaurusDialog* AbstractDialogFactory_Impl::CreateThesaurusDialog( Window* pParent, 
+AbstractThesaurusDialog* AbstractDialogFactory_Impl::CreateThesaurusDialog( Window* pParent,
                                 ::com::sun::star::uno::Reference< ::com::sun::star::linguistic2::XThesaurus >  xThesaurus,
                                 const String &rWord, sal_Int16 nLanguage )
 {
@@ -1220,7 +1223,7 @@ AbstractDialogFactory_Impl::CreateScriptErrorDialog(
 
 AbstractScriptSelectorDialog*
 AbstractDialogFactory_Impl::CreateScriptSelectorDialog(
-    Window* pParent, BOOL bShowSlots, const Reference< frame::XFrame >& _rxFrame )
+    Window* pParent, sal_Bool bShowSlots, const Reference< frame::XFrame >& _rxFrame )
 {
     SvxScriptSelectorDialog* pDlg = NULL;
 
@@ -1316,7 +1319,7 @@ SfxAbstractDialog* AbstractDialogFactory_Impl::CreateSfxDialog( sal_uInt32 nResI
     switch ( nResId )
     {
         case RID_SVXDLG_CHARMAP :
-            pDlg = new SvxCharacterMap( pParent, TRUE, pAttrSet );
+            pDlg = new SvxCharacterMap( pParent, sal_True, pAttrSet );
             break;
         default:
             break;
@@ -1348,17 +1351,17 @@ SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateTabItemDialog( Window* p
 
 VclAbstractDialog* 		AbstractDialogFactory_Impl::CreateSvxSearchAttributeDialog( Window* pParent,
                                             SearchAttrItemList& rLst,
-                                            const USHORT* pWhRanges )
+                                            const sal_uInt16* pWhRanges )
 {
     Dialog* pDlg = new SvxSearchAttributeDialog( pParent, rLst, pWhRanges);
     return new VclAbstractDialog_Impl( pDlg );
 }
 
 AbstractSvxSearchSimilarityDialog * AbstractDialogFactory_Impl::CreateSvxSearchSimilarityDialog( Window* pParent,
-                                                            BOOL bRelax,
-                                                            USHORT nOther,
-                                                            USHORT nShorter,
-                                                            USHORT nLonger)
+                                                            sal_Bool bRelax,
+                                                            sal_uInt16 nOther,
+                                                            sal_uInt16 nShorter,
+                                                            sal_uInt16 nLonger)
 {
     SvxSearchSimilarityDialog* pDlg = new SvxSearchSimilarityDialog( pParent, bRelax, nOther, nShorter, nLonger );
     if ( pDlg )
@@ -1368,7 +1371,7 @@ AbstractSvxSearchSimilarityDialog * AbstractDialogFactory_Impl::CreateSvxSearchS
 
 SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateSvxBorderBackgroundDlg( Window* pParent,
                                             const SfxItemSet& rCoreSet,
-                                            BOOL bEnableSelector)
+                                            sal_Bool bEnableSelector)
 {
     SfxTabDialog* pDlg = new SvxBorderBackgroundDlg( pParent, rCoreSet, bEnableSelector);
     return new AbstractTabDialog_Impl( pDlg );
@@ -1377,7 +1380,7 @@ SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateSvxBorderBackgroundDlg(
 AbstractSvxTransformTabDialog* AbstractDialogFactory_Impl::CreateSvxTransformTabDialog( Window* pParent,
                                                                               const SfxItemSet* pAttr,
                                                                                 const SdrView* pView,
-                                                                                USHORT nAnchorTypes )
+                                                                                sal_uInt16 nAnchorTypes )
 {
     SvxTransformTabDialog* pDlg = new SvxTransformTabDialog( pParent, pAttr,pView, nAnchorTypes);
     return new AbstractSvxTransformTabDialog_Impl( pDlg );
@@ -1417,7 +1420,7 @@ SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateSchTransformTabDialog( W
 
 AbstractSvxJSearchOptionsDialog * AbstractDialogFactory_Impl::CreateSvxJSearchOptionsDialog( Window* pParent,
                                                             const SfxItemSet& rOptionsSet,
-                                                            INT32 nInitialFlags)
+                                                            sal_Int32 nInitialFlags)
 {
     SvxJSearchOptionsDialog* pDlg = new SvxJSearchOptionsDialog( pParent, rOptionsSet, nInitialFlags );
     return new AbstractSvxJSearchOptionsDialog_Impl( pDlg );
@@ -1503,13 +1506,13 @@ AbstractSvxMessDialog * AbstractDialogFactory_Impl::CreateSvxMessDialog( Window*
     return 0;
 }
 
-AbstractSvxMultiPathDialog * AbstractDialogFactory_Impl::CreateSvxMultiPathDialog( Window* pParent, BOOL bEmptyAllowed )
+AbstractSvxMultiPathDialog * AbstractDialogFactory_Impl::CreateSvxMultiPathDialog( Window* pParent, sal_Bool bEmptyAllowed )
 {
     SvxMultiPathDialog* pDlg = new SvxMultiPathDialog( pParent, bEmptyAllowed );
     return new AbstractSvxMultiPathDialog_Impl( pDlg );
 }
 
-AbstractSvxMultiFileDialog * AbstractDialogFactory_Impl::CreateSvxMultiFileDialog( Window* pParent, BOOL bEmptyAllowed )
+AbstractSvxMultiFileDialog * AbstractDialogFactory_Impl::CreateSvxMultiFileDialog( Window* pParent, sal_Bool bEmptyAllowed )
 {
     SvxMultiFileDialog* pDlg = new SvxMultiFileDialog( pParent, bEmptyAllowed );
     return new AbstractSvxMultiFileDialog_Impl( pDlg );
@@ -1557,7 +1560,7 @@ AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterEmb
 
 AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterPosterSepia (Window* pParent,
                                             const Graphic& rGraphic,
-                                            USHORT nCount,
+                                            sal_uInt16 nCount,
                                             sal_uInt32 nResId)
 {
     GraphicFilterDialog* pDlg=NULL;
@@ -1581,7 +1584,7 @@ AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterPos
 
 AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterSolarize (Window* pParent,  //add for GraphicFilterSolarize
                                             const Graphic& rGraphic,
-                                            BYTE nGreyThreshold, BOOL bInvert, sal_uInt32 )
+                                            sal_uInt8 nGreyThreshold, sal_Bool bInvert, sal_uInt32 )
 {
     GraphicFilterDialog* pDlg = new GraphicFilterSolarize( pParent, rGraphic, nGreyThreshold, bInvert );
     return new AbstractGraphicFilterDialog_Impl( pDlg );
@@ -1589,7 +1592,7 @@ AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterSol
 
 AbstractGraphicFilterDialog * AbstractDialogFactory_Impl::CreateGraphicFilterMosaic (Window* pParent,  //add for GraphicFilterMosaic
                                             const Graphic& rGraphic,
-                                            USHORT nTileWidth, USHORT nTileHeight, BOOL bEnhanceEdges,
+                                            sal_uInt16 nTileWidth, sal_uInt16 nTileHeight, sal_Bool bEnhanceEdges,
                                             sal_uInt32 nResId)
 {
     GraphicFilterDialog* pDlg=NULL;
@@ -1619,7 +1622,7 @@ AbstractSvxAreaTabDialog* AbstractDialogFactory_Impl::CreateSvxAreaTabDialog( Wi
 SfxAbstractTabDialog* AbstractDialogFactory_Impl::CreateSvxLineTabDialog( Window* pParent, const SfxItemSet* pAttr, //add forSvxLineTabDialog
                                                                  SdrModel* pModel,
                                                                  const SdrObject* pObj ,
-                                                                BOOL bHasObj)
+                                                                sal_Bool bHasObj)
 {
     SfxTabDialog* pDlg = new SvxLineTabDialog( pParent, pAttr, pModel,pObj,bHasObj );
     return new AbstractTabDialog_Impl( pDlg );
@@ -1641,7 +1644,7 @@ SfxAbstractDialog* AbstractDialogFactory_Impl::CreateSfxDialog( Window* pParent,
             pDlg = new SvxShortcutAssignDlg( pParent, _rxDocumentFrame, rAttr );
             break;
         case RID_SVXDLG_CHARMAP :
-            pDlg = new SvxCharacterMap( pParent, TRUE, &rAttr );
+            pDlg = new SvxCharacterMap( pParent, sal_True, &rAttr );
             break;
         default:
             break;
@@ -1689,7 +1692,7 @@ SfxAbstractDialog* AbstractDialogFactory_Impl::CreateSfxDialog( Window* pParent,
 
 AbstractSvxPostItDialog* AbstractDialogFactory_Impl::CreateSvxPostItDialog( Window* pParent,
                                                                         const SfxItemSet& rCoreSet,
-                                                                        BOOL bPrevNext, BOOL bRedline )
+                                                                        sal_Bool bPrevNext, sal_Bool bRedline )
 {
     SvxPostItDialog* pDlg = new SvxPostItDialog( pParent, rCoreSet, bPrevNext, bRedline );
     return new AbstractSvxPostItDialog_Impl( pDlg );
@@ -1731,7 +1734,7 @@ VclAbstractDialog * AbstractDialogFactory_Impl::CreateSvxMacroAssignDlg(
 }
 
 // Factories for TabPages
-CreateTabPage AbstractDialogFactory_Impl::GetTabPageCreatorFunc( USHORT nId )
+CreateTabPage AbstractDialogFactory_Impl::GetTabPageCreatorFunc( sal_uInt16 nId )
 {
     switch ( nId )
     {
@@ -1817,7 +1820,7 @@ CreateSvxDistributePage	AbstractDialogFactory_Impl::GetSvxDistributePageCreatorF
     return SvxDistributePage::Create;
 }
 
-DialogGetRanges	AbstractDialogFactory_Impl::GetDialogGetRangesFunc( USHORT nId )
+DialogGetRanges	AbstractDialogFactory_Impl::GetDialogGetRangesFunc( sal_uInt16 nId )
 {
         switch ( nId )
     {
@@ -1829,7 +1832,7 @@ DialogGetRanges	AbstractDialogFactory_Impl::GetDialogGetRangesFunc( USHORT nId )
 
     return 0;
 }
-GetTabPageRanges AbstractDialogFactory_Impl::GetTabPageRangesFunc( USHORT nId )
+GetTabPageRanges AbstractDialogFactory_Impl::GetTabPageRangesFunc( sal_uInt16 nId )
 {
     switch ( nId )
     {
@@ -1889,53 +1892,47 @@ GetTabPageRanges AbstractDialogFactory_Impl::GetTabPageRangesFunc( USHORT nId )
     return 0;
 }
 
-SfxAbstractInsertObjectDialog* AbstractDialogFactory_Impl::CreateInsertObjectDialog( Window* pParent, USHORT nSlotId,
+SfxAbstractInsertObjectDialog* AbstractDialogFactory_Impl::CreateInsertObjectDialog( Window* pParent, const rtl::OUString& rCommand,
             const Reference < com::sun::star::embed::XStorage >& xStor,
             const SvObjectServerList* pList )
 {
     InsertObjectDialog_Impl* pDlg=0;
-    switch ( nSlotId )
-    {
-        case SID_INSERT_OBJECT : pDlg = new SvInsertOleDlg( pParent, xStor, pList ); break;
-        case SID_INSERT_PLUGIN : pDlg = new SvInsertPlugInDialog( pParent, xStor ); break;
-        case SID_INSERT_APPLET : pDlg = new SvInsertAppletDialog( pParent, xStor ); break;
-        case SID_INSERT_FLOATINGFRAME : pDlg = new SfxInsertFloatingFrameDialog( pParent, xStor ); break;
-        default: break;
-    }
+    if ( rCommand.equalsAscii(".uno:InsertObject" ) )
+        pDlg = new SvInsertOleDlg( pParent, xStor, pList );
+    else if ( rCommand.equalsAscii(".uno:InsertPlugin" ) )
+        pDlg = new SvInsertPlugInDialog( pParent, xStor );
+    else if ( rCommand.equalsAscii(".uno:InsertObjectFloatingFrame" ) )
+        pDlg = new SfxInsertFloatingFrameDialog( pParent, xStor );
 
     if ( pDlg )
     {
-        pDlg->SetHelpId( nSlotId );
+        pDlg->SetHelpId( rtl::OString( rCommand, rCommand.getLength(), RTL_TEXTENCODING_UTF8 ) );
         return new AbstractInsertObjectDialog_Impl( pDlg );
     }
     return 0;
 }
 
-VclAbstractDialog* AbstractDialogFactory_Impl::CreateEditObjectDialog( Window* pParent, USHORT nSlotId,
+VclAbstractDialog* AbstractDialogFactory_Impl::CreateEditObjectDialog( Window* pParent,  const rtl::OUString& rCommand,
             const Reference < com::sun::star::embed::XEmbeddedObject >& xObj )
 {
     InsertObjectDialog_Impl* pDlg=0;
-    switch ( nSlotId )
+    if ( rCommand.equalsAscii(".uno:InsertObjectFloatingFrame" ) )
     {
-        case SID_INSERT_APPLET : pDlg = new SvInsertAppletDialog( pParent, xObj ); break;
-        case SID_INSERT_FLOATINGFRAME : pDlg = new SfxInsertFloatingFrameDialog( pParent, xObj ); break;
-        default: break;
-    }
-
-    if ( pDlg )
-    {
-        pDlg->SetHelpId( nSlotId );
+        pDlg = new SfxInsertFloatingFrameDialog( pParent, xObj );
+        pDlg->SetHelpId( rtl::OString( rCommand, rCommand.getLength(), RTL_TEXTENCODING_UTF8 ) );
         return new VclAbstractDialog_Impl( pDlg );
     }
     return 0;
 }
 
+
+
 SfxAbstractPasteDialog* AbstractDialogFactory_Impl::CreatePasteDialog( Window* pParent )
 {
     return new AbstractPasteDialog_Impl( new SvPasteObjectDialog( pParent ) );
 }
 
-SfxAbstractLinksDialog* AbstractDialogFactory_Impl::CreateLinksDialog( Window* pParent, sfx2::LinkManager* pMgr, BOOL bHTML, sfx2::SvBaseLink* p)
+SfxAbstractLinksDialog* AbstractDialogFactory_Impl::CreateLinksDialog( Window* pParent, sfx2::LinkManager* pMgr, sal_Bool bHTML, sfx2::SvBaseLink* p)
 {
     SvBaseLinksDlg* pLinkDlg = new SvBaseLinksDlg( pParent, pMgr, bHTML );
     if ( p )
@@ -1953,7 +1950,7 @@ SvxAbstractSplittTableDialog* AbstractDialogFactory_Impl::CreateSvxSplittTableDi
     return new SvxSplitTableDlg( pParent, bIsTableVertical, nMaxVertical, nMaxHorizontal );
 }
 
-SvxAbstractNewTableDialog* AbstractDialogFactory_Impl::CreateSvxNewTableDialog( Window* pParent ) 
+SvxAbstractNewTableDialog* AbstractDialogFactory_Impl::CreateSvxNewTableDialog( Window* pParent )
 {
     return new SvxNewTableDialog( pParent );
 }
@@ -1964,18 +1961,18 @@ VclAbstractDialog* AbstractDialogFactory_Impl::CreateOptionsDialog(
     return new VclAbstractDialog_Impl( new OfaTreeOptionsDialog( pParent, rExtensionId ) );
 }
 
-SvxAbstractInsRowColDlg* AbstractDialogFactory_Impl::CreateSvxInsRowColDlg( Window* pParent, bool bCol, ULONG nHelpId )
+SvxAbstractInsRowColDlg* AbstractDialogFactory_Impl::CreateSvxInsRowColDlg( Window* pParent, bool bCol, const rtl::OString& sHelpId )
 {
-    return new SvxInsRowColDlg( pParent, bCol, nHelpId );
+    return new SvxInsRowColDlg( pParent, bCol, sHelpId );
 }
 
-AbstractPasswordToOpenModifyDialog * AbstractDialogFactory_Impl::CreatePasswordToOpenModifyDialog( 
+AbstractPasswordToOpenModifyDialog * AbstractDialogFactory_Impl::CreatePasswordToOpenModifyDialog(
     Window * pParent,
     sal_uInt16 nMinPasswdLen, sal_uInt16 nMaxPasswdLen, bool bIsPasswordToModify )
 {
     PasswordToOpenModifyDialog * pDlg = new PasswordToOpenModifyDialog( pParent, nMinPasswdLen, nMaxPasswdLen, bIsPasswordToModify );
     return new AbstractPasswordToOpenModifyDialog_Impl( pDlg );
-}    
+}
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
