@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 // include ---------------------------------------------------------------
 #include <tools/shl.hxx>
 #include <sfx2/app.hxx>
@@ -66,7 +63,7 @@
 
 // static ----------------------------------------------------------------
 
-static USHORT pCaptionRanges[] =
+static sal_uInt16 pCaptionRanges[] =
 {
     SDRATTR_CAPTIONTYPE,
     SDRATTR_CAPTIONFIXEDANGLE,
@@ -126,10 +123,7 @@ SvxCaptionTabPage::SvxCaptionTabPage(Window* pParent, const SfxItemSet& rInAttrs
 
     sal_uInt16 nBitmap;
     for( nBitmap = 0; nBitmap < CAPTYPE_BITMAPS_COUNT; nBitmap++ )
-    {
         mpBmpCapTypes[nBitmap]  = new Image(Bitmap(CUI_RES(BMP_CAPTTYPE_1   + nBitmap)), COL_LIGHTMAGENTA );
-        mpBmpCapTypesH[nBitmap] = new Image(Bitmap(CUI_RES(BMP_CAPTTYPE_1_H + nBitmap)), COL_LIGHTMAGENTA );
-    }
 
     //------------ValueSet installieren--------------------------
     aCT_CAPTTYPE.SetStyle( aCT_CAPTTYPE.GetStyle() | WB_ITEMBORDER | WB_DOUBLEBORDER | WB_NAMEFIELD );
@@ -157,10 +151,7 @@ SvxCaptionTabPage::~SvxCaptionTabPage()
 {
     sal_uInt16 nBitmap;
     for( nBitmap = 0; nBitmap < CAPTYPE_BITMAPS_COUNT; nBitmap++ )
-    {
         delete mpBmpCapTypes[nBitmap];
-        delete mpBmpCapTypesH[nBitmap];
-    }
 }
 
 // -----------------------------------------------------------------------
@@ -173,7 +164,7 @@ void SvxCaptionTabPage::Construct()
 
 // -----------------------------------------------------------------------
 
-BOOL SvxCaptionTabPage::FillItemSet( SfxItemSet&  _rOutAttrs)
+sal_Bool SvxCaptionTabPage::FillItemSet( SfxItemSet&  _rOutAttrs)
 {
     SfxItemPool*    pPool = _rOutAttrs.GetPool();
     DBG_ASSERT( pPool, "Wo ist der Pool" );
@@ -240,7 +231,7 @@ BOOL SvxCaptionTabPage::FillItemSet( SfxItemSet&  _rOutAttrs)
 
 //NYI-------------die Winkel muessen noch hier rein!!! XXX----------------------
 
-    return( TRUE );
+    return( sal_True );
 }
 
 // -----------------------------------------------------------------------
@@ -268,7 +259,7 @@ void SvxCaptionTabPage::Reset( const SfxItemSet&  )
     SfxItemPool* 	pPool = rOutAttrs.GetPool();
     DBG_ASSERT( pPool, "Wo ist der Pool" );
 
-    USHORT			nWhich;
+    sal_uInt16			nWhich;
     SfxMapUnit		eUnit;
 
     //------- Winkel ----------
@@ -392,14 +383,14 @@ SfxTabPage* SvxCaptionTabPage::Create( Window* pWindow,
 
 //------------------------------------------------------------------------
 
-USHORT*	SvxCaptionTabPage::GetRanges()
+sal_uInt16*	SvxCaptionTabPage::GetRanges()
 {
     return( pCaptionRanges );
 }
 
 //------------------------------------------------------------------------
 
-void SvxCaptionTabPage::SetupAnsatz_Impl( USHORT nType )
+void SvxCaptionTabPage::SetupAnsatz_Impl( sal_uInt16 nType )
 {
     xub_StrLen	nCnt=0, nIdx=0;
 
@@ -516,7 +507,7 @@ IMPL_LINK_INLINE_END( SvxCaptionTabPage, SelectCaptTypeHdl_Impl, void *, EMPTYAR
 
 //------------------------------------------------------------------------
 
-void SvxCaptionTabPage::SetupType_Impl( USHORT nType )
+void SvxCaptionTabPage::SetupType_Impl( sal_uInt16 nType )
 {
     switch( nType-1 )
     {
@@ -568,9 +559,7 @@ void SvxCaptionTabPage::DataChanged( const DataChangedEvent& rDCEvt )
 
 void SvxCaptionTabPage::FillValueSet()
 {
-    bool bHighContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
-
-    Image** ppBitmaps = bHighContrast ? mpBmpCapTypesH : mpBmpCapTypes;
+    Image** ppBitmaps = mpBmpCapTypes;
     aCT_CAPTTYPE.SetItemImage(BMP_CAPTTYPE_1, *(ppBitmaps[0]) );
     aCT_CAPTTYPE.SetItemImage(BMP_CAPTTYPE_2, *(ppBitmaps[1]) );
     aCT_CAPTTYPE.SetItemImage(BMP_CAPTTYPE_3, *(ppBitmaps[2]) );
@@ -579,7 +568,7 @@ void SvxCaptionTabPage::FillValueSet()
 //========================================================================
 
 
-SvxCaptionTabDialog::SvxCaptionTabDialog(Window* pParent, const SdrView* pSdrView, USHORT nAnchorTypes)
+SvxCaptionTabDialog::SvxCaptionTabDialog(Window* pParent, const SdrView* pSdrView, sal_uInt16 nAnchorTypes)
  :	SfxTabDialog( pParent, CUI_RES( RID_SVXDLG_CAPTION ) ),
     pView       ( pSdrView ),
     nAnchorCtrls(nAnchorTypes)
@@ -590,13 +579,13 @@ SvxCaptionTabDialog::SvxCaptionTabDialog(Window* pParent, const SdrView* pSdrVie
 
     //different positioning page in Writer
     if(nAnchorCtrls & 0x00ff )
-    {        
-        AddTabPage( RID_SVXPAGE_SWPOSSIZE, SvxSwPosSizeTabPage::Create, 
+    {
+        AddTabPage( RID_SVXPAGE_SWPOSSIZE, SvxSwPosSizeTabPage::Create,
                                 SvxSwPosSizeTabPage::GetRanges );
         RemoveTabPage( RID_SVXPAGE_POSITION_SIZE);
     }
     else
-    {        
+    {
         AddTabPage( RID_SVXPAGE_POSITION_SIZE, SvxPositionSizeTabPage::Create,
                                 SvxPositionSizeTabPage::GetRanges );
         RemoveTabPage( RID_SVXPAGE_SWPOSSIZE );
@@ -613,7 +602,7 @@ SvxCaptionTabDialog::~SvxCaptionTabDialog()
 
 // -----------------------------------------------------------------------
 
-void SvxCaptionTabDialog::PageCreated( USHORT nId, SfxTabPage &rPage )
+void SvxCaptionTabDialog::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
 {
     switch( nId )
     {
@@ -631,7 +620,7 @@ void SvxCaptionTabDialog::PageCreated( USHORT nId, SfxTabPage &rPage )
             SvxSwPosSizeTabPage& rSwPage = static_cast<SvxSwPosSizeTabPage&>(rPage);
             rSwPage.EnableAnchorTypes(nAnchorCtrls);
             rSwPage.SetValidateFramePosLink( aValidateLink );
-        }            
+        }
         break;
 
         case RID_SVXPAGE_CAPTION:
@@ -640,13 +629,11 @@ void SvxCaptionTabDialog::PageCreated( USHORT nId, SfxTabPage &rPage )
         break;
     }
 }
-/*-- 05.03.2004 13:54:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SvxCaptionTabDialog::SetValidateFramePosLink( const Link& rLink )
 {
     aValidateLink = rLink;
-}            
+}
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
