@@ -58,12 +58,10 @@
 #define CPPUTYPE_DEFAULT		  CPPUTYPE_SEQSALINT8
 #define CPPUTYPE_OUSTR			  getCppuType( (const ::rtl::OUString*) 0 )
 #define CPPUTYPE_SALINT32         getCppuType( ( sal_Int32 * ) 0 )
-#define OUSTR( str )			  OUString::createFromAscii( #str )
-#define OUSTR_( str )             OUString::createFromAscii( str )
-#define EMPTY_OUSTR               OUString::createFromAscii( "" )
-//#define PRIVATE_OO				  OUString::createFromAscii( "application/x-openoffice;" "windows_formatname=" )
+#define OUSTR( str )			  OUString(RTL_CONSTASCII_USTRINGPARAM( #str ))
+#define EMPTY_OUSTR               OUString()
 
-const rtl::OUString Windows_FormatName = rtl::OUString::createFromAscii("windows_formatname");
+const rtl::OUString Windows_FormatName (RTL_CONSTASCII_USTRINGPARAM("windows_formatname"));
 const com::sun::star::uno::Type CppuType_ByteSequence = ::getCppuType((const com::sun::star::uno::Sequence<sal_Int8>*)0);
 const com::sun::star::uno::Type CppuType_String       = ::getCppuType((const ::rtl::OUString*)0);
 
@@ -71,7 +69,7 @@ const com::sun::star::uno::Type CppuType_String       = ::getCppuType((const ::r
 // namespace directives
 //------------------------------------------------------------------------
 
-using namespace rtl;
+using ::rtl::OUString;
 using namespace osl;
 using namespace cppu;
 using namespace std;
@@ -89,7 +87,7 @@ namespace MODULE_PRIVATE
     Sequence< OUString > SAL_CALL DataFormatTranslator_getSupportedServiceNames( )
     {
         Sequence< OUString > aRet(1);
-        aRet[0] = OUString::createFromAscii("com.sun.star.datatransfer.DataFormatTranslator");
+        aRet[0] = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.datatransfer.DataFormatTranslator"));
         return aRet;
     }
 }
@@ -183,15 +181,15 @@ Any SAL_CALL CDataFormatTranslator::getSystemDataTypeFromDataFlavor( const DataF
     }
     catch( IllegalArgumentException& )
     {
-        OSL_ENSURE( sal_False, "Invalid content-type detected!" );
+        OSL_FAIL( "Invalid content-type detected!" );
     }
     catch( NoSuchElementException& )
     {
-        OSL_ENSURE( sal_False, "Illegal content-type parameter" );
+        OSL_FAIL( "Illegal content-type parameter" );
     }
     catch( ... )
     {
-        OSL_ENSURE( sal_False, "Unexpected error" );
+        OSL_FAIL( "Unexpected error" );
         throw;
     }
 
@@ -224,7 +222,7 @@ DataFlavor SAL_CALL CDataFormatTranslator::getDataFlavorFromSystemDataType( cons
         findDataFlavorForNativeFormatName( nativeFormatName, aFlavor );
     }
     else
-        OSL_ENSURE( sal_False, "Invalid data type received" );
+        OSL_FAIL( "Invalid data type received" );
 
     return aFlavor;
 }
@@ -236,7 +234,7 @@ DataFlavor SAL_CALL CDataFormatTranslator::getDataFlavorFromSystemDataType( cons
 OUString SAL_CALL CDataFormatTranslator::getImplementationName(  )
     throw( RuntimeException )
 {
-    return OUString::createFromAscii( IMPL_NAME );
+    return OUString(RTL_CONSTASCII_USTRINGPARAM( IMPL_NAME ));
 }
 
 // -------------------------------------------------
@@ -280,6 +278,7 @@ void SAL_CALL CDataFormatTranslator::initTranslationTable()
     m_TranslTable.push_back(FormatEntry("application/x-openoffice-dif;windows_formatname=\"DIF\"", "DIF", "DIF", CF_DIF, CPPUTYPE_DEFAULT)); 
     // SOT_FORMAT_BITMAP
     m_TranslTable.push_back(FormatEntry("application/x-openoffice-bitmap;windows_formatname=\"Bitmap\"", "Bitmap", "Bitmap", CF_DIB, CPPUTYPE_DEFAULT));
+    m_TranslTable.push_back(FormatEntry("application/x-openoffice-bitmap;windows_formatname=\"Bitmap\"", "Bitmap", "Bitmap", CF_BITMAP, CPPUTYPE_DEFAULT));
     // SOT_FORMAT_STRING	
     m_TranslTable.push_back(FormatEntry("text/plain;charset=utf-16", "Unicode-Text", "", CF_UNICODETEXT, CppuType_String));
     // Format Locale - for internal use
