@@ -32,10 +32,9 @@
 #include <map>
 #include <set>
 #include <vector>
-#include <slist>
+#include <list>
 #include <memory>
 #include <editeng/unolingu.hxx>
-#include <tools/debug.hxx>
 #include <tools/urlobj.hxx>
 #include <rtl/logfile.hxx>
 #include <unotools/pathoptions.hxx>
@@ -80,9 +79,6 @@ using namespace ::com::sun::star::linguistic2;
 
 #define CSS com::sun::star
 
-///////////////////////////////////////////////////////////////////////////
-
-
 static uno::Reference< XLinguServiceManager > GetLngSvcMgr_Impl()
 {
     uno::Reference< XLinguServiceManager > xRes;
@@ -96,14 +92,12 @@ static uno::Reference< XLinguServiceManager > GetLngSvcMgr_Impl()
     return xRes;
 }
 
-///////////////////////////////////////////////////////////////////////////
-
-BOOL lcl_FindEntry( const OUString &rEntry, const Sequence< OUString > &rCfgSvcs )
+sal_Bool lcl_FindEntry( const OUString &rEntry, const Sequence< OUString > &rCfgSvcs )
 {
-    INT32 nRes = -1;
-    INT32 nEntries = rCfgSvcs.getLength();
+    sal_Int32 nRes = -1;
+    sal_Int32 nEntries = rCfgSvcs.getLength();
     const OUString *pEntry = rCfgSvcs.getConstArray();
-    for (INT32 i = 0;  i < nEntries && nRes == -1;  ++i)
+    for (sal_Int32 i = 0;  i < nEntries && nRes == -1;  ++i)
     {
         if (rEntry == pEntry[i])
             nRes = i;
@@ -118,11 +112,11 @@ Sequence< OUString > lcl_RemoveMissingEntries(
 {
     Sequence< OUString > aRes( rCfgSvcs.getLength() );
     OUString *pRes = aRes.getArray();
-    INT32 nCnt = 0;
+    sal_Int32 nCnt = 0;
 
-    INT32 nEntries = rCfgSvcs.getLength();
+    sal_Int32 nEntries = rCfgSvcs.getLength();
     const OUString *pEntry = rCfgSvcs.getConstArray();
-    for (INT32 i = 0;  i < nEntries;  ++i)
+    for (sal_Int32 i = 0;  i < nEntries;  ++i)
     {
         if (pEntry[i].getLength() && lcl_FindEntry( pEntry[i], rAvailSvcs ))
             pRes[ nCnt++ ] = pEntry[i];
@@ -144,7 +138,7 @@ Sequence< OUString > lcl_GetLastFoundSvcs(
                                 SvxLocaleToLanguage( rAvailLocale ) ) );
 
     Sequence< OUString > aNodeNames( rCfg.GetNodeNames(rLastFoundList) );
-    BOOL bFound = lcl_FindEntry( aCfgLocaleStr, aNodeNames);
+    sal_Bool bFound = lcl_FindEntry( aCfgLocaleStr, aNodeNames);
 
     if (bFound)
     {
@@ -154,19 +148,15 @@ Sequence< OUString > lcl_GetLastFoundSvcs(
         rNodeName += OUString::valueOf( (sal_Unicode)'/' );
         rNodeName += aCfgLocaleStr;
         Sequence< Any > aValues( rCfg.GetProperties( aNames ) );
-#if OSL_DEBUG_LEVEL > 1
-        const Any *pValue;
-        pValue = aValues.getConstArray();
-#endif
         if (aValues.getLength())
         {
-            DBG_ASSERT( aValues.getLength() == 1, "unexpected length of sequence" );
+            OSL_ENSURE( aValues.getLength() == 1, "unexpected length of sequence" );
             Sequence< OUString > aSvcImplNames;
             if (aValues.getConstArray()[0] >>= aSvcImplNames)
                 aRes = aSvcImplNames;
             else
             {
-                DBG_ERROR( "type mismatch" );
+                OSL_FAIL( "type mismatch" );
             }
         }
     }
@@ -179,13 +169,13 @@ Sequence< OUString > lcl_GetNewEntries(
         const Sequence< OUString > &rLastFoundSvcs,
         const Sequence< OUString > &rAvailSvcs )
 {
-    INT32 nLen = rAvailSvcs.getLength();
+    sal_Int32 nLen = rAvailSvcs.getLength();
     Sequence< OUString > aRes( nLen );
     OUString *pRes = aRes.getArray();
-    INT32 nCnt = 0;
+    sal_Int32 nCnt = 0;
 
     const OUString *pEntry = rAvailSvcs.getConstArray();
-    for (INT32 i = 0;  i < nLen;  ++i)
+    for (sal_Int32 i = 0;  i < nLen;  ++i)
     {
         if (pEntry[i].getLength() && !lcl_FindEntry( pEntry[i], rLastFoundSvcs ))
             pRes[ nCnt++ ] = pEntry[i];
@@ -202,17 +192,17 @@ Sequence< OUString > lcl_MergeSeq(
 {
     Sequence< OUString > aRes( rCfgSvcs.getLength() + rNewSvcs.getLength() );
     OUString *pRes = aRes.getArray();
-    INT32 nCnt = 0;
+    sal_Int32 nCnt = 0;
 
-    for (INT32 k = 0;  k < 2;  ++k)
+    for (sal_Int32 k = 0;  k < 2;  ++k)
     {
         // add previously configuerd service first and append
         // new found services at the end
         const Sequence< OUString > &rSeq = k == 0 ? rCfgSvcs : rNewSvcs;
 
-        INT32 nLen = rSeq.getLength();
+        sal_Int32 nLen = rSeq.getLength();
         const OUString *pEntry = rSeq.getConstArray();
-        for (INT32 i = 0;  i < nLen;  ++i)
+        for (sal_Int32 i = 0;  i < nLen;  ++i)
         {
             if (pEntry[i].getLength() && !lcl_FindEntry( pEntry[i], aRes ))
                 pRes[ nCnt++ ] = pEntry[i];
@@ -223,11 +213,8 @@ Sequence< OUString > lcl_MergeSeq(
     return aRes;
 }
 
-///////////////////////////////////////////////////////////////////////////
-
-// static member initialization
-INT16 SvxLinguConfigUpdate::nNeedUpdating = -1;
-INT32 SvxLinguConfigUpdate::nCurrentDataFilesChangedCheckValue = -1;
+sal_Int16 SvxLinguConfigUpdate::nNeedUpdating = -1;
+sal_Int32 SvxLinguConfigUpdate::nCurrentDataFilesChangedCheckValue = -1;
 
 void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
 {
@@ -244,10 +231,10 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
 
         RTL_LOGFILE_CONTEXT( aLog, "svx: SvxLinguConfigUpdate::UpdateAll - updating..." );
 
-        DBG_ASSERT( nNeedUpdating == 1, "SvxLinguConfigUpdate::UpdateAll already updated!" );
+        OSL_ENSURE( nNeedUpdating == 1, "SvxLinguConfigUpdate::UpdateAll already updated!" );
 
         uno::Reference< XLinguServiceManager > xLngSvcMgr( GetLngSvcMgr_Impl() );
-        DBG_ASSERT( xLngSvcMgr.is(), "service manager missing");
+        OSL_ENSURE( xLngSvcMgr.is(), "service manager missing");
         if (!xLngSvcMgr.is())
             return;
 
@@ -264,16 +251,16 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
 
         for (int k = 0;  k < nNumServices;  ++k)
         {
-            OUString aService( A2OU( apServices[k] ) );
-            OUString aActiveList( A2OU( apCurLists[k] ) );
-            OUString aLastFoundList( A2OU( apLastFoundLists[k] ) );
-            INT32 i;
+            OUString aService( ::rtl::OUString::createFromAscii( apServices[k] ) );
+            OUString aActiveList( ::rtl::OUString::createFromAscii( apCurLists[k] ) );
+            OUString aLastFoundList( ::rtl::OUString::createFromAscii( apLastFoundLists[k] ) );
+            sal_Int32 i;
 
             //
             // remove configured but not available language/services entries
             //
             Sequence< OUString > aNodeNames( aCfg.GetNodeNames( aActiveList ) );   // list of configured locales
-            INT32 nNodeNames = aNodeNames.getLength();
+            sal_Int32 nNodeNames = aNodeNames.getLength();
             const OUString *pNodeName = aNodeNames.getConstArray();
             for (i = 0;  i < nNodeNames;  ++i)
             {
@@ -298,7 +285,7 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
             //
             uno::Reference< XAvailableLocales > xAvail( xLngSvcMgr, UNO_QUERY );
             Sequence< Locale > aAvailLocales( xAvail->getAvailableLocales(aService) );
-            INT32 nAvailLocales = aAvailLocales.getLength();
+            sal_Int32 nAvailLocales = aAvailLocales.getLength();
             const Locale *pAvailLocale = aAvailLocales.getConstArray();
             for (i = 0;  i < nAvailLocales;  ++i)
             {
@@ -342,9 +329,9 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
                         xLngSvcMgr->getAvailableServices( aService, pAvailLocale[i] ) );
 
 #if OSL_DEBUG_LEVEL > 1
-                INT32 nSvcs = aSvcImplNames.getLength();
+                sal_Int32 nSvcs = aSvcImplNames.getLength();
                 const OUString *pSvcImplName = aSvcImplNames.getConstArray();
-                for (INT32 j = 0;  j < nSvcs;  ++j)
+                for (sal_Int32 j = 0;  j < nSvcs;  ++j)
                 {
                     OUString aImplName( pSvcImplName[j] );
                 }
@@ -364,7 +351,7 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
             for (int i = 0;  i < 2;  ++i)
             {
                 const sal_Char *pSubNodeName = (i == 0) ? apCurLists[k] : apLastFoundLists[k];
-                OUString aSubNodeName( A2OU(pSubNodeName) );
+                OUString aSubNodeName( ::rtl::OUString::createFromAscii(pSubNodeName) );
 
                 list_entry_map_t &rCurMap = (i == 0) ? aCurSvcs[k] : aLastFoundSvcs[k];
                 list_entry_map_t::const_iterator aIt( rCurMap.begin() );
@@ -379,9 +366,9 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
 
 #if OSL_DEBUG_LEVEL > 1
                     Sequence< OUString > aSvcImplNames( (*aIt).second );
-                    INT32 nSvcs = aSvcImplNames.getLength();
+                    sal_Int32 nSvcs = aSvcImplNames.getLength();
                     const OUString *pSvcImplName = aSvcImplNames.getConstArray();
-                    for (INT32 j = 0;  j < nSvcs;  ++j)
+                    for (sal_Int32 j = 0;  j < nSvcs;  ++j)
                     {
                         OUString aImplName( pSvcImplName[j] );
                     }
@@ -391,23 +378,23 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
                     ++pNewValue;
                     ++aIt;
                 }
-                DBG_ASSERT( pNewValue - aNewValues.getArray() == nVals,
+                OSL_ENSURE( pNewValue - aNewValues.getArray() == nVals,
                         "possible mismatch of sequence size and property number" );
 
                 {
                     RTL_LOGFILE_CONTEXT( aLog, "svx: SvxLinguConfigUpdate::UpdateAll - ReplaceSetProperties" );
                     // add new or replace existing entries.
-                    BOOL bRes = aCfg.ReplaceSetProperties( aSubNodeName, aNewValues );
+                    sal_Bool bRes = aCfg.ReplaceSetProperties( aSubNodeName, aNewValues );
                     if (!bRes)
                     {
 #if OSL_DEBUG_LEVEL > 1
-                        DBG_ERROR( "failed to set new configuration values" );
+                        OSL_FAIL( "failed to set new configuration values" );
 #endif
                     }
                 }
             }
         }
-        DBG_ASSERT( nCurrentDataFilesChangedCheckValue != -1, "SvxLinguConfigUpdate::UpdateAll DataFilesChangedCheckValue not yet calculated!" );
+        OSL_ENSURE( nCurrentDataFilesChangedCheckValue != -1, "SvxLinguConfigUpdate::UpdateAll DataFilesChangedCheckValue not yet calculated!" );
         Any aAny;
 
         // for the time being (developer builds until OOo 3.0)
@@ -419,7 +406,7 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
         // not be too troublesome.
         // In OOo 3.0 we will not need the respective code anymore at all.
 //		aAny <<= nCurrentDataFilesChangedCheckValue;
-        aAny <<= (INT32) -1;	// keep the value set to 'need to check'
+        aAny <<= (sal_Int32) -1;	// keep the value set to 'need to check'
 
         aCfg.SetProperty( A2OU( "DataFilesChangedCheckValue" ), aAny );
 
@@ -436,17 +423,17 @@ void SvxLinguConfigUpdate::UpdateAll( sal_Bool bForceCheck )
 }
 
 
-INT32 SvxLinguConfigUpdate::CalcDataFilesChangedCheckValue()
+sal_Int32 SvxLinguConfigUpdate::CalcDataFilesChangedCheckValue()
 {
     RTL_LOGFILE_CONTEXT( aLog, "svx: SvxLinguConfigUpdate::CalcDataFilesChangedCheckValue" );
 
-    INT32 nHashVal = 0;
+    sal_Int32 nHashVal = 0;
     // nothing to be checked anymore since those old directory paths are gone by now
     return nHashVal;
 }
 
 
-BOOL SvxLinguConfigUpdate::IsNeedUpdateAll( sal_Bool bForceCheck )
+sal_Bool SvxLinguConfigUpdate::IsNeedUpdateAll( sal_Bool bForceCheck )
 {
     RTL_LOGFILE_CONTEXT( aLog, "svx: SvxLinguConfigUpdate::IsNeedUpdateAll" );
     if (nNeedUpdating == -1 || bForceCheck )    // need to check if updating is necessary
@@ -461,14 +448,12 @@ BOOL SvxLinguConfigUpdate::IsNeedUpdateAll( sal_Bool bForceCheck )
         aCfg.GetOptions( aLinguOpt );
         nNeedUpdating = (nCurrentDataFilesChangedCheckValue == aLinguOpt.nDataFilesChangedCheckValue) ? 0 : 1;
     }
-    DBG_ASSERT( nNeedUpdating != -1,
+    OSL_ENSURE( nNeedUpdating != -1,
             "need for linguistic configuration update should have been already checked." );
 
     return nNeedUpdating == 1;
 }
 
-///////////////////////////////////////////////////////////////////////////
-
 
 //! Dummy implementation in order to avoid loading of lingu DLL
 //! when only the XSupportedLocales interface is used.
@@ -523,10 +508,10 @@ void ThesDummy_Impl::GetCfgLocales()
         String  aNode( A2OU( "ServiceManager/ThesaurusList" ) );
         Sequence < OUString > aNodeNames( aCfg.GetNodeNames( aNode ) );
         const OUString *pNodeNames = aNodeNames.getConstArray();
-        INT32 nLen = aNodeNames.getLength();
+        sal_Int32 nLen = aNodeNames.getLength();
         pLocaleSeq = new Sequence< Locale >( nLen );
         Locale *pLocale = pLocaleSeq->getArray();
-        for (INT32 i = 0;  i < nLen;  ++i)
+        for (sal_Int32 i = 0;  i < nLen;  ++i)
         {
             pLocale[i] = SvxCreateLocale(
                             MsLangId::convertIsoStringToLanguage( pNodeNames[i] ) );
@@ -581,8 +566,8 @@ sal_Bool SAL_CALL
     else if (!pLocaleSeq)       // if not already loaded save startup time by avoiding loading them now
         GetCfgLocales();
         GetCfgLocales();
-    BOOL bFound = FALSE;
-    INT32 nLen = pLocaleSeq->getLength();
+    sal_Bool bFound = sal_False;
+    sal_Int32 nLen = pLocaleSeq->getLength();
     const Locale *pLocale = pLocaleSeq->getConstArray();
     const Locale *pEnd = pLocale + nLen;
     for ( ;  pLocale < pEnd  &&  !bFound;  ++pLocale)
@@ -605,16 +590,13 @@ uno::Sequence< uno::Reference< linguistic2::XMeaning > > SAL_CALL
 {
     GetThes_Impl();
     uno::Sequence< uno::Reference< linguistic2::XMeaning > > aRes;
-    DBG_ASSERT( xThes.is(), "Thesaurus missing" );
+    OSL_ENSURE( xThes.is(), "Thesaurus missing" );
     if (xThes.is())
         aRes = xThes->queryMeanings( rTerm, rLocale, rProperties );
     return aRes;
 }
 
 
-///////////////////////////////////////////////////////////////////////////
-
-
 //! Dummy implementation in order to avoid loading of lingu DLL.
 //! The dummy accesses the real implementation (and thus loading the DLL)
 //! when it needs to be done only.
@@ -682,7 +664,7 @@ sal_Bool SAL_CALL
         throw(uno::RuntimeException)
 {
     GetSpell_Impl();
-    BOOL bRes = FALSE;
+    sal_Bool bRes = sal_False;
     if (xSpell.is())
         bRes = xSpell->hasLanguage( nLanguage );
     return bRes;
@@ -696,7 +678,7 @@ sal_Bool SAL_CALL
               uno::RuntimeException)
 {
     GetSpell_Impl();
-    BOOL bRes = TRUE;
+    sal_Bool bRes = sal_True;
     if (xSpell.is())
         bRes = xSpell->isValid( rWord, nLanguage, rProperties );
     return bRes;
@@ -717,9 +699,6 @@ uno::Reference< linguistic2::XSpellAlternatives > SAL_CALL
 }
 
 
-///////////////////////////////////////////////////////////////////////////
-
-
 //! Dummy implementation in order to avoid loading of lingu DLL.
 //! The dummy accesses the real implementation (and thus loading the DLL)
 //! when it needs to be done only.
@@ -801,7 +780,7 @@ sal_Bool SAL_CALL
         throw(uno::RuntimeException)
 {
     GetHyph_Impl();
-    BOOL bRes = FALSE;
+    sal_Bool bRes = sal_False;
     if (xHyph.is())
         bRes = xHyph->hasLocale( rLocale );
     return bRes;
@@ -858,11 +837,9 @@ uno::Reference< linguistic2::XPossibleHyphens > SAL_CALL
 }
 
 
-///////////////////////////////////////////////////////////////////////////
-
-
 typedef cppu::WeakImplHelper1 < XEventListener > LinguMgrAppExitLstnrBaseClass;
 
+
 class LinguMgrAppExitLstnr : public LinguMgrAppExitLstnrBaseClass
 {
     uno::Reference< XComponent > 		xDesktop;
@@ -901,7 +878,7 @@ LinguMgrAppExitLstnr::~LinguMgrAppExitLstnr()
         xDesktop->removeEventListener( this );
         xDesktop = NULL;	//! release reference to desktop
     }
-    DBG_ASSERT(!xDesktop.is(), "reference to desktop should be realeased");
+    OSL_ENSURE(!xDesktop.is(), "reference to desktop should be realeased");
 }
 
 void LinguMgrAppExitLstnr::disposing(const EventObject& rSource)
@@ -916,8 +893,6 @@ void LinguMgrAppExitLstnr::disposing(const EventObject& rSource)
     }
 }
 
-///////////////////////////////////////////////////////////////////////////
-
 class LinguMgrExitLstnr : public LinguMgrAppExitLstnr
 {
 public:
@@ -938,16 +913,10 @@ void LinguMgrExitLstnr::AtExit()
 
     LinguMgr::bExiting		= sal_True;
 
-    //TL:TODO: MBA fragen wie ich ohne Absturz hier meinen Speicher
-    //  wieder freibekomme...
-    //delete LinguMgr::pExitLstnr;
     LinguMgr::pExitLstnr	= 0;
 }
 
-///////////////////////////////////////////////////////////////////////////
 
-
-// static member initialization
 LinguMgrExitLstnr * 			LinguMgr::pExitLstnr	= 0;
 sal_Bool						LinguMgr::bExiting		= sal_False;
 uno::Reference< XLinguServiceManager >	LinguMgr::xLngSvcMgr	= 0;
@@ -1028,16 +997,6 @@ uno::Reference< XSpellChecker1 > LinguMgr::GetSpell()
 
     //! use dummy implementation in order to avoid loading of lingu DLL
     xSpell = new SpellDummy_Impl;
-
-/*    if (!xLngSvcMgr.is())
-        xLngSvcMgr = GetLngSvcMgr_Impl();
-
-    if (xLngSvcMgr.is())
-    {
-        xSpell = uno::Reference< XSpellChecker1 > (
-                        xLngSvcMgr->getSpellChecker(), UNO_QUERY );
-    }
-*/
     return xSpell;
 }
 
@@ -1051,16 +1010,6 @@ uno::Reference< XHyphenator > LinguMgr::GetHyph()
 
     //! use dummy implementation in order to avoid loading of lingu DLL
     xHyph = new HyphDummy_Impl;
-
-/*
-    if (!xLngSvcMgr.is())
-        xLngSvcMgr = GetLngSvcMgr_Impl();
-
-    if (xLngSvcMgr.is())
-    {
-        xHyph = xLngSvcMgr->getHyphenator();
-    }
-*/
     return xHyph;
 }
 
@@ -1077,15 +1026,6 @@ uno::Reference< XThesaurus > LinguMgr::GetThes()
     //! The dummy accesses the real implementation (and thus loading the DLL)
     //! when "real" work needs to be done only.
     xThes = new ThesDummy_Impl;
-/*
-    if (!xLngSvcMgr.is())
-        xLngSvcMgr = GetLngSvcMgr_Impl();
-
-    if (xLngSvcMgr.is())
-    {
-        xThes = xLngSvcMgr->getThesaurus();
-    }
-*/
     return xThes;
 }
 
@@ -1206,19 +1146,17 @@ uno::Reference< XDictionary > LinguMgr::GetStandard()
     }
 #if OSL_DEBUG_LEVEL > 1
     uno::Reference< XStorable >      xStor( xDic, UNO_QUERY );
-    DBG_ASSERT( xDic.is() && xDic->getDictionaryType() == DictionaryType_POSITIVE,
+    OSL_ENSURE( xDic.is() && xDic->getDictionaryType() == DictionaryType_POSITIVE,
             "wrong dictionary type");
-    DBG_ASSERT( xDic.is() && SvxLocaleToLanguage( xDic->getLocale() ) == LANGUAGE_NONE,
+    OSL_ENSURE( xDic.is() && SvxLocaleToLanguage( xDic->getLocale() ) == LANGUAGE_NONE,
             "wrong dictionary language");
-    DBG_ASSERT( !xStor.is() || (xStor->hasLocation() && !xStor->isReadonly()),
+    OSL_ENSURE( !xStor.is() || (xStor->hasLocation() && !xStor->isReadonly()),
             "dictionary not editable" );
 #endif
 
     return xDic;
 }
 
-///////////////////////////////////////////////////////////////////////////
-
 uno::Reference< XSpellChecker1 >  SvxGetSpellChecker()
 {
     return LinguMgr::GetSpellChecker();
@@ -1244,7 +1182,7 @@ uno::Reference< XPropertySet > 	SvxGetLinguPropertySet()
     return LinguMgr::GetLinguPropertySet();
 }
 
-//TL:TODO: remove argument or provide SvxGetIgnoreAllList with the same one
+//TODO: remove argument or provide SvxGetIgnoreAllList with the same one
 uno::Reference< XDictionary >  SvxGetOrCreatePosDic(
         uno::Reference< XDictionaryList >  /* xDicList */ )
 {
@@ -1261,9 +1199,6 @@ uno::Reference< XDictionary >  SvxGetChangeAllList()
     return LinguMgr::GetChangeAllList();
 }
 
-///////////////////////////////////////////////////////////////////////////
-
-
 #include <com/sun/star/linguistic2/XHyphenatedWord.hpp>
 
 SvxAlternativeSpelling SvxGetAltSpelling(
@@ -1275,40 +1210,38 @@ SvxAlternativeSpelling SvxGetAltSpelling(
     {
         OUString aWord( rHyphWord->getWord() ),
                  aAltWord( rHyphWord->getHyphenatedWord() );
-        INT16	nHyphenationPos		= rHyphWord->getHyphenationPos(),
+        sal_Int16	nHyphenationPos		= rHyphWord->getHyphenationPos(),
                 nHyphenPos			= rHyphWord->getHyphenPos();
-        INT16   nLen    = (INT16)aWord.getLength();
-        INT16   nAltLen = (INT16)aAltWord.getLength();
+        sal_Int16   nLen    = (sal_Int16)aWord.getLength();
+        sal_Int16   nAltLen = (sal_Int16)aAltWord.getLength();
         const sal_Unicode *pWord	= aWord.getStr(),
                           *pAltWord = aAltWord.getStr();
 
         // count number of chars from the left to the
         // hyphenation pos / hyphen pos that are equal
-        INT16 nL = 0;
+        sal_Int16 nL = 0;
         while (nL <= nHyphenationPos && nL <= nHyphenPos
                && pWord[ nL ] == pAltWord[ nL ])
             ++nL;
         // count number of chars from the right to the
         // hyphenation pos / hyphen pos that are equal
-        INT16 nR = 0;
-        INT32 nIdx    = nLen - 1;
-        INT32 nAltIdx = nAltLen - 1;
+        sal_Int16 nR = 0;
+        sal_Int32 nIdx    = nLen - 1;
+        sal_Int32 nAltIdx = nAltLen - 1;
         while (nIdx > nHyphenationPos && nAltIdx > nHyphenPos
                && pWord[ nIdx-- ] == pAltWord[ nAltIdx-- ])
             ++nR;
 
         aRes.aReplacement       = OUString( aAltWord.copy( nL, nAltLen - nL - nR ) );
-        aRes.nChangedPos        = (INT16) nL;
+        aRes.nChangedPos        = (sal_Int16) nL;
         aRes.nChangedLength     = nLen - nL - nR;
-        aRes.bIsAltSpelling		= TRUE;
+        aRes.bIsAltSpelling		= sal_True;
         aRes.xHyphWord			= rHyphWord;
     }
     return aRes;
 }
 
 
-///////////////////////////////////////////////////////////////////////////
-
 SvxDicListChgClamp::SvxDicListChgClamp( uno::Reference< XDictionaryList >  &rxDicList ) :
     xDicList	( rxDicList )
 {
@@ -1326,8 +1259,6 @@ SvxDicListChgClamp::~SvxDicListChgClamp()
     }
 }
 
-///////////////////////////////////////////////////////////////////////////
-
 short SvxDicError( Window *pParent, sal_Int16 nError )
 {
     short nRes = 0;
@@ -1340,7 +1271,7 @@ short SvxDicError( Window *pParent, sal_Int16 nError )
             case DIC_ERR_READONLY : nRid = RID_SVXSTR_DIC_ERR_READONLY;  break;
             default:
                 nRid = RID_SVXSTR_DIC_ERR_UNKNOWN;
-                DBG_ASSERT(0, "unexpected case");
+                OSL_FAIL("unexpected case");
         }
         nRes = InfoBox( pParent, EE_RESSTR( nRid ) ).Execute();
     }
@@ -1349,7 +1280,6 @@ short SvxDicError( Window *pParent, sal_Int16 nError )
 
 LanguageType SvxLocaleToLanguage( const Locale& rLocale )
 {
-    //	empty Locale -> LANGUAGE_NONE
     if ( rLocale.Language.getLength() == 0 )
         return LANGUAGE_NONE;
 
@@ -1358,7 +1288,7 @@ LanguageType SvxLocaleToLanguage( const Locale& rLocale )
 
 Locale& SvxLanguageToLocale( Locale& rLocale, LanguageType eLang )
 {
-    if ( eLang != LANGUAGE_NONE	/* &&  eLang != LANGUAGE_SYSTEM */)
+    if ( eLang != LANGUAGE_NONE	)
         MsLangId::convertLanguageToLocale( eLang, rLocale );
     else
         rLocale = Locale();
@@ -1369,7 +1299,7 @@ Locale& SvxLanguageToLocale( Locale& rLocale, LanguageType eLang )
 Locale SvxCreateLocale( LanguageType eLang )
 {
     Locale aLocale;
-    if ( eLang != LANGUAGE_NONE /* &&  eLang != LANGUAGE_SYSTEM */)
+    if ( eLang != LANGUAGE_NONE )
         MsLangId::convertLanguageToLocale( eLang, aLocale );
 
     return aLocale;
