@@ -5,6 +5,7 @@
 
 #include "so_activex.h"
 #include "SOActionsApproval.h"
+#include <sal/macros.h>
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -16,7 +17,7 @@ STDMETHODIMP SOActionsApproval::InterfaceSupportsErrorInfo(REFIID riid)
         &IID_ISOActionsApproval,
     };
 
-    for (int i=0;i<sizeof(arr)/sizeof(arr[0]);i++)
+    for (int i=0;i<SAL_N_ELEMENTS(arr);i++)
     {
 #if defined(_MSC_VER) && (_MSC_VER >= 1300)
         if (InlineIsEqualGUID(*arr[i],riid))
