@@ -47,6 +47,7 @@
 
 #include <functional>
 #include <algorithm>
+#include <o3tl/compat_functional.hxx>
 
 //........................................................................
 namespace pcr
@@ -108,7 +109,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::isEForm: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::isEForm: caught an exception!" );
         }
         return false;
     }
@@ -201,7 +202,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::canBindToDataType: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::canBindToDataType: caught an exception!" );
         }
 
         return bCan;
@@ -218,7 +219,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::isListEntrySink: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::isListEntrySink: caught an exception!" );
         }
         return bIs;
     }
@@ -327,7 +328,7 @@ namespace pcr
             }
             catch( const Exception& )
             {
-                OSL_ENSURE( sal_False, "EFormsHelper::getFormModelNames: caught an exception!" );
+                OSL_FAIL( "EFormsHelper::getFormModelNames: caught an exception!" );
             }
         }
     }
@@ -353,7 +354,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getBindingNames: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getBindingNames: caught an exception!" );
         }
     }
 
@@ -370,7 +371,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getFormModelByName: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getFormModelByName: caught an exception!" );
         }
         return xReturn;
     }
@@ -389,7 +390,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getCurrentFormModel: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getCurrentFormModel: caught an exception!" );
         }
         return xModel;
     }
@@ -406,7 +407,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getCurrentFormModel: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getCurrentFormModel: caught an exception!" );
         }
         return sModelName;
     }
@@ -423,7 +424,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getCurrentBinding: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getCurrentBinding: caught an exception!" );
         }
 
         return xBinding;
@@ -441,7 +442,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getCurrentBindingName: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getCurrentBindingName: caught an exception!" );
         }
         return sBindingName;
     }
@@ -459,7 +460,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getCurrentListSourceBinding: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getCurrentListSourceBinding: caught an exception!" );
         }
         return xReturn;
     }
@@ -476,7 +477,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::setListSourceBinding: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::setListSourceBinding: caught an exception!" );
         }
     }
 
@@ -502,7 +503,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::setBinding: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::setBinding: caught an exception!" );
         }
     }
 
@@ -636,7 +637,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getModelElementUIName: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getModelElementUIName: caught an exception!" );
         }
 
         return sUIName;
@@ -711,11 +712,11 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::getAllElementUINames: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::getAllElementUINames: caught an exception!" );
         }
 
         _rElementNames.resize( rMapUINameToElement.size() );
-        ::std::transform( rMapUINameToElement.begin(), rMapUINameToElement.end(), _rElementNames.begin(), ::std::select1st< MapStringToPropertySet::value_type >() );
+        ::std::transform( rMapUINameToElement.begin(), rMapUINameToElement.end(), _rElementNames.begin(), ::o3tl::select1st< MapStringToPropertySet::value_type >() );
     }
 
     //--------------------------------------------------------------------
@@ -740,7 +741,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::firePropertyChange: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::firePropertyChange: caught an exception!" );
         }
     }
 
@@ -777,7 +778,7 @@ namespace pcr
         }
         catch( const Exception& )
         {
-            OSL_ENSURE( sal_False, "EFormsHelper::firePropertyChanges: caught an exception!" );
+            OSL_FAIL( "EFormsHelper::firePropertyChanges: caught an exception!" );
         }
     }
 
