@@ -46,15 +46,15 @@
 
 typedef struct
 {
-    UINT32	nSignature;
-    UINT16	nVersion;
-    UINT32	nPad1;
-    UINT16	nPad2;
-    UINT16	nChannels;
-    UINT32	nRows;
-    UINT32	nColumns;
-    UINT16	nDepth;
-    UINT16	nMode;
+    sal_uInt32	nSignature;
+    sal_uInt16	nVersion;
+    sal_uInt32	nPad1;
+    sal_uInt16	nPad2;
+    sal_uInt16	nChannels;
+    sal_uInt32	nRows;
+    sal_uInt32	nColumns;
+    sal_uInt16	nDepth;
+    sal_uInt16	nMode;
 
 } PSDFileHeader;
 
@@ -62,7 +62,7 @@ class PSDReader {
 
 private:
 
-    SvStream*			mpPSD;			// Die einzulesende PSD-Datei
+    SvStream& m_rPSD;			// Die einzulesende PSD-Datei
     PSDFileHeader*		mpFileHeader;
 
     sal_uInt32          mnXResFixed;
@@ -76,31 +76,32 @@ private:
     BitmapReadAccess*	mpReadAcc;
     BitmapWriteAccess*	mpWriteAcc;
     BitmapWriteAccess*	mpMaskWriteAcc;
-    USHORT				mnDestBitDepth;
-    BOOL				mbCompression;	// RLE decoding
-    BYTE*				mpPalette;
+    sal_uInt16				mnDestBitDepth;
+    sal_Bool				mbCompression;	// RLE decoding
+    sal_uInt8*				mpPalette;
 
-    BOOL				ImplReadBody();
-    BOOL				ImplReadHeader();
+    sal_Bool				ImplReadBody();
+    sal_Bool				ImplReadHeader();
 
 public:
-                        PSDReader();
-                        ~PSDReader();
-    BOOL				ReadPSD( SvStream & rPSD, Graphic & rGraphic );
+    PSDReader(SvStream &rStream);
+    ~PSDReader();
+    sal_Bool ReadPSD(Graphic & rGraphic);
 };
 
 //=================== Methoden von PSDReader ==============================
 
-PSDReader::PSDReader() :
-    mpFileHeader	( NULL ),
-    mnXResFixed     ( 0 ),
-    mnYResFixed     ( 0 ),
-    mbStatus		( TRUE ),
-    mbTransparent	( FALSE ),
-    mpReadAcc		( NULL ),
-    mpWriteAcc		( NULL ),
-    mpMaskWriteAcc	( NULL ),
-    mpPalette		( NULL )
+PSDReader::PSDReader(SvStream &rStream)
+    : m_rPSD(rStream)
+    , mpFileHeader(NULL)
+    , mnXResFixed(0)
+    , mnYResFixed(0)
+    , mbStatus(sal_True)
+    , mbTransparent(sal_False)
+    , mpReadAcc(NULL)
+    , mpWriteAcc(NULL)
+    , mpMaskWriteAcc(NULL)
+    , mpPalette(NULL)
 {
 }
 
@@ -112,35 +113,34 @@ PSDReader::~PSDReader()
 
 // ------------------------------------------------------------------------
 
-BOOL PSDReader::ReadPSD( SvStream & rPSD, Graphic & rGraphic )
+sal_Bool PSDReader::ReadPSD(Graphic & rGraphic )
 {
-    if ( rPSD.GetError() )
-        return FALSE;
+    if (m_rPSD.GetError())
+        return sal_False;
 
-    mpPSD = &rPSD;
-    mpPSD->SetNumberFormatInt( NUMBERFORMAT_INT_BIGENDIAN );
+    m_rPSD.SetNumberFormatInt( NUMBERFORMAT_INT_BIGENDIAN );
 
     // Kopf einlesen:
 
-    if ( ImplReadHeader() == FALSE )
-        return FALSE;
+    if ( ImplReadHeader() == sal_False )
+        return sal_False;
     
     Size aBitmapSize( mpFileHeader->nColumns, mpFileHeader->nRows );
     maBmp = Bitmap( aBitmapSize, mnDestBitDepth );
     if ( ( mpWriteAcc = maBmp.AcquireWriteAccess() ) == NULL )
-        mbStatus = FALSE;
+        mbStatus = sal_False;
     if ( ( mpReadAcc = maBmp.AcquireReadAccess() ) == NULL )
-        mbStatus = FALSE;
+        mbStatus = sal_False;
     if ( mbTransparent && mbStatus )
     {
         maMaskBmp = Bitmap( aBitmapSize, 1 );
         if ( ( mpMaskWriteAcc = maMaskBmp.AcquireWriteAccess() ) == NULL )
-            mbStatus = FALSE;
+            mbStatus = sal_False;
     }
     if ( mpPalette && mbStatus )
     {
         mpWriteAcc->SetPaletteEntryCount( 256 );
-        for ( USHORT i = 0; i < 256; i++ )
+        for ( sal_uInt16 i = 0; i < 256; i++ )
         {
             mpWriteAcc->SetPaletteColor( i, Color( mpPalette[ i ], mpPalette[ i + 256 ], mpPalette[ i + 512 ] ) );
         }
@@ -165,7 +165,7 @@ BOOL PSDReader::ReadPSD( SvStream & rPSD, Graphic & rGraphic )
         }
     }
     else
-        mbStatus = FALSE;
+        mbStatus = sal_False;
     if ( mpWriteAcc )
         maBmp.ReleaseAccess( mpWriteAcc );
     if ( mpReadAcc )
@@ -177,62 +177,62 @@ BOOL PSDReader::ReadPSD( SvStream & rPSD, Graphic & rGraphic )
 
 // ------------------------------------------------------------------------
 
-BOOL PSDReader::ImplReadHeader()
+sal_Bool PSDReader::ImplReadHeader()
 {
-    UINT16	nCompression;
-    UINT32	nColorLength, nResourceLength, nLayerMaskLength;
+    sal_uInt16	nCompression;
+    sal_uInt32	nColorLength, nResourceLength, nLayerMaskLength;
 
     mpFileHeader = new PSDFileHeader;
 
     if ( !mpFileHeader )
-        return FALSE;
+        return sal_False;
 
-    *mpPSD >> mpFileHeader->nSignature >> mpFileHeader->nVersion >> mpFileHeader->nPad1 >>
+    m_rPSD >> mpFileHeader->nSignature >> mpFileHeader->nVersion >> mpFileHeader->nPad1 >>
         mpFileHeader->nPad2 >> mpFileHeader->nChannels >> mpFileHeader->nRows >>
             mpFileHeader->nColumns >> mpFileHeader->nDepth >> mpFileHeader->nMode;
 
     if ( ( mpFileHeader->nSignature != 0x38425053 ) || ( mpFileHeader->nVersion != 1 ) )
-        return FALSE;
+        return sal_False;
 
     if ( mpFileHeader->nRows == 0 || mpFileHeader->nColumns == 0 )
-        return FALSE;
+        return sal_False;
 
     if ( ( mpFileHeader->nRows > 30000 ) || ( mpFileHeader->nColumns > 30000 ) )
-        return FALSE;
+        return sal_False;
 
-    UINT16 nDepth = mpFileHeader->nDepth;
+    sal_uInt16 nDepth = mpFileHeader->nDepth;
     if (!( ( nDepth == 1 ) || ( nDepth == 8 ) || ( nDepth == 16 ) ) )
-        return FALSE;
+        return sal_False;
 
     mnDestBitDepth = ( nDepth == 16 ) ? 8 : nDepth;
 
-    *mpPSD >> nColorLength;
+    m_rPSD >> nColorLength;
     if ( mpFileHeader->nMode == PSD_CMYK )
     {
         switch ( mpFileHeader->nChannels )
         {
             case 5 :
-                mbTransparent = TRUE;
+                mbTransparent = sal_True;
             case 4 :
                 mnDestBitDepth = 24;
             break;
             default :
-                return FALSE;
+                return sal_False;
         }
     }
     else switch ( mpFileHeader->nChannels )
     {
         case 2 :
-            mbTransparent = TRUE;
+            mbTransparent = sal_True;
         case 1 :
             break;
         case 4 :
-            mbTransparent = TRUE;
+            mbTransparent = sal_True;
         case 3 :
             mnDestBitDepth = 24;
             break;
         default:
-            return FALSE;
+            return sal_False;
     }
 
     switch ( mpFileHeader->nMode )
@@ -240,34 +240,34 @@ BOOL PSDReader::ImplReadHeader()
         case PSD_BITMAP :
         {
             if ( nColorLength || ( nDepth != 1 ) )
-                return FALSE;
+                return sal_False;
         }
         break;
 
         case PSD_INDEXED :
         {
             if ( nColorLength != 768 )		// we need the color map
-                return FALSE;
-            mpPalette = new BYTE[ 768 ];
+                return sal_False;
+            mpPalette = new sal_uInt8[ 768 ];
             if ( mpPalette == NULL )
-                return FALSE;
-            mpPSD->Read( mpPalette, 768 );
+                return sal_False;
+            m_rPSD.Read( mpPalette, 768 );
         }
         break;
 
         case PSD_DUOTONE :					// we'll handle the doutone color like a normal grayscale picture
-            mpPSD->SeekRel( nColorLength );
+            m_rPSD.SeekRel( nColorLength );
             nColorLength = 0;
         case PSD_GRAYSCALE :
         {
             if ( nColorLength )
-                return FALSE;
-            mpPalette = new BYTE[ 768 ];
+                return sal_False;
+            mpPalette = new sal_uInt8[ 768 ];
             if ( mpPalette == NULL )
-                return FALSE;
-            for ( USHORT i = 0; i < 256; i++ )
+                return sal_False;
+            for ( sal_uInt16 i = 0; i < 256; i++ )
             {
-                mpPalette[ i ] = mpPalette[ i + 256 ] = mpPalette[ i + 512 ] = (BYTE)i;
+                mpPalette[ i ] = mpPalette[ i + 256 ] = mpPalette[ i + 512 ] = (sal_uInt8)i;
             }
         }
         break;
@@ -278,34 +278,34 @@ BOOL PSDReader::ImplReadHeader()
         case PSD_LAB :
         {
             if ( nColorLength )		// color table is not supported by the other graphic modes
-                return FALSE;
+                return sal_False;
         }
         break;
 
         default:
-            return FALSE;
+            return sal_False;
     }
-    *mpPSD >> nResourceLength;
-    sal_uInt32 nLayerPos = mpPSD->Tell() + nResourceLength;
+    m_rPSD >> nResourceLength;
+    sal_uInt32 nLayerPos = m_rPSD.Tell() + nResourceLength;
 
     // this is a loop over the resource entries to get the resolution info
-    while( mpPSD->Tell() < nLayerPos )
+    while( m_rPSD.Tell() < nLayerPos )
     {
         sal_uInt8 n8;
         sal_uInt32 nType, nPStringLen, nResEntryLen;
         sal_uInt16 nUniqueID;
 
-        *mpPSD >> nType >> nUniqueID >> n8;
+        m_rPSD >> nType >> nUniqueID >> n8;
         nPStringLen = n8;
         if ( nType != 0x3842494d )
             break;
         if ( ! ( nPStringLen & 1 ) )
             nPStringLen++;
-        mpPSD->SeekRel( nPStringLen );  // skipping the pstring
-        *mpPSD >> nResEntryLen;
+        m_rPSD.SeekRel( nPStringLen );  // skipping the pstring
+        m_rPSD >> nResEntryLen;
         if ( nResEntryLen & 1 )
             nResEntryLen++;             // the resource entries are padded
-        sal_uInt32 nCurrentPos = mpPSD->Tell();
+        sal_uInt32 nCurrentPos = m_rPSD.Tell();
         if ( ( nResEntryLen + nCurrentPos ) > nLayerPos )   // check if size
             break;                                          // is possible
         switch( nUniqueID )
@@ -314,41 +314,41 @@ BOOL PSDReader::ImplReadHeader()
             {
                 sal_Int16   nUnit;
 
-                *mpPSD >> mnXResFixed >> nUnit >> nUnit
+                m_rPSD >> mnXResFixed >> nUnit >> nUnit
                        >> mnYResFixed >> nUnit >> nUnit;
             }
             break;
         }
-        mpPSD->Seek( nCurrentPos + nResEntryLen );          // set the stream to the next 
+        m_rPSD.Seek( nCurrentPos + nResEntryLen );          // set the stream to the next
     }                                                       // resource entry
-    mpPSD->Seek( nLayerPos );
-    *mpPSD >> nLayerMaskLength;
-    mpPSD->SeekRel( nLayerMaskLength );
+    m_rPSD.Seek( nLayerPos );
+    m_rPSD >> nLayerMaskLength;
+    m_rPSD.SeekRel( nLayerMaskLength );
 
-    *mpPSD >> nCompression;
+    m_rPSD >> nCompression;
     if ( nCompression == 0 )
     {
-        mbCompression = FALSE;
+        mbCompression = sal_False;
     }
     else if ( nCompression == 1 )
     {
-        mpPSD->SeekRel( ( mpFileHeader->nRows * mpFileHeader->nChannels ) << 1 );
-        mbCompression = TRUE;
+        m_rPSD.SeekRel( ( mpFileHeader->nRows * mpFileHeader->nChannels ) << 1 );
+        mbCompression = sal_True;
     }
     else
-        return FALSE;
+        return sal_False;
 
-    return TRUE;
+    return sal_True;
 }
 
 // ------------------------------------------------------------------------
 
-BOOL PSDReader::ImplReadBody()
+sal_Bool PSDReader::ImplReadBody()
 {
-    ULONG		nX, nY;
+    sal_uLong		nX, nY;
     char		nRunCount = 0;
     signed char	nBitCount = -1;
-    BYTE		nDat = 0, nDummy, nRed, nGreen, nBlue;
+    sal_uInt8		nDat = 0, nDummy, nRed, nGreen, nBlue;
     BitmapColor	aBitmapColor;
     nX = nY = 0;
 
@@ -361,19 +361,19 @@ BOOL PSDReader::ImplReadBody()
                 if ( nBitCount == -1 )
                 {
                     if ( mbCompression )	// else nRunCount = 0 -> so we use only single raw packets
-                        *mpPSD >> nRunCount;
+                        m_rPSD >> nRunCount;
                 }
                 if ( nRunCount & 0x80 ) 	// a run length packet
                 {
                     if ( nBitCount == -1 )	// bits left in nDat ?
                     {
-                        *mpPSD >> nDat;
+                        m_rPSD >> nDat;
                         nDat ^= 0xff;
                         nBitCount = 7;
                     }
-                    for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                     {
-                        mpWriteAcc->SetPixel( nY, nX, (BYTE)nDat >> nBitCount-- );
+                        mpWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat >> nBitCount-- );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -386,15 +386,15 @@ BOOL PSDReader::ImplReadBody()
                 }
                 else						// a raw packet
                 {
-                    for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                     {
                         if ( nBitCount == -1 )	// bits left in nDat ?
                         {
-                            *mpPSD >> nDat;
+                            m_rPSD >> nDat;
                             nDat ^= 0xff;
                             nBitCount = 7;
                         }
-                        mpWriteAcc->SetPixel( nY, nX, (BYTE)nDat >> nBitCount-- );
+                        mpWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat >> nBitCount-- );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -414,16 +414,16 @@ BOOL PSDReader::ImplReadBody()
             while ( nY < mpFileHeader->nRows )
             {
                 if ( mbCompression )		// else nRunCount = 0 -> so we use only single raw packets
-                    *mpPSD >> nRunCount;
+                    m_rPSD >> nRunCount;
 
                 if ( nRunCount & 0x80 ) 	// a run length packet
                 {
-                    *mpPSD >> nDat;
+                    m_rPSD >> nDat;
                     if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                        *mpPSD >> nDummy;
-                    for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                        m_rPSD >> nDummy;
+                    for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                     {
-                        mpWriteAcc->SetPixel( nY, nX, (BYTE)nDat );
+                        mpWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -435,12 +435,12 @@ BOOL PSDReader::ImplReadBody()
                 }
                 else						// a raw packet
                 {
-                    for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                     {
-                        *mpPSD >> nDat;
+                        m_rPSD >> nDat;
                         if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                            *mpPSD >> nDummy;
-                        mpWriteAcc->SetPixel( nY, nX, (BYTE)nDat );
+                            m_rPSD >> nDummy;
+                        mpWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -463,16 +463,16 @@ BOOL PSDReader::ImplReadBody()
             while ( nY < mpFileHeader->nRows )
             {
                 if ( mbCompression )		// else nRunCount = 0 -> so we use only single raw packets
-                    *mpPSD >> nRunCount;
+                    m_rPSD >> nRunCount;
 
                 if ( nRunCount & 0x80 ) 	// a run length packet
                 {
-                    *mpPSD >> nRed;
+                    m_rPSD >> nRed;
                     if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                        *mpPSD >> nDummy;
-                    for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                        m_rPSD >> nDummy;
+                    for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                     {
-                        mpWriteAcc->SetPixel( nY, nX, BitmapColor( nRed, (BYTE)0, (BYTE)0 ) );
+                        mpWriteAcc->SetPixel( nY, nX, BitmapColor( nRed, (sal_uInt8)0, (sal_uInt8)0 ) );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -484,12 +484,12 @@ BOOL PSDReader::ImplReadBody()
                 }
                 else						// a raw packet
                 {
-                    for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                     {
-                        *mpPSD >> nRed;
+                        m_rPSD >> nRed;
                         if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                            *mpPSD >> nDummy;
-                        mpWriteAcc->SetPixel( nY, nX, BitmapColor( nRed, (BYTE)0, (BYTE)0 ) );
+                            m_rPSD >> nDummy;
+                        mpWriteAcc->SetPixel( nY, nX, BitmapColor( nRed, (sal_uInt8)0, (sal_uInt8)0 ) );
                         if ( ++nX == mpFileHeader->nColumns )
                         {
                             nX = 0;
@@ -504,13 +504,13 @@ BOOL PSDReader::ImplReadBody()
             while ( nY < mpFileHeader->nRows )
             {
                 if ( mbCompression )
-                    *mpPSD >> nRunCount;
+                    m_rPSD >> nRunCount;
                 if ( nRunCount & 0x80 ) 	// a run length packet
                 {
-                    *mpPSD >> nGreen;
+                    m_rPSD >> nGreen;
                     if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                        *mpPSD >> nDummy;
-                    for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                        m_rPSD >> nDummy;
+                    for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                     {
                         aBitmapColor = mpReadAcc->GetPixel( nY, nX );
                         mpWriteAcc->SetPixel( nY, nX, BitmapColor( aBitmapColor.GetRed(), nGreen, aBitmapColor.GetBlue() ) );
@@ -525,11 +525,11 @@ BOOL PSDReader::ImplReadBody()
                 }
                 else						// a raw packet
                 {
-                    for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                     {
-                        *mpPSD >> nGreen;
+                        m_rPSD >> nGreen;
                         if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                            *mpPSD >> nDummy;
+                            m_rPSD >> nDummy;
                         aBitmapColor = mpReadAcc->GetPixel( nY, nX );
                         mpWriteAcc->SetPixel( nY, nX, BitmapColor( aBitmapColor.GetRed(), nGreen, aBitmapColor.GetBlue() ) );
                         if ( ++nX == mpFileHeader->nColumns )
@@ -546,13 +546,13 @@ BOOL PSDReader::ImplReadBody()
             while ( nY < mpFileHeader->nRows )
             {
                 if ( mbCompression )
-                    *mpPSD >> nRunCount;
+                    m_rPSD >> nRunCount;
                 if ( nRunCount & 0x80 ) 	// a run length packet
                 {
-                    *mpPSD >> nBlue;
+                    m_rPSD >> nBlue;
                     if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                        *mpPSD >> nDummy;
-                    for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                        m_rPSD >> nDummy;
+                    for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                     {
                         aBitmapColor = mpReadAcc->GetPixel( nY, nX );
                         mpWriteAcc->SetPixel( nY, nX, BitmapColor( aBitmapColor.GetRed(), aBitmapColor.GetGreen(), nBlue ) );
@@ -567,11 +567,11 @@ BOOL PSDReader::ImplReadBody()
                 }
                 else						// a raw packet
                 {
-                    for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                    for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                     {
-                        *mpPSD >> nBlue;
+                        m_rPSD >> nBlue;
                         if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                            *mpPSD >> nDummy;
+                            m_rPSD >> nDummy;
                         aBitmapColor = mpReadAcc->GetPixel( nY, nX );
                         mpWriteAcc->SetPixel( nY, nX, BitmapColor( aBitmapColor.GetRed(), aBitmapColor.GetGreen(), nBlue ) );
                         if ( ++nX == mpFileHeader->nColumns )
@@ -586,30 +586,30 @@ BOOL PSDReader::ImplReadBody()
             }
             if ( mpFileHeader->nMode == PSD_CMYK )
             {
-                UINT32	nBlack, nBlackMax = 0;
-                BYTE*	pBlack = new BYTE[ mpFileHeader->nRows * mpFileHeader->nColumns ];
+                sal_uInt32	nBlack, nBlackMax = 0;
+                sal_uInt8*	pBlack = new sal_uInt8[ mpFileHeader->nRows * mpFileHeader->nColumns ];
                 nY = 0;
                 while ( nY < mpFileHeader->nRows )
                 {
                     if ( mbCompression )		// else nRunCount = 0 -> so we use only single raw packets
-                        *mpPSD >> nRunCount;
+                        m_rPSD >> nRunCount;
 
                     if ( nRunCount & 0x80 ) 	// a run length packet
                     {
-                        *mpPSD >> nDat;
+                        m_rPSD >> nDat;
 
                         if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                            *mpPSD >> nDummy;
+                            m_rPSD >> nDummy;
 
-                        for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                        for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                         {
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetRed() + nDat;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetRed() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetGreen() + nDat;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetGreen() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetBlue() + nDat;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetBlue() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
                             pBlack[ nX + nY * mpFileHeader->nColumns ] = nDat ^ 0xff;
@@ -624,19 +624,19 @@ BOOL PSDReader::ImplReadBody()
                     }
                     else						// a raw packet
                     {
-                        for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                        for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                         {
-                            *mpPSD >> nDat;
+                            m_rPSD >> nDat;
 
                             if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                                *mpPSD >> nDummy;
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetRed() + nDat;
+                                m_rPSD >> nDummy;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetRed() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetGreen() + nDat;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetGreen() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
-                            nBlack = (BYTE)mpReadAcc->GetPixel( nY, nX ).GetBlue() + nDat;
+                            nBlack = (sal_uInt8)mpReadAcc->GetPixel( nY, nX ).GetBlue() + nDat;
                             if ( nBlack > nBlackMax )
                                 nBlackMax = nBlack;
                             pBlack[ nX + nY * mpFileHeader->nColumns ] = nDat ^ 0xff;
@@ -655,12 +655,12 @@ BOOL PSDReader::ImplReadBody()
                 {
                     for ( nX = 0; nX < mpFileHeader->nColumns; nX++ )
                     {
-                        INT32 nDAT = pBlack[ nX + nY * mpFileHeader->nColumns ] * ( nBlackMax - 256 ) / 0x1ff;
+                        sal_Int32 nDAT = pBlack[ nX + nY * mpFileHeader->nColumns ] * ( nBlackMax - 256 ) / 0x1ff;
 
                         aBitmapColor = mpReadAcc->GetPixel( nY, nX );
-                        BYTE cR = (BYTE) MinMax( aBitmapColor.GetRed() - nDAT, 0L, 255L );
-                        BYTE cG = (BYTE) MinMax( aBitmapColor.GetGreen() - nDAT, 0L, 255L );
-                        BYTE cB = (BYTE) MinMax( aBitmapColor.GetBlue() - nDAT, 0L, 255L );
+                        sal_uInt8 cR = (sal_uInt8) MinMax( aBitmapColor.GetRed() - nDAT, 0L, 255L );
+                        sal_uInt8 cG = (sal_uInt8) MinMax( aBitmapColor.GetGreen() - nDAT, 0L, 255L );
+                        sal_uInt8 cB = (sal_uInt8) MinMax( aBitmapColor.GetBlue() - nDAT, 0L, 255L );
                         mpWriteAcc->SetPixel( nY, nX, BitmapColor( cR, cG, cB ) );
                     }
                 }
@@ -678,20 +678,20 @@ BOOL PSDReader::ImplReadBody()
         while ( nY < mpFileHeader->nRows )
         {
             if ( mbCompression )		// else nRunCount = 0 -> so we use only single raw packets
-                *mpPSD >> nRunCount;
+                m_rPSD >> nRunCount;
 
             if ( nRunCount & 0x80 ) 	// a run length packet
             {
-                *mpPSD >> nDat;
+                m_rPSD >> nDat;
                 if ( nDat )
                     nDat = 0;
                 else
                     nDat = 1;
                 if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                    *mpPSD >> nDummy;
-                for ( USHORT i = 0; i < ( -nRunCount + 1 ); i++ )
+                    m_rPSD >> nDummy;
+                for ( sal_uInt16 i = 0; i < ( -nRunCount + 1 ); i++ )
                 {
-                    mpMaskWriteAcc->SetPixel( nY, nX, (BYTE)nDat );
+                    mpMaskWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat );
                     if ( ++nX == mpFileHeader->nColumns )
                     {
                         nX = 0;
@@ -703,16 +703,16 @@ BOOL PSDReader::ImplReadBody()
             }
             else						// a raw packet
             {
-                for ( USHORT i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
+                for ( sal_uInt16 i = 0; i < ( ( nRunCount & 0x7f ) + 1 ); i++ )
                 {
-                    *mpPSD >> nDat;
+                    m_rPSD >> nDat;
                     if ( nDat )
                         nDat = 0;
                     else
                         nDat = 1;
                     if ( mpFileHeader->nDepth == 16 )	// 16 bit depth is to be skipped
-                        *mpPSD >> nDummy;
-                    mpMaskWriteAcc->SetPixel( nY, nX, (BYTE)nDat );
+                        m_rPSD >> nDummy;
+                    mpMaskWriteAcc->SetPixel( nY, nX, (sal_uInt8)nDat );
                     if ( ++nX == mpFileHeader->nColumns )
                     {
                         nX = 0;
@@ -724,41 +724,17 @@ BOOL PSDReader::ImplReadBody()
             }
         }
     }
-    return TRUE;
+    return sal_True;
 }
 
 //================== GraphicImport - die exportierte Funktion ================
 
-extern "C" BOOL __LOADONCALLAPI GraphicImport(SvStream & rStream, Graphic & rGraphic, FilterConfigItem*, BOOL )
+extern "C" sal_Bool __LOADONCALLAPI GraphicImport(SvStream & rStream, Graphic & rGraphic, FilterConfigItem*, sal_Bool )
 {
-    PSDReader aPSDReader;
+    PSDReader aPSDReader(rStream);
 
-    return aPSDReader.ReadPSD( rStream, rGraphic );
+    return aPSDReader.ReadPSD(rGraphic);
 }
 
-//================== ein bischen Muell fuer Windows ==========================
-
-#ifdef WIN
-
-static HINSTANCE hDLLInst = 0;		// HANDLE der DLL
-
-extern "C" int CALLBACK LibMain( HINSTANCE hDLL, WORD, WORD nHeap, LPSTR )
-{
-#ifndef WNT
-    if ( nHeap )
-        UnlockData( 0 );
-#endif
-
-    hDLLInst = hDLL;
-
-    return TRUE;
-}
-
-extern "C" int CALLBACK WEP( int )
-{
-    return 1;
-}
-
-#endif
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
