@@ -34,7 +34,9 @@
 #include "vcl/svapp.hxx"
 #include "vcl/msgbox.hxx"
 #include "sfx2/passwd.hxx"
-#include "com/sun/star/uno/Sequence.hxx"
+
+#include "comphelper/storagehelper.hxx"
+
 #include "com/sun/star/text/XTextRange.hpp"
 #include "com/sun/star/drawing/XShapes.hpp"
 #include "com/sun/star/container/XIndexAccess.hpp"
@@ -69,7 +71,7 @@ ImpPDFTabDialog::ImpPDFTabDialog( Window* pParent,
                                   const Reference< XComponent >& rxDoc,
                                   const Reference< lang::XMultiServiceFactory >& xFact
                                   ) :
-    SfxTabDialog( pParent, PDFFilterResId( RID_PDF_EXPORT_DLG ), 0, FALSE, 0 ),
+    SfxTabDialog( pParent, PDFFilterResId( RID_PDF_EXPORT_DLG ), 0, sal_False, 0 ),
     mxMSF( xFact ),
     maConfigItem( String( RTL_CONSTASCII_USTRINGPARAM( "Office.Common/Filter/PDF/Export/" ) ), &rFilterData ),
     maConfigI18N( String( RTL_CONSTASCII_USTRINGPARAM( "Office.Common/I18N/CTL/" ) ) ),
@@ -179,7 +181,7 @@ ImpPDFTabDialog::ImpPDFTabDialog( Window* pParent,
     {
     }
 
-//get the CTL (Complex Text Layout) from general options, returns TRUE if we have a CTL font on our hands.
+//get the CTL (Complex Text Layout) from general options, returns sal_True if we have a CTL font on our hands.
     mbUseCTLFont = maConfigI18N.ReadBool( OUString( RTL_CONSTASCII_USTRINGPARAM( "CTLFont" ) ), sal_False );
 
     mbUseLosslessCompression = maConfigItem.ReadBool( OUString( RTL_CONSTASCII_USTRINGPARAM( "UseLosslessCompression" ) ), sal_False );
@@ -273,7 +275,7 @@ ImpPDFTabDialog::~ImpPDFTabDialog()
 }
 
 // -----------------------------------------------------------------------------
-void ImpPDFTabDialog::PageCreated( USHORT _nId,
+void ImpPDFTabDialog::PageCreated( sal_uInt16 _nId,
                                    SfxTabPage& _rPage )
 {
     switch( _nId )
@@ -383,8 +385,8 @@ Sequence< PropertyValue > ImpPDFTabDialog::GetFilterData()
     nElementAdded--;
 
 // add the open password
-    aRet[ aRet.getLength() - nElementAdded ].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "DocumentOpenPassword" ) );
-    aRet[ aRet.getLength() - nElementAdded ].Value <<= OUString( msUserPassword );
+    aRet[ aRet.getLength() - nElementAdded ].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPasswords" ) );
+    aRet[ aRet.getLength() - nElementAdded ].Value <<= mxPreparedPasswords;
     nElementAdded--;
 
 //the restrict permission flag (needed to have the scripting consistent with the dialog)
@@ -393,8 +395,8 @@ Sequence< PropertyValue > ImpPDFTabDialog::GetFilterData()
     nElementAdded--;
 
 //add the permission password
-    aRet[ aRet.getLength() - nElementAdded ].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "PermissionPassword" ) );
-    aRet[ aRet.getLength() - nElementAdded ].Value <<= OUString( msOwnerPassword );
+    aRet[ aRet.getLength() - nElementAdded ].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPermissionPassword" ) );
+    aRet[ aRet.getLength() - nElementAdded ].Value <<= maPreparedOwnerPassword;
     nElementAdded--;
 
 // this should be the last added...
@@ -472,6 +474,10 @@ ImpPDFTabGeneralPage::ImpPDFTabGeneralPage( Window* pParent,
         aNewPos.Y() -= nDelta;
         maCbEmbedStandardFonts.SetPosPixel( aNewPos );
     }
+
+    maEdPages.SetAccessibleName(maRbRange.GetText());
+    maEdPages.SetAccessibleRelationLabeledBy(&maRbRange);
+
     maCbExportEmptyPages.SetStyle( maCbExportEmptyPages.GetStyle() | WB_VCENTER );
 }
 
@@ -523,7 +529,7 @@ void ImpPDFTabGeneralPage::SetFilterConfigItem( const ImpPDFTabDialog* paParent
     switch( paParent->mnPDFTypeSelection )
     {
     default:
-    case 0: maCbPDFA1b.Check( FALSE ); // PDF 1.4
+    case 0: maCbPDFA1b.Check( sal_False ); // PDF 1.4
         break;
     case 1: maCbPDFA1b.Check(); // PDF/A-1a
         break;
@@ -555,7 +561,7 @@ void ImpPDFTabGeneralPage::SetFilterConfigItem( const ImpPDFTabDialog* paParent
 
     if ( mbIsPresentation )
     {
-        maCbExportNotesPages.Show( TRUE );
+        maCbExportNotesPages.Show( sal_True );
         maCbExportNotesPages.Check( paParent->mbExportNotesPages );
     }
     else
@@ -569,8 +575,8 @@ void ImpPDFTabGeneralPage::SetFilterConfigItem( const ImpPDFTabDialog* paParent
         maCbAddStream.SetPosPixel( Point( aPos.X(), aPos.Y() - nCheckBoxHeight ) );
         aPos = maCbEmbedStandardFonts.GetPosPixel();
         maCbEmbedStandardFonts.SetPosPixel( Point( aPos.X(), aPos.Y() - nCheckBoxHeight ) );
-        maCbExportNotesPages.Show( FALSE );
-        maCbExportNotesPages.Check( FALSE );
+        maCbExportNotesPages.Show( sal_False );
+        maCbExportNotesPages.Check( sal_False );
     }
 
     maCbExportEmptyPages.Check( !paParent->mbIsSkipEmptyPages );
@@ -583,13 +589,13 @@ void ImpPDFTabGeneralPage::SetFilterConfigItem( const ImpPDFTabDialog* paParent
     }
     if( xIfc.is() )
     {
-        maCbAddStream.Show( TRUE );
+        maCbAddStream.Show( sal_True );
         maCbAddStream.Check( paParent->mbAddStream );
     }
     else
     {
-        maCbAddStream.Show( FALSE );
-        maCbAddStream.Check( FALSE );
+        maCbAddStream.Show( sal_False );
+        maCbAddStream.Check( sal_False );
     }
     maCbAddStream.SetToggleHdl( LINK( this, ImpPDFTabGeneralPage, ToggleAddStreamHdl ) );
     // init addstream dependencies
@@ -657,7 +663,8 @@ SfxTabPage*  ImpPDFTabGeneralPage::Create( Window* pParent,
 IMPL_LINK( ImpPDFTabGeneralPage, TogglePagesHdl, void*, EMPTYARG )
 {
     maEdPages.Enable( maRbRange.IsChecked() );
-    maEdPages.SetReadOnly( !maRbRange.IsChecked() );
+    //Sym2_5805, When the control is disabled, it is also readonly. So here, it is not necessary to set it as readonly.
+    //maEdPages.SetReadOnly( !maRbRange.IsChecked() );
     return 0;
 }
 
@@ -691,17 +698,18 @@ IMPL_LINK( ImpPDFTabGeneralPage, ToggleAddStreamHdl, void*, EMPTYARG )
         if( maCbAddStream.IsChecked() )
         {
             maRbAll.Check();
-            maRbRange.Enable( FALSE );
-            maRbSelection.Enable( FALSE );
-            maEdPages.Enable( FALSE );
-            maEdPages.SetReadOnly( TRUE );
-            maRbAll.Enable( FALSE );
+            maRbRange.Enable( sal_False );
+            maRbSelection.Enable( sal_False );
+            maEdPages.Enable( sal_False );
+            //Sym2_5805, When the control is disabled, it is also readonly. So here, it is not necessary to set it as readonly.
+            //maEdPages.SetReadOnly( sal_True );
+            maRbAll.Enable( sal_False );
         }
         else
         {
-            maRbAll.Enable( TRUE );
-            maRbRange.Enable( TRUE );
-            maRbSelection.Enable( TRUE );
+            maRbAll.Enable( sal_True );
+            maRbRange.Enable( sal_True );
+            maRbSelection.Enable( sal_True );
         }
     }
     return 0;
@@ -710,9 +718,13 @@ IMPL_LINK( ImpPDFTabGeneralPage, ToggleAddStreamHdl, void*, EMPTYARG )
 // -----------------------------------------------------------------------------
 IMPL_LINK( ImpPDFTabGeneralPage, ToggleExportPDFAHdl, void*, EMPTYARG )
 {
+    ImpPDFTabSecurityPage* pSecPage = NULL;
 //set the security page status (and its controls as well)
     if( mpaParent && mpaParent->GetTabPage( RID_PDF_TAB_SECURITY ) )
-        ( ( ImpPDFTabSecurityPage* )mpaParent->GetTabPage( RID_PDF_TAB_SECURITY ) )->ImplPDFASecurityControl( !maCbPDFA1b.IsChecked() );
+    {
+        pSecPage = static_cast<ImpPDFTabSecurityPage*>(mpaParent->GetTabPage( RID_PDF_TAB_SECURITY ));
+        pSecPage->ImplPDFASecurityControl( !maCbPDFA1b.IsChecked() );
+    }
 
 //PDF/A-1 needs tagged PDF, so  force disable the control, will be forced in pdfexport.
     sal_Bool bPDFA1Sel = maCbPDFA1b.IsChecked();
@@ -747,6 +759,13 @@ IMPL_LINK( ImpPDFTabGeneralPage, ToggleExportPDFAHdl, void*, EMPTYARG )
     if( mpaParent && mpaParent->GetTabPage( RID_PDF_TAB_LINKS ) )
         ( ( ImpPDFTabLinksPage* )mpaParent->GetTabPage( RID_PDF_TAB_LINKS ) )->ImplPDFALinkControl( !maCbPDFA1b.IsChecked() );
 
+    // if a password was set, inform the user that this will not be used in PDF/A case
+    if( maCbPDFA1b.IsChecked() && pSecPage && pSecPage->hasPassword() )
+    {
+        WarningBox aBox( this, PDFFilterResId( RID_PDF_WARNPDFAPASSWORD ) );
+        aBox.Execute();
+    }
+    
     return 0;
 }
 
@@ -787,6 +806,8 @@ ImpPDFTabOpnFtrPage::ImpPDFTabOpnFtrPage( Window* pParent,
     maRbMagnFitWidth.SetToggleHdl( LINK( this, ImpPDFTabOpnFtrPage, ToggleRbMagnHdl ) );
     maRbMagnFitVisible.SetToggleHdl( LINK( this, ImpPDFTabOpnFtrPage, ToggleRbMagnHdl ) );
     maRbMagnZoom.SetToggleHdl( LINK( this, ImpPDFTabOpnFtrPage, ToggleRbMagnHdl ) );
+    maNumZoom.SetAccessibleName(maRbMagnZoom.GetText());
+    maNumZoom.SetAccessibleRelationLabeledBy(&maRbMagnZoom);
 }
 
 // -----------------------------------------------------------------------------
@@ -876,23 +897,23 @@ void ImpPDFTabOpnFtrPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParent
     default:
     case 0:
         maRbMagnDefault.Check();
-        maNumZoom.Enable( FALSE );
+        maNumZoom.Enable( sal_False );
         break;
     case 1:
         maRbMagnFitWin.Check();
-        maNumZoom.Enable( FALSE );
+        maNumZoom.Enable( sal_False );
         break;
     case 2:
         maRbMagnFitWidth.Check();
-        maNumZoom.Enable( FALSE );
+        maNumZoom.Enable( sal_False );
         break;
     case 3:
         maRbMagnFitVisible.Check();
-        maNumZoom.Enable( FALSE );
+        maNumZoom.Enable( sal_False );
         break;
     case 4:
         maRbMagnZoom.Check();
-        maNumZoom.Enable( TRUE );
+        maNumZoom.Enable( sal_True );
         break;
     };
 
@@ -909,9 +930,8 @@ void ImpPDFTabOpnFtrPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParent
     }
 }
 
-IMPL_LINK( ImpPDFTabOpnFtrPage, ToggleRbPgLyContinueFacingHdl, void*, p )
+IMPL_LINK( ImpPDFTabOpnFtrPage, ToggleRbPgLyContinueFacingHdl, void*, EMPTYARG )
 {
-    p = p; //for compiler warning
     maCbPgLyFirstOnLeft.Enable( maRbPgLyContinueFacing.IsChecked() );
     return 0;
 }
@@ -950,6 +970,8 @@ ImpPDFTabViewerPage::ImpPDFTabViewerPage( Window* pParent,
     FreeResource();
     maRbAllBookmarkLevels.SetToggleHdl( LINK( this, ImpPDFTabViewerPage, ToggleRbBookmarksHdl ) );
     maRbVisibleBookmarkLevels.SetToggleHdl( LINK( this, ImpPDFTabViewerPage, ToggleRbBookmarksHdl ) );
+    maNumBookmarkLevels.SetAccessibleName(maRbVisibleBookmarkLevels.GetText());
+    maNumBookmarkLevels.SetAccessibleRelationLabeledBy(&maRbVisibleBookmarkLevels);
 }
 
 // -----------------------------------------------------------------------------
@@ -1001,13 +1023,13 @@ void ImpPDFTabViewerPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParent
     maCbTransitionEffects.Enable( mbIsPresentation );
     if( paParent->mnOpenBookmarkLevels < 0 )
     {
-        maRbAllBookmarkLevels.Check( TRUE );
-        maNumBookmarkLevels.Enable( FALSE );
+        maRbAllBookmarkLevels.Check( sal_True );
+        maNumBookmarkLevels.Enable( sal_False );
     }
     else
     {
-        maRbVisibleBookmarkLevels.Check( TRUE );
-        maNumBookmarkLevels.Enable( TRUE );
+        maRbVisibleBookmarkLevels.Check( sal_True );
+        maNumBookmarkLevels.Enable( sal_True );
         maNumBookmarkLevels.SetValue( paParent->mnOpenBookmarkLevels );
     }
 }
@@ -1018,15 +1040,18 @@ void ImpPDFTabViewerPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParent
 ImpPDFTabSecurityPage::ImpPDFTabSecurityPage( Window* i_pParent,
                                               const SfxItemSet& i_rCoreSet ) :
     SfxTabPage( i_pParent, PDFFilterResId( RID_PDF_TAB_SECURITY ), i_rCoreSet ),
-    maPbUserPwd( this, PDFFilterResId( BTN_USER_PWD ) ),
+    maFlGroup( this, PDFFilterResId( FL_PWD_GROUP ) ),
+    maPbSetPwd( this, PDFFilterResId( BTN_SET_PWD ) ),
     maFtUserPwd( this, PDFFilterResId( FT_USER_PWD ) ),
     maUserPwdSet( PDFFilterResId( STR_USER_PWD_SET ) ),
     maUserPwdUnset( PDFFilterResId( STR_USER_PWD_UNSET ) ),
-
-    maPbOwnerPwd( this,	PDFFilterResId( BTN_OWNER_PWD ) ),
+    maUserPwdPdfa( PDFFilterResId( STR_USER_PWD_PDFA ) ),
+    
+    maStrSetPwd( PDFFilterResId( STR_SET_PWD ) ),
     maFtOwnerPwd( this, PDFFilterResId( FT_OWNER_PWD ) ),
     maOwnerPwdSet( PDFFilterResId( STR_OWNER_PWD_SET ) ),
     maOwnerPwdUnset( PDFFilterResId( STR_OWNER_PWD_UNSET ) ),
+    maOwnerPwdPdfa( PDFFilterResId( STR_OWNER_PWD_PDFA ) ),
 
     maFlPrintPermissions( this, PDFFilterResId( FL_PRINT_PERMISSIONS ) ),
     maRbPrintNone( this, PDFFilterResId( RB_PRINT_NONE ) ),
@@ -1044,6 +1069,8 @@ ImpPDFTabSecurityPage::ImpPDFTabSecurityPage( Window* i_pParent,
     maCbEnableAccessibility( this, PDFFilterResId( CB_ENAB_ACCESS ) ),
 
     msUserPwdTitle( PDFFilterResId( STR_PDF_EXPORT_UDPWD ) ),
+    mbHaveOwnerPassword( false ),
+    mbHaveUserPassword( false ),
 
     msOwnerPwdTitle( PDFFilterResId( STR_PDF_EXPORT_ODPWD ) )
 {
@@ -1082,6 +1109,8 @@ ImpPDFTabSecurityPage::ImpPDFTabSecurityPage( Window* i_pParent,
             (*pCurrent++)->SetPosPixel( aNewPos );
         }
     }
+    
+    maPbSetPwd.SetClickHdl( LINK( this, ImpPDFTabSecurityPage, ClickmaPbSetPwdHdl ) );
 }
 
 // -----------------------------------------------------------------------------
@@ -1101,13 +1130,11 @@ void ImpPDFTabSecurityPage::GetFilterConfigItem( ImpPDFTabDialog* paParent  )
 {
 // please note that in PDF/A-1a mode even if this are copied back,
 // the security settings are forced disabled in PDFExport::Export
-    paParent->mbEncrypt = (msUserPassword.Len() > 0);
-    if( paParent->mbEncrypt )
-        paParent->msUserPassword = msUserPassword;
+    paParent->mbEncrypt = mbHaveUserPassword;
+    paParent->mxPreparedPasswords = mxPreparedPasswords;
 
-    paParent->mbRestrictPermissions = (msOwnerPassword.Len() > 0);
-    if( msOwnerPassword.Len() > 0 )
-        paParent->msOwnerPassword = msOwnerPassword;
+    paParent->mbRestrictPermissions = mbHaveOwnerPassword;
+    paParent->maPreparedOwnerPassword = maPreparedOwnerPassword;
 
 //verify print status
     paParent->mnPrint = 0;
@@ -1136,10 +1163,6 @@ void ImpPDFTabSecurityPage::GetFilterConfigItem( ImpPDFTabDialog* paParent  )
 // -----------------------------------------------------------------------------
 void ImpPDFTabSecurityPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParent )
 {
-    maPbUserPwd.SetClickHdl( LINK( this, ImpPDFTabSecurityPage, ClickmaPbUserPwdHdl ) );
-
-    maPbOwnerPwd.SetClickHdl( LINK( this, ImpPDFTabSecurityPage, ClickmaPbOwnerPwdHdl ) );
-
     switch( paParent->mnPrint )
     {
     default:
@@ -1185,40 +1208,56 @@ void ImpPDFTabSecurityPage::SetFilterConfigItem( const  ImpPDFTabDialog* paParen
             !( ( ImpPDFTabGeneralPage* )paParent->GetTabPage( RID_PDF_TAB_GENER ) )->IsPdfaSelected() );
 }
 
-//method common to both the password entry procedures
-void ImpPDFTabSecurityPage::ImplPwdPushButton( const String & i_rDlgTitle, String & io_rDestPassword )
+IMPL_LINK( ImpPDFTabSecurityPage, ClickmaPbSetPwdHdl, void*, EMPTYARG )
 {
-// string needed: dialog title, message box text, depending on the button clicked
-    SfxPasswordDialog aPwdDialog( this );
+    SfxPasswordDialog aPwdDialog( this, &msUserPwdTitle );
     aPwdDialog.SetMinLen( 0 );
-    aPwdDialog.ShowExtras( SHOWEXTRAS_CONFIRM );
-    aPwdDialog.SetText( i_rDlgTitle );
+    aPwdDialog.ShowExtras( SHOWEXTRAS_CONFIRM | SHOWEXTRAS_PASSWORD2 | SHOWEXTRAS_CONFIRM2 );
+    aPwdDialog.SetText( maStrSetPwd );
+    aPwdDialog.SetGroup2Text( msOwnerPwdTitle );
     aPwdDialog.AllowAsciiOnly();
     if( aPwdDialog.Execute() == RET_OK )  //OK issued get password and set it
-        io_rDestPassword = aPwdDialog.GetPassword();
+    {
+        rtl::OUString aUserPW( aPwdDialog.GetPassword() );
+        rtl::OUString aOwnerPW( aPwdDialog.GetPassword2() );
+        
+        mbHaveUserPassword = (aUserPW.getLength() != 0);
+        mbHaveOwnerPassword = (aOwnerPW.getLength() != 0);
+        
+        mxPreparedPasswords = vcl::PDFWriter::InitEncryption( aOwnerPW, aUserPW, true );
+        
+        if( mbHaveOwnerPassword )
+        {
+            maPreparedOwnerPassword = comphelper::OStorageHelper::CreatePackageEncryptionData( aOwnerPW );
+        }
+        else
+            maPreparedOwnerPassword = Sequence< NamedValue >();
+        
+        // trash clear text passwords string memory
+        rtl_zeroMemory( (void*)aUserPW.getStr(), aUserPW.getLength() );
+        rtl_zeroMemory( (void*)aOwnerPW.getStr(), aOwnerPW.getLength() );
+    }
     enablePermissionControls();
-}
-
-IMPL_LINK( ImpPDFTabSecurityPage, ClickmaPbUserPwdHdl, void*, EMPTYARG )
-{
-    ImplPwdPushButton(msUserPwdTitle, msUserPassword );
-    return 0;
-}
-
-IMPL_LINK( ImpPDFTabSecurityPage, ClickmaPbOwnerPwdHdl, void*, EMPTYARG )
-{
-    ImplPwdPushButton( msOwnerPwdTitle, msOwnerPassword );
-
     return 0;
 }
 
 void ImpPDFTabSecurityPage::enablePermissionControls()
 {
-    maFtUserPwd.SetText( (msUserPassword.Len() > 0 && IsEnabled()) ? maUserPwdSet : maUserPwdUnset );
+    sal_Bool bIsPDFASel =  sal_False;
+    ImpPDFTabDialog* pParent = static_cast<ImpPDFTabDialog*>(GetTabDialog());
+    if( pParent && pParent->GetTabPage( RID_PDF_TAB_GENER ) )
+        bIsPDFASel = ( ( ImpPDFTabGeneralPage* )pParent->
+                       GetTabPage( RID_PDF_TAB_GENER ) )->IsPdfaSelected();
+    if( bIsPDFASel )
+        maFtUserPwd.SetText( maUserPwdPdfa );
+    else
+        maFtUserPwd.SetText( (mbHaveUserPassword && IsEnabled()) ? maUserPwdSet : maUserPwdUnset );
     
-    sal_Bool bLocalEnable = (msOwnerPassword.Len() > 0) && IsEnabled();
-    
-    maFtOwnerPwd.SetText( bLocalEnable ? maOwnerPwdSet : maOwnerPwdUnset );
+    sal_Bool bLocalEnable = mbHaveOwnerPassword && IsEnabled();
+    if( bIsPDFASel )
+        maFtOwnerPwd.SetText( maOwnerPwdPdfa );
+    else
+        maFtOwnerPwd.SetText( bLocalEnable ? maOwnerPwdSet : maOwnerPwdUnset );
 
     maFlPrintPermissions.Enable( bLocalEnable );
     maRbPrintNone.Enable( bLocalEnable );
@@ -1470,28 +1509,28 @@ ImplErrorDialog::ImplErrorDialog( const std::set< vcl::PDFWriter::ErrorCode >& r
         {
         case vcl::PDFWriter::Warning_Transparency_Omitted_PDFA:
         {
-            USHORT nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_PDFA_SHORT ) ),
+            sal_uInt16 nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_PDFA_SHORT ) ),
                                                 aWarnImg );
             maErrors.SetEntryData( nPos, new String( PDFFilterResId( STR_WARN_TRANSP_PDFA ) ) );
         }
         break;
         case vcl::PDFWriter::Warning_Transparency_Omitted_PDF13:
         {
-            USHORT nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_VERSION_SHORT ) ),
+            sal_uInt16 nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_VERSION_SHORT ) ),
                                                 aWarnImg );
             maErrors.SetEntryData( nPos, new String( PDFFilterResId( STR_WARN_TRANSP_VERSION ) ) );
         }
         break;
         case vcl::PDFWriter::Warning_FormAction_Omitted_PDFA:
         {
-            USHORT nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_FORMACTION_PDFA_SHORT ) ),
+            sal_uInt16 nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_FORMACTION_PDFA_SHORT ) ),
                                                 aWarnImg );
             maErrors.SetEntryData( nPos, new String( PDFFilterResId( STR_WARN_FORMACTION_PDFA ) ) );
         }
         break;
         case vcl::PDFWriter::Warning_Transparency_Converted:
         {
-            USHORT nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_CONVERTED_SHORT ) ),
+            sal_uInt16 nPos = maErrors.InsertEntry( String( PDFFilterResId( STR_WARN_TRANSP_CONVERTED_SHORT ) ),
                                                 aWarnImg );
             maErrors.SetEntryData( nPos, new String( PDFFilterResId( STR_WARN_TRANSP_CONVERTED ) ) );
         }
@@ -1542,7 +1581,7 @@ ImplErrorDialog::ImplErrorDialog( const std::set< vcl::PDFWriter::ErrorCode >& r
 ImplErrorDialog::~ImplErrorDialog()
 {
     // free strings again
-    for( USHORT n = 0; n < maErrors.GetEntryCount(); n++ )
+    for( sal_uInt16 n = 0; n < maErrors.GetEntryCount(); n++ )
         delete (String*)maErrors.GetEntryData( n );
 }
 
