@@ -134,7 +134,7 @@ void registerClassInfo(
 //.......................................................................................
 #define REGISTER_CLASS_CORE(classImplName) \
     registerClassInfo( \
-        ::rtl::OUString::createFromAscii("com.sun.star.form.") + ::rtl::OUString::createFromAscii(#classImplName), \
+        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.form.") ) + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(#classImplName)), \
         aServices, \
         frm::classImplName##_CreateInstance)
 
@@ -229,7 +229,7 @@ void ensureClassInfos()
     aServices.getArray()[2] = frm::FRM_SUN_COMPONENT_DATABASE_FORMATTEDFIELD;
     aServices.getArray()[3] = frm::BINDABLE_DATABASE_FORMATTED_FIELD;
 
-    registerClassInfo(::rtl::OUString::createFromAscii("com.sun.star.comp.forms.OFormattedFieldWrapper_ForcedFormatted"),
+    registerClassInfo(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.forms.OFormattedFieldWrapper_ForcedFormatted") ),
         aServices,
         frm::OFormattedFieldWrapper_CreateInstance_ForceFormatted);
 
@@ -276,7 +276,7 @@ void ensureClassInfos()
     // = XForms core
 #define REGISTER_XFORMS_CLASS(name) \
     aServices.realloc(1); \
-    aServices.getArray()[0] = rtl::OUString::createFromAscii( "com.sun.star.xforms." #name ); \
+    aServices.getArray()[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.xforms." #name )); \
     REGISTER_CLASS_CORE(name)
 
     REGISTER_XFORMS_CLASS(Model);
@@ -284,22 +284,6 @@ void ensureClassInfos()
 
 }
 
-//---------------------------------------------------------------------------------------
-void registerServiceProvider(const ::rtl::OUString& _rServiceImplName, const Sequence< ::rtl::OUString >& _rServices, XRegistryKey* _pKey)
-{
-    ::rtl::OUString sMainKeyName = ::rtl::OUString::createFromAscii("/");
-    sMainKeyName += _rServiceImplName;
-    sMainKeyName += ::rtl::OUString::createFromAscii("/UNO/SERVICES");
-    Reference< XRegistryKey > xNewKey = _pKey->createKey(sMainKeyName);
-    OSL_ENSURE(xNewKey.is(), "forms::registerProvider : could not create a registry key !");
-    if (!xNewKey.is())
-        return;
-
-    const ::rtl::OUString* pSupportedServices = _rServices.getConstArray();
-    for (sal_Int32 i=0; i<_rServices.getLength(); ++i, ++pSupportedServices)
-        xNewKey->createKey(*pSupportedServices);
-}
-
 //=======================================================================================
 extern "C"
 {
@@ -342,57 +326,6 @@ SAL_DLLPUBLIC_EXPORT void SAL_CALL component_getImplementationEnvironment(const
     *_ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-//---------------------------------------------------------------------------------------
-SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo(void* _pServiceManager, XRegistryKey* _pRegistryKey)
-{
-    if (_pRegistryKey)
-    {
-        try
-        {
-            // ========================================================================
-            // the real way - use the OModule
-            createRegistryInfo_FORMS();
-            if ( !::frm::OFormsModule::writeComponentInfos(
-                    static_cast<XMultiServiceFactory*>( _pServiceManager ),
-                    static_cast<XRegistryKey*>( _pRegistryKey ) )
-                )
-                return sal_False;
-
-            // ========================================================================
-            // a lot of stuff which is implemented "manually" here in this file
-
-            // collect the class infos
-            ensureClassInfos();
-
-            // both our static sequences should have the same length ...
-            sal_Int32 nClasses = s_aClassImplementationNames.getLength();
-            OSL_ENSURE(s_aClassServiceNames.getLength() == nClasses,
-                "forms::component_writeInfo : invalid class infos !");
-
-            // loop through the sequences and register the service providers
-            const ::rtl::OUString* pClasses = s_aClassImplementationNames.getConstArray();
-            const Sequence< ::rtl::OUString >* pServices = s_aClassServiceNames.getConstArray();
-
-            for (sal_Int32 i=0; i<nClasses; ++i, ++pClasses, ++pServices)
-                registerServiceProvider(*pClasses, *pServices, _pRegistryKey);
-
-            s_aClassImplementationNames.realloc(0);
-            s_aClassServiceNames.realloc(0);
-            s_aFactories.realloc(0);
-
-            return sal_True;
-        }
-        catch ( InvalidRegistryException& )
-        {
-            OSL_ENSURE(sal_False, "forms::component_writeInfo : InvalidRegistryException !");
-        }
-    }
-    s_aClassImplementationNames.realloc(0);
-    s_aClassServiceNames.realloc(0);
-    s_aFactories.realloc(0);
-    return sal_False;
-}
-
 //---------------------------------------------------------------------------------------
 SAL_DLLPUBLIC_EXPORT void* SAL_CALL component_getFactory(const sal_Char* _pImplName, XMultiServiceFactory* _pServiceManager, void* /*_pRegistryKey*/)
 {
@@ -410,7 +343,7 @@ SAL_DLLPUBLIC_EXPORT void* SAL_CALL component_getFactory(const sal_Char* _pImplN
     sal_Int32 nClasses = s_aClassImplementationNames.getLength();
     OSL_ENSURE((s_aClassServiceNames.getLength() == nClasses) &&
         (s_aFactories.getLength() == nClasses),
-        "forms::component_writeInfo : invalid class infos !");
+        "forms::component_getFactory : invalid class infos !");
 
     // loop through the sequences and register the service providers
     const ::rtl::OUString* pClasses = s_aClassImplementationNames.getConstArray();
@@ -419,7 +352,7 @@ SAL_DLLPUBLIC_EXPORT void* SAL_CALL component_getFactory(const sal_Char* _pImplN
 
     for (sal_Int32 i=0; i<nClasses; ++i, ++pClasses, ++pServices, ++pFunctionsAsInts)
     {
-        if (rtl_ustr_ascii_compare(*pClasses, _pImplName) == 0)
+        if (rtl_ustr_ascii_compare(pClasses->getStr(), _pImplName) == 0)
         {
             ::cppu::ComponentInstantiation aCurrentCreateFunction =
                 reinterpret_cast< ::cppu::ComponentInstantiation>(*pFunctionsAsInts);
