@@ -158,7 +158,7 @@ namespace frm
         {
             m_pEngine->SetModifyHdl( LINK( this, ORichTextModel, OnEngineContentModified ) );
 
-            ULONG nEngineControlWord = m_pEngine->GetControlWord();
+            sal_uLong nEngineControlWord = m_pEngine->GetControlWord();
             nEngineControlWord = nEngineControlWord & ~EE_CNTRL_AUTOPAGESIZE;
             m_pEngine->SetControlWord( nEngineControlWord );
 
@@ -549,7 +549,7 @@ namespace frm
             }
             catch( const Exception& )
             {
-                OSL_ENSURE( sal_False, "ORichTextModel::getEditEngine: caught an exception!" );
+                OSL_FAIL( "ORichTextModel::getEditEngine: caught an exception!" );
             }
         }
         return pEngine;
