@@ -107,7 +107,7 @@ namespace frm
     DBG_NAME( ONavigationBarControl )
     //------------------------------------------------------------------
     ONavigationBarControl::ONavigationBarControl( const Reference< XMultiServiceFactory >& _rxORB )
-        :m_xORB( _rxORB )
+        :UnoControl( _rxORB )
     {
         DBG_CTOR( ONavigationBarControl, NULL );
     }
@@ -182,7 +182,7 @@ namespace frm
             }
 
             // create the peer
-            ONavigationBarPeer* pPeer = ONavigationBarPeer::Create( m_xORB, pParentWin, getModel() );
+            ONavigationBarPeer* pPeer = ONavigationBarPeer::Create( maContext.getLegacyServiceFactory(), pParentWin, getModel() );
             DBG_ASSERT( pPeer, "ONavigationBarControl::createPeer: invalid peer returned!" );
             if ( pPeer )
                 // by definition, the returned component is aquired once
@@ -301,7 +301,7 @@ namespace frm
         MouseSettings aMouseSettings = aSettings.GetMouseSettings();
         aMouseSettings.SetButtonRepeat( 10 );
         aSettings.SetMouseSettings( aMouseSettings );
-        pNavBar->SetSettings( aSettings, TRUE );
+        pNavBar->SetSettings( aSettings, sal_True );
 
         // outta here
         return pPeer;
