@@ -34,8 +34,8 @@
 
 #include <dispatch/popupmenudispatcher.hxx>
 #include <general.h>
-#include <xml/menuconfiguration.hxx>
-#include <classes/addonmenu.hxx>
+#include <framework/menuconfiguration.hxx>
+#include <framework/addonmenu.hxx>
 #include <services.h>
 #include <properties.h>
 
