@@ -581,29 +581,6 @@ void SAL_CALL component_getImplementationEnvironment( const sal_Char** ppEnvType
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-sal_Bool SAL_CALL component_writeInfo( void* /*_pServiceManager*/, void* _pRegistryKey )
-{
-    if (_pRegistryKey)
-    {
-        ::com::sun::star::registry::XRegistryKey * pRegistryKey =
-            reinterpret_cast< ::com::sun::star::registry::XRegistryKey* >(
-                                _pRegistryKey );
-        ::com::sun::star::uno::Reference<
-                        ::com::sun::star::registry::XRegistryKey > xNewKey;
-
-        for( const InstancesArray* pArr = aInstances; pArr->pServiceNm; ++pArr )
-        {
-            xNewKey = pRegistryKey->createKey(
-                    ::rtl::OUString::createFromAscii( pArr->pImplementationNm )  );
-            xNewKey = xNewKey->createKey(
-                    ::rtl::OUString::createFromAscii( "/UNO/SERVICES" ) );
-            xNewKey->createKey(
-                    ::rtl::OUString::createFromAscii( pArr->pServiceNm ) );
-        }
-    }
-    return sal_True;
-}
-
 void* SAL_CALL component_getFactory( const sal_Char* sImplementationName, void* _pServiceManager, void* /*_pRegistryKey*/ )
 {
     void* pRet = NULL;
