@@ -58,10 +58,10 @@ extern "C" { int YYWarning( char * ); }
 #define STATE_ISOCODE99	0x000D
 
 // set of global variables
-BOOL bEnableExport;
-BOOL bMergeMode;
-BOOL bErrorLog;
-BOOL bUTF8;
+sal_Bool bEnableExport;
+sal_Bool bMergeMode;
+sal_Bool bErrorLog;
+sal_Bool bUTF8;
 ByteString sPrj;
 ByteString sPrjRoot;
 ByteString sInputFileName;
@@ -78,17 +78,17 @@ extern "C" {
 extern char *GetOutputFile( int argc, char* argv[])
 /*****************************************************************************/
 {
-    bEnableExport = FALSE;
-    bMergeMode = FALSE;
-    bErrorLog = TRUE;
-    bUTF8 = TRUE;
+    bEnableExport = sal_False;
+    bMergeMode = sal_False;
+    bErrorLog = sal_True;
+    bUTF8 = sal_True;
     sPrj = "";
     sPrjRoot = "";
     sInputFileName = "";
     sActFileName = "";
     Export::sLanguages = "";
-    USHORT nState = STATE_NON;
-    BOOL bInput = FALSE;
+    sal_uInt16 nState = STATE_NON;
+    sal_Bool bInput = sal_False;
 
     // parse command line
     for( int i = 1; i < argc; i++ ) {
@@ -109,15 +109,15 @@ extern char *GetOutputFile( int argc, char* argv[])
         }
         else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-E" ) {
             nState = STATE_ERRORLOG;
-            bErrorLog = FALSE;
+            bErrorLog = sal_False;
         }
         else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-UTF8" ) {
             nState = STATE_UTF8;
-            bUTF8 = TRUE;
+            bUTF8 = sal_True;
         }
         else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-NOUTF8" ) {
             nState = STATE_UTF8;
-            bUTF8 = FALSE;
+            bUTF8 = sal_False;
         }
         else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-L" ) {
             nState = STATE_LANGUAGES;
@@ -132,7 +132,7 @@ extern char *GetOutputFile( int argc, char* argv[])
                 }
                 case STATE_INPUT: {
                     sInputFileName = argv[ i ];
-                    bInput = TRUE; // source file found
+                    bInput = sal_True; // source file found
                 }
                 break;
                 case STATE_OUTPUT: {
@@ -149,7 +149,7 @@ extern char *GetOutputFile( int argc, char* argv[])
                 break;
                 case STATE_MERGESRC: {
                     sMergeSrc = ByteString( argv[ i ]);
-                    bMergeMode = TRUE; // activate merge mode, cause merge database found
+                    bMergeMode = sal_True; // activate merge mode, cause merge database found
                 }
                 break;
                 case STATE_LANGUAGES: {
@@ -162,7 +162,7 @@ extern char *GetOutputFile( int argc, char* argv[])
 
     if ( bInput ) {
         // command line is valid
-        bEnableExport = TRUE;
+        bEnableExport = sal_True;
         char *pReturn = new char[ sOutputFile.Len() + 1 ];
         strcpy( pReturn, sOutputFile.GetBuffer());  // #100211# - checked
         return pReturn;
@@ -290,8 +290,8 @@ int GetError()
 /*****************************************************************************/
 XRMResParser::XRMResParser()
 /*****************************************************************************/
-                : bError( FALSE ),
-                bText( FALSE )
+                : bError( sal_False ),
+                bText( sal_False )
 {
     aLanguages = Export::GetLanguages();
 }
@@ -322,9 +322,6 @@ int XRMResParser::Execute( int nToken, char * pToken )
             sLID = "";
             sGID += ".";
             sGID += GetAttribute( rToken, "id" );
-            //sLocalized = "1";
-            
-            //sLocalized = "X:";
             sLocalized = true;
         break;
 
@@ -336,11 +333,6 @@ int XRMResParser::Execute( int nToken, char * pToken )
             sLID = "";
             sGID += ".";
             sGID += GetAttribute( rToken, "id" );
-//			if ( GetAttribute( rToken, "localized" ) == "false" )
-//				sLocalized += "0";
-//                sLocalized = false;
-//			else
-//				sLocalized += "1";
                 sLocalized = true;				
         break;
 
@@ -349,7 +341,7 @@ int XRMResParser::Execute( int nToken, char * pToken )
                 EndOfText( sCurrentOpenTag, sCurrentCloseTag );
             ByteString sTmp = sGID;
             sGID = "";
-            for ( USHORT i = 0; i + 1 < sTmp.GetTokenCount( '.' ); i++ ) {
+            for ( sal_uInt16 i = 0; i + 1 < sTmp.GetTokenCount( '.' ); i++ ) {
                 if ( sGID.Len())
                     sGID += ".";
                 sGID += sTmp.GetToken( i, '.' );
@@ -365,7 +357,7 @@ int XRMResParser::Execute( int nToken, char * pToken )
                     //EndOfText( sCurrentOpenTag, sCurrentCloseTag );
                     sLID = sNewLID;
                 }
-                bText = TRUE;
+                bText = sal_True;
                 sCurrentText = "";
                 sCurrentOpenTag = rToken;
                 Output( rToken );
@@ -380,7 +372,7 @@ int XRMResParser::Execute( int nToken, char * pToken )
                 WorkOnText( sCurrentOpenTag, sCurrentText );
                 Output( sCurrentText );
                 EndOfText( sCurrentOpenTag, sCurrentCloseTag );// <---
-                bText = FALSE;
+                bText = sal_False;
                 rToken = ByteString("");
                 sCurrentText  = ByteString("");
                 //printf("<-XRM_TEXT_END");
@@ -420,7 +412,7 @@ ByteString XRMResParser::GetAttribute( const ByteString &rToken, const ByteStrin
     ByteString sSearch( " " );
     sSearch += rAttribute;
     sSearch += "=";
-    USHORT nPos = sTmp.Search( sSearch );
+    sal_uInt16 nPos = sTmp.Search( sSearch );
 
     if ( nPos != STRING_NOTFOUND ) {
         sTmp = sTmp.Copy( nPos );
@@ -446,9 +438,7 @@ void XRMResParser::ConvertStringToDBFormat( ByteString &rString )
     do {
         sResult = rString;
         rString.EraseLeadingChars( _LF );
-    //	rString.EraseLeadingChars( ' ' );
         rString.EraseLeadingChars( '\t' );
-    //	rString.EraseTrailingChars( ' ' );
         rString.EraseTrailingChars( '\t' );
     } while ( sResult != rString );
 
@@ -563,9 +553,6 @@ void XRMResExport::EndOfText(
         char cSearch = 0x00;
         ByteString sSearch( cSearch );
 
-     //	if ( !pResData->sText[ ByteString("en-US") ].Len() ) 
-    //        pResData->sText[ ByteString("en-US") ] = pResData->sText[ ByteString("de") ];
-
         Export::FillInFallbacks( pResData );
 
         ByteString sTimeStamp( Export::GetTimeStamp());
@@ -574,7 +561,6 @@ void XRMResExport::EndOfText(
             sCur = aLanguages[ n ];
         
             ByteString sAct = pResData->sText[ sCur ];
-                //Export::UnquotHTML( sAct );
                 sAct.EraseAllChars( 0x0A );
 
                 ByteString sOutput( sPrj ); sOutput += "\t";
@@ -594,7 +580,6 @@ void XRMResExport::EndOfText(
                 sOutput += sTimeStamp;
 
                 sOutput.SearchAndReplaceAll( sSearch, "_" );
-                //if( !sCur.EqualsIgnoreCaseAscii("de") ||( sCur.EqualsIgnoreCaseAscii("de") && !Export::isMergingGermanAllowed( sPrj ) ) )
                 if( sAct.Len() > 1 )
                     pOutputStream->WriteLine( sOutput );
             }
@@ -647,7 +632,6 @@ void XRMResMerge::WorkOnText(
     if ( pMergeDataFile ) {
         if ( !pResData ) {
             ByteString sPlatform( "" );
-//			pResData = new ResData( sPlatform, GetGID() , sFilename );
             pResData = new ResData( sPlatform, GetLID() , sFilename );
             pResData->sId = GetLID();
 
@@ -698,12 +682,10 @@ void XRMResMerge::EndOfText(
                 ByteString sContent;
                 if ( !sCur.EqualsIgnoreCaseAscii("en-US")  &&
                     ( pEntrys->GetText(
-                        sContent, STRING_TYP_TEXT, sCur, TRUE )) &&
+                        sContent, STRING_TYP_TEXT, sCur, sal_True )) &&
                     ( sContent != "-" ) && ( sContent.Len()))
                 {
                     ByteString sText( sContent );
-                    //Export::QuotHTMLXRM( sText );
-
                     ByteString sAdditionalLine( "\t" );
                     sAdditionalLine += rOpenTag;
                     ByteString sSearch = "xml:lang=\"";
@@ -718,7 +700,7 @@ void XRMResMerge::EndOfText(
                     sAdditionalLine += rCloseTag;
                     sAdditionalLine += "\n";
 
-                    for ( USHORT i = 0; i + 1 < GetGID().GetTokenCount( '.' ); i++ )
+                    for ( sal_uInt16 i = 0; i + 1 < GetGID().GetTokenCount( '.' ); i++ )
                         sAdditionalLine += "\t";
 
                     Output( sAdditionalLine );
