@@ -27,13 +27,11 @@
  ************************************************************************/
 
 #include "oox/drawingml/chart/objectformatter.hxx"
-#include <rtl/strbuf.hxx>
-#include <osl/thread.h>
+
 #include <com/sun/star/util/XNumberFormatsSupplier.hpp>
 #include <com/sun/star/util/XNumberFormatTypes.hpp>
-#include "properties.hxx"
-#include "tokens.hxx"
-#include "oox/helper/modelobjecthelper.hxx"
+#include <osl/thread.h>
+#include <rtl/strbuf.hxx>
 #include "oox/core/xmlfilterbase.hxx"
 #include "oox/drawingml/fillproperties.hxx"
 #include "oox/drawingml/lineproperties.hxx"
@@ -41,24 +39,7 @@
 #include "oox/drawingml/textparagraph.hxx"
 #include "oox/drawingml/theme.hxx"
 #include "oox/drawingml/chart/chartspacemodel.hxx"
-
-using ::rtl::OStringBuffer;
-using ::rtl::OUString;
-using ::rtl::OUStringToOString;
-using ::com::sun::star::uno::Any;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::UNO_QUERY;
-using ::com::sun::star::uno::UNO_QUERY_THROW;
-using ::com::sun::star::lang::Locale;
-using ::com::sun::star::lang::XMultiServiceFactory;
-using ::com::sun::star::frame::XModel;
-using ::com::sun::star::chart2::XChartDocument;
-using ::com::sun::star::graphic::XGraphic;
-using ::com::sun::star::util::XNumberFormats;
-using ::com::sun::star::util::XNumberFormatsSupplier;
-using ::com::sun::star::util::XNumberFormatTypes;
-using ::oox::core::XmlFilterBase;
+#include "oox/helper/modelobjecthelper.hxx"
 
 namespace oox {
 namespace drawingml {
@@ -66,6 +47,20 @@ namespace chart {
 
 // ============================================================================
 
+using namespace ::com::sun::star::chart2;
+using namespace ::com::sun::star::frame;
+using namespace ::com::sun::star::graphic;
+using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star::uno;
+using namespace ::com::sun::star::util;
+
+using ::oox::core::XmlFilterBase;
+using ::rtl::OStringBuffer;
+using ::rtl::OUString;
+using ::rtl::OUStringToOString;
+
+// ============================================================================
+
 namespace {
 
 struct AutoFormatPatternEntry
@@ -195,7 +190,7 @@ static const AutoFormatEntry spNoFormats[] =
     AUTOFORMAT_END()
 };
 
-static const AutoFormatEntry spChartSpaceLines[] =
+static const AutoFormatEntry spDataTableLines[] =
 {
     AUTOFORMAT_COLORMOD(  1, 32, THEMED_STYLE_SUBTLE, XML_tx1, XML_tint, 75000 ),
     AUTOFORMAT_COLORMOD( 33, 40, THEMED_STYLE_SUBTLE, XML_dk1, XML_tint, 75000 ),
@@ -203,14 +198,6 @@ static const AutoFormatEntry spChartSpaceLines[] =
     AUTOFORMAT_END()
 };
 
-static const AutoFormatEntry spChartSpaceFills[] =
-{
-    AUTOFORMAT_COLOR(  1, 32, THEMED_STYLE_SUBTLE, XML_bg1 ),
-    AUTOFORMAT_COLOR( 33, 40, THEMED_STYLE_SUBTLE, XML_lt1 ),
-    AUTOFORMAT_COLOR( 41, 48, THEMED_STYLE_SUBTLE, XML_dk1 ),
-    AUTOFORMAT_END()
-};
-
 static const AutoFormatEntry spPlotArea2dFills[] =
 {
     AUTOFORMAT_COLOR(       1, 32, THEMED_STYLE_SUBTLE, XML_bg1 ),
@@ -524,7 +511,7 @@ struct ObjectTypeFormatEntry
 static const ObjectTypeFormatEntry spObjTypeFormatEntries[] =
 {
     //                object type                property type              auto text          auto line            auto fill              auto effect
-    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTSPACE,     PROPERTYTYPE_COMMON,       0,                 spChartSpaceLines,   spChartSpaceFills,     0 /* eq to Ch2 */ ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTSPACE,     PROPERTYTYPE_COMMON,       0,                 spNoFormats,         spNoFormats,           0 /* eq to Ch2 */ ),
     TYPEFORMAT_FRAME( OBJECTTYPE_CHARTTITLE,     PROPERTYTYPE_COMMON,       spChartTitleTexts, 0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
     TYPEFORMAT_FRAME( OBJECTTYPE_LEGEND,         PROPERTYTYPE_COMMON,       spOtherTexts,      spNoFormats,         spNoFormats,           0 /* eq to Ch2 */ ),
     TYPEFORMAT_FRAME( OBJECTTYPE_PLOTAREA2D,     PROPERTYTYPE_COMMON,       0,                 0 /* eq to Ch2 */,   spPlotArea2dFills,     0 /* eq to Ch2 */ ),
@@ -549,7 +536,7 @@ static const ObjectTypeFormatEntry spObjTypeFormatEntries[] =
     TYPEFORMAT_LINE(  OBJECTTYPE_HILOLINE,       PROPERTYTYPE_LINEARSERIES, 0,                 spOtherLines ),
     TYPEFORMAT_FRAME( OBJECTTYPE_UPBAR,          PROPERTYTYPE_COMMON,       0,                 spUpDownBarLines,    spUpBarFills,          spUpDownBarEffects ),
     TYPEFORMAT_FRAME( OBJECTTYPE_DOWNBAR,        PROPERTYTYPE_COMMON,       0,                 spUpDownBarLines,    spDownBarFills,        spUpDownBarEffects ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_DATATABLE,      PROPERTYTYPE_COMMON,       spOtherTexts,      spChartSpaceLines )
+    TYPEFORMAT_LINE(  OBJECTTYPE_DATATABLE,      PROPERTYTYPE_COMMON,       spOtherTexts,      spDataTableLines )
 };
 
 #undef TYPEFORMAT_FRAME
@@ -1178,8 +1165,7 @@ void ObjectFormatter::convertNumberFormat( PropertySet& rPropSet, const NumberFo
         }
         catch( Exception& )
         {
-            OSL_ENSURE( false,
-                OStringBuffer( "ObjectFormatter::convertNumberFormat - cannot create number format '" ).
+            OSL_FAIL( OStringBuffer( "ObjectFormatter::convertNumberFormat - cannot create number format '" ).
                 append( OUStringToOString( rNumberFormat.maFormatCode, osl_getThreadTextEncoding() ) ).append( '\'' ).getStr() );
         }
     }
