@@ -27,28 +27,18 @@
  ************************************************************************/
 
 #include "oox/drawingml/chart/plotareaconverter.hxx"
-#include <com/sun/star/drawing/Direction3D.hpp>
-#include <com/sun/star/drawing/ProjectionMode.hpp>
-#include <com/sun/star/drawing/ShadeMode.hpp>
+
 #include <com/sun/star/chart/XChartDocument.hpp>
 #include <com/sun/star/chart/XDiagramPositioning.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/chart2/XCoordinateSystemContainer.hpp>
 #include <com/sun/star/chart2/XDiagram.hpp>
+#include <com/sun/star/drawing/Direction3D.hpp>
+#include <com/sun/star/drawing/ProjectionMode.hpp>
+#include <com/sun/star/drawing/ShadeMode.hpp>
 #include "oox/drawingml/chart/axisconverter.hxx"
 #include "oox/drawingml/chart/plotareamodel.hxx"
 #include "oox/drawingml/chart/typegroupconverter.hxx"
-#include "properties.hxx"
-
-using ::rtl::OUString;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::UNO_QUERY_THROW;
-using ::com::sun::star::awt::Rectangle;
-using ::com::sun::star::chart2::XCoordinateSystem;
-using ::com::sun::star::chart2::XCoordinateSystemContainer;
-using ::com::sun::star::chart2::XDiagram;
 
 namespace oox {
 namespace drawingml {
@@ -56,6 +46,14 @@ namespace chart {
 
 // ============================================================================
 
+using namespace ::com::sun::star::awt;
+using namespace ::com::sun::star::chart2;
+using namespace ::com::sun::star::uno;
+
+using ::rtl::OUString;
+
+// ============================================================================
+
 namespace {
 
 /** Axes set model. This is a helper for the plot area converter collecting all
@@ -303,7 +301,7 @@ void WallFloorConverter::convertFromModel( const Reference< XDiagram >& rxDiagra
         {
             case OBJECTTYPE_FLOOR:  aPropSet.set( rxDiagram->getFloor() );  break;
             case OBJECTTYPE_WALL:   aPropSet.set( rxDiagram->getWall() );   break;
-            default:                OSL_ENSURE( false, "WallFloorConverter::convertFromModel - invalid object type" );
+            default:                OSL_FAIL( "WallFloorConverter::convertFromModel - invalid object type" );
         }
         if( aPropSet.is() )
             getFormatter().convertFrameFormatting( aPropSet, mrModel.mxShapeProp, mrModel.mxPicOptions.getOrCreate(), eObjType );
@@ -440,7 +438,7 @@ void PlotAreaConverter::convertPositionFromModel()
                 xPositioning->setDiagramPositionIncludingAxes( aDiagramRect );
             break;
             default:
-                OSL_ENSURE( false, "PlotAreaConverter::convertPositionFromModel - unknown positioning target" );
+                OSL_FAIL( "PlotAreaConverter::convertPositionFromModel - unknown positioning target" );
         }
     }
     catch( Exception& )
