@@ -27,27 +27,30 @@
  ************************************************************************/
 
 #include "oox/drawingml/chart/seriescontext.hxx"
+
 #include "oox/drawingml/shapepropertiescontext.hxx"
 #include "oox/drawingml/textbodycontext.hxx"
 #include "oox/drawingml/chart/datasourcecontext.hxx"
 #include "oox/drawingml/chart/seriesmodel.hxx"
 #include "oox/drawingml/chart/titlecontext.hxx"
 
-using ::rtl::OUString;
-using ::oox::core::ContextHandler2;
-using ::oox::core::ContextHandler2Helper;
-using ::oox::core::ContextHandlerRef;
-
 namespace oox {
 namespace drawingml {
 namespace chart {
 
 // ============================================================================
 
+using ::oox::core::ContextHandler2;
+using ::oox::core::ContextHandler2Helper;
+using ::oox::core::ContextHandlerRef;
+using ::rtl::OUString;
+
+// ============================================================================
+
 namespace {
 
-ContextHandlerRef lclDataLabelSharedCreateContext(
-        ContextHandler2& rContext, sal_Int32 nElement, const AttributeList& rAttribs, DataLabelModelBase& orModel )
+ContextHandlerRef lclDataLabelSharedCreateContext( ContextHandler2& rContext,
+        sal_Int32 nElement, const AttributeList& rAttribs, DataLabelModelBase& orModel )
 {
     if( rContext.isRootElement() ) switch( nElement )
     {
@@ -80,7 +83,7 @@ ContextHandlerRef lclDataLabelSharedCreateContext(
             orModel.mobShowVal = rAttribs.getBool( XML_val );
             return 0;
         case C_TOKEN( separator ):
-            // collect separator text in onEndElement()
+            // collect separator text in onCharacters()
             return &rContext;
         case C_TOKEN( spPr ):
             return new ShapePropertiesContext( rContext, orModel.mxShapeProp.create() );
@@ -90,14 +93,10 @@ ContextHandlerRef lclDataLabelSharedCreateContext(
     return 0;
 }
 
-void lclDataLabelSharedEndElement( ContextHandler2& rContext, const OUString& rChars, DataLabelModelBase& orModel )
+void lclDataLabelSharedCharacters( ContextHandler2& rContext, const OUString& rChars, DataLabelModelBase& orModel )
 {
-    switch( rContext.getCurrentElement() )
-    {
-        case C_TOKEN( separator ):
-            orModel.moaSeparator = rChars;
-        break;
-    }
+    if( rContext.isCurrentElement( C_TOKEN( separator ) ) )
+        orModel.moaSeparator = rChars;
 }
 
 } // namespace
@@ -128,9 +127,9 @@ ContextHandlerRef DataLabelContext::onCreateContext( sal_Int32 nElement, const A
     return lclDataLabelSharedCreateContext( *this, nElement, rAttribs, mrModel );
 }
 
-void DataLabelContext::onEndElement( const OUString& rChars )
+void DataLabelContext::onCharacters( const OUString& rChars )
 {
-    lclDataLabelSharedEndElement( *this, rChars, mrModel );
+    lclDataLabelSharedCharacters( *this, rChars, mrModel );
 }
 
 // ============================================================================
@@ -160,9 +159,9 @@ ContextHandlerRef DataLabelsContext::onCreateContext( sal_Int32 nElement, const
     return lclDataLabelSharedCreateContext( *this, nElement, rAttribs, mrModel );
 }
 
-void DataLabelsContext::onEndElement( const OUString& rChars )
+void DataLabelsContext::onCharacters( const OUString& rChars )
 {
-    lclDataLabelSharedEndElement( *this, rChars, mrModel );
+    lclDataLabelSharedCharacters( *this, rChars, mrModel );
 }
 
 // ============================================================================
@@ -306,7 +305,7 @@ ContextHandlerRef TrendlineContext::onCreateContext( sal_Int32 nElement, const A
             mrModel.mfIntercept = rAttribs.getDouble( XML_val, 0.0 );
             return 0;
         case C_TOKEN( name ):
-            return this;    // collect name in onEndElement()
+            return this;    // collect name in onCharacters()
         case C_TOKEN( order ):
             mrModel.mnOrder = rAttribs.getInteger( XML_val, 2 );
             return 0;
@@ -324,14 +323,10 @@ ContextHandlerRef TrendlineContext::onCreateContext( sal_Int32 nElement, const A
     return 0;
 }
 
-void TrendlineContext::onEndElement( const ::rtl::OUString& rChars )
+void TrendlineContext::onCharacters( const OUString& rChars )
 {
-    switch( getCurrentElement() )
-    {
-        case C_TOKEN( name ):
-            mrModel.maName = rChars;
-        break;
-    }
+    if( isCurrentElement( C_TOKEN( name ) ) )
+        mrModel.maName = rChars;
 }
 
 // ============================================================================
@@ -759,4 +754,4 @@ ContextHandlerRef SurfaceSeriesContext::onCreateContext( sal_Int32 nElement, con
 } // namespace drawingml
 } // namespace oox
 
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
\ No newline at end of file
