@@ -149,7 +149,7 @@ void SAL_CALL ImportDocumentHandler::startElement(const ::rtl::OUString & _sName
 {
     uno::Reference< xml::sax::XAttributeList > xNewAttribs = _xAttrList;
     bool bExport = true;
-    if ( _sName.equalsAscii("office:report") )
+    if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("office:report")) )
     {
         const sal_Int16 nLength = (_xAttrList.is()) ? _xAttrList->getLength() : 0;
         static const ::rtl::OUString s_sTRUE = ::xmloff::token::GetXMLToken(XML_TRUE);
@@ -192,13 +192,12 @@ void SAL_CALL ImportDocumentHandler::startElement(const ::rtl::OUString & _sName
         }
         catch(uno::Exception&)
         {
-            // OSL_ENSURE(0,"Exception catched while filling the report definition props");
         }
         m_xDelegatee->startElement(lcl_createAttribute(XML_NP_OFFICE,XML_CHART),NULL);
         bExport = false;
         m_bImportedChart = true;
     }
-    else if ( _sName.equalsAscii("rpt:master-detail-field") )
+    else if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:master-detail-field")) )
     {
         const sal_Int16 nLength = (_xAttrList.is()) ? _xAttrList->getLength() : 0;
         static const ::rtl::OUString s_sTRUE = ::xmloff::token::GetXMLToken(XML_TRUE);
@@ -234,17 +233,17 @@ void SAL_CALL ImportDocumentHandler::startElement(const ::rtl::OUString & _sName
         }
         catch(uno::Exception&)
         {
-            OSL_ENSURE(0,"Exception catched while filling the report definition props");
+            OSL_FAIL("Exception catched while filling the report definition props");
         }
         bExport = false;
     }
-    else if ( _sName.equalsAscii("rpt:detail")
-        ||    _sName.equalsAscii("rpt:formatted-text")
-        ||    _sName.equalsAscii("rpt:master-detail-fields")
-        ||    _sName.equalsAscii("rpt:report-component")
-        ||    _sName.equalsAscii("rpt:report-element"))
+    else if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:detail"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:formatted-text"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:master-detail-fields"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:report-component"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:report-element")))
         bExport = false;
-    else if ( _sName.equalsAscii("chart:plot-area"))
+    else if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("chart:plot-area")))
     {
         sal_Bool bHasCategories = sal_True;
         const sal_Int16 nLength = (_xAttrList.is()) ? _xAttrList->getLength() : 0;
@@ -258,24 +257,23 @@ void SAL_CALL ImportDocumentHandler::startElement(const ::rtl::OUString & _sName
                 sLocalName = sAttrName;
             else
                 sLocalName = sAttrName.copy( nColonPos + 1L );
-            if ( sLocalName.equalsAscii("data-source-has-labels") )
+            if ( sLocalName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("data-source-has-labels")) )
             {
                 const rtl::OUString sValue = _xAttrList->getValueByIndex( i );
-                bHasCategories = sValue.equalsAscii("both");
+                bHasCategories = sValue.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("both"));
                 break;
             }
-        } // for(sal_Int16 i = 0; i < nLength; ++i)
+        }
         beans::PropertyValue* pArgIter = m_aArguments.getArray();
         beans::PropertyValue* pArgEnd  = pArgIter + m_aArguments.getLength();
         for(;pArgIter != pArgEnd;++pArgIter)
         {
-            if ( pArgIter->Name.equalsAscii("HasCategories") )
+            if ( pArgIter->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("HasCategories")) )
             {
                 pArgIter->Value <<= bHasCategories;
                 break;
             }
-        } // for(;pArgIter != pArgEnd;++pArgIter)
-
+        }
 
         SvXMLAttributeList* pList = new SvXMLAttributeList();
         xNewAttribs = pList;
@@ -292,11 +290,11 @@ void SAL_CALL ImportDocumentHandler::endElement(const ::rtl::OUString & _sName)
 {
     bool bExport = true;
     ::rtl::OUString sNewName = _sName;
-    if ( _sName.equalsAscii("office:report") )
+    if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("office:report")) )
     {
         sNewName = lcl_createAttribute(XML_NP_OFFICE,XML_CHART);
     }
-    else if ( _sName.equalsAscii("rpt:master-detail-fields") )
+    else if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:master-detail-fields")) )
     {
         if ( !m_aMasterFields.empty() )
             m_xDatabaseDataProvider->setMasterFields(uno::Sequence< ::rtl::OUString>(&*m_aMasterFields.begin(),m_aMasterFields.size()));
@@ -304,11 +302,11 @@ void SAL_CALL ImportDocumentHandler::endElement(const ::rtl::OUString & _sName)
             m_xDatabaseDataProvider->setDetailFields(uno::Sequence< ::rtl::OUString>(&*m_aDetailFields.begin(),m_aDetailFields.size()));
         bExport = false;
     }
-    else if ( _sName.equalsAscii("rpt:detail") 
-        ||    _sName.equalsAscii("rpt:formatted-text")
-        ||    _sName.equalsAscii("rpt:master-detail-field")
-        ||    _sName.equalsAscii("rpt:report-component")
-        ||    _sName.equalsAscii("rpt:report-element"))
+    else if ( _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:detail"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:formatted-text"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:master-detail-field"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:report-component"))
+        ||    _sName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("rpt:report-element")))
         bExport = false;
 
     if ( bExport )
@@ -358,7 +356,7 @@ void SAL_CALL ImportDocumentHandler::initialize( const uno::Sequence< uno::Any >
 
         uno::Reference< chart2::data::XDataReceiver > xReceiver(m_xModel,uno::UNO_QUERY_THROW);
         xReceiver->attachDataProvider(m_xDatabaseDataProvider.get());
-    } // if ( !m_xDatabaseDataProvider.is() )
+    }
 
     m_aArguments = m_xDatabaseDataProvider->detectArguments(NULL);
     
