@@ -26,16 +26,11 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_sal.hxx"
- 
 //------------------------------------------------------------------------
 // include files
 //------------------------------------------------------------------------
-#include "cppunit/TestAssert.h"
-#include "cppunit/TestFixture.h"
-#include "cppunit/extensions/HelperMacros.h"
-#include "cppunit/plugin/TestPlugIn.h"
+#include <sal/cppunit.h>
+
 #include <osl_Mutex_Const.h> 
 
 using namespace	osl;
