@@ -41,10 +41,10 @@
 
 #include <stdio.h> // printf
 
-const UINT16	TokenPool::nScTokenOff = 8192;
+const sal_uInt16	TokenPool::nScTokenOff = 8192;
 
 
-TokenStack::TokenStack( UINT16 nNewSize )
+TokenStack::TokenStack( sal_uInt16 nNewSize )
 {
     pStack = new TokenId[ nNewSize ];
 
@@ -70,17 +70,17 @@ TokenStack::~TokenStack()
 
 TokenPool::TokenPool( void )
 {
-    UINT16	nLauf = nScTokenOff;
+    sal_uInt16	nLauf = nScTokenOff;
 
     // Sammelstelle fuer Id-Folgen
     nP_Id = 256;
-    pP_Id = new UINT16[ nP_Id ];
+    pP_Id = new sal_uInt16[ nP_Id ];
 
     // Sammelstelle fuer Ids
     nElement = 32;
-    pElement = new UINT16[ nElement ];
+    pElement = new sal_uInt16[ nElement ];
     pType = new E_TYPE[ nElement ];
-    pSize = new UINT16[ nElement ];
+    pSize = new sal_uInt16[ nElement ];
     nP_IdLast = 0;
 
     // Sammelstelle fuer Strings
@@ -95,7 +95,7 @@ TokenPool::TokenPool( void )
 
     // Sammelstelle fuer error codes
     nP_Err = 8;
-    pP_Err = new USHORT[ nP_Err ];
+    pP_Err = new sal_uInt16[ nP_Err ];
 
     // Sammelstellen fuer Referenzen
     nP_RefTr = 32;
@@ -123,7 +123,7 @@ TokenPool::TokenPool( void )
 
 TokenPool::~TokenPool()
 {
-    UINT16	n;
+    sal_uInt16	n;
 
     delete[] pP_Id;
     delete[] pElement;
@@ -173,8 +173,8 @@ TokenPool::~TokenPool()
 
 void TokenPool::GrowString( void )
 {
-    UINT16		nP_StrNew = nP_Str * 2;
-    UINT16		nL;
+    sal_uInt16		nP_StrNew = nP_Str * 2;
+    sal_uInt16		nL;
 
     String**	ppP_StrNew = new String *[ nP_StrNew ];
 
@@ -192,11 +192,11 @@ void TokenPool::GrowString( void )
 
 void TokenPool::GrowDouble( void )
 {
-    UINT16		nP_DblNew = nP_Dbl * 2;
+    sal_uInt16		nP_DblNew = nP_Dbl * 2;
 
     double*		pP_DblNew = new double[ nP_DblNew ];
 
-    for( UINT16 nL = 0 ; nL < nP_Dbl ; nL++ )
+    for( sal_uInt16 nL = 0 ; nL < nP_Dbl ; nL++ )
         pP_DblNew[ nL ] = pP_Dbl[ nL ];
 
     nP_Dbl = nP_DblNew;
@@ -207,8 +207,8 @@ void TokenPool::GrowDouble( void )
 
 void TokenPool::GrowTripel( void )
 {
-    UINT16			nP_RefTrNew = nP_RefTr * 2;
-    UINT16			nL;
+    sal_uInt16			nP_RefTrNew = nP_RefTr * 2;
+    sal_uInt16			nL;
 
     ScSingleRefData**	ppP_RefTrNew = new ScSingleRefData *[ nP_RefTrNew ];
 
@@ -226,11 +226,11 @@ void TokenPool::GrowTripel( void )
 
 void TokenPool::GrowId( void )
 {
-    UINT16	nP_IdNew = nP_Id * 2;
+    sal_uInt16	nP_IdNew = nP_Id * 2;
 
-    UINT16*	pP_IdNew = new UINT16[ nP_IdNew ];
+    sal_uInt16*	pP_IdNew = new sal_uInt16[ nP_IdNew ];
 
-    for( UINT16 nL = 0 ; nL < nP_Id ; nL++ )
+    for( sal_uInt16 nL = 0 ; nL < nP_Id ; nL++ )
         pP_IdNew[ nL ] = pP_Id[ nL ];
 
     nP_Id = nP_IdNew;
@@ -242,13 +242,13 @@ void TokenPool::GrowId( void )
 
 void TokenPool::GrowElement( void )
 {
-    UINT16	nElementNew = nElement * 2;
+    sal_uInt16	nElementNew = nElement * 2;
 
-    UINT16*	pElementNew = new UINT16[ nElementNew ];
+    sal_uInt16*	pElementNew = new sal_uInt16[ nElementNew ];
     E_TYPE*	pTypeNew = new E_TYPE[ nElementNew ];
-    UINT16*	pSizeNew = new UINT16[ nElementNew ];
+    sal_uInt16*	pSizeNew = new sal_uInt16[ nElementNew ];
 
-    for( UINT16 nL = 0 ; nL < nElement ; nL++ )
+    for( sal_uInt16 nL = 0 ; nL < nElement ; nL++ )
     {
         pElementNew[ nL ] = pElement[ nL ];
         pTypeNew[ nL ] = pType[ nL ];
@@ -268,7 +268,7 @@ void TokenPool::GrowElement( void )
 
 void TokenPool::GrowExt( void )
 {
-    UINT16		nNewSize = nP_Ext * 2;
+    sal_uInt16		nNewSize = nP_Ext * 2;
 
     EXTCONT**	ppNew = new EXTCONT*[ nNewSize ];
 
@@ -283,7 +283,7 @@ void TokenPool::GrowExt( void )
 
 void TokenPool::GrowNlf( void )
 {
-    UINT16		nNewSize = nP_Nlf * 2;
+    sal_uInt16		nNewSize = nP_Nlf * 2;
 
     NLFCONT**	ppNew = new NLFCONT*[ nNewSize ];
 
@@ -298,7 +298,7 @@ void TokenPool::GrowNlf( void )
 
 void TokenPool::GrowMatrix( void )
 {
-    UINT16      nNewSize = nP_Matrix * 2;
+    sal_uInt16      nNewSize = nP_Matrix * 2;
 
     ScMatrix**  ppNew = new ScMatrix*[ nNewSize ];
 
@@ -310,7 +310,7 @@ void TokenPool::GrowMatrix( void )
     nP_Matrix = nNewSize;
 }
 
-void TokenPool::GetElement( const UINT16 nId )
+void TokenPool::GetElement( const sal_uInt16 nId )
 {
     DBG_ASSERT( nId < nElementAkt, "*TokenPool::GetElement(): Id zu gross!?" );
 
@@ -322,7 +322,7 @@ void TokenPool::GetElement( const UINT16 nId )
         {
 #ifdef DBG_UTIL
             case T_Id:
-                DBG_ERROR( "-TokenPool::GetElement(): hier hast Du nichts zu suchen!" );
+                OSL_FAIL( "-TokenPool::GetElement(): hier hast Du nichts zu suchen!" );
                 break;
 #endif
             case T_Str:
@@ -334,7 +334,7 @@ void TokenPool::GetElement( const UINT16 nId )
             case T_Err:
                 break;
             case T_RefC:
-                pScToken->AddSingleReference( *ppP_RefTr[ pElement[ (UINT16) nId ] ] );
+                pScToken->AddSingleReference( *ppP_RefTr[ pElement[ (sal_uInt16) nId ] ] );
                 break;
             case T_RefA:
                 {
@@ -345,11 +345,18 @@ void TokenPool::GetElement( const UINT16 nId )
                 }
                 break;
             case T_RN:
-                pScToken->AddName( pElement[ nId ] );
-                break;
+            {
+                sal_uInt16 n = pElement[nId];
+                if (n < maRangeNames.size())
+                {
+                    const RangeName& r = maRangeNames[n];
+                    pScToken->AddRangeName(r.mnIndex, r.mbGlobal);
+                }
+            }
+            break;
             case T_Ext:
                 {
-                UINT16			n = pElement[ nId ];
+                sal_uInt16			n = pElement[ nId ];
                 EXTCONT*		p = ( n < nP_Ext )? ppP_Ext[ n ] : NULL;
 
                 if( p )
@@ -363,7 +370,7 @@ void TokenPool::GetElement( const UINT16 nId )
                 break;
             case T_Nlf:
                 {
-                UINT16			n = pElement[ nId ];
+                sal_uInt16			n = pElement[ nId ];
                 NLFCONT*		p = ( n < nP_Nlf )? ppP_Nlf[ n ] : NULL;
 
                 if( p )
@@ -372,7 +379,7 @@ void TokenPool::GetElement( const UINT16 nId )
                 break;
             case T_Matrix:
                 {
-                UINT16          n = pElement[ nId ];
+                sal_uInt16          n = pElement[ nId ];
                 ScMatrix*       p = ( n < nP_Matrix )? ppP_Matrix[ n ] : NULL;
 
                 if( p )
@@ -381,25 +388,27 @@ void TokenPool::GetElement( const UINT16 nId )
                 break;
             case T_ExtName:
             {
-                UINT16 n = pElement[nId];
+                sal_uInt16 n = pElement[nId];
                 if (n < maExtNames.size())
                 {
                     const ExtName& r = maExtNames[n];
                     pScToken->AddExternalName(r.mnFileId, r.maName);
                 }
             }
+            break;
             case T_ExtRefC:
             {
-                UINT16 n = pElement[nId];
+                sal_uInt16 n = pElement[nId];
                 if (n < maExtCellRefs.size())
                 {
                     const ExtCellRef& r = maExtCellRefs[n];
                     pScToken->AddExternalSingleReference(r.mnFileId, r.maTabName, r.maRef);
                 }
             }
+            break;
             case T_ExtRefA:
             {
-                UINT16 n = pElement[nId];
+                sal_uInt16 n = pElement[nId];
                 if (n < maExtAreaRefs.size())
                 {
                     const ExtAreaRef& r = maExtAreaRefs[n];
@@ -408,13 +417,13 @@ void TokenPool::GetElement( const UINT16 nId )
             }
             break;
             default:
-                DBG_ERROR("-TokenPool::GetElement(): Zustand undefiniert!?");
+                OSL_FAIL("-TokenPool::GetElement(): Zustand undefiniert!?");
         }
     }
 }
 
 
-void TokenPool::GetElementRek( const UINT16 nId )
+void TokenPool::GetElementRek( const sal_uInt16 nId )
 {
 #ifdef DBG_UTIL
     nRek++;
@@ -426,8 +435,8 @@ void TokenPool::GetElementRek( const UINT16 nId )
     DBG_ASSERT( pType[ nId ] == T_Id, "-TokenPool::GetElementRek(): nId nicht Id-Folge!" );
 
 
-    UINT16		nAnz = pSize[ nId ];
-    UINT16*		pAkt = &pP_Id[ pElement[ nId ] ];
+    sal_uInt16		nAnz = pSize[ nId ];
+    sal_uInt16*		pAkt = &pP_Id[ pElement[ nId ] ];
     for( ; nAnz > 0 ; nAnz--, pAkt++ )
     {
         if( *pAkt < nScTokenOff )
@@ -457,11 +466,18 @@ void TokenPool::GetElementRek( const UINT16 nId )
                     }
                     break;
                 case T_RN:
-                    pScToken->AddName( pElement[ *pAkt ] );
-                    break;
+                {
+                    sal_uInt16 n = pElement[*pAkt];
+                    if (n < maRangeNames.size())
+                    {
+                        const RangeName& r = maRangeNames[n];
+                        pScToken->AddRangeName(r.mnIndex, r.mbGlobal);
+                    }
+                }
+                break;
                 case T_Ext:
                     {
-                    UINT16		n = pElement[ *pAkt ];
+                    sal_uInt16		n = pElement[ *pAkt ];
                     EXTCONT*	p = ( n < nP_Ext )? ppP_Ext[ n ] : NULL;
 
                     if( p )
@@ -470,7 +486,7 @@ void TokenPool::GetElementRek( const UINT16 nId )
                     break;
                 case T_Nlf:
                     {
-                    UINT16		n = pElement[ *pAkt ];
+                    sal_uInt16		n = pElement[ *pAkt ];
                     NLFCONT*	p = ( n < nP_Nlf )? ppP_Nlf[ n ] : NULL;
 
                     if( p )
@@ -479,7 +495,7 @@ void TokenPool::GetElementRek( const UINT16 nId )
                     break;
                 case T_Matrix:
                     {
-                    UINT16          n = pElement[ *pAkt ];
+                    sal_uInt16          n = pElement[ *pAkt ];
                     ScMatrix*       p = ( n < nP_Matrix )? ppP_Matrix[ n ] : NULL;
 
                     if( p )
@@ -488,25 +504,27 @@ void TokenPool::GetElementRek( const UINT16 nId )
                     break;
                 case T_ExtName:
                 {
-                    UINT16 n = pElement[*pAkt];
+                    sal_uInt16 n = pElement[*pAkt];
                     if (n < maExtNames.size())
                     {
                         const ExtName& r = maExtNames[n];
                         pScToken->AddExternalName(r.mnFileId, r.maName);
                     }
                 }
+                break;
                 case T_ExtRefC:
                 {
-                    UINT16 n = pElement[*pAkt];
+                    sal_uInt16 n = pElement[*pAkt];
                     if (n < maExtCellRefs.size())
                     {
                         const ExtCellRef& r = maExtCellRefs[n];
                         pScToken->AddExternalSingleReference(r.mnFileId, r.maTabName, r.maRef);
                     }
                 }
+                break;
                 case T_ExtRefA:
                 {
-                    UINT16 n = pElement[*pAkt];
+                    sal_uInt16 n = pElement[*pAkt];
                     if (n < maExtAreaRefs.size())
                     {
                         const ExtAreaRef& r = maExtAreaRefs[n];
@@ -515,7 +533,7 @@ void TokenPool::GetElementRek( const UINT16 nId )
                 }
                 break;
                 default:
-                    DBG_ERROR("-TokenPool::GetElementRek(): Zustand undefiniert!?");
+                    OSL_FAIL("-TokenPool::GetElementRek(): Zustand undefiniert!?");
             }
         }
         else	// elementarer SC_Token
@@ -568,16 +586,9 @@ const TokenId TokenPool::Store( const double& rDouble )
 }
 
 
-const TokenId TokenPool::Store( const UINT16 nIndex )
+const TokenId TokenPool::Store( const sal_uInt16 nIndex )
 {
-    if( nElementAkt >= nElement )
-        GrowElement();
-
-    pElement[ nElementAkt ] = nIndex;			// Daten direkt im Index!
-    pType[ nElementAkt ] = T_RN;				// Typinfo Range Name eintragen
-
-    nElementAkt++;
-    return ( const TokenId ) nElementAkt;				// Ausgabe von altem Wert + 1!
+    return StoreName(nIndex, true);
 }
 
 
@@ -604,7 +615,7 @@ const TokenId TokenPool::Store( const String& rString )
 
     DBG_ASSERT( sizeof( xub_StrLen ) <= 2, "*TokenPool::Store(): StrLen doesn't match!" );
 
-    pSize[ nElementAkt ] = ( UINT16 ) ppP_Str[ nP_StrAkt ]->Len();
+    pSize[ nElementAkt ] = ( sal_uInt16 ) ppP_Str[ nP_StrAkt ]->Len();
 
     nElementAkt++;
     nP_StrAkt++;
@@ -738,12 +749,30 @@ const TokenId TokenPool::StoreMatrix()
     return ( const TokenId ) nElementAkt;
 }
 
+const TokenId TokenPool::StoreName( sal_uInt16 nIndex, bool bGlobal )
+{
+    if ( nElementAkt >= nElement )
+        GrowElement();
+
+    pElement[nElementAkt] = static_cast<sal_uInt16>(maRangeNames.size());
+    pType[nElementAkt] = T_RN;
+
+    maRangeNames.push_back(RangeName());
+    RangeName& r = maRangeNames.back();
+    r.mnIndex = nIndex;
+    r.mbGlobal = bGlobal;
+
+    ++nElementAkt;
+
+    return static_cast<const TokenId>(nElementAkt);
+}
+
 const TokenId TokenPool::StoreExtName( sal_uInt16 nFileId, const String& rName )
 {
     if ( nElementAkt >= nElement )
         GrowElement();
 
-    pElement[nElementAkt] = static_cast<UINT16>(maExtNames.size());
+    pElement[nElementAkt] = static_cast<sal_uInt16>(maExtNames.size());
     pType[nElementAkt] = T_ExtName;
     
     maExtNames.push_back(ExtName());
@@ -761,7 +790,7 @@ const TokenId TokenPool::StoreExtRef( sal_uInt16 nFileId, const String& rTabName
     if ( nElementAkt >= nElement )
         GrowElement();
 
-    pElement[nElementAkt] = static_cast<UINT16>(maExtCellRefs.size());
+    pElement[nElementAkt] = static_cast<sal_uInt16>(maExtCellRefs.size());
     pType[nElementAkt] = T_ExtRefC;
     
     maExtCellRefs.push_back(ExtCellRef());
@@ -780,7 +809,7 @@ const TokenId TokenPool::StoreExtRef( sal_uInt16 nFileId, const String& rTabName
     if ( nElementAkt >= nElement )
         GrowElement();
 
-    pElement[nElementAkt] = static_cast<UINT16>(maExtAreaRefs.size());
+    pElement[nElementAkt] = static_cast<sal_uInt16>(maExtAreaRefs.size());
     pType[nElementAkt] = T_ExtRefA;
     
     maExtAreaRefs.push_back(ExtAreaRef());
@@ -797,15 +826,16 @@ const TokenId TokenPool::StoreExtRef( sal_uInt16 nFileId, const String& rTabName
 void TokenPool::Reset( void )
 {
     nP_IdAkt = nP_IdLast = nElementAkt = nP_StrAkt = nP_DblAkt = nP_ErrAkt = nP_RefTrAkt = nP_ExtAkt = nP_NlfAkt = nP_MatrixAkt = 0;
+    maRangeNames.clear();
     maExtNames.clear();
     maExtCellRefs.clear();
     maExtAreaRefs.clear();
 }
 
 
-BOOL TokenPool::IsSingleOp( const TokenId& rId, const DefTokenId eId ) const
+sal_Bool TokenPool::IsSingleOp( const TokenId& rId, const DefTokenId eId ) const
 {
-    UINT16 nId = (UINT16) rId;
+    sal_uInt16 nId = (sal_uInt16) rId;
     if( nId && nId <= nElementAkt )
     {// existent?
         nId--;
@@ -813,7 +843,7 @@ BOOL TokenPool::IsSingleOp( const TokenId& rId, const DefTokenId eId ) const
         {// Tokenfolge?
             if( pSize[ nId ] == 1 )
             {// GENAU 1 Token
-                UINT16	nSecId = pP_Id[ pElement[ nId ] ];
+                sal_uInt16	nSecId = pP_Id[ pElement[ nId ] ];
                 if( nSecId >= nScTokenOff )
                 {// Default-Token?
                     return ( DefTokenId ) ( nSecId - nScTokenOff ) == eId;	// Gesuchter?
@@ -822,13 +852,13 @@ BOOL TokenPool::IsSingleOp( const TokenId& rId, const DefTokenId eId ) const
         }
     }
 
-    return FALSE;
+    return false;
 }
 
 const String* TokenPool::GetExternal( const TokenId& rId ) const
 {
     const String*   p = NULL;
-    UINT16 n = (UINT16) rId;
+    sal_uInt16 n = (sal_uInt16) rId;
     if( n && n <= nElementAkt )
     {
         n--;
