@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,7 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sc.hxx"
 
-
 // INCLUDE ---------------------------------------------------------------
 #include "xmlsubti.hxx"
 #include "global.hxx"
@@ -69,7 +68,7 @@ using ::std::auto_ptr;
 using namespace com::sun::star;
 
 ScMyTableData::ScMyTableData(sal_Int32 nSheet, sal_Int32 nCol, sal_Int32 nRow)
-    : 	nColsPerCol(nDefaultColCount, 1),
+    :   nColsPerCol(nDefaultColCount, 1),
         nRealCols(nDefaultColCount + 1, 0),
         nRowsPerRow(nDefaultRowCount, 1),
         nRealRows(nDefaultRowCount + 1, 0),
@@ -160,26 +159,17 @@ ScXMLTabProtectionData::ScXMLTabProtectionData() :
 
 ScMyTables::ScMyTables(ScXMLImport& rTempImport)
     : rImport(rTempImport),
-    aResizeShapes(rTempImport),
+    aFixupOLEs(rTempImport),
     nCurrentColStylePos(0),
     nCurrentDrawPage( -1 ),
     nCurrentXShapes( -1 ),
-    nTableCount( 0 ),
-    nCurrentSheet( -1 )
+    nCurrentSheet( -1 ),
+    pLastTable(NULL)
 {
-    aTableVec.resize(nDefaultTabCount, NULL);
 }
 
 ScMyTables::~ScMyTables()
 {
-    ScMyTableData* pTable;
-    while (nTableCount > 0)
-    {
-        pTable = aTableVec[nTableCount - 1];
-        delete pTable;
-        aTableVec[nTableCount - 1] = NULL;
-        --nTableCount;
-    }
 }
 
 void ScMyTables::NewSheet(const rtl::OUString& sTableName, const rtl::OUString& sStyleName,
@@ -189,14 +179,8 @@ void ScMyTables::NewSheet(const rtl::OUString& sTableName, const rtl::OUString&
     {
         nCurrentColStylePos = 0;
         sCurrentSheetName = sTableName;
-        ScMyTableData* aTable;
-        while (nTableCount > 0)
-        {
-            aTable = aTableVec[nTableCount - 1];
-            delete aTable;
-            aTableVec[nTableCount - 1] = NULL;
-            --nTableCount;
-        }
+        maTables.clear();
+        pLastTable = NULL;
         ++nCurrentSheet;
 
         maProtectionData = rProtectData;
@@ -217,12 +201,11 @@ void ScMyTables::NewSheet(const rtl::OUString& sTableName, const rtl::OUString&
                         ScDocument *pDoc = ScXMLConverter::GetScDocument(rImport.GetModel());
                         if (pDoc)
                         {
-                            rImport.LockSolarMutex();
+                            ScXMLImport::MutexGuard aGuard(rImport);
                             String sTabName(String::CreateFromAscii("Table"));
                             pDoc->CreateValidTabName(sTabName);
                             rtl::OUString sOUTabName(sTabName);
                             xSheets->insertNewByName(sOUTabName, sal::static_int_cast<sal_Int16>(nCurrentSheet));
-                            rImport.UnlockSolarMutex();
                         }
                     }
                 }
@@ -246,12 +229,11 @@ void ScMyTables::NewSheet(const rtl::OUString& sTableName, const rtl::OUString&
                                     ScDocument *pDoc = ScXMLConverter::GetScDocument(rImport.GetModel());
                                     if (pDoc)
                                     {
-                                        rImport.LockSolarMutex();
+                                        ScXMLImport::MutexGuard aGuard(rImport);
                                         String sTabName(String::CreateFromAscii("Table"));
                                         pDoc->CreateValidTabName(sTabName);
                                         rtl::OUString sOUTabName(sTabName);
                                         xNamed->setName(sOUTabName);
-                                        rImport.UnlockSolarMutex();
                                     }
                                 }
                         }
@@ -313,13 +295,13 @@ sal_Bool ScMyTables::IsMerged (const uno::Reference <table::XCellRange>& xCellRa
                 aCellAddress = xMergeCellAddress->getRangeAddress();
                 if (aCellAddress.StartColumn == nCol && aCellAddress.EndColumn == nCol &&
                     aCellAddress.StartRow == nRow && aCellAddress.EndRow == nRow)
-                    return sal_False;
+                    return false;
                 else
                     return sal_True;
             }
         }
     }
-    return sal_False;
+    return false;
 }
 
 void ScMyTables::UnMerge()
@@ -333,7 +315,7 @@ void ScMyTables::UnMerge()
             uno::Reference <util::XMergeable> xMergeable (xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
                                                     aCellAddress.EndColumn, aCellAddress.EndRow), uno::UNO_QUERY);
             if (xMergeable.is())
-                xMergeable->merge(sal_False);
+                xMergeable->merge(false);
         }
     }
 }
@@ -349,22 +331,26 @@ void ScMyTables::DoMerge(sal_Int32 nCount)
             uno::Reference <util::XMergeable> xMergeable (xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
                                                     aCellAddress.EndColumn, aCellAddress.EndRow), uno::UNO_QUERY);
             if (xMergeable.is())
-                xMergeable->merge(sal_False);
+                xMergeable->merge(false);
         }
 
         //merge
         uno::Reference <table::XCellRange> xMergeCellRange;
         if (nCount == -1)
-            xMergeCellRange.set(xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
-                                                    aCellAddress.EndColumn
-                                                    + aTableVec[nTableCount - 1]->GetColsPerCol(aTableVec[nTableCount - 1]->GetColumn()) - 1,
-                                                    aCellAddress.EndRow
-                                                    + aTableVec[nTableCount - 1]->GetRowsPerRow(aTableVec[nTableCount - 1]->GetRow()) - 1));
+        {
+            xMergeCellRange.set(
+                xCurrentCellRange->getCellRangeByPosition(
+                    aCellAddress.StartColumn, aCellAddress.StartRow,
+                    aCellAddress.EndColumn + pLastTable->GetColsPerCol(pLastTable->GetColumn()) - 1,
+                    aCellAddress.EndRow + pLastTable->GetRowsPerRow(pLastTable->GetRow()) - 1));
+        }
         else
-            xMergeCellRange.set(xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
-                                                    aCellAddress.StartColumn
-                                                    + nCount - 1,
-                                                    aCellAddress.EndRow));
+            xMergeCellRange.set(
+                xCurrentCellRange->getCellRangeByPosition(
+                    aCellAddress.StartColumn, aCellAddress.StartRow,
+                    aCellAddress.StartColumn + nCount - 1,
+                    aCellAddress.EndRow));
+
         uno::Reference <util::XMergeable> xMergeable (xMergeCellRange, uno::UNO_QUERY);
         if (xMergeable.is())
             xMergeable->merge(sal_True);
@@ -377,7 +363,8 @@ void ScMyTables::InsertRow()
     {
         table::CellRangeAddress aCellAddress;
         sal_Int32 nRow(GetRealCellPos().Row);
-        for (sal_Int32 j = 0; j < GetRealCellPos().Column - aTableVec[nTableCount - 1]->GetColumn() - 1; ++j)
+
+        for (sal_Int32 j = 0; j < GetRealCellPos().Column - pLastTable->GetColumn() - 1; ++j)
         {
             if (IsMerged(xCurrentCellRange, j, nRow - 1, aCellAddress))
             {
@@ -385,7 +372,7 @@ void ScMyTables::InsertRow()
                 uno::Reference <util::XMergeable> xMergeable (xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
                                                         aCellAddress.EndColumn, aCellAddress.EndRow), uno::UNO_QUERY);
                 if (xMergeable.is())
-                    xMergeable->merge(sal_False);
+                    xMergeable->merge(false);
             }
 
             //merge
@@ -401,34 +388,40 @@ void ScMyTables::InsertRow()
 
 void ScMyTables::NewRow()
 {
-    if (nTableCount > 1)
-        if (aTableVec[nTableCount - 1]->GetRealRows(aTableVec[nTableCount - 1]->GetRow()) >
-            aTableVec[nTableCount - 2]->GetRowsPerRow(aTableVec[nTableCount - 2]->GetRow()) - 1)
+    size_t n = maTables.size();
+    if (n <= 1)
+        return;
+
+    if (pLastTable->GetRealRows(pLastTable->GetRow()) >
+        maTables[n-2].GetRowsPerRow(maTables[n-2].GetRow()) - 1)
+    {
+        if (GetRealCellPos().Column > 0)
+            InsertRow();
+
+        for (size_t i = n - 1; i > 0; --i)
         {
-            if (GetRealCellPos().Column > 0)
-                InsertRow();
-            for (sal_Int16 i = sal::static_int_cast<sal_Int16>(nTableCount - 1); i > 0; i--)
-            {
-                sal_Int32 nRow = aTableVec[i - 1]->GetRow();
-                aTableVec[i - 1]->SetRowsPerRow(nRow,
-                    aTableVec[i - 1]->GetRowsPerRow(nRow) + 1);
-                aTableVec[i - 1]->SetRealRows(nRow + 1,
-                    aTableVec[i - 1]->GetRealRows(nRow)
-                    + aTableVec[i - 1]->GetRowsPerRow(nRow));
-            }
+            sal_Int32 nRow = maTables[i-1].GetRow();
+            maTables[i-1].SetRowsPerRow(
+                nRow,
+                maTables[i-1].GetRowsPerRow(nRow) + 1);
+
+            maTables[i-1].SetRealRows(
+                nRow + 1,
+                maTables[i-1].GetRealRows(nRow) + maTables[i-1].GetRowsPerRow(nRow));
         }
+    }
 }
 
 void ScMyTables::AddRow()
 {
-    aTableVec[nTableCount - 1]->AddRow();
-    aTableVec[nTableCount - 1]->SetFirstColumn();
-    sal_Int32 nRow = aTableVec[nTableCount - 1]->GetRow();
+    pLastTable->AddRow();
+    pLastTable->SetFirstColumn();
+    sal_Int32 nRow = pLastTable->GetRow();
     if (nRow > 0)
         NewRow();
-    aTableVec[nTableCount - 1]->SetRealRows(nRow + 1,
-        aTableVec[nTableCount - 1]->GetRealRows(nRow)
-        + aTableVec[nTableCount - 1]->GetRowsPerRow(nRow));
+
+    pLastTable->SetRealRows(
+        nRow + 1, pLastTable->GetRealRows(nRow) + pLastTable->GetRowsPerRow(nRow));
 }
 
 void ScMyTables::SetRowStyle(const rtl::OUString& rCellStyleName)
@@ -442,7 +435,9 @@ void ScMyTables::InsertColumn()
     {
         table::CellRangeAddress aCellAddress;
         sal_Int32 nCol(GetRealCellPos().Column);
-        for (sal_Int32 j = 0; j <= GetRealCellPos().Row - aTableVec[nTableCount - 1]->GetRow() - 1; ++j)
+        sal_Int32 n = GetRealCellPos().Row - pLastTable->GetRow() - 1;
+
+        for (sal_Int32 j = 0; j <= n; ++j)
         {
             table::CellRangeAddress aTempCellAddress;
             if (IsMerged(xCurrentCellRange, nCol - 1, j, aCellAddress))
@@ -451,7 +446,7 @@ void ScMyTables::InsertColumn()
                 uno::Reference <util::XMergeable> xMergeable (xCurrentCellRange->getCellRangeByPosition(aCellAddress.StartColumn, aCellAddress.StartRow,
                                                         aCellAddress.EndColumn, aCellAddress.EndRow), uno::UNO_QUERY);
                 if (xMergeable.is())
-                    xMergeable->merge(sal_False);
+                    xMergeable->merge(false);
                 aTempCellAddress = aCellAddress;
                 aTempCellAddress.StartColumn = aTempCellAddress.EndColumn + 1;
                 aTempCellAddress.EndColumn = aTempCellAddress.StartColumn;
@@ -465,7 +460,7 @@ void ScMyTables::InsertColumn()
 
             //insert Cell
             sheet::CellInsertMode aCellInsertMode(sheet::CellInsertMode_RIGHT);
-            uno::Reference <sheet::XCellRangeMovement>	xCellRangeMovement (xCurrentSheet, uno::UNO_QUERY);
+            uno::Reference <sheet::XCellRangeMovement> xCellRangeMovement (xCurrentSheet, uno::UNO_QUERY);
             xCellRangeMovement->insertCells(aTempCellAddress, aCellInsertMode);
 
             //merge
@@ -481,49 +476,53 @@ void ScMyTables::InsertColumn()
 
 void ScMyTables::NewColumn(sal_Bool bIsCovered)
 {
-    if (!bIsCovered)
+    if (bIsCovered)
+        return;
+
+    sal_Int32 nColCount = pLastTable->GetColCount();
+    sal_Int32 nSpannedCols = pLastTable->GetSpannedCols();
+
+
+    if ( (nSpannedCols > nColCount) &&
+        (pLastTable->GetRow() == 0) &&
+        (pLastTable->GetColumn() == 0) )
+
     {
-        sal_Int32 nColCount(aTableVec[nTableCount - 1]->GetColCount());
-        sal_Int32 nSpannedCols(aTableVec[nTableCount - 1]->GetSpannedCols());
-        if ( (nSpannedCols > nColCount) &&
-            (aTableVec[nTableCount - 1]->GetRow() == 0) &&
-            (aTableVec[nTableCount - 1]->GetColumn() == 0) )
+        if (nColCount > 0)
         {
-            if (nColCount > 0)
+            sal_Int32 FirstColsSpanned(nSpannedCols / nColCount);
+            sal_Int32 LastColSpanned(FirstColsSpanned
+                + (nSpannedCols % nColCount));
+            for (sal_Int32 i = 0; i < nColCount - 1; ++i)
             {
-                sal_Int32 FirstColsSpanned(nSpannedCols / nColCount);
-                sal_Int32 LastColSpanned(FirstColsSpanned
-                    + (nSpannedCols	% nColCount));
-                for (sal_Int32 i = 0; i < nColCount - 1; ++i)
-                {
-                    aTableVec[nTableCount - 1]->SetColsPerCol(i, FirstColsSpanned);
-                    aTableVec[nTableCount - 1]->SetRealCols(i + 1,
-                        aTableVec[nTableCount - 1]->GetRealCols(i)
-                        + FirstColsSpanned);
-                }
-                aTableVec[nTableCount - 1]->SetColsPerCol(nColCount - 1, LastColSpanned);
-                aTableVec[nTableCount - 1]->SetRealCols(nColCount - 1 + 1,
-                    aTableVec[nTableCount - 1]->GetRealCols(nColCount - 1)
-                    + LastColSpanned);
+                pLastTable->SetColsPerCol(i, FirstColsSpanned);
+                pLastTable->SetRealCols(i + 1, pLastTable->GetRealCols(i) + FirstColsSpanned);
             }
+            pLastTable->SetColsPerCol(nColCount - 1, LastColSpanned);
+            pLastTable->SetRealCols(
+                nColCount, pLastTable->GetRealCols(nColCount - 1) + LastColSpanned);
         }
-        if (aTableVec[nTableCount - 1]->GetRealCols(aTableVec[nTableCount - 1]->GetColumn()) > nSpannedCols - 1)
+    }
+    if (pLastTable->GetRealCols(pLastTable->GetColumn()) > nSpannedCols - 1)
+    {
+        if (pLastTable->GetRow() == 0)
         {
-            if ( aTableVec[nTableCount - 1]->GetRow() == 0)
+            InsertColumn();
+            size_t n = maTables.size();
+            for (size_t i = n - 1; i > 0; --i)
             {
-                InsertColumn();
-                for (sal_Int16 i = sal::static_int_cast<sal_Int16>(nTableCount - 1); i > 0; i--)
-                {
-                    sal_Int32 nColPos = aTableVec[i - 1]->GetColumn() +
-                        aTableVec[i]->GetSpannedCols() - 1;
-                    aTableVec[i - 1]->SetColsPerCol(nColPos,
-                        aTableVec[i - 1]->GetColsPerCol(nColPos) +
-                        aTableVec[nTableCount - 1]->GetColsPerCol(aTableVec[nTableCount - 1]->GetColumn()));
-                    aTableVec[i - 1]->SetRealCols(nColPos + 1,
-                        aTableVec[i - 1]->GetRealCols(nColPos)
-                        + aTableVec[i - 1]->GetColsPerCol(nColPos));
-                    aTableVec[i - 1]->SetChangedCols(nColPos);
-                }
+                sal_Int32 nColPos =
+                    maTables[i-1].GetColumn() + maTables[i].GetSpannedCols() - 1;
+
+                maTables[i-1].SetColsPerCol(nColPos,
+                    maTables[i-1].GetColsPerCol(nColPos) +
+                    pLastTable->GetColsPerCol(pLastTable->GetColumn()));
+
+                maTables[i-1].SetRealCols(
+                    nColPos + 1,
+                    maTables[i-1].GetRealCols(nColPos) + maTables[i-1].GetColsPerCol(nColPos));
+
+                maTables[i-1].SetChangedCols(nColPos);
             }
         }
     }
@@ -531,21 +530,20 @@ void ScMyTables::NewColumn(sal_Bool bIsCovered)
 
 void ScMyTables::AddColumn(sal_Bool bIsCovered)
 {
-    aTableVec[nTableCount - 1]->AddColumn();
-    if (aTableVec[nTableCount - 1]->GetSubTableSpanned() > 1)
-        aTableVec[nTableCount - 1]->SetSubTableSpanned(aTableVec[nTableCount - 1]->GetSubTableSpanned() - 1);
+    pLastTable->AddColumn();
+    if (pLastTable->GetSubTableSpanned() > 1)
+        pLastTable->SetSubTableSpanned(pLastTable->GetSubTableSpanned() - 1);
     else
     {
         NewColumn(bIsCovered);
-    //	if (!bIsCovered)
-            aTableVec[nTableCount - 1]->SetRealCols(aTableVec[nTableCount - 1]->GetColumn() + 1,
-                aTableVec[nTableCount - 1]->GetRealCols(aTableVec[nTableCount - 1]->GetColumn())
-                + aTableVec[nTableCount - 1]->GetColsPerCol(aTableVec[nTableCount - 1]->GetColumn()));
-        if ((!bIsCovered) || (bIsCovered &&
-            (aTableVec[nTableCount - 1]->GetColsPerCol(aTableVec[nTableCount - 1]->GetColumn()) > 1)))
+        sal_Int32 nCol = pLastTable->GetColumn();
+        sal_Int32 nRow = pLastTable->GetRow();
+        pLastTable->SetRealCols(
+            nCol + 1, pLastTable->GetRealCols(nCol) + pLastTable->GetColsPerCol(nCol));
+
+        if ((!bIsCovered) || (bIsCovered && (pLastTable->GetColsPerCol(nCol) > 1)))
         {
-            if ((aTableVec[nTableCount - 1]->GetRowsPerRow(aTableVec[nTableCount - 1]->GetRow()) > 1) ||
-                (aTableVec[nTableCount - 1]->GetColsPerCol(aTableVec[nTableCount - 1]->GetColumn()) > 1))
+            if ((pLastTable->GetRowsPerRow(nRow) > 1) || (pLastTable->GetColsPerCol(nCol) > 1))
                 DoMerge();
         }
     }
@@ -553,38 +551,41 @@ void ScMyTables::AddColumn(sal_Bool bIsCovered)
 
 void ScMyTables::NewTable(sal_Int32 nTempSpannedCols)
 {
-    ++nTableCount;
-    if (static_cast<sal_uInt32>(nTableCount) >= aTableVec.size())
-        aTableVec.resize(aTableVec.size() + nDefaultTabCount);
-    ScMyTableData* aTable(new ScMyTableData(nCurrentSheet));
-    if (nTableCount > 1)
+    maTables.push_back(new ScMyTableData(nCurrentSheet));
+    pLastTable = &maTables.back();
+
+    if (maTables.size() > 1)
     {
-        ScMyTableData* pTableData = aTableVec[nTableCount - 2];
-        const sal_Int32 nCol(pTableData->GetColumn());
-        const sal_Int32 nColCount(pTableData->GetColCount());
-        const sal_Int32 nColsPerCol(pTableData->GetColsPerCol(nCol));
-        sal_Int32 nSpannedCols(pTableData->GetSpannedCols());
-        sal_Int32 nTemp(nSpannedCols - nColCount);
-        sal_Int32 nTemp2(nCol - (nColCount - 1));
+        ScMyTableData& rFirstTab = maTables.front();
+
+        const sal_Int32 nCol = rFirstTab.GetColumn();
+        const sal_Int32 nColCount = rFirstTab.GetColCount();
+        const sal_Int32 nColsPerCol = rFirstTab.GetColsPerCol(nCol);
+
+        sal_Int32 nSpannedCols = rFirstTab.GetSpannedCols();
+        sal_Int32 nTemp = nSpannedCols - nColCount;
+        sal_Int32 nTemp2 = nCol - nColCount + 1;
         if ((nTemp > 0) && (nTemp2 == 0))
-            nTempSpannedCols *= (nTemp + 1);
+            nTempSpannedCols *= nTemp + 1;
         else
             if (nColsPerCol > 1)
                 nTempSpannedCols *= nColsPerCol;
 
         sal_Int32 nToMerge;
         if (nSpannedCols > nColCount)
-            nToMerge = pTableData->GetChangedCols(nCol, nCol + nColsPerCol + nSpannedCols - nColCount);
+            nToMerge = rFirstTab.GetChangedCols(nCol, nCol + nColsPerCol + nSpannedCols - nColCount);
         else
-            nToMerge = pTableData->GetChangedCols(nCol, nCol + nColsPerCol);
+            nToMerge = rFirstTab.GetChangedCols(nCol, nCol + nColsPerCol);
         if (nToMerge > nCol)
             nTempSpannedCols += nToMerge;
     }
-    aTable->SetSpannedCols(nTempSpannedCols);
-    aTableVec[nTableCount - 1] = aTable;
-    if (nTableCount > 1)
+
+    pLastTable->SetSpannedCols(nTempSpannedCols);
+
+    size_t n = maTables.size();
+    if (n > 1)
     {
-        aTableVec[nTableCount - 2]->SetSubTableSpanned(aTable->GetSpannedCols());
+        maTables[n-2].SetSubTableSpanned(pLastTable->GetSpannedCols());
         UnMerge();
     }
 }
@@ -593,7 +594,8 @@ void ScMyTables::UpdateRowHeights()
 {
     if (rImport.GetModel().is())
     {
-        rImport.LockSolarMutex();
+        ScXMLImport::MutexGuard aGuard(rImport);
+
         // update automatic row heights
 
         // For sheets with any kind of shapes (including notes),
@@ -615,9 +617,9 @@ void ScMyTables::UpdateRowHeights()
             {
                 const SdrPage* pPage = pDrawLayer ? pDrawLayer->GetPage(nTab) : NULL;
                 if ( nTab == nVisible || ( pPage && pPage->GetObjCount() != 0 ) )
-                    aUpdateSheets.SelectTable( nTab, TRUE );
+                    aUpdateSheets.SelectTable( nTab, sal_True );
                 else
-                    pDoc->SetPendingRowHeights( nTab, TRUE );
+                    pDoc->SetPendingRowHeights( nTab, sal_True );
             }
 
             if (aUpdateSheets.GetSelectCount())
@@ -627,24 +629,24 @@ void ScMyTables::UpdateRowHeights()
                 pDoc->LockStreamValid( false );
             }
         }
-
-        rImport.UnlockSolarMutex();
     }
 }
 
 void ScMyTables::DeleteTable()
 {
-    rImport.LockSolarMutex();
+    ScXMLImport::MutexGuard aGuard(rImport);
 
     nCurrentColStylePos = 0;
-    if (nTableCount > 0)
+    if (!maTables.empty())
     {
-        ScMyTableData* aTable = aTableVec[nTableCount - 1];
-        delete aTable;
-        aTableVec[nTableCount - 1] = NULL;
-        nTableCount--;
+          maTables.pop_back();
+          if (maTables.empty())
+               pLastTable = NULL;
+          else
+               pLastTable = &maTables.back();
     }
-    if (nTableCount == 0) // only set the styles if all subtables are importet and the table is finished
+
+    if (maTables.empty()) // only set the styles if all subtables are importet and the table is finished
     {
         rImport.GetStylesImportHelper()->SetStylesToRanges();
         rImport.SetStylesToRangesFinished();
@@ -676,8 +678,6 @@ void ScMyTables::DeleteTable()
         rImport.GetDocument()->SetTabProtection(static_cast<SCTAB>(nCurrentSheet), pProtect.get());
     }
 
-    rImport.UnlockSolarMutex();
-
     //#95582#; find out whether it was possible to set the sheet name
     // test it here, because if it is a linked table the name is changed by importing
     // the linking informations
@@ -688,30 +688,23 @@ void ScMyTables::DeleteTable()
         if (sCurrentName != sCurrentSheetName && rImport.GetDocument())
         {
             rImport.GetDocument()->RenameTab( static_cast<SCTAB>(nCurrentSheet),
-                sCurrentSheetName, sal_False, sal_True);
-
-/*			rtl::OUString sErrorMessage(RTL_CONSTASCII_USTRINGPARAM("Could not create a table with the name "));
-            sErrorMessage += sCurrentSheetName;
-            sErrorMessage += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(". The new name is "));
-            sErrorMessage += sCurrentName;
-            uno::Sequence<rtl::OUString> aSeq(1);
-            aSeq[0] = sErrorMessage;
-            uno::Reference<xml::sax::XLocator> xLocator;
-            rImport.SetError(XMLERROR_API | XMLERROR_FLAG_ERROR, aSeq, rtl::OUString(), xLocator);*/
+                sCurrentSheetName, false, sal_True);
         }
     }
 }
 
 table::CellAddress ScMyTables::GetRealCellPos()
 {
-    sal_Int32 nRow(0);
-    sal_Int32 nCol(0);
-    for (sal_Int32 i = 0; i < nTableCount; ++i)
+    sal_Int32 nRow = 0;
+    sal_Int32 nCol = 0;
+    size_t n = maTables.size();
+    for (size_t i = 0; i < n; ++i)
     {
-        ScMyTableData* pTableData = aTableVec[i];
-        nCol += pTableData->GetRealCols(pTableData->GetColumn());
-        nRow += pTableData->GetRealRows(pTableData->GetRow());
+        const ScMyTableData& rTab = maTables[i];
+        nCol += rTab.GetRealCols(rTab.GetColumn());
+        nRow += rTab.GetRealRows(rTab.GetRow());
     }
+
     aRealCellPos.Row = nRow;
     aRealCellPos.Column = nCol;
     aRealCellPos.Sheet = sal::static_int_cast<sal_Int16>(nCurrentSheet);
@@ -720,12 +713,12 @@ table::CellAddress ScMyTables::GetRealCellPos()
 
 void ScMyTables::AddColCount(sal_Int32 nTempColCount)
 {
-    aTableVec[nTableCount - 1]->SetColCount(aTableVec[nTableCount - 1]->GetColCount() + nTempColCount);
+    pLastTable->SetColCount(pLastTable->GetColCount() + nTempColCount);
 }
 
 void ScMyTables::AddColStyle(const sal_Int32 nRepeat, const rtl::OUString& rCellStyleName)
 {
-    DBG_ASSERT(nTableCount == 1, "not possible to use default styles on columns in subtables");
+    DBG_ASSERT(maTables.size() == 1, "not possible to use default styles on columns in subtables");
     rImport.GetStylesImportHelper()->AddColumnStyle(rCellStyleName, nCurrentColStylePos, nRepeat);
     nCurrentColStylePos += nRepeat;
 }
@@ -766,12 +759,10 @@ sal_Bool ScMyTables::HasXShapes()
     return !((nCurrentSheet != nCurrentXShapes) || !xShapes.is());
 }
 
-void ScMyTables::AddShape(uno::Reference <drawing::XShape>& rShape,
-    rtl::OUString* pRangeList,
-    table::CellAddress& rStartAddress, table::CellAddress& rEndAddress,
-    sal_Int32 nEndX, sal_Int32 nEndY)
+void ScMyTables::AddOLE(uno::Reference <drawing::XShape>& rShape,
+      const rtl::OUString &rRangeList)
 {
-    aResizeShapes.AddShape(rShape, pRangeList, rStartAddress, rEndAddress, nEndX, nEndY);
+      aFixupOLEs.AddOLE(rShape, rRangeList);
 }
 
 void ScMyTables::AddMatrixRange(
@@ -792,17 +783,17 @@ void ScMyTables::AddMatrixRange(
 
 sal_Bool ScMyTables::IsPartOfMatrix(sal_Int32 nColumn, sal_Int32 nRow)
 {
-    sal_Bool bResult(sal_False);
+    sal_Bool bResult(false);
     if (!aMatrixRangeList.empty())
     {
         ScMyMatrixRangeList::iterator aItr(aMatrixRangeList.begin());
         ScMyMatrixRangeList::iterator aEndItr(aMatrixRangeList.end());
-        sal_Bool bReady(sal_False);
+        sal_Bool bReady(false);
         while(!bReady && aItr != aEndItr)
         {
             if (nCurrentSheet > aItr->aRange.Sheet)
             {
-                DBG_ERROR("should never hapen, because the list should be cleared in DeleteTable");
+                OSL_FAIL("should never hapen, because the list should be cleared in DeleteTable");
                 aItr = aMatrixRangeList.erase(aItr);
             }
             else if ((nRow > aItr->aRange.EndRow) && (nColumn > aItr->aRange.EndColumn))
