@@ -29,14 +29,8 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sc.hxx"
 
-
-
-// INCLUDE ---------------------------------------------------------------
-
 #include "scitems.hxx"
 #include <editeng/eeitem.hxx>
-
-
 #include <vcl/timer.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/app.hxx>
@@ -79,8 +73,8 @@ void ScTabView::PaintMarks(SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCRO
     if (!ValidCol(nEndCol)) nEndCol = MAXCOL;
     if (!ValidRow(nEndRow)) nEndRow = MAXROW;
 
-    BOOL bLeft = (nStartCol==0 && nEndCol==MAXCOL);
-    BOOL bTop = (nStartRow==0 && nEndRow==MAXROW);
+    sal_Bool bLeft = (nStartCol==0 && nEndCol==MAXCOL);
+    sal_Bool bTop = (nStartRow==0 && nEndRow==MAXROW);
 
     if (bLeft)
         PaintLeftArea( nStartRow, nEndRow );
@@ -92,7 +86,7 @@ void ScTabView::PaintMarks(SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCRO
     PaintArea( nStartCol, nStartRow, nEndCol, nEndRow, SC_UPDATE_MARKS );
 }
 
-BOOL ScTabView::IsMarking( SCCOL nCol, SCROW nRow, SCTAB nTab ) const
+sal_Bool ScTabView::IsMarking( SCCOL nCol, SCROW nRow, SCTAB nTab ) const
 {
     return bIsBlockMode
         && nBlockStartX == nCol
@@ -108,9 +102,8 @@ void ScTabView::InitOwnBlockMode()
 
         ScMarkData& rMark = aViewData.GetMarkData();
         if (!rMark.IsMarked() && !rMark.IsMultiMarked())
-            GetSelEngine()->CursorPosChanging( FALSE, FALSE );
+            GetSelEngine()->CursorPosChanging( false, false );
 
-//		bIsBlockMode = TRUE;
         bIsBlockMode = SC_BLOCKMODE_OWN;			//! Variable umbenennen!
         nBlockStartX = 0;
         nBlockStartY = 0;
@@ -124,7 +117,7 @@ void ScTabView::InitOwnBlockMode()
 }
 
 void ScTabView::InitBlockMode( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
-                                BOOL bTestNeg, BOOL bCols, BOOL bRows )
+                                sal_Bool bTestNeg, sal_Bool bCols, sal_Bool bRows )
 {
     if (!bIsBlockMode)
     {
@@ -145,10 +138,9 @@ void ScTabView::InitBlockMode( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
                 bBlockNeg = rMark.IsCellMarked( nCurX, nCurY );
         }
         else
-            bBlockNeg = FALSE;
+            bBlockNeg = false;
         rMark.SetMarkNegative(bBlockNeg);
 
-//		bIsBlockMode = TRUE;
         bIsBlockMode = SC_BLOCKMODE_NORMAL;			//! Variable umbenennen!
         bBlockCols = bCols;
         bBlockRows = bRows;
@@ -173,14 +165,11 @@ void ScTabView::InitBlockMode( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
 
         rMark.SetMarkArea( ScRange( nBlockStartX,nBlockStartY, nTab, nBlockEndX,nBlockEndY, nTab ) );
 
-#ifdef OLD_SELECTION_PAINT
-        InvertBlockMark( nBlockStartX,nBlockStartY,nBlockEndX,nBlockEndY );
-#endif
         UpdateSelectionOverlay();
     }
 }
 
-void ScTabView::DoneBlockMode( BOOL bContinue )            // Default FALSE
+void ScTabView::DoneBlockMode( sal_Bool bContinue )            // Default FALSE
 {
     //	Wenn zwischen Tabellen- und Header SelectionEngine gewechselt wird,
     //	wird evtl. DeselectAll gerufen, weil die andere Engine keinen Anker hat.
@@ -189,8 +178,8 @@ void ScTabView::DoneBlockMode( BOOL bContinue )            // Default FALSE
     if (bIsBlockMode && !bMoveIsShift)
     {
         ScMarkData& rMark = aViewData.GetMarkData();
-        BOOL bFlag = rMark.GetMarkingFlag();
-        rMark.SetMarking(FALSE);
+        sal_Bool bFlag = rMark.GetMarkingFlag();
+        rMark.SetMarking(false);
 
         if (bBlockNeg && !bContinue)
             rMark.MarkToMulti();
@@ -206,28 +195,27 @@ void ScTabView::DoneBlockMode( BOOL bContinue )            // Default FALSE
             SCTAB nTab = aViewData.GetTabNo();
             ScDocument* pDoc = aViewData.GetDocument();
             if ( pDoc->HasTable(nTab) )
-                PaintBlock( TRUE );								// TRUE -> Block loeschen
+                PaintBlock( sal_True );								// sal_True -> Block loeschen
             else
                 rMark.ResetMark();
         }
-//		bIsBlockMode = FALSE;
         bIsBlockMode = SC_BLOCKMODE_NONE;			//! Variable umbenennen!
 
         rMark.SetMarking(bFlag);
-        rMark.SetMarkNegative(FALSE);
+        rMark.SetMarkNegative(false);
     }
 }
 
 void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
-                            BOOL bCols, BOOL bRows, BOOL bCellSelection )
+                            sal_Bool bCols, sal_Bool bRows, sal_Bool bCellSelection )
 {
     if (!ValidCol(nCurX)) nCurX = MAXCOL;
     if (!ValidRow(nCurY)) nCurY = MAXROW;
 
     if (!bIsBlockMode)
     {
-        DBG_ERROR( "MarkCursor nicht im BlockMode" );
-        InitBlockMode( nCurX, nCurY, nCurZ, FALSE, bCols, bRows );
+        OSL_FAIL( "MarkCursor nicht im BlockMode" );
+        InitBlockMode( nCurX, nCurY, nCurZ, false, bCols, bRows );
     }
 
     if (bCols)
@@ -247,9 +235,9 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
         //	(z.B. MarkToSimple, wenn per negativ alles bis auf ein Rechteck geloescht wurde)
         //	oder nach InitOwnBlockMode wird mit Shift-Klick weitermarkiert...
 
-        BOOL bOldShift = bMoveIsShift;
-        bMoveIsShift = FALSE;				//	wirklich umsetzen
-        DoneBlockMode(FALSE);				//!	direkt Variablen setzen? (-> kein Geflacker)
+        sal_Bool bOldShift = bMoveIsShift;
+        bMoveIsShift = false;				//	wirklich umsetzen
+        DoneBlockMode(false);				//!	direkt Variablen setzen? (-> kein Geflacker)
         bMoveIsShift = bOldShift;
 
         InitBlockMode( aMarkRange.aStart.Col(), aMarkRange.aStart.Row(),
@@ -265,13 +253,6 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
 
         SCTAB		nTab = nCurZ;
 
-#ifdef OLD_SELECTION_PAINT
-        SCCOL		nDrawStartCol;
-        SCROW		nDrawStartRow;
-        SCCOL		nDrawEndCol;
-        SCROW		nDrawEndRow;
-#endif
-
         // Set old selection area
         ScUpdateRect aRect( nBlockStartX, nBlockStartY, nOldBlockEndX, nOldBlockEndY );
 
@@ -283,7 +264,7 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
             SCsCOL nBlockStartXOffset = 0;
             SCsROW nCurYOffset = 0;
             SCsROW nBlockStartYOffset = 0;
-            BOOL bBlockStartMerged = FALSE;
+            sal_Bool bBlockStartMerged = false;
             const ScMergeAttr* pMergeAttr = NULL;
             ScDocument* pDocument = aViewData.GetDocument();
 
@@ -309,7 +290,7 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
                         nBlockStartXOrig - nCurX + nColSpan - 1 : 0;
                     nCurYOffset  = nCurY >= nBlockStartYOrig && nCurY < nBlockStartYOrig + nRowSpan - 1 ?
                         nBlockStartYOrig - nCurY + nRowSpan - 1 : 0;
-                    bBlockStartMerged = TRUE;
+                    bBlockStartMerged = sal_True;
                 }
             }
 
@@ -374,25 +355,6 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
         aRect.SetNew( nBlockStartX, nBlockStartY, nBlockEndX, nBlockEndY );
         rMark.SetMarkArea( ScRange( nBlockStartX, nBlockStartY, nTab, nBlockEndX, nBlockEndY, nTab ) );
 
-#ifdef OLD_SELECTION_PAINT
-        BOOL bCont;
-        BOOL bDraw = aRect.GetXorDiff( nDrawStartCol, nDrawStartRow,
-                                        nDrawEndCol, nDrawEndRow, bCont );
-        if ( bDraw )
-        {
-//?			PutInOrder( nDrawStartCol, nDrawEndCol );
-//?			PutInOrder( nDrawStartRow, nDrawEndRow );
-
-            HideAllCursors();
-            InvertBlockMark( nDrawStartCol, nDrawStartRow, nDrawEndCol, nDrawEndRow );
-            if (bCont)
-            {
-                aRect.GetContDiff( nDrawStartCol, nDrawStartRow, nDrawEndCol, nDrawEndRow );
-                InvertBlockMark( nDrawStartCol, nDrawStartRow, nDrawEndCol, nDrawEndRow );
-            }
-            ShowAllCursors();
-        }
-#endif
         UpdateSelectionOverlay();
         SelectionChanged();
 
@@ -400,18 +362,33 @@ void ScTabView::MarkCursor( SCCOL nCurX, SCROW nCurY, SCTAB nCurZ,
         nOldCurY = nCurY;
 
         aViewData.GetViewShell()->UpdateInputHandler();
-//		InvalidateAttribs();
     }
 
     if ( !bCols && !bRows )
-        aHdrFunc.SetAnchorFlag( FALSE );
+        aHdrFunc.SetAnchorFlag( false );
 }
 
 void ScTabView::GetPageMoveEndPosition(SCsCOL nMovX, SCsROW nMovY, SCsCOL& rPageX, SCsROW& rPageY)
 {
     SCCOL nCurX;
     SCROW nCurY;
-    aViewData.GetMoveCursor( nCurX,nCurY );
+    if (aViewData.IsRefMode())
+    {
+        nCurX = aViewData.GetRefEndX();
+        nCurY = aViewData.GetRefEndY();
+    }
+    else if (IsBlockMode())
+    {
+        // block end position.
+        nCurX = nBlockEndX;
+        nCurY = nBlockEndY;
+    }
+    else
+    {
+        // cursor position
+        nCurX = aViewData.GetCurX();
+        nCurY = aViewData.GetCurY();
+    }
 
     ScSplitPos eWhich = aViewData.GetActivePart();
     ScHSplitPos eWhichX = WhichH( eWhich );
@@ -452,6 +429,7 @@ void ScTabView::GetAreaMoveEndPosition(SCsCOL nMovX, SCsROW nMovY, ScFollowMode
     }
     else if (IsBlockMode())
     {
+        // block end position.
         nNewX = nBlockEndX;
         nNewY = nBlockEndY;
     }
@@ -469,16 +447,16 @@ void ScTabView::GetAreaMoveEndPosition(SCsCOL nMovX, SCsROW nMovY, ScFollowMode
     SCsCOLROW i;
     if ( nMovX > 0 )
         for ( i=0; i<nMovX; i++ )
-            pDoc->FindAreaPos( nNewX, nNewY, nTab,  1,  0 );
+            pDoc->FindAreaPos( nNewX, nCurY, nTab,  1,  0 );
     if ( nMovX < 0 )
         for ( i=0; i<-nMovX; i++ )
-            pDoc->FindAreaPos( nNewX, nNewY, nTab, -1,  0 );
+            pDoc->FindAreaPos( nNewX, nCurY, nTab, -1,  0 );
     if ( nMovY > 0 )
         for ( i=0; i<nMovY; i++ )
-            pDoc->FindAreaPos( nNewX, nNewY, nTab,  0,  1 );
+            pDoc->FindAreaPos( nCurX, nNewY, nTab,  0,  1 );
     if ( nMovY < 0 )
         for ( i=0; i<-nMovY; i++ )
-            pDoc->FindAreaPos( nNewX, nNewY, nTab,  0, -1 );
+            pDoc->FindAreaPos( nCurX, nNewY, nTab,  0, -1 );
 
     if (eMode==SC_FOLLOW_JUMP)                  // unten/rechts nicht zuviel grau anzeigen
     {
@@ -523,8 +501,7 @@ void ScTabView::SkipCursorHorizontal(SCsCOL& rCurX, SCsROW& rCurY, SCsCOL nOldX,
     bool bHFlip = false;
     do
     {
-        SCCOL nLastCol = -1;
-        bSkipCell = pDoc->ColHidden(rCurX, nTab, nLastCol) || pDoc->IsHorOverlapped(rCurX, rCurY, nTab);
+        bSkipCell = pDoc->ColHidden(rCurX, nTab) || pDoc->IsHorOverlapped(rCurX, rCurY, nTab);
         if (bSkipProtected && !bSkipCell)
             bSkipCell = pDoc->HasAttrib(rCurX, rCurY, nTab, rCurX, rCurY, nTab, HASATTR_PROTECTED);
         if (bSkipUnprotected && !bSkipCell)
@@ -584,7 +561,7 @@ void ScTabView::SkipCursorVertical(SCsCOL& rCurX, SCsROW& rCurY, SCsROW nOldY, S
     do
     {
         SCROW nLastRow = -1;
-        bSkipCell = pDoc->RowHidden(rCurY, nTab, nLastRow) || pDoc->IsVerOverlapped( rCurX, rCurY, nTab );
+        bSkipCell = pDoc->RowHidden(rCurY, nTab, NULL, &nLastRow) || pDoc->IsVerOverlapped( rCurX, rCurY, nTab );
         if (bSkipProtected && !bSkipCell)
             bSkipCell = pDoc->HasAttrib(rCurX, rCurY, nTab, rCurX, rCurY, nTab, HASATTR_PROTECTED);
         if (bSkipUnprotected && !bSkipCell)
@@ -656,53 +633,185 @@ void moveCursorByProtRule(
 
     if (nMovX > 0)
     {
-        if (rCol < MAXCOL)
+        for (SCCOL i = 0; i < nMovX && rCol < MAXCOL; ++i)
         {
-            for (SCCOL i = 0; i < nMovX; ++i)
-            {
-                if (!isCellQualified(pDoc, rCol+1, rRow, nTab, bSelectLocked, bSelectUnlocked))
-                    break;
-                ++rCol;
-            }
+            if (!isCellQualified(pDoc, rCol+1, rRow, nTab, bSelectLocked, bSelectUnlocked))
+                break;
+            ++rCol;
         }
     }
     else if (nMovX < 0)
     {
-        if (rCol > 0)
+        for (SCCOL i = 0; i > nMovX && rCol > 0; --i)
         {
-            nMovX = -nMovX;
-            for (SCCOL i = 0; i < nMovX; ++i)
-            {
-                if (!isCellQualified(pDoc, rCol-1, rRow, nTab, bSelectLocked, bSelectUnlocked))
-                    break;
-                --rCol;
-            }
+            if (!isCellQualified(pDoc, rCol-1, rRow, nTab, bSelectLocked, bSelectUnlocked))
+                break;
+            --rCol;
         }
     }
 
     if (nMovY > 0)
     {
-        if (rRow < MAXROW)
+        for (SCROW i = 0; i < nMovY && rRow < MAXROW; ++i)
         {
-            for (SCROW i = 0; i < nMovY; ++i)
-            {
-                if (!isCellQualified(pDoc, rCol, rRow+1, nTab, bSelectLocked, bSelectUnlocked))
-                    break;
-                ++rRow;
-            }
+            if (!isCellQualified(pDoc, rCol, rRow+1, nTab, bSelectLocked, bSelectUnlocked))
+                break;
+            ++rRow;
         }
     }
     else if (nMovY < 0)
     {
-        if (rRow > 0)
+        for (SCROW i = 0; i > nMovY && rRow > 0; --i)
         {
-            nMovY = -nMovY;
-            for (SCROW i = 0; i < nMovY; ++i)
-            {
-                if (!isCellQualified(pDoc, rCol, rRow-1, nTab, bSelectLocked, bSelectUnlocked))
-                    break;
+            if (!isCellQualified(pDoc, rCol, rRow-1, nTab, bSelectLocked, bSelectUnlocked))
+                break;
+            --rRow;
+        }
+    }
+}
+
+bool checkBoundary(SCCOL& rCol, SCROW& rRow)
+{
+    bool bGood = true;
+    if (rCol < 0)
+    {
+        rCol = 0;
+        bGood = false;
+    }
+    else if (rCol > MAXCOL)
+    {
+        rCol = MAXCOL;
+        bGood = false;
+    }
+
+    if (rRow < 0)
+    {
+        rRow = 0;
+        bGood = false;
+    }
+    else if (rRow > MAXROW)
+    {
+        rRow = MAXROW;
+        bGood = false;
+    }
+    return bGood;
+}
+
+void moveCursorByMergedCell(
+    SCCOL& rCol, SCROW& rRow, SCsCOL nMovX, SCsROW nMovY, SCTAB nTab,
+    ScDocument* pDoc, const ScViewData& rViewData)
+{
+    SCCOL nOrigX = rViewData.GetCurX();
+    SCROW nOrigY = rViewData.GetCurY();
+
+    ScTableProtection* pTabProtection = pDoc->GetTabProtection(nTab);
+    bool bSelectLocked = true;
+    bool bSelectUnlocked = true;
+    if (pTabProtection && pTabProtection->isProtected())
+    {
+        bSelectLocked   = pTabProtection->isOptionEnabled(ScTableProtection::SELECT_LOCKED_CELLS);
+        bSelectUnlocked = pTabProtection->isOptionEnabled(ScTableProtection::SELECT_UNLOCKED_CELLS);
+    }
+
+    const ScMergeAttr* pMergeAttr = static_cast<const ScMergeAttr*>(
+        pDoc->GetAttr(nOrigX, nOrigY, nTab, ATTR_MERGE));
+
+    bool bOriginMerged = false;
+    SCsCOL nColSpan = 1;
+    SCsROW nRowSpan = 1;
+    if (pMergeAttr && pMergeAttr->IsMerged())
+    {
+        nColSpan = pMergeAttr->GetColMerge();
+        nRowSpan = pMergeAttr->GetRowMerge();
+        bOriginMerged = true;
+    }
+
+    if (nMovX > 0)
+    {
+        SCCOL nOld = rCol;
+        if (bOriginMerged)
+        {
+            // Original cell is merged.  Push the block end outside the merged region.
+            if (nOrigX < MAXCOL && nOrigX < rCol && rCol <= nOrigX + nColSpan - 1)
+                rCol = nOrigX + nColSpan;
+        }
+        else
+        {
+            pDoc->SkipOverlapped(rCol, rRow, nTab);
+        }
+
+        if (nOld < rCol)
+        {
+            // The block end has moved.  Check the protection setting and move back if needed.
+            checkBoundary(rCol, rRow);
+            if (!isCellQualified(pDoc, rCol, rRow, nTab, bSelectLocked, bSelectUnlocked))
+                --rCol;
+        }
+    }
+    if (nMovX < 0)
+    {
+        SCCOL nOld = rCol;
+        if (bOriginMerged)
+        {
+            if (nOrigX > 0 && nOrigX <= rCol && rCol < nOrigX + nColSpan - 1)
+                // Block end is still within the merged region.  Push it outside.
+                rCol = nOrigX - 1;
+        }
+        else
+        {
+            pDoc->SkipOverlapped(rCol, rRow, nTab);
+        }
+
+        if (nOld > rCol)
+        {
+            // The block end has moved.  Check the protection setting and move back if needed.
+            checkBoundary(rCol, rRow);
+            if (!isCellQualified(pDoc, rCol, rRow, nTab, bSelectLocked, bSelectUnlocked))
+                ++rCol;
+        }
+    }
+    if (nMovY > 0)
+    {
+        SCROW nOld = rRow;
+        if (bOriginMerged)
+        {
+            // Original cell is merged.  Push the block end outside the merged region.
+            if (nOrigY < MAXROW && nOrigY < rRow && rRow <= nOrigY + nRowSpan - 1)
+                rRow = nOrigY + nRowSpan;
+        }
+        else
+        {
+            pDoc->SkipOverlapped(rCol, rRow, nTab);
+        }
+
+        if (nOld < rRow)
+        {
+            // The block end has moved.  Check the protection setting and move back if needed.
+            checkBoundary(rCol, rRow);
+            if (!isCellQualified(pDoc, rCol, rRow, nTab, bSelectLocked, bSelectUnlocked))
                 --rRow;
-            }
+        }
+    }
+    if (nMovY < 0)
+    {
+        SCROW nOld = rRow;
+        if (bOriginMerged)
+        {
+            if (nOrigY > 0 && nOrigY <= rRow && rRow < nOrigY + nRowSpan - 1)
+                // Block end is still within the merged region.  Push it outside.
+                rRow = nOrigY - 1;
+        }
+        else
+        {
+            pDoc->SkipOverlapped(rCol, rRow, nTab);
+        }
+
+        if (nOld > rRow)
+        {
+            // The block end has moved.  Check the protection setting and move back if needed.
+            checkBoundary(rCol, rRow);
+            if (!isCellQualified(pDoc, rCol, rRow, nTab, bSelectLocked, bSelectUnlocked))
+                ++rRow;
         }
     }
 }
@@ -741,6 +850,7 @@ void ScTabView::ExpandBlock(SCsCOL nMovX, SCsROW nMovY, ScFollowMode eMode)
         }
 
         moveCursorByProtRule(nNewX, nNewY, nMovX, nMovY, nRefTab, pDoc);
+        checkBoundary(nNewX, nNewY);
 
         if (nMovX)
         {
@@ -751,6 +861,8 @@ void ScTabView::ExpandBlock(SCsCOL nMovX, SCsROW nMovY, ScFollowMode eMode)
                     ++nTempX;
                 else
                     --nTempX;
+                if (!checkBoundary(nTempX, nNewY))
+                    break;
             }
             if (isCellQualified(pDoc, nTempX, nNewY, nRefTab, bSelectLocked, bSelectUnlocked))
                 nNewX = nTempX;
@@ -765,6 +877,8 @@ void ScTabView::ExpandBlock(SCsCOL nMovX, SCsROW nMovY, ScFollowMode eMode)
                     ++nTempY;
                 else
                     --nTempY;
+                if (!checkBoundary(nNewX, nTempY))
+                    break;
             }
             if (isCellQualified(pDoc, nNewX, nTempY, nRefTab, bSelectLocked, bSelectUnlocked))
                 nNewY = nTempY;
@@ -779,23 +893,19 @@ void ScTabView::ExpandBlock(SCsCOL nMovX, SCsROW nMovY, ScFollowMode eMode)
         // normal selection mode
 
         SCTAB nTab = aViewData.GetTabNo();
+        SCCOL nOrigX = aViewData.GetCurX();
+        SCROW nOrigY = aViewData.GetCurY();
+
+        // Note that the origin position *never* moves during selection.
 
         if (!IsBlockMode())
-            InitBlockMode(aViewData.GetCurX(), aViewData.GetCurY(), nTab, true);
+            InitBlockMode(nOrigX, nOrigY, nTab, true);
 
         moveCursorByProtRule(nBlockEndX, nBlockEndY, nMovX, nMovY, nTab, pDoc);
+        checkBoundary(nBlockEndX, nBlockEndY);
+        moveCursorByMergedCell(nBlockEndX, nBlockEndY, nMovX, nMovY, nTab, pDoc, aViewData);
+        checkBoundary(nBlockEndX, nBlockEndY);
 
-        if (nBlockEndX < 0)
-            nBlockEndX = 0;
-        else if (nBlockEndX > MAXCOL)
-            nBlockEndX = MAXCOL;
-
-        if (nBlockEndY < 0)
-            nBlockEndY = 0;
-        else if (nBlockEndY > MAXROW)
-            nBlockEndY = MAXROW;
-
-        pDoc->SkipOverlapped(nBlockEndX, nBlockEndY, nTab);
         MarkCursor(nBlockEndX, nBlockEndY, nTab, false, false, true);
 
         // Check if the entire row(s) or column(s) are selected.
@@ -836,21 +946,21 @@ void ScTabView::UpdateCopySourceOverlay()
 
 void ScTabView::UpdateSelectionOverlay()
 {
-    for (USHORT i=0; i<4; i++)
+    for (sal_uInt16 i=0; i<4; i++)
         if ( pGridWin[i] && pGridWin[i]->IsVisible() )
             pGridWin[i]->UpdateSelectionOverlay();
 }
 
 void ScTabView::UpdateShrinkOverlay()
 {
-    for (USHORT i=0; i<4; i++)
+    for (sal_uInt16 i=0; i<4; i++)
         if ( pGridWin[i] && pGridWin[i]->IsVisible() )
             pGridWin[i]->UpdateShrinkOverlay();
 }
 
 void ScTabView::UpdateAllOverlays()
 {
-    for (USHORT i=0; i<4; i++)
+    for (sal_uInt16 i=0; i<4; i++)
         if ( pGridWin[i] && pGridWin[i]->IsVisible() )
             pGridWin[i]->UpdateAllOverlays();
 }
@@ -859,28 +969,26 @@ void ScTabView::UpdateAllOverlays()
 //!	PaintBlock in zwei Methoden aufteilen: RepaintBlock und RemoveBlock o.ae.
 //!
 
-void ScTabView::PaintBlock( BOOL bReset )
+void ScTabView::PaintBlock( sal_Bool bReset )
 {
-    ScDocument* pDoc = aViewData.GetDocument();
     ScMarkData& rMark = aViewData.GetMarkData();
     SCTAB nTab = aViewData.GetTabNo();
-    BOOL bMark = rMark.IsMarked();
-    BOOL bMulti = rMark.IsMultiMarked();
+    sal_Bool bMark = rMark.IsMarked();
+    sal_Bool bMulti = rMark.IsMultiMarked();
     if (bMark || bMulti)
     {
         ScRange aMarkRange;
         HideAllCursors();
         if (bMulti)
         {
-            BOOL bFlag = rMark.GetMarkingFlag();
-            rMark.SetMarking(FALSE);
+            sal_Bool bFlag = rMark.GetMarkingFlag();
+            rMark.SetMarking(false);
             rMark.MarkToMulti();
             rMark.GetMultiMarkArea(aMarkRange);
             rMark.MarkToSimple();
             rMark.SetMarking(bFlag);
 
             bMark = rMark.IsMarked();
-            bMulti = rMark.IsMultiMarked();
         }
         else
             rMark.GetMarkArea(aMarkRange);
@@ -892,7 +1000,7 @@ void ScTabView::PaintBlock( BOOL bReset )
         nBlockEndY = aMarkRange.aEnd.Row();
         nBlockEndZ = aMarkRange.aEnd.Tab();
 
-        BOOL bDidReset = FALSE;
+        sal_Bool bDidReset = false;
 
         if ( nTab>=nBlockStartZ && nTab<=nBlockEndZ )
         {
@@ -901,63 +1009,9 @@ void ScTabView::PaintBlock( BOOL bReset )
                 // Invertieren beim Loeschen nur auf aktiver View
                 if ( aViewData.IsActive() )
                 {
-                    USHORT i;
-                    if ( bMulti )
-                    {
-#ifdef OLD_SELECTION_PAINT
-                        for (i=0; i<4; i++)
-                            if (pGridWin[i] && pGridWin[i]->IsVisible())
-                                pGridWin[i]->InvertSimple( nBlockStartX, nBlockStartY,
-                                                            nBlockEndX, nBlockEndY,
-                                                            TRUE, TRUE );
-#endif
-                        rMark.ResetMark();
-                        UpdateSelectionOverlay();
-                        bDidReset = TRUE;
-                    }
-                    else
-                    {
-#ifdef OLD_SELECTION_PAINT
-                        // (mis)use InvertBlockMark to remove all of the selection
-                        // -> set bBlockNeg (like when removing parts of a selection)
-                        //	  and convert everything to Multi
-
-                        rMark.MarkToMulti();
-                        BOOL bOld = bBlockNeg;
-                        bBlockNeg = TRUE;
-                        // #73130# (negative) MarkArea must be set in case of repaint
-                        rMark.SetMarkArea( ScRange( nBlockStartX,nBlockStartY, nTab,
-                                                    nBlockEndX,nBlockEndY, nTab ) );
-
-                        InvertBlockMark( nBlockStartX, nBlockStartY, nBlockEndX, nBlockEndY );
-
-                        bBlockNeg = bOld;
-#endif
-                        rMark.ResetMark();
-                        UpdateSelectionOverlay();
-                        bDidReset = TRUE;
-                    }
-
-                    //	repaint if controls are touched (#69680# in both cases)
-                    // #i74768# Forms are rendered by DrawingLayer's EndDrawLayers()
-                    static bool bSuppressControlExtraStuff(true);
-
-                    if(!bSuppressControlExtraStuff)
-                    {
-                        Rectangle aMMRect = pDoc->GetMMRect(nBlockStartX,nBlockStartY,nBlockEndX,nBlockEndY, nTab);
-                        if (pDoc->HasControl( nTab, aMMRect ))
-                        {
-                            for (i=0; i<4; i++)
-                            {
-                                if (pGridWin[i] && pGridWin[i]->IsVisible())
-                                {
-                                    //	MapMode muss logischer (1/100mm) sein !!!
-                                    pDoc->InvalidateControls( pGridWin[i], nTab, aMMRect );
-                                    pGridWin[i]->Update();
-                                }
-                            }
-                        }
-                    }
+                    rMark.ResetMark();
+                    UpdateSelectionOverlay();
+                    bDidReset = true;
                 }
             }
             else
@@ -971,7 +1025,7 @@ void ScTabView::PaintBlock( BOOL bReset )
     }
 }
 
-void ScTabView::SelectAll( BOOL bContinue )
+void ScTabView::SelectAll( sal_Bool bContinue )
 {
     ScMarkData& rMark = aViewData.GetMarkData();
     SCTAB nTab = aViewData.GetTabNo();
@@ -995,16 +1049,12 @@ void ScTabView::SelectAllTables()
 {
     ScDocument* pDoc = aViewData.GetDocument();
     ScMarkData& rMark = aViewData.GetMarkData();
-//    SCTAB nTab = aViewData.GetTabNo();
     SCTAB nCount = pDoc->GetTableCount();
 
     if (nCount>1)
     {
         for (SCTAB i=0; i<nCount; i++)
-            rMark.SelectTable( i, TRUE );
-
-        //		Markierungen werden per Default nicht pro Tabelle gehalten
-//		pDoc->ExtendMarksFromTable( nTab );
+            rMark.SelectTable( i, sal_True );
 
         aViewData.GetDocShell()->PostPaintExtras();
         SfxBindings& rBind = aViewData.GetBindings();
@@ -1029,7 +1079,7 @@ void ScTabView::DeselectAllTables()
     rBind.Invalidate( FID_TAB_DESELECTALL );
 }
 
-BOOL lcl_FitsInWindow( double fScaleX, double fScaleY, USHORT nZoom,
+sal_Bool lcl_FitsInWindow( double fScaleX, double fScaleY, sal_uInt16 nZoom,
                         long nWindowX, long nWindowY, ScDocument* pDoc, SCTAB nTab,
                         SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow,
                         SCCOL nFixPosX, SCROW nFixPosY )
@@ -1043,22 +1093,22 @@ BOOL lcl_FitsInWindow( double fScaleX, double fScaleY, USHORT nZoom,
     for (nCol=0; nCol<nFixPosX; nCol++)
     {
         //	for frozen panes, add both parts
-        USHORT nColTwips = pDoc->GetColWidth( nCol, nTab );
+        sal_uInt16 nColTwips = pDoc->GetColWidth( nCol, nTab );
         if (nColTwips)
         {
             nBlockX += (long)(nColTwips * fScaleX);
             if (nBlockX > nWindowX)
-                return FALSE;
+                return false;
         }
     }
     for (nCol=nStartCol; nCol<=nEndCol; nCol++)
     {
-        USHORT nColTwips = pDoc->GetColWidth( nCol, nTab );
+        sal_uInt16 nColTwips = pDoc->GetColWidth( nCol, nTab );
         if (nColTwips)
         {
             nBlockX += (long)(nColTwips * fScaleX);
             if (nBlockX > nWindowX)
-                return FALSE;
+                return false;
         }
     }
 
@@ -1069,31 +1119,31 @@ BOOL lcl_FitsInWindow( double fScaleX, double fScaleY, USHORT nZoom,
             continue;
 
         //	for frozen panes, add both parts
-        USHORT nRowTwips = pDoc->GetRowHeight(nRow, nTab);
+        sal_uInt16 nRowTwips = pDoc->GetRowHeight(nRow, nTab);
         if (nRowTwips)
         {
             nBlockY += (long)(nRowTwips * fScaleY);
             if (nBlockY > nWindowY)
-                return FALSE;
+                return false;
         }
     }
     for (SCROW nRow = nStartRow; nRow <= nEndRow; ++nRow)
     {
-        USHORT nRowTwips = pDoc->GetRowHeight(nRow, nTab);
+        sal_uInt16 nRowTwips = pDoc->GetRowHeight(nRow, nTab);
         if (nRowTwips)
         {
             nBlockY += (long)(nRowTwips * fScaleY);
             if (nBlockY > nWindowY)
-                return FALSE;
+                return false;
         }
     }
 
-    return TRUE;
+    return sal_True;
 }
 
-USHORT ScTabView::CalcZoom( SvxZoomType eType, USHORT nOldZoom )
+sal_uInt16 ScTabView::CalcZoom( SvxZoomType eType, sal_uInt16 nOldZoom )
 {
-    USHORT nZoom = 0; // Ergebnis
+    sal_uInt16 nZoom = 0; // Ergebnis
 
     switch ( eType )
     {
@@ -1164,11 +1214,11 @@ USHORT ScTabView::CalcZoom( SvxZoomType eType, USHORT nOldZoom )
                         double nPPTX = ScGlobal::nScreenPPTX / pDocSh->GetOutputFactor();
                         double nPPTY = ScGlobal::nScreenPPTY;
 
-                        USHORT nMin = MINZOOM;
-                        USHORT nMax = MAXZOOM;
+                        sal_uInt16 nMin = MINZOOM;
+                        sal_uInt16 nMax = MAXZOOM;
                         while ( nMax > nMin )
                         {
-                            USHORT nTest = (nMin+nMax+1)/2;
+                            sal_uInt16 nTest = (nMin+nMax+1)/2;
                             if ( lcl_FitsInWindow(
                                         nPPTX, nPPTY, nTest, aWinSize.Width(), aWinSize.Height(),
                                         pDoc, nTab, nStartCol, nStartRow, nEndCol, nEndRow,
@@ -1210,7 +1260,7 @@ USHORT ScTabView::CalcZoom( SvxZoomType eType, USHORT nOldZoom )
                     if ( pStyleSheet )
                     {
                         ScPrintFunc aPrintFunc( aViewData.GetDocShell(),
-                                                aViewData.GetViewShell()->GetPrinter(TRUE),
+                                                aViewData.GetViewShell()->GetPrinter(sal_True),
                                                 nCurTab );
 
                         Size aPageSize = aPrintFunc.GetDataSize();
@@ -1266,13 +1316,13 @@ USHORT ScTabView::CalcZoom( SvxZoomType eType, USHORT nOldZoom )
                         if (eType == SVX_ZOOM_WHOLEPAGE && nZoomY < nNew)
                             nNew = nZoomY;
 
-                        nZoom = (USHORT) nNew;
+                        nZoom = (sal_uInt16) nNew;
                     }
                 }
                 break;
 
         default:
-            DBG_ERROR("Unknown Zoom-Revision");
+            OSL_FAIL("Unknown Zoom-Revision");
             nZoom = 0;
     }
 
@@ -1298,7 +1348,7 @@ void ScTabView::StopMarking()
 
 void ScTabView::HideNoteMarker()
 {
-    for (USHORT i=0; i<4; i++)
+    for (sal_uInt16 i=0; i<4; i++)
         if (pGridWin[i] && pGridWin[i]->IsVisible())
             pGridWin[i]->HideNoteMarker();
 }
@@ -1323,7 +1373,7 @@ void ScTabView::MakeDrawLayer()
     }
 }
 
-void ScTabView::ErrorMessage( USHORT nGlobStrId )
+void ScTabView::ErrorMessage( sal_uInt16 nGlobStrId )
 {
     if ( SC_MOD()->IsInExecuteDrop() )
     {
@@ -1335,7 +1385,7 @@ void ScTabView::ErrorMessage( USHORT nGlobStrId )
 
     Window* pParent = aViewData.GetDialogParent();
     ScWaitCursorOff aWaitOff( pParent );
-    BOOL bFocus = pParent && pParent->HasFocus();
+    sal_Bool bFocus = pParent && pParent->HasFocus();
 
     if(nGlobStrId==STR_PROTECTIONERR)
     {
@@ -1351,7 +1401,7 @@ void ScTabView::ErrorMessage( USHORT nGlobStrId )
         pParent->GrabFocus();
 }
 
-Window* ScTabView::GetParentOrChild( USHORT nChildId )
+Window* ScTabView::GetParentOrChild( sal_uInt16 nChildId )
 {
     SfxViewFrame* pViewFrm = aViewData.GetViewShell()->GetViewFrame();
 
@@ -1369,7 +1419,7 @@ Window* ScTabView::GetParentOrChild( USHORT nChildId )
     return aViewData.GetDialogParent();
 }
 
-void ScTabView::UpdatePageBreakData( BOOL bForcePaint )
+void ScTabView::UpdatePageBreakData( sal_Bool bForcePaint )
 {
     ScPageBreakData* pNewData = NULL;
 
@@ -1379,7 +1429,7 @@ void ScTabView::UpdatePageBreakData( BOOL bForcePaint )
         ScDocument* pDoc = pDocSh->GetDocument();
         SCTAB nTab = aViewData.GetTabNo();
 
-        USHORT nCount = pDoc->GetPrintRangeCount(nTab);
+        sal_uInt16 nCount = pDoc->GetPrintRangeCount(nTab);
         if (!nCount)
             nCount = 1;
         pNewData = new ScPageBreakData(nCount);
