@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -41,6 +41,7 @@
 #include <svl/stritem.hxx>
 #include <svl/whiter.hxx>
 #include <vcl/msgbox.hxx>
+#include <sfx2/objface.hxx>
 #include <svx/svxdlg.hxx>
 #include <editeng/colritem.hxx>
 
@@ -58,12 +59,15 @@
 
 #include "tabbgcolor.hxx"
 #include "tabbgcolordlg.hxx"
+#include "sccommands.h"
+
+#include <vector>
 
 using ::boost::scoped_ptr;
 using namespace com::sun::star;
 
 #define IS_AVAILABLE(WhichId,ppItem) \
-    (pReqArgs->GetItemState((WhichId), TRUE, ppItem ) == SFX_ITEM_SET)
+    (pReqArgs->GetItemState((WhichId), sal_True, ppItem ) == SFX_ITEM_SET)
 
 //------------------------------------------------------------------
 
@@ -74,7 +78,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
     SCTAB		nCurrentTab	= pViewData->GetTabNo();
     SCTAB		nTabCount	= pDoc->GetTableCount();
-    USHORT		nSlot		= rReq.GetSlot();
+    sal_uInt16		nSlot		= rReq.GetSlot();
     const SfxItemSet* pReqArgs = rReq.GetArgs();
 
     HideListBox();					// Autofilter-DropDown-Listbox
@@ -86,7 +90,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 String aName;
                 pDoc->GetName( nCurrentTab, aName );
 
-                BOOL bVisible=TRUE;
+                sal_Bool bVisible=sal_True;
                 if( pReqArgs != NULL )
                 {
                     const SfxPoolItem* pItem;
@@ -98,7 +102,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 {
                     ScMarkData& rMark = pViewData->GetMarkData();
                     SCTAB nTabSelCount = rMark.GetSelectCount();
-                    USHORT nVis = 0;
+                    sal_uInt16 nVis = 0;
                     for ( SCTAB i=0; i < nTabCount && nVis<2; i++ )
                         if (pDoc->IsVisible(i))
                             ++nVis;
@@ -120,7 +124,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
             {
                 ScMarkData& rMark = pViewData->GetMarkData();
                 SCTAB nTabSelCount = rMark.GetSelectCount();
-                USHORT nVis = 0;
+                sal_uInt16 nVis = 0;
                 for ( SCTAB i=0; i < nTabCount && nVis<2; i++ )
                     if (pDoc->IsVisible(i))
                         ++nVis;
@@ -176,21 +180,21 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     DBG_ASSERT(pDlg, "Dialog create fail!");
 
                     String aTabName;
-                    BOOL bFirst = TRUE;
+                    sal_Bool bFirst = sal_True;
                     for ( SCTAB i=0; i != nTabCount; i++ )
                     {
                         if (!pDoc->IsVisible(i))
                         {
                             pDoc->GetName( i, aTabName );
                             pDlg->Insert( aTabName, bFirst );
-                            bFirst = FALSE;
+                            bFirst = false;
                         }
                     }
 
                     if ( pDlg->Execute() == RET_OK )
                     {
-                        USHORT nCount = pDlg->GetSelectEntryCount();
-                        for (USHORT nPos=0; nPos<nCount; nPos++)
+                        sal_uInt16 nCount = pDlg->GetSelectEntryCount();
+                        for (sal_uInt16 nPos=0; nPos<nCount; nPos++)
                         {
                             aName = pDlg->GetSelectEntry(nPos);
                             ShowTable( aName );
@@ -215,7 +219,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                 if ( pReqArgs != NULL )				// von Basic
                 {
-                    BOOL bOk = FALSE;
+                    sal_Bool bOk = false;
                     const SfxPoolItem*	pTabItem;
                     const SfxPoolItem*	pNameItem;
                     String				aName;
@@ -250,14 +254,14 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                         {
                             SCTAB nTabs[MAXTABCOUNT];
                             SCTAB nCount = 0;
-                            USHORT n = 0;
+                            sal_uInt16 n = 0;
                             const String* pStr = pDlg->GetFirstTable( &n );
                             while ( pStr )
                             {
                                 nTabs[nCount++] = static_cast<SCTAB>(n);
                                 pStr = pDlg->GetNextTable( &n );
                             }
-                            BOOL bLink = pDlg->GetTablesAsLink();
+                            sal_Bool bLink = pDlg->GetTablesAsLink();
                             if (nCount != 0)
                             {
                                 if(pDlg->IsTableBefore())
@@ -368,7 +372,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                 if( pReqArgs != NULL )
                 {
-                    BOOL		bDone	= FALSE;
+                    sal_Bool		bDone	= false;
                     const SfxPoolItem* pItem;
                     String		aName;
 
@@ -395,33 +399,36 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 }
                 else
                 {
-                    USHORT		nRet	= RET_OK;
-                    BOOL		bDone	= FALSE;
+                    sal_uInt16		nRet	= RET_OK;
+                    sal_Bool		bDone	= false;
                     String		aErrMsg ( ScGlobal::GetRscString( STR_INVALIDTABNAME ) );
                     String		aName;
                     String		aDlgTitle;
+                    const sal_Char* pHelpId = 0;
 
                     switch ( nSlot )
                     {
                         case FID_TAB_APPEND:
                             aDlgTitle = String(ScResId(SCSTR_APDTABLE));
                             pDoc->CreateValidTabName( aName );
+                            pHelpId = HID_SC_APPEND_NAME;
                             break;
 
                         case FID_TAB_RENAME:
                             aDlgTitle = String(ScResId(SCSTR_RENAMETAB));
                             pDoc->GetName( pViewData->GetTabNo(), aName );
+                            pHelpId = HID_SC_RENAME_NAME;
                             break;
                     }
 
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     DBG_ASSERT(pFact, "ScAbstractFactory create fail!");
 
-                    AbstractScStringInputDlg* pDlg = pFact->CreateScStringInputDlg( GetDialogParent(),
-                                                                                    aDlgTitle,
-                                                                                    String(ScResId(SCSTR_NAME)),
-                                                                                    aName,
-                                                                                    nSlot,RID_SCDLG_STRINPUT);
+                    AbstractScStringInputDlg* pDlg = pFact->CreateScStringInputDlg(
+                        GetDialogParent(), aDlgTitle, String(ScResId(SCSTR_NAME)),
+                        aName, GetStaticInterface()->GetSlot(nSlot)->GetCommand(),
+                        pHelpId, RID_SCDLG_STRINPUT);
+
                     DBG_ASSERT(pDlg, "Dialog create fail!");
 
                     while ( !bDone && nRet == RET_OK )
@@ -474,11 +481,12 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 if ( pDoc->GetChangeTrack() != NULL )
                     break;		// bei aktiviertem ChangeTracking kein TabMove
 
-                BOOL   bDoIt = FALSE;
-                USHORT nDoc = 0;
+                sal_Bool   bDoIt = false;
+                sal_uInt16 nDoc = 0;
                 SCTAB nTab = pViewData->GetTabNo();
-                BOOL   bCpy = FALSE;
+                sal_Bool   bCpy = false;
                 String aDocName;
+                String aTabName;
 
                 if( pReqArgs != NULL )
                 {
@@ -501,7 +509,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     {
                         SfxObjectShell* pSh		= SfxObjectShell::GetFirst();
                         ScDocShell*		pScSh	= NULL;
-                        USHORT			i=0;
+                        sal_uInt16			i=0;
 
                         while ( pSh )
                         {
@@ -528,7 +536,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     else // Kein Dokumentname -> neues Dokument
                     {
                         nDoc = SC_DOC_NEW;
-                        bDoIt = TRUE;
+                        bDoIt = sal_True;
                     }
 
                     if ( bDoIt && nTab >= nTableCount )		// ggf. anhaengen
@@ -536,10 +544,15 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 }
                 else
                 {
+                    String aDefaultName;
+                    pDoc->GetName( pViewData->GetTabNo(), aDefaultName );
+
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     DBG_ASSERT(pFact, "ScAbstractFactory create fail!");
 
-                    AbstractScMoveTableDlg* pDlg = pFact->CreateScMoveTableDlg( GetDialogParent(), RID_SCDLG_MOVETAB );
+                    AbstractScMoveTableDlg* pDlg = pFact->CreateScMoveTableDlg( GetDialogParent(),
+                                                                                aDefaultName,
+                                                                                RID_SCDLG_MOVETAB );
                     DBG_ASSERT(pDlg, "Dialog create fail!");
 
                     SCTAB nTableCount = pDoc->GetTableCount();
@@ -549,15 +562,25 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     if(nTableCount==nTabSelCount)
                     {
-                        pDlg->SetCopyTable();
-                        pDlg->EnableCopyTable(FALSE);
+                        pDlg->SetForceCopyTable();
                     }
+
+                    // We support direct renaming of sheet only when one sheet
+                    // is selected.
+                    pDlg->EnableRenameTable(nTabSelCount == 1);
+
                     if ( pDlg->Execute() == RET_OK )
                     {
                         nDoc = pDlg->GetSelectedDocument();
                         nTab = pDlg->GetSelectedTable();
                         bCpy = pDlg->GetCopyTable();
-                        bDoIt = TRUE;
+                        bool bRna = pDlg->GetRenameTable();
+                        // Leave aTabName string empty, when Rename is FALSE.
+                        if( bRna )
+                        {
+                           pDlg->GetTabNameString( aTabName );
+                        }
+                        bDoIt = true;
 
                         String aFoundDocName;
                         if ( nDoc != SC_DOC_NEW )
@@ -569,7 +592,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                                 if ( !pSh->GetDocument()->IsDocEditable() )
                                 {
                                     ErrorMessage(STR_READONLYERR);
-                                    bDoIt = FALSE;
+                                    bDoIt = false;
                                 }
                             }
                         }
@@ -586,7 +609,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 {
                     rReq.Done();		// aufzeichnen, solange das Dokument noch aktiv ist
 
-                    MoveTable( nDoc, nTab, bCpy );
+                    MoveTable( nDoc, nTab, bCpy, &aTabName );
                 }
             }
             break;
@@ -595,7 +618,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
             {
                 //	Parameter war ueberfluessig, weil die Methode an der Table haengt
 
-                BOOL bDoIt = rReq.IsAPI();
+                sal_Bool bDoIt = rReq.IsAPI();
                 if( !bDoIt )
                 {
                     //	wenn's nicht von Basic kommt, nochmal nachfragen:
@@ -616,15 +639,15 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 {
                     SCTAB nNewTab	= nCurrentTab;
                     SCTAB nFirstTab=0;
-                    BOOL   bTabFlag=FALSE;
+                    sal_Bool   bTabFlag=false;
                     ScMarkData& rMark = pViewData->GetMarkData();
-                    SvShorts TheTabs;
+                    std::vector<SCTAB> TheTabs;
                     for(SCTAB i=0;i<nTabCount;i++)
                     {
                         if(rMark.GetTableSelect(i) &&!pDoc->IsTabProtected(i))
                         {
-                            TheTabs.Insert(i,TheTabs.Count());
-                            bTabFlag=TRUE;
+                            TheTabs.push_back(i);
+                            bTabFlag=true;
                             if(nNewTab==i) nNewTab++;
                         }
                         if(!bTabFlag) nFirstTab=i;
@@ -633,7 +656,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     pViewData->SetTabNo(nNewTab);
                     DeleteTables(TheTabs);
-                    TheTabs.Remove(0,TheTabs.Count());
+                    TheTabs.clear();
                     rReq.Done();
                 }
             }
@@ -643,25 +666,25 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
             {
                 ScDocShell* pDocSh = pViewData->GetDocShell();
                 ScDocFunc aFunc(*pDocSh);
-                BOOL bSet = !pDoc->IsLayoutRTL( nCurrentTab );
+                sal_Bool bSet = !pDoc->IsLayoutRTL( nCurrentTab );
 
                 const ScMarkData& rMark = pViewData->GetMarkData();
                 if ( rMark.GetSelectCount() != 0 )
                 {
                     //	handle several sheets
 
-                    SfxUndoManager* pUndoManager = pDocSh->GetUndoManager();
+                    ::svl::IUndoManager* pUndoManager = pDocSh->GetUndoManager();
                     String aUndo = ScGlobal::GetRscString( STR_UNDO_TAB_RTL );
                     pUndoManager->EnterListAction( aUndo, aUndo );
 
                     for (SCTAB nTab=0; nTab<nTabCount; nTab++)
                         if ( rMark.GetTableSelect(nTab) )
-                            aFunc.SetLayoutRTL( nTab, bSet, FALSE );
+                            aFunc.SetLayoutRTL( nTab, bSet, false );
 
                     pUndoManager->LeaveListAction();
                 }
                 else
-                    aFunc.SetLayoutRTL( nCurrentTab, bSet, FALSE );
+                    aFunc.SetLayoutRTL( nCurrentTab, bSet, false );
             }
             break;
 
@@ -692,7 +715,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                 if( pReqArgs != NULL )
                 {
-                    BOOL                bDone = FALSE;
+                    sal_Bool                bDone = false;
                     const SfxPoolItem*  pItem;
                     Color               aColor;
                     if( IS_AVAILABLE( FN_PARAM_1, &pItem ) )
@@ -727,8 +750,8 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                 }
                 else
                 {
-                    USHORT      nRet    = RET_OK; /// temp
-                    BOOL        bDone   = FALSE; /// temp
+                    sal_uInt16      nRet    = RET_OK; /// temp
+                    sal_Bool        bDone   = false; /// temp
                     Color       aTabBgColor;
                     Color       aNewTabBgColor;
 
@@ -740,7 +763,8 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                                                                 String(ScResId(SCSTR_SET_TAB_BG_COLOR)),
                                                                 String(ScResId(SCSTR_NO_TAB_BG_COLOR)),
                                                                 aTabBgColor,
-                                                                nSlot,RID_SCDLG_TAB_BG_COLOR);
+                                                                CMD_FID_TAB_SET_TAB_BG_COLOR,
+                                                                RID_SCDLG_TAB_BG_COLOR);
                     while ( !bDone && nRet == RET_OK )
                     {
                         nRet = pDlg->Execute();
@@ -805,7 +829,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
             break;
 
         default:
-            DBG_ERROR("Unbekannte Message bei ViewShell");
+            OSL_FAIL("Unbekannte Message bei ViewShell");
             break;
     }
 }
@@ -824,7 +848,7 @@ void ScTabViewShell::GetStateTable( SfxItemSet& rSet )
     SCTAB nTabSelCount = rMark.GetSelectCount();
 
     SfxWhichIter	aIter(rSet);
-    USHORT			nWhich = aIter.FirstWhich();
+    sal_uInt16			nWhich = aIter.FirstWhich();
 
     while ( nWhich )
     {
@@ -837,7 +861,7 @@ void ScTabViewShell::GetStateTable( SfxItemSet& rSet )
 
             case FID_TABLE_HIDE:
                 {
-                    USHORT nVis = 0;
+                    sal_uInt16 nVis = 0;
                     for ( SCTAB i=0; i < nTabCount && nVis<2; i++ )
                         if (pDoc->IsVisible(i))
                             ++nVis;
@@ -849,10 +873,10 @@ void ScTabViewShell::GetStateTable( SfxItemSet& rSet )
 
             case FID_TABLE_SHOW:
                 {
-                    BOOL bHasHidden = FALSE;
+                    sal_Bool bHasHidden = false;
                     for ( SCTAB i=0; i < nTabCount && !bHasHidden; i++ )
                         if (!pDoc->IsVisible(i))
-                            bHasHidden = TRUE;
+                            bHasHidden = sal_True;
                     if ( !bHasHidden || pDoc->IsDocProtected() || nTabSelCount > 1 )
                         rSet.DisableItem( nWhich );
                 }
@@ -864,7 +888,7 @@ void ScTabViewShell::GetStateTable( SfxItemSet& rSet )
                         rSet.DisableItem( nWhich );
                     else
                     {
-                        USHORT nVis = 0;
+                        sal_uInt16 nVis = 0;
                         for ( SCTAB i=0; i < nTabCount && nVis<2; i++ )
                             if (pDoc->IsVisible(i))
                                 ++nVis;
