@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -50,7 +50,7 @@
 #include <svl/undo.hxx>
 #include "DrawDocShell.hxx"
 #include <vcl/gdimtf.hxx>
-#include <vcl/wintypes.hxx>
+#include <tools/wintypes.hxx>
 #include "docprev.hxx"
 #include <sfx2/app.hxx>
 #include <sfx2/docfile.hxx>
@@ -81,11 +81,13 @@
 #include "WindowUpdater.hxx"
 
 #include <comphelper/processfactory.hxx>
+#include <vector>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::sd;
 
+using ::std::vector;
 
 void InterpolateFixedBitmap( FixedBitmap * pBitmap )
 {
@@ -99,7 +101,7 @@ void InterpolateFixedBitmap( FixedBitmap * pBitmap )
 // ====================================================================
 // ====================================================================
 
-UINT32 PageHelpIds[] =
+const char* PageHelpIds[] =
 {
     HID_SD_AUTOPILOT_PAGE1,
     HID_SD_AUTOPILOT_PAGE2,
@@ -117,8 +119,6 @@ public:
     String maPath;
 };
 
-DECLARE_LIST( PasswordEntryList, PasswordEntry * )
-
 // ====================================================================
 
 /** A simple wrapper that looks like a PushButton and is used to force the
@@ -150,7 +150,7 @@ private:
 class AssistentDlgImpl : public SfxListener
 {
 public:
-    AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink, BOOL bAutoPilot  );
+    AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink, sal_Bool bAutoPilot  );
     ~AssistentDlgImpl();
 
     /// Local mutex used to serialize concurrent method calls.
@@ -165,10 +165,10 @@ public:
         files and insert them into a listbox.
     */
     void	ScanDocmenu			(void);
-    /**	Flag that is set to TRUE after the recently used files have been
+    /**	Flag that is set to sal_True after the recently used files have been
         scanned.
     */
-    BOOL mbRecentDocumentsReady;
+    sal_Bool mbRecentDocumentsReady;
 
     /**	When the list of templates has not been scanned already this is done
         when this method is called.  That includes requesting the whole list
@@ -190,16 +190,16 @@ public:
     */
     void TemplateScanDone (std::vector<TemplateDir*>& rTemplateFolders);
 
-    /**	Flag that is set to TRUE after the impress templates have been
+    /**	Flag that is set to sal_True after the impress templates have been
         scanned.
     */
-    BOOL mbTemplatesReady;
+    sal_Bool mbTemplatesReady;
 
     /** Flag used to prevent nested or concurrent calls to the
         <member>UpdatePreview</memember> method.  A <TRUE/> value indicates
         that a preview update is currently active.
     */
-    BOOL mbPreviewUpdating;
+    sal_Bool mbPreviewUpdating;
 
     ::Window* mpWindow;
 
@@ -208,7 +208,7 @@ public:
     String GetPassword( const String rPath );
     void DeletePassords();
 
-    PasswordEntryList maPasswordList;
+    vector< PasswordEntry* > maPasswordList;
 
     String maDocFile;
     String maLayoutFile;
@@ -229,7 +229,7 @@ public:
     TemplateDir* mpLayoutRegion;
 
     // preview
-    BOOL mbUserDataDirty;
+    sal_Bool mbUserDataDirty;
     Timer maPrevTimer;
     Timer maEffectPrevTimer;
     Timer maUpdatePageListTimer;
@@ -239,19 +239,19 @@ public:
 
     ::std::auto_ptr<WindowUpdater> mpWindowUpdater;
 
-    BOOL mbPreview;
-    USHORT mnShowPage;
-    BOOL mbDocPreview;
+    sal_Bool mbPreview;
+    sal_uInt16 mnShowPage;
+    sal_Bool mbDocPreview;
 
-    ULONG mnTemplate;
+    sal_uLong mnTemplate;
 
     String maPageListFile;
 
-    void UpdatePreview( BOOL bDocPreview );
+    void UpdatePreview( sal_Bool bDocPreview );
     void UpdatePageList();
     void UpdateUserData();
 
-    BOOL IsOwnFormat( const String& rPath );
+    sal_Bool IsOwnFormat( const String& rPath );
 
     // dlg status
     void EndDialog( long nResult = 0 );
@@ -362,15 +362,15 @@ public:
 
 // ====================================================================
 
-AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink, BOOL bAutoPilot ) :
+AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink, sal_Bool bAutoPilot ) :
     mpTemplateRegion(NULL),
     mpLayoutRegion(NULL),
-    mbUserDataDirty(FALSE),
+    mbUserDataDirty(sal_False),
     xDocShell (NULL),
     mpWindowUpdater (new WindowUpdater()),
-    mbPreview(TRUE),
+    mbPreview(sal_True),
     mnShowPage(0),
-    mbDocPreview(FALSE),
+    mbDocPreview(sal_False),
     maAssistentFunc(5),
     maPreviewFlag(pWindow,SdResId(CB_PREVIEW)),
     maStartWithFlag(pWindow,SdResId(CB_STARTWITH)),
@@ -384,9 +384,9 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
     maOpenStr(SdResId(STR_OPEN))
 {
     maPageListFile += sal_Unicode('?'),
-    mbRecentDocumentsReady = FALSE;
-    mbTemplatesReady = FALSE;
-    mbPreviewUpdating = FALSE;
+    mbRecentDocumentsReady = sal_False;
+    mbTemplatesReady = sal_False;
+    mbPreviewUpdating = sal_False;
 
     mpWindow = pWindow;
 
@@ -438,15 +438,15 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
         String sText (GetUiTextForCommand(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:Open"))));
         // Remove the mnemonic and add a leading space so that icon and text
         // are not too close together.
-        sText.SearchAndReplaceAll(String(RTL_CONSTASCII_STRINGPARAM("~")),String());
-        sText.Insert(String(RTL_CONSTASCII_STRINGPARAM(" ")),0);
+        sText.SearchAndReplaceAll(String(RTL_CONSTASCII_USTRINGPARAM("~")),String());
+        sText.Insert(String(RTL_CONSTASCII_USTRINGPARAM(" ")),0);
         mpPage1OpenPB->SetText(sText);
         // Place icon left of text and both centered in the button.
         mpPage1OpenPB->SetModeImage(
-            GetUiIconForCommand(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:Open"))),
-            BMP_COLOR_NORMAL);
-        mpPage1OpenPB->EnableImageDisplay(TRUE);
-        mpPage1OpenPB->EnableTextDisplay(TRUE);
+            GetUiIconForCommand(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:Open")))
+        );
+        mpPage1OpenPB->EnableImageDisplay(sal_True);
+        mpPage1OpenPB->EnableTextDisplay(sal_True);
         mpPage1OpenPB->SetImageAlign(IMAGEALIGN_LEFT);
         mpPage1OpenPB->SetStyle(mpPage1OpenPB->GetStyle() | WB_CENTER);
     }
@@ -463,7 +463,6 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
     mpPage1OpenLB->SetSelectHdl(LINK(this,AssistentDlgImpl,SelectFileHdl));
     mpPage1OpenLB->SetDoubleClickHdl(rFinishLink);
     mpPage1OpenPB->SetClickHdl(LINK(this,AssistentDlgImpl,OpenButtonHdl));
-    //	mpPage1OpenLB->InsertEntry(String(SdResId(STR_WIZARD_POSITION)));
 
     // Seite 2
     maAssistentFunc.InsertControl(2, &maPreview );
@@ -529,7 +528,6 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
         mpPage3LogoCB = new CheckBox( pWindow, SdResId( CB_PAGE3_LOGO) ));
 
     mpPage3EffectLB->Fill();
-//	mpPage3EffectLB->SelectEffect( presentation::FadeEffect_NONE );
     mpPage3EffectLB->SetSelectHdl( LINK(this,AssistentDlgImpl,SelectEffectHdl ));
     mpPage3EffectLB->SetDropDownLineCount( 12 );
 
@@ -627,7 +625,7 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
 
     mpWindowUpdater->RegisterWindow (&maPreview);
 
-    UpdatePreview( TRUE );
+    UpdatePreview( sal_True );
 
     //check wether we should start with a template document initialy and preselect it
     const ::rtl::OUString aServiceName( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.PresentationDocument" ) );
@@ -641,11 +639,11 @@ AssistentDlgImpl::AssistentDlgImpl( ::Window* pWindow, const Link& rFinishLink,
         TemplateEntry* pStandardTemplateEntry = 0;
 
         std::vector<TemplateDir*>::iterator	I;
-        for (I=maPresentList.begin(); I!=maPresentList.end(); I++)
+        for (I=maPresentList.begin(); I!=maPresentList.end(); ++I)
         {
             TemplateDir* pDir = *I;
             std::vector<TemplateEntry*>::iterator	J;
-            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); J++)
+            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); ++J)
             {
                 TemplateEntry* pEntry = *J;
                 if(pEntry->msPath == aStandardTemplate)
@@ -682,9 +680,9 @@ AssistentDlgImpl::~AssistentDlgImpl()
     //	Delete the template file infos.
     std::vector<TemplateDir*>::iterator	I;
     std::vector<TemplateEntry*>::iterator	J;
-    for (I=maPresentList.begin(); I!=maPresentList.end(); I++)
+    for (I=maPresentList.begin(); I!=maPresentList.end(); ++I)
     {
-        for (J=(*I)->maEntries.begin(); J!=(*I)->maEntries.end(); J++)
+        for (J=(*I)->maEntries.begin(); J!=(*I)->maEntries.end(); ++J)
             delete (*J);
         delete (*I);
     }
@@ -746,7 +744,7 @@ AssistentDlgImpl::~AssistentDlgImpl()
 
     //	Delete the file history list.
     std::vector<String*>::iterator	I2;
-    for (I2=maOpenFilesList.begin(); I2!=maOpenFilesList.end(); I2++)
+    for (I2=maOpenFilesList.begin(); I2!=maOpenFilesList.end(); ++I2)
         delete *I2;
 }
 
@@ -754,14 +752,11 @@ void AssistentDlgImpl::CloseDocShell()
 {
     if(xDocShell.Is())
     {
-        //uno::Reference< lang::XComponent > xModel( xDocShell->GetModel(), uno::UNO_QUERY );
         uno::Reference< util::XCloseable > xCloseable( xDocShell->GetModel(), uno::UNO_QUERY );
-        //if( xModel.is() )
         if( xCloseable.is() )
         {
             xCloseable->close( sal_True );
             xDocShell = NULL;
-            //xModel->dispose();
         }
         else
         {
@@ -849,10 +844,10 @@ void	AssistentDlgImpl::ScanDocmenu	(void)
             }
         }
     }
-    mbRecentDocumentsReady = TRUE;
+    mbRecentDocumentsReady = sal_True;
     try
     {
-        UpdatePreview(TRUE);
+        UpdatePreview(sal_True);
     }
     catch (uno::RuntimeException& )
     {
@@ -872,7 +867,7 @@ void AssistentDlgImpl::ProvideTemplates (void)
 
         try
         {
-            UpdatePreview(TRUE);
+            UpdatePreview(sal_True);
         }
         catch (uno::RuntimeException& e)
         {
@@ -896,7 +891,7 @@ void AssistentDlgImpl::TemplateScanDone (
     mpPage1RegionLB->Clear();
     std::vector<TemplateDir*>::iterator	I;
     int	i;
-    for (i=0,I=maPresentList.begin(); I!=maPresentList.end(); I++,i++)
+    for (i=0,I=maPresentList.begin(); I!=maPresentList.end(); ++I,++i)
     {
         TemplateDir* pDir = *I;
         if (pDir == NULL)
@@ -914,14 +909,14 @@ void AssistentDlgImpl::TemplateScanDone (
 
         mpPage1RegionLB->InsertEntry (pDir->msRegion);
     }
-    mpPage1RegionLB->SelectEntryPos ((USHORT)nFirstEntry);
+    mpPage1RegionLB->SelectEntryPos ((sal_uInt16)nFirstEntry);
     mpPage1RegionLB->Update();
     SelectTemplateRegion (mpPage1RegionLB->GetSelectEntry());
 
     //	Fill in the list box on the second page.
     nFirstEntry = 0;
     mpPage2RegionLB->Clear();
-    for (i=0,I=maPresentList.begin(); I!=maPresentList.end(); I++,i++)
+    for (i=0,I=maPresentList.begin(); I!=maPresentList.end(); ++I,++i)
     {
         TemplateDir* pDir = *I;
         if (pDir == NULL)
@@ -939,12 +934,12 @@ void AssistentDlgImpl::TemplateScanDone (
 
         mpPage2RegionLB->InsertEntry (pDir->msRegion);
     }
-    mpPage2RegionLB->SelectEntryPos ((USHORT)nFirstEntry);
+    mpPage2RegionLB->SelectEntryPos ((sal_uInt16)nFirstEntry);
     mpPage2RegionLB->Update();
     SelectLayoutRegion (mpPage2RegionLB->GetSelectEntry());
 
     //	Make the changes visible.
-    mbTemplatesReady = TRUE;
+    mbTemplatesReady = sal_True;
     if (mpWindow)
         UpdatePage();
 }
@@ -990,7 +985,7 @@ String AssistentDlgImpl::GetDocFileName()
     if(mpWindow)
     {
         aTitle = mpWindow->GetText();
-        USHORT nPos = aTitle.Search(sal_Unicode('('));
+        sal_uInt16 nPos = aTitle.Search(sal_Unicode('('));
         if(nPos != STRING_NOTFOUND)
             aTitle.Erase( nPos-1 );
     }
@@ -998,9 +993,9 @@ String AssistentDlgImpl::GetDocFileName()
     String aDocFile;
     if( GetStartType() == ST_TEMPLATE )
     {
-        const USHORT nEntry = mpPage1TemplateLB->GetSelectEntryPos();
+        const sal_uInt16 nEntry = mpPage1TemplateLB->GetSelectEntryPos();
         TemplateEntry* pEntry = NULL;
-        if(nEntry != (USHORT)-1)
+        if(nEntry != (sal_uInt16)-1)
             pEntry = mpTemplateRegion->maEntries[nEntry];
 
         if(pEntry)
@@ -1014,8 +1009,8 @@ String AssistentDlgImpl::GetDocFileName()
     }
     else if( GetStartType() == ST_OPEN )
     {
-        const USHORT nEntry = mpPage1OpenLB->GetSelectEntryPos();
-        if(nEntry != (USHORT)-1 )
+        const sal_uInt16 nEntry = mpPage1OpenLB->GetSelectEntryPos();
+        if(nEntry != (sal_uInt16)-1 )
             aDocFile = *maOpenFilesList[nEntry];
     }
 
@@ -1028,9 +1023,9 @@ String AssistentDlgImpl::GetDocFileName()
 String AssistentDlgImpl::GetLayoutFileName()
 {
     String aFile;
-    const USHORT nEntry = mpPage2LayoutLB->GetSelectEntryPos();
+    const sal_uInt16 nEntry = mpPage2LayoutLB->GetSelectEntryPos();
     TemplateEntry* pEntry = NULL;
-    if(nEntry != (USHORT)-1 && nEntry > 0)
+    if(nEntry != (sal_uInt16)-1 && nEntry > 0)
         pEntry = mpLayoutRegion->maEntries[nEntry-1];
 
     if(pEntry)
@@ -1041,8 +1036,7 @@ String AssistentDlgImpl::GetLayoutFileName()
 
 SfxObjectShellLock AssistentDlgImpl::GetDocument()
 {
-//	mbPreview = FALSE;		// Document nicht anzeigen
-    UpdatePreview(FALSE);	// aber komplett laden
+    UpdatePreview(sal_False);	// aber komplett laden
     UpdatePageList();
 
     SfxObjectShell* pShell = xDocShell;
@@ -1051,9 +1045,9 @@ SfxObjectShellLock AssistentDlgImpl::GetDocument()
 
     if(pDoc)
     {
-        const USHORT nPageCount = pDoc->GetSdPageCount(PK_STANDARD);
-        BOOL bKiosk = mpPage3PresTypeKioskRB->IsChecked();
-        UINT32 nNewTime = (UINT32)mpPage3PresTimeTMF->GetTime().GetMSFromTime() / 1000;
+        const sal_uInt16 nPageCount = pDoc->GetSdPageCount(PK_STANDARD);
+        sal_Bool bKiosk = mpPage3PresTypeKioskRB->IsChecked();
+        sal_uInt32 nNewTime = (sal_uInt32)mpPage3PresTimeTMF->GetTime().GetMSFromTime() / 1000;
         if(bKiosk)
         {
             PresentationSettings& rSettings = pDoc->getPresentationSettings();
@@ -1062,8 +1056,8 @@ SfxObjectShellLock AssistentDlgImpl::GetDocument()
             rSettings.mbShowPauseLogo = mpPage3LogoCB->IsChecked();
         }
 
-        USHORT nPgAbsNum = 0;
-        USHORT nPgRelNum = 0;
+        sal_uInt16 nPgAbsNum = 0;
+        sal_uInt16 nPgRelNum = 0;
         while( nPgAbsNum < nPageCount )
         {
             SdPage* pPage = pDoc->GetSdPage( nPgRelNum, PK_STANDARD );
@@ -1091,7 +1085,7 @@ SfxObjectShellLock AssistentDlgImpl::GetDocument()
     }
     else
     {
-        DBG_ERROR("sd::AssistentDlgImpl::GetDocument(), no template?");
+        OSL_FAIL("sd::AssistentDlgImpl::GetDocument(), no template?");
     }
 
     SfxObjectShellLock xRet = xDocShell;
@@ -1113,10 +1107,12 @@ void AssistentDlgImpl::ChangePage()
     maNextPageButton.Enable(!maAssistentFunc.IsLastPage());
     maLastPageButton.Enable(!maAssistentFunc.IsFirstPage());
 
-    USHORT nPage = (USHORT)maAssistentFunc.GetCurrentPage();
+    sal_uInt16 nPage = (sal_uInt16)maAssistentFunc.GetCurrentPage();
 
     if( mpWindow )
+    {
         mpWindow->SetHelpId( PageHelpIds[nPage-1]);
+    }
 
     UpdatePage();
 
@@ -1130,7 +1126,7 @@ void AssistentDlgImpl::ChangePage()
 
 void AssistentDlgImpl::UpdatePage()
 {
-    USHORT nPage = (USHORT)maAssistentFunc.GetCurrentPage();
+    sal_uInt16 nPage = (sal_uInt16)maAssistentFunc.GetCurrentPage();
 
     switch(nPage)
     {
@@ -1138,7 +1134,7 @@ void AssistentDlgImpl::UpdatePage()
         {
             // Elemente auf der ersten Seite abhaengig vom Starttype Zeigen
             SetStartType( GetStartType() );
-            mpPage1TemplateRB->Enable(TRUE /*mbTemplatesReady*/);
+            mpPage1TemplateRB->Enable(sal_True /*mbTemplatesReady*/);
             break;
         }
 
@@ -1149,11 +1145,11 @@ void AssistentDlgImpl::UpdatePage()
 
             if( GetStartType() != ST_EMPTY )
             {
-                mpPage2Medium5RB->Enable( TRUE );
+                mpPage2Medium5RB->Enable( sal_True );
             }
             else
             {
-                mpPage2Medium5RB->Enable( FALSE );
+                mpPage2Medium5RB->Enable( sal_False );
                 if(mpPage2Medium5RB->IsChecked())
                     mpPage2Medium1RB->Check();
             }
@@ -1174,7 +1170,7 @@ void AssistentDlgImpl::UpdatePage()
             if(GetStartType() != ST_TEMPLATE)
                 maNextPageButton.Enable(false);
 
-            BOOL bKiosk = mpPage3PresTypeKioskRB->IsChecked();
+            sal_Bool bKiosk = mpPage3PresTypeKioskRB->IsChecked();
             mpPage3PresTimeFT->Enable(bKiosk);
             mpPage3BreakFT->Enable(bKiosk);
             mpPage3PresTimeTMF->Enable(bKiosk);
@@ -1245,7 +1241,7 @@ IMPL_LINK( AssistentDlgImpl, PreviewFlagHdl, CheckBox *, EMPTYARG )
     if( maPreviewFlag.IsChecked() != mbPreview )
     {
         mbPreview = maPreviewFlag.IsChecked();
-        UpdatePreview(TRUE);
+        UpdatePreview(sal_True);
     }
     return 0;
 }
@@ -1274,11 +1270,11 @@ IMPL_LINK( AssistentDlgImpl, SelectFileHdl, ListBox *, EMPTYARG )
 
 IMPL_LINK( AssistentDlgImpl, PageSelectHdl, Control *, EMPTYARG )
 {
-    USHORT nPage = mpPage5PageListCT->GetSelectedPage();
+    sal_uInt16 nPage = mpPage5PageListCT->GetSelectedPage();
     if( mnShowPage != nPage )
     {
         mnShowPage = nPage;
-        UpdatePreview(FALSE);
+        UpdatePreview(sal_False);
     }
 
     return 0;
@@ -1292,7 +1288,7 @@ IMPL_LINK( AssistentDlgImpl, UpdatePageListHdl, void *, EMPTYARG )
 
 IMPL_LINK( AssistentDlgImpl, UpdatePreviewHdl, void *, EMPTYARG )
 {
-    UpdatePreview( TRUE );
+    UpdatePreview( sal_True );
     return 0;
 }
 
@@ -1349,7 +1345,7 @@ IMPL_LINK( AssistentDlgImpl, PresTypeHdl, RadioButton*, EMPTYARG )
         maNextPageButton.Enable(false);
       }
 
-    BOOL bKiosk = mpPage3PresTypeKioskRB->IsChecked();
+    sal_Bool bKiosk = mpPage3PresTypeKioskRB->IsChecked();
     mpPage3PresTimeFT->Enable(bKiosk);
     mpPage3BreakFT->Enable(bKiosk);
     mpPage3PresTimeTMF->Enable(bKiosk);
@@ -1360,7 +1356,7 @@ IMPL_LINK( AssistentDlgImpl, PresTypeHdl, RadioButton*, EMPTYARG )
 
 IMPL_LINK( AssistentDlgImpl, UpdateUserDataHdl, Edit*, EMPTYARG )
 {
-    mbUserDataDirty = TRUE;
+    mbUserDataDirty = sal_True;
     String aTopic = mpPage4AskTopicEDT->GetText();
     String aName  = mpPage4AskNameEDT->GetText();
     String aInfo  = mpPage4AskInfoEDT->GetText();
@@ -1378,14 +1374,14 @@ void AssistentDlgImpl::SelectTemplateRegion( const String& rRegion )
 {
     mpPage1TemplateLB->Clear();
     std::vector<TemplateDir*>::iterator	I;
-    for (I=maPresentList.begin(); I!=maPresentList.end(); I++)
+    for (I=maPresentList.begin(); I!=maPresentList.end(); ++I)
     {
         TemplateDir * pDir = *I;
         mpTemplateRegion = *I;
         if (pDir->msRegion.Equals( rRegion ) )
         {
             std::vector<TemplateEntry*>::iterator	J;
-            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); J++)
+            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); ++J)
                 mpPage1TemplateLB->InsertEntry ((*J)->msTitle);
             mpPage1TemplateLB->Update();
             if(GetStartType() == ST_TEMPLATE)
@@ -1403,7 +1399,7 @@ void AssistentDlgImpl::SelectLayoutRegion( const String& rRegion )
     mpPage2LayoutLB->Clear();
     mpPage2LayoutLB->InsertEntry(String(SdResId(STR_WIZARD_ORIGINAL)));
     std::vector<TemplateDir*>::iterator	I;
-    for (I=maPresentList.begin(); I!=maPresentList.end(); I++)
+    for (I=maPresentList.begin(); I!=maPresentList.end(); ++I)
     {
         TemplateDir * pDir = *I;
         mpLayoutRegion = *I;
@@ -1411,7 +1407,7 @@ void AssistentDlgImpl::SelectLayoutRegion( const String& rRegion )
         if (pDir->msRegion.Equals (rRegion))
         {
             std::vector<TemplateEntry*>::iterator	J;
-            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); J++)
+            for (J=pDir->maEntries.begin(); J!=pDir->maEntries.end(); ++J)
                 mpPage2LayoutLB->InsertEntry ((*J)->msTitle);
             mpPage2LayoutLB->Update();
             break;
@@ -1433,7 +1429,7 @@ void AssistentDlgImpl::UpdateUserData()
     if(pPage && ( aTopic.Len() != 0 || aName.Len() != 0 || aInfo.Len() != 0 ) )
     {
         if( pPage->GetAutoLayout() == AUTOLAYOUT_NONE )
-            pPage->SetAutoLayout(AUTOLAYOUT_TITLE, TRUE);
+            pPage->SetAutoLayout(AUTOLAYOUT_TITLE, sal_True);
 
         SdrTextObj* pObj;
         String aEmptyString;
@@ -1444,8 +1440,8 @@ void AssistentDlgImpl::UpdateUserData()
             if( pObj )
             {
                 pPage->SetObjText( pObj, NULL, PRESOBJ_TITLE, aTopic );
-                pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_TITLE ), TRUE );
-                pObj->SetEmptyPresObj(FALSE);
+                pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_TITLE ), sal_True );
+                pObj->SetEmptyPresObj(sal_False);
             }
 
         }
@@ -1461,8 +1457,8 @@ void AssistentDlgImpl::UpdateUserData()
             if( pObj )
             {
                 pPage->SetObjText( pObj, NULL, PRESOBJ_OUTLINE, aStrTmp );
-                pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_OUTLINE ), TRUE );
-                pObj->SetEmptyPresObj(FALSE);
+                pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_OUTLINE ), sal_True );
+                pObj->SetEmptyPresObj(sal_False);
             }
             else
             {
@@ -1470,20 +1466,20 @@ void AssistentDlgImpl::UpdateUserData()
                 if( pObj )
                 {
                     pPage->SetObjText( pObj, NULL, PRESOBJ_TEXT, aStrTmp );
-                    pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_TEXT ), TRUE );
-                    pObj->SetEmptyPresObj(FALSE);
+                    pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( PRESOBJ_TEXT ), sal_True );
+                    pObj->SetEmptyPresObj(sal_False);
                 }
             }
         }
     }
 
-    mbUserDataDirty = FALSE;
+    mbUserDataDirty = sal_False;
 }
 
 void AssistentDlgImpl::UpdatePageList()
 {
     if(mbDocPreview || !mbPreview)
-        UpdatePreview(FALSE);
+        UpdatePreview(sal_False);
     else if(maPageListFile == maDocFile)
         return;
 
@@ -1499,20 +1495,20 @@ void AssistentDlgImpl::UpdatePageList()
         mpPage5PageListCT->Fill(pDoc);
 }
 
-void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
+void AssistentDlgImpl::UpdatePreview( sal_Bool bDocPreview )
 {
     // Guard against multiple concurrent execution to this method caused either
     // by calls from different threads or recursion.
     ::osl::MutexGuard aGuard (maMutex);
     if (mbPreviewUpdating)
         return;
-    mbPreviewUpdating = TRUE;
+    mbPreviewUpdating = sal_True;
 
     if(!mbPreview && bDocPreview)
     {
         maPreview.Invalidate();
         maPreview.SetObjectShell(0);
-        mbPreviewUpdating = FALSE;
+        mbPreviewUpdating = sal_False;
         return;
     }
 
@@ -1521,8 +1517,8 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
     String aEmptyStr;
 
     SfxApplication *pSfxApp = SFX_APP();
-    ULONG lErr;
-    BOOL bChangeMaster = aLayoutFile.Len() != 0;
+    sal_uLong lErr;
+    sal_Bool bChangeMaster = aLayoutFile.Len() != 0;
 
     if( aDocFile.Len() == 0 )
     {
@@ -1532,15 +1528,15 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
             CloseDocShell();
 
             DrawDocShell* pNewDocSh;
-            xDocShell = pNewDocSh = new DrawDocShell(SFX_CREATE_MODE_STANDARD, FALSE);
+            xDocShell = pNewDocSh = new DrawDocShell(SFX_CREATE_MODE_STANDARD, sal_False);
             pNewDocSh->DoInitNew(NULL);
             SdDrawDocument* pDoc = pNewDocSh->GetDoc();
             pDoc->CreateFirstPages();
             pDoc->StopWorkStartupDelay();
-            mbDocPreview = FALSE;
+            mbDocPreview = sal_False;
 
             maDocFile = aDocFile;
-            mbUserDataDirty = TRUE;
+            mbUserDataDirty = sal_True;
         }
         else
             bChangeMaster = (aLayoutFile.Len() != 0) && (maLayoutFile != aLayoutFile);
@@ -1551,13 +1547,13 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
         {
             SfxObjectShell* pShell = xDocShell;
             DrawDocShell* pDocShell = PTR_CAST(DrawDocShell,pShell);
-            SfxUndoManager* pUndoMgr = pDocShell?pDocShell->GetUndoManager():NULL;
+            ::svl::IUndoManager* pUndoMgr = pDocShell?pDocShell->GetUndoManager():NULL;
             if(pUndoMgr)
                 pUndoMgr->Undo();
-            mbUserDataDirty = TRUE;
+            mbUserDataDirty = sal_True;
         }
         else
-            bChangeMaster = FALSE;
+            bChangeMaster = sal_False;
     }
     else
     {
@@ -1571,11 +1567,11 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
         SfxItemSet* pSet = new SfxAllItemSet( pSfxApp->GetPool() );
         if(IsOwnFormat(aDocFile))
         {
-            pSet->Put( SfxBoolItem( SID_TEMPLATE, TRUE ) );
+            pSet->Put( SfxBoolItem( SID_TEMPLATE, sal_True ) );
             if(bDocPreview)
-                pSet->Put( SfxBoolItem( SID_PREVIEW, TRUE ) );
+                pSet->Put( SfxBoolItem( SID_PREVIEW, sal_True ) );
             RestorePassword( pSet, aDocFile );
-            if( (lErr = pSfxApp->LoadTemplate( xDocShell, aDocFile, TRUE, pSet )) != 0 )
+            if( (lErr = pSfxApp->LoadTemplate( xDocShell, aDocFile, sal_True, pSet )) != 0 )
                 ErrorHandler::HandleError(lErr);
             else
                 SavePassword( xDocShell, aDocFile );
@@ -1588,7 +1584,7 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
             aReq.AppendItem( SfxStringItem( SID_FILE_NAME, aDocFile ));
             aReq.AppendItem( SfxStringItem( SID_REFERER, aEmptyStr ) );
             aReq.AppendItem( SfxStringItem( SID_TARGETNAME, aTargetStr ) );
-            aReq.AppendItem( SfxBoolItem( SID_HIDDEN, TRUE ) );
+            aReq.AppendItem( SfxBoolItem( SID_HIDDEN, sal_True ) );
             aReq.AppendItem( SfxBoolItem( SID_PREVIEW, bDocPreview ) );
 
             const SfxViewFrameItem* pRet = PTR_CAST( SfxViewFrameItem, SFX_APP()->ExecuteSlot( aReq ) );
@@ -1603,7 +1599,7 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
         mnShowPage = 0;
         mbDocPreview = bDocPreview;
         maDocFile = aDocFile;
-        mbUserDataDirty = TRUE;
+        mbUserDataDirty = sal_True;
     }
 
     if(bChangeMaster && (aLayoutFile != maDocFile))
@@ -1618,11 +1614,11 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
 
         if(IsOwnFormat(aLayoutFile))
         {
-            pSet->Put( SfxBoolItem( SID_TEMPLATE, TRUE ) );
-            pSet->Put( SfxBoolItem( SID_PREVIEW, TRUE ) );
+            pSet->Put( SfxBoolItem( SID_TEMPLATE, sal_True ) );
+            pSet->Put( SfxBoolItem( SID_PREVIEW, sal_True ) );
 
             RestorePassword( pSet, aLayoutFile );
-            if( (lErr = pSfxApp->LoadTemplate( xLayoutDocShell, aLayoutFile, TRUE, pSet )) != 0 )
+            if( (lErr = pSfxApp->LoadTemplate( xLayoutDocShell, aLayoutFile, sal_True, pSet )) != 0 )
                 ErrorHandler::HandleError(lErr);
             SavePassword( xLayoutDocShell, aLayoutFile );
         }
@@ -1640,14 +1636,14 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
 
         if( pDoc && pLayoutDoc )
         {
-            pDoc->SetMasterPage(0, aEmptyStr, pLayoutDoc, TRUE,  FALSE );
+            pDoc->SetMasterPage(0, aEmptyStr, pLayoutDoc, sal_True,  sal_False );
         }
         else
         {
-            DBG_ERROR("sd::AssistentDlgImpl::UpdatePreview(), no document for preview?");
+            OSL_FAIL("sd::AssistentDlgImpl::UpdatePreview(), no document for preview?");
         }
 
-        mbUserDataDirty = TRUE;
+        mbUserDataDirty = sal_True;
     }
     maLayoutFile = aLayoutFile;
 
@@ -1661,7 +1657,7 @@ void AssistentDlgImpl::UpdatePreview( BOOL bDocPreview )
         maPreview.SetObjectShell( xDocShell, mnShowPage );
     }
 
-    mbPreviewUpdating = FALSE;
+    mbPreviewUpdating = sal_False;
 }
 
 void AssistentDlgImpl::SavePassword( SfxObjectShellLock xDoc, const String& rPath )
@@ -1673,28 +1669,28 @@ void AssistentDlgImpl::SavePassword( SfxObjectShellLock xDoc, const String& rPat
         {
             SfxItemSet * pSet = pMedium->GetItemSet();
           const SfxPoolItem *pItem = 0;
-          if( pSet->GetItemState(SID_PASSWORD, TRUE, &pItem) == SFX_ITEM_SET )
+          if( pSet->GetItemState(SID_PASSWORD, sal_True, &pItem) == SFX_ITEM_SET )
           {
             //TODO/MBA: testing
             String aPass( ((const SfxStringItem*)pItem)->GetValue());
             if(aPass.Len() == 0)
                 return;
 
-            PasswordEntry* pEntry = maPasswordList.First();
-            while(pEntry)
+            PasswordEntry* pEntry = NULL;
+            for ( size_t i = 0, n = maPasswordList.size(); i < n; ++i )
             {
-                if(pEntry->maPath == rPath)
+                if ( maPasswordList[ i ]->maPath == rPath )
+                {
+                    pEntry = maPasswordList[ i ];
                     break;
-
-                pEntry = maPasswordList.Next();
-
+                }
             }
 
             if(pEntry == NULL)
             {
                 pEntry = new PasswordEntry();
                 pEntry->maPath = rPath;
-                maPasswordList.Insert( pEntry );
+                maPasswordList.push_back( pEntry );
             }
 
             if(pEntry)
@@ -1714,29 +1710,23 @@ void AssistentDlgImpl::RestorePassword( SfxItemSet* pSet, const String& rPath )
 
 String AssistentDlgImpl::GetPassword( const String rPath )
 {
-    PasswordEntry* pEntry = maPasswordList.First();
-    while(pEntry)
+    for ( size_t i = 0, n = maPasswordList.size(); i < n; ++i )
     {
+        PasswordEntry* pEntry = maPasswordList[ i ];
         if(pEntry->maPath == rPath)
             return pEntry->maPassword;
-
-        pEntry = maPasswordList.Next();
     }
-
     return String();
 }
 
 void AssistentDlgImpl::DeletePassords()
 {
-    PasswordEntry* pEntry = maPasswordList.First();
-    while(pEntry)
-    {
-        delete pEntry;
-        pEntry = maPasswordList.Next();
-    }
+    for ( size_t i = 0, n = maPasswordList.size(); i < n; ++i )
+        delete maPasswordList[ i ];
+    maPasswordList.clear();
 }
 
-BOOL AssistentDlgImpl::IsOwnFormat( const String& rPath )
+sal_Bool AssistentDlgImpl::IsOwnFormat( const String& rPath )
 {
     INetURLObject	aURL( rPath );
     String			aExt( aURL.GetFileExtension() );
@@ -1789,7 +1779,7 @@ String AssistentDlgImpl::GetUiTextForCommand (const ::rtl::OUString& sCommandURL
                 for (sal_Int32 i=0; i<nCount; i++)
                 {
                     ::rtl::OUString sPropertyName (aProperties[i].Name);
-                    if (sPropertyName.equalsAscii("Label"))
+                    if (sPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Label")))
                     {
                         aProperties[i].Value >>= sString;
                         break;
@@ -1868,7 +1858,7 @@ Image AssistentDlgImpl::GetUiIconForCommand (const ::rtl::OUString& sCommandURL)
 
 //////////////////////////////////////////////
 
-AssistentDlg::AssistentDlg(Window* pParent, BOOL bAutoPilot) :
+AssistentDlg::AssistentDlg(Window* pParent, sal_Bool bAutoPilot) :
     ModalDialog(pParent,SdResId(DLG_ASS))
 {
     Link aFinishLink = LINK(this,AssistentDlg, FinishHdl);
@@ -1902,7 +1892,7 @@ IMPL_LINK( AssistentDlg, FinishHdl, OKButton *, EMPTYARG )
                 INetURLObject aURL;
                 aURL.SetSmartURL(aFileToOpen);
                 mpImpl->maOpenFilesList.push_back (new String (aURL.GetMainURL( INetURLObject::NO_DECODE )));
-                USHORT nNewPos = mpImpl->mpPage1OpenLB->InsertEntry(aURL.getName());
+                sal_uInt16 nNewPos = mpImpl->mpPage1OpenLB->InsertEntry(aURL.getName());
                 mpImpl->mpPage1OpenLB->SelectEntryPos(nNewPos);
             }
         }
@@ -1939,7 +1929,7 @@ OutputType AssistentDlg::GetOutputMedium() const
         return OUTPUT_ORIGINAL;
 }
 
-BOOL AssistentDlg::IsSummary() const
+sal_Bool AssistentDlg::IsSummary() const
 {
     return mpImpl->mpPage5SummaryCB->IsChecked();
 }
@@ -1954,12 +1944,12 @@ String AssistentDlg::GetDocPath() const
     return mpImpl->GetDocFileName();
 }
 
-BOOL AssistentDlg::GetStartWithFlag() const
+sal_Bool AssistentDlg::GetStartWithFlag() const
 {
     return !mpImpl->maStartWithFlag.IsChecked();
 }
 
-BOOL AssistentDlg::IsDocEmpty() const
+sal_Bool AssistentDlg::IsDocEmpty() const
 {
     return mpImpl->GetDocFileName().Len() == 0 &&
            mpImpl->GetLayoutFileName().Len() == 0;
