@@ -33,7 +33,7 @@
 #include <sfx2/filedlghelper.hxx>
 #include <sfx2/sfx.hrc>
 #include <sfx2/docfac.hxx>
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 #include <osl/thread.h>
 #include <com/sun/star/ui/dialogs/XFilterGroupManager.hpp>
 #include <com/sun/star/beans/StringPair.hpp>
@@ -224,7 +224,7 @@ namespace sfx2
             if ( m_aClassReferrer.end() == aClassRef )
             {
                 // we do not know this global class
-                DBG_ERROR( "ReadGlobalFilter::operator(): unknown filter name!" );
+                OSL_FAIL( "ReadGlobalFilter::operator(): unknown filter name!" );
                 // TODO: perhaps we should be more tolerant - at the moment, the filter is dropped
                 // We could silently push_back it to the container ....
             }
@@ -693,12 +693,6 @@ namespace sfx2
             FilterGroupEntryReferrer::iterator aBelongsToLocal = aLocalClassesRef.find( sFilterName );
             if ( aLocalClassesRef.end() != aBelongsToLocal )
             {
-/*
-#ifdef DBG_UTIL
-                const ::rtl::OUString& rLocalClassDisplayName = aBelongsToLocal->second->First;
-                const ::rtl::OUString& rLocalClassExtension = aBelongsToLocal->second->Second;
-#endif
-*/
                 // okay, there is a local class which the filter belongs to
                 // -> append the wildcard
                 aExtendWildcard( *aBelongsToLocal );
@@ -832,7 +826,7 @@ namespace sfx2
 #ifdef DBG_UTIL
                 ByteString aMsg( "sfx2::lcl_EnsureAllFilesEntry: could not append Filter" );
                 aMsg += ByteString( String( sAllFilterName ), RTL_TEXTENCODING_UTF8 );
-                DBG_ERROR( aMsg.GetBuffer() );
+                OSL_FAIL( aMsg.GetBuffer() );
 #endif
             }
         }
@@ -920,7 +914,7 @@ namespace sfx2
         {
             ::comphelper::SequenceAsHashMap lFilterProps (xFilterList->nextElement());
             ::rtl::OUString                 sFilterName  = lFilterProps.getUnpackedValueOrDefault(
-                                                             ::rtl::OUString::createFromAscii("Name"),
+                                                             ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name")),
                                                              ::rtl::OUString());
             if (sFilterName.getLength())
                 m_lFilters.push_back(sFilterName);
@@ -968,10 +962,9 @@ namespace sfx2
         // retrieve the default filter for this application module.
         // It must be set as first of the generated filter list.
         const SfxFilter* pDefaultFilter = SfxFilterContainer::GetDefaultFilter_Impl(_rFactory);
-        // --> PB 2004-11-01 #i32434# only use one extension
+        // Only use one extension (#i32434#)
         // (and always the first if there are more than one)
         sExtension = pDefaultFilter->GetWildcard().GetWildCard().GetToken( 0, ';' );
-        // <--
         sUIName = addExtension( pDefaultFilter->GetUIName(), sExtension, sal_False, _rFileDlgImpl );
         try
         {
@@ -993,10 +986,9 @@ namespace sfx2
             if (pFilter->GetName() == pDefaultFilter->GetName())
                 continue;
 
-            // --> PB 2004-09-21 #i32434# only use one extension
+            // Only use one extension (#i32434#)
             // (and always the first if there are more than one)
             sExtension = pFilter->GetWildcard().GetWildCard().GetToken( 0, ';' );
-            // <--
             sUIName = addExtension( pFilter->GetUIName(), sExtension, sal_False, _rFileDlgImpl );
             try
             {
@@ -1076,9 +1068,9 @@ namespace sfx2
             {
                 std::vector< ExportFilter >::iterator aIter = aImportantFilterGroup.begin();
                 if ( nHTMLIndex != -1 )
-                    aIter++;
+                    ++aIter;
                 if ( nXHTMLIndex != -1 )
-                    aIter++;
+                    ++aIter;
                 aImportantFilterGroup.insert( aIter, aExportFilter );
                 nPDFIndex = 0;
             }
@@ -1086,11 +1078,11 @@ namespace sfx2
             {
                 std::vector< ExportFilter >::iterator aIter = aImportantFilterGroup.begin();
                 if ( nHTMLIndex != -1 )
-                    aIter++;
+                    ++aIter;
                 if ( nXHTMLIndex != -1 )
-                    aIter++;
+                    ++aIter;
                 if ( nPDFIndex != -1 )
-                    aIter++;
+                    ++aIter;
                 aImportantFilterGroup.insert( aIter, aExportFilter );
                 nFlashIndex = 0;
             }
