@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -52,19 +52,19 @@
 #include <com/sun/star/security/XDocumentDigitalSignatures.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/frame/XDispatch.hpp>
+#include <com/sun/star/frame/XStatusListener.hpp>
 #include <com/sun/star/ucb/InsertCommandArgument.hpp>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
 #include <com/sun/star/document/XExporter.hpp>
-
 #include <rtl/textenc.h>
 #include <rtl/uri.h>
 #include <rtl/uri.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <vcl/msgbox.hxx>
 
-#include <mailmodelapi.hxx>
+#include <sfx2/mailmodelapi.hxx>
 #include "sfxtypes.hxx"
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 #include <sfx2/sfxsids.hrc>
 #include "dialog.hrc"
 
@@ -81,6 +81,7 @@
 #include <comphelper/mediadescriptor.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
+#include <cppuhelper/implbase1.hxx>
 
 // --------------------------------------------------------------
 using namespace ::com::sun::star;
@@ -95,11 +96,54 @@ using namespace ::com::sun::star::system;
 using namespace ::rtl;
 
 namespace css = ::com::sun::star;
+// - class PrepareListener_Impl ------------------------------------------
+class PrepareListener_Impl : public ::cppu::WeakImplHelper1< css::frame::XStatusListener >
+{
+    bool m_bState;
+public:
+        PrepareListener_Impl();
+        virtual ~PrepareListener_Impl();
 
-// class AddressList_Impl ------------------------------------------------
+        // css.frame.XStatusListener
+        virtual void SAL_CALL statusChanged(const css::frame::FeatureStateEvent& aEvent)
+          throw(css::uno::RuntimeException);
 
-typedef String* AddressItemPtr_Impl;
-DECLARE_LIST( AddressList_Impl, AddressItemPtr_Impl )
+        // css.lang.XEventListener
+        virtual void SAL_CALL disposing(const css::lang::EventObject& aEvent)
+          throw(css::uno::RuntimeException);
+
+        bool IsSet() const {return m_bState;}
+};
+
+/*-- 25.08.2010 14:32:49---------------------------------------------------
+
+  -----------------------------------------------------------------------*/
+PrepareListener_Impl::PrepareListener_Impl() : 
+    m_bState( false )
+{
+}
+/*-- 25.08.2010 14:32:51---------------------------------------------------
+
+  -----------------------------------------------------------------------*/
+PrepareListener_Impl::~PrepareListener_Impl()
+{
+}
+/*-- 25.08.2010 14:32:51---------------------------------------------------
+
+  -----------------------------------------------------------------------*/
+void PrepareListener_Impl::statusChanged(const css::frame::FeatureStateEvent& rEvent) throw(css::uno::RuntimeException)
+{
+    if( rEvent.IsEnabled ) 
+        rEvent.State >>= m_bState;
+    else
+        m_bState = sal_False;
+}
+/*-- 25.08.2010 14:32:52---------------------------------------------------
+
+  -----------------------------------------------------------------------*/
+void PrepareListener_Impl::disposing(const css::lang::EventObject& /*rEvent*/) throw(css::uno::RuntimeException)
+{
+}
 
 // class SfxMailModel -----------------------------------------------
 
@@ -110,10 +154,9 @@ void SfxMailModel::ClearList( AddressList_Impl* pList )
 {
     if ( pList )
     {
-        ULONG i, nCount = pList->Count();
-        for ( i = 0; i < nCount; ++i )
-            delete pList->GetObject(i);
-        pList->Clear();
+        for( size_t i = 0, n = pList->size(); i < n; ++i )
+            delete pList->at(i);
+        pList->clear();
     }
 }
 
@@ -122,12 +165,11 @@ void SfxMailModel::MakeValueList( AddressList_Impl* pList, String& rValueList )
     rValueList.Erase();
     if ( pList )
     {
-        ULONG i, nCount = pList->Count();
-        for ( i = 0; i < nCount; ++i )
+        for( size_t i = 0, n = pList->size(); i < n; ++i )
         {
             if ( rValueList.Len() > 0 )
                 rValueList += ',';
-            rValueList += *pList->GetObject(i);
+            rValueList += *pList->at(i);
         }
     }
 }
@@ -173,7 +215,7 @@ SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
             ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > xFilterCFG =
                 uno::Reference< container::XNameAccess >(
                     xSMGR->createInstance(
-                        ::rtl::OUString::createFromAscii( "com.sun.star.document.FilterFactory" ) ), uno::UNO_QUERY );
+                        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.FilterFactory")) ), uno::UNO_QUERY );
         css::uno::Reference< css::util::XModifiable > xModifiable( xModel, css::uno::UNO_QUERY );
 
         if ( !xFilterCFG.is() )
@@ -186,7 +228,7 @@ SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
             sal_Int32 nPropertyCount = aProps.getLength();
             for( sal_Int32 nProperty=0; nProperty < nPropertyCount; ++nProperty )
             {
-                if( aProps[nProperty].Name.equals( ::rtl::OUString::createFromAscii( "UIComponent" )) )
+                if( aProps[nProperty].Name.equals( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("UIComponent"))) )
                 {
                     ::rtl::OUString aServiceName;
                     aProps[nProperty].Value >>= aServiceName;
@@ -233,7 +275,7 @@ SfxMailModel::SaveResult SfxMailModel::ShowFilterOptionsDialog(
                                 //add them to the args
                                 for ( sal_Int32 nInd = 0; nInd < aPropsFromDialog.getLength(); nInd++ )
                                 {
-                                    if( aPropsFromDialog[ nInd ].Name.equals( ::rtl::OUString::createFromAscii( "FilterData" ) ) )
+                                    if( aPropsFromDialog[ nInd ].Name.equals( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FilterData")) ) )
                                     {
                                         //found the filterdata, add to the storing argument
                                         rArgs.realloc( ++rNumArgs );
@@ -393,7 +435,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                 {
                     ::comphelper::SequenceAsHashMap aFilterPropsHM( xEnumeration->nextElement() );
                     aFilterName = aFilterPropsHM.getUnpackedValueOrDefault(
-                                                ::rtl::OUString::createFromAscii( "Name" ),
+                                                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name")),
                                                 ::rtl::OUString() );
                 }
 
@@ -432,7 +474,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     {
                         ::comphelper::SequenceAsHashMap aFilterPropsHM( xNameAccess->getByName( aModule ) );
                         aFilterName = aFilterPropsHM.getUnpackedValueOrDefault(
-                                                    ::rtl::OUString::createFromAscii( "ooSetupFactoryDefaultFilter" ),
+                                                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ooSetupFactoryDefaultFilter")),
                                                     ::rtl::OUString() );
                         css::uno::Reference< css::container::XNameAccess > xNameAccess2(
                             xContainerQuery, css::uno::UNO_QUERY );
@@ -440,7 +482,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                         {
                             ::comphelper::SequenceAsHashMap aFilterPropsHM2( xNameAccess2->getByName( aFilterName ) );
                             aTypeName = aFilterPropsHM2.getUnpackedValueOrDefault(
-                                                        ::rtl::OUString::createFromAscii( "Type" ),
+                                                        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Type")),
                                                         ::rtl::OUString() );
                         }
                     }
@@ -479,7 +521,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                     {
                         ::comphelper::SequenceAsHashMap aTypeNamePropsHM( xTypeDetection->getByName( aTypeName ) );
                         uno::Sequence< ::rtl::OUString > aExtensions = aTypeNamePropsHM.getUnpackedValueOrDefault(
-                                                        ::rtl::OUString::createFromAscii( "Extensions" ),
+                                                        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Extensions")),
                                                         ::uno::Sequence< ::rtl::OUString >() );
                         if ( aExtensions.getLength() )
                             aExtension = aExtensions[0];
@@ -544,46 +586,68 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
                 aArgs[nNumArgs-1].Value = css::uno::makeAny( aPassword );
             }
 
-            if ( bModified || !bHasLocation || bStoreTo )
+            bool bNeedsPreparation = false;
+            css::util::URL aPrepareURL;
+            css::uno::Reference< css::frame::XDispatch > xPrepareDispatch;
+            css::uno::Reference< css::frame::XDispatchProvider > xDispatchProvider( xFrame, css::uno::UNO_QUERY );
+            css::uno::Reference< css::util::XURLTransformer > xURLTransformer(
+                        xSMGR->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.util.URLTransformer" ))),
+                        css::uno::UNO_QUERY );
+            if( !bSendAsPDF )
+            {
+                try
+                {
+                    // check if the document needs to be prepared for sending as mail (embedding of links, removal of invisible content)
+
+                    if ( xURLTransformer.is() )
+                    {
+                        aPrepareURL.Complete = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:PrepareMailExport" ));
+                        xURLTransformer->parseStrict( aPrepareURL );
+                    }
+
+                    if ( xDispatchProvider.is() )
+                    {
+                        xPrepareDispatch = css::uno::Reference< css::frame::XDispatch >(
+                            xDispatchProvider->queryDispatch( aPrepareURL, ::rtl::OUString(), 0 ));
+                        if ( xPrepareDispatch.is() )
+                        {
+                                PrepareListener_Impl* pPrepareListener;
+                                uno::Reference< css::frame::XStatusListener > xStatusListener = pPrepareListener = new PrepareListener_Impl;
+                                xPrepareDispatch->addStatusListener( xStatusListener, aPrepareURL );
+                                bNeedsPreparation = pPrepareListener->IsSet();
+                                xPrepareDispatch->removeStatusListener( xStatusListener, aPrepareURL );
+                        }
+                    }
+                }
+                catch ( css::uno::RuntimeException& )
+                {
+                    throw;
+                }
+                catch ( css::uno::Exception& )
+                {
+                }
+            }
+            
+            if ( bModified || !bHasLocation || bStoreTo || bNeedsPreparation )
             {
                 // Document is modified, is newly created or should be stored in a special format
                 try
                 {
-                    css::uno::Reference< css::util::XURLTransformer > xURLTransformer(
-                        xSMGR->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.util.URLTransformer" ))),
-                        css::uno::UNO_QUERY );
-
-                    css::uno::Reference< css::frame::XDispatchProvider > xDispatchProvider( xFrame, css::uno::UNO_QUERY );
-                    css::uno::Reference< css::frame::XDispatch > xDispatch;
-
-                    css::util::URL aURL;
-                    css::uno::Sequence< css::beans::PropertyValue > aDispatchArgs;
-
-                    if( !bSendAsPDF )
+                    if( bNeedsPreparation && xPrepareDispatch.is() )
                     {
-                        if ( xURLTransformer.is() )
+                        if ( xPrepareDispatch.is() )
                         {
-                            aURL.Complete = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:PrepareMailExport" ));
-                            xURLTransformer->parseStrict( aURL );
-                        }
-
-                        if ( xDispatchProvider.is() )
-                        {
-                            xDispatch = css::uno::Reference< css::frame::XDispatch >(
-                                xDispatchProvider->queryDispatch( aURL, ::rtl::OUString(), 0 ));
-                            if ( xDispatch.is() )
+                            try
+                            {
+                                css::uno::Sequence< css::beans::PropertyValue > aDispatchArgs;
+                                xPrepareDispatch->dispatch( aPrepareURL, aDispatchArgs );
+                            }
+                            catch ( css::uno::RuntimeException& )
+                            {
+                                throw;
+                            }
+                            catch ( css::uno::Exception& )
                             {
-                                try
-                                {
-                                    xDispatch->dispatch( aURL, aDispatchArgs );
-                                }
-                                catch ( css::uno::RuntimeException& )
-                                {
-                                    throw;
-                                }
-                                catch ( css::uno::Exception& )
-                                {
-                                }
                             }
                         }
                     }
@@ -605,6 +669,7 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
 
                     if( !bSendAsPDF )
                     {
+                        css::util::URL aURL;
                         // #i30432# notify that export is finished - the Writer may want to restore removed content
                         if ( xURLTransformer.is() )
                         {
@@ -614,12 +679,13 @@ SfxMailModel::SaveResult SfxMailModel::SaveDocumentAsFormat(
 
                         if ( xDispatchProvider.is() )
                         {
-                            xDispatch = css::uno::Reference< css::frame::XDispatch >(
+                            css::uno::Reference< css::frame::XDispatch > xDispatch = css::uno::Reference< css::frame::XDispatch >(
                                 xDispatchProvider->queryDispatch( aURL, ::rtl::OUString(), 0 ));
                             if ( xDispatch.is() )
                             {
                                 try
                                 {
+                                    css::uno::Sequence< css::beans::PropertyValue > aDispatchArgs;
                                     xDispatch->dispatch( aURL, aDispatchArgs );
                                 }
                                 catch ( css::uno::RuntimeException& )
@@ -704,21 +770,21 @@ void SfxMailModel::AddAddress( const String& rAddress, AddressRole eRole )
         {
             if ( !mpToList )
                 // create the list
-                mpToList = new AddressList_Impl;
+                mpToList = new AddressList_Impl();
             pList = mpToList;
         }
         else if ( ROLE_CC == eRole )
         {
             if ( !mpCcList )
                 // create the list
-                mpCcList = new AddressList_Impl;
+                mpCcList = new AddressList_Impl();
             pList = mpCcList;
         }
         else if ( ROLE_BCC == eRole )
         {
             if ( !mpBccList )
                 // create the list
-                mpBccList = new AddressList_Impl;
+                mpBccList = new AddressList_Impl();
             pList = mpBccList;
         }
         else
@@ -730,7 +796,7 @@ void SfxMailModel::AddAddress( const String& rAddress, AddressRole eRole )
         {
             // add address to list
             AddressItemPtr_Impl pAddress = new String( rAddress );
-            pList->Insert( pAddress, LIST_APPEND );
+            pList->push_back( pAddress );
         }
     }
 }
@@ -793,63 +859,63 @@ SfxMailModel::SendMailResult SfxMailModel::Send( const css::uno::Reference< css:
                     }
                     xSimpleMailMessage->setOriginator( maFromAddress );
 
-                    sal_Int32 nToCount		= mpToList ? mpToList->Count() : 0;
-                    sal_Int32 nCcCount		= mpCcList ? mpCcList->Count() : 0;
-                    sal_Int32 nCcSeqCount	= nCcCount;
+                    size_t nToCount		= mpToList ? mpToList->size() : 0;
+                    size_t nCcCount		= mpCcList ? mpCcList->size() : 0;
+                    size_t nCcSeqCount	= nCcCount;
 
                     // set recipient (only one) for this simple mail server!!
                     if ( nToCount > 1 )
                     {
                         nCcSeqCount = nToCount - 1 + nCcCount;
-                        xSimpleMailMessage->setRecipient( *mpToList->GetObject( 0 ));
+                        xSimpleMailMessage->setRecipient( *mpToList->at( 0 ) );
                         nSendFlags = SimpleMailClientFlags::NO_USER_INTERFACE;
                     }
                     else if ( nToCount == 1 )
                     {
-                        xSimpleMailMessage->setRecipient( *mpToList->GetObject( 0 ));
+                        xSimpleMailMessage->setRecipient( *mpToList->at( 0 ) );
                         nSendFlags = SimpleMailClientFlags::NO_USER_INTERFACE;
                     }
 
                     // all other recipient must be handled with CC recipients!
                     if ( nCcSeqCount > 0 )
                     {
-                        sal_Int32				nIndex = 0;
-                        Sequence< OUString >	aCcRecipientSeq;
+                        size_t                  nIndex = 0;
+                        Sequence< OUString >    aCcRecipientSeq;
 
                         aCcRecipientSeq.realloc( nCcSeqCount );
                         if ( nCcSeqCount > nCcCount )
                         {
-                            for ( sal_Int32 i = 1; i < nToCount; ++i )
+                            for ( size_t i = 1; i < nToCount; ++i )
                             {
-                                aCcRecipientSeq[nIndex++] = *mpToList->GetObject(i);
+                                aCcRecipientSeq[nIndex++] = *mpToList->at(i);
                             }
                         }
 
-                        for ( sal_Int32 i = 0; i < nCcCount; i++ )
+                        for ( size_t i = 0; i < nCcCount; i++ )
                         {
-                            aCcRecipientSeq[nIndex++] = *mpCcList->GetObject(i);
+                            aCcRecipientSeq[nIndex++] = *mpCcList->at(i);
                         }
                         xSimpleMailMessage->setCcRecipient( aCcRecipientSeq );
                     }
 
-                    sal_Int32 nBccCount = mpBccList ? mpBccList->Count() : 0;
+                    size_t nBccCount = mpBccList ? mpBccList->size() : 0;
                     if ( nBccCount > 0 )
                     {
                         Sequence< OUString > aBccRecipientSeq( nBccCount );
-                        for ( sal_Int32 i = 0; i < nBccCount; ++i )
+                        for ( size_t i = 0; i < nBccCount; ++i )
                         {
-                            aBccRecipientSeq[i] = *mpBccList->GetObject(i);
+                            aBccRecipientSeq[i] = *mpBccList->at(i);
                         }
                         xSimpleMailMessage->setBccRecipient( aBccRecipientSeq );
                     }
 
                     Sequence< OUString > aAttachmentSeq(&(maAttachedDocuments[0]),maAttachedDocuments.size());
- 
+
                     if ( xSimpleMailMessage->getSubject().getLength() == 0 ) {
                         OUString baseName( maAttachedDocuments[0].copy( maAttachedDocuments[0].lastIndexOf( '/' ) + 1 ) );
                         OUString subject( baseName );
                         if ( maAttachedDocuments.size() > 1 )
-                            subject += OUString::createFromAscii( ", ..." );
+                            subject += OUString(RTL_CONSTASCII_USTRINGPARAM(", ..."));
                         xSimpleMailMessage->setSubject( subject );
                     }
                     xSimpleMailMessage->setAttachement( aAttachmentSeq );
@@ -911,19 +977,18 @@ SfxMailModel::SendMailResult SfxMailModel::SaveAndSend( const css::uno::Referenc
 
 // functions -------------------------------------------------------------
 
-BOOL CreateFromAddress_Impl( String& rFrom )
+sal_Bool CreateFromAddress_Impl( String& rFrom )
 
-/*	[Beschreibung]
+/* [Description]
 
-    Diese Funktion versucht mit Hilfe des IniManagers eine From-Adresse
-    zu erzeugen. daf"ur werden die Felder 'Vorname', 'Name' und 'EMail'
-    aus der Applikations-Ini-Datei ausgelesen. Sollten diese Felder
-    nicht gesetzt sein, wird FALSE zur"uckgegeben.
+    This function tries to create a From-address with the help of IniManagers.
+    For this the fields 'first name', 'Name' and 'Email' are read from the
+    application-ini-data. If these fields are not set, FALSE is returned.
 
-    [R"uckgabewert]
+    [Return value]
 
-    TRUE:	Adresse konnte erzeugt werden.
-    FALSE:	Adresse konnte nicht erzeugt werden.
+    sal_True:       Address could be created.
+    sal_False:      Address could not be created.
 */
 
 {
@@ -940,14 +1005,14 @@ BOOL CreateFromAddress_Impl( String& rFrom )
                 rFrom += ' ';
         }
         rFrom += TRIM( aName );
-        // unerlaubte Zeichen entfernen
+        // remove illegal characters
         rFrom.EraseAllChars( '<' );
         rFrom.EraseAllChars( '>' );
         rFrom.EraseAllChars( '@' );
     }
     String aEmailName = aUserCFG.GetEmail();
 
-    // unerlaubte Zeichen entfernen
+    // remove illegal characters
     aEmailName.EraseAllChars( '<' );
     aEmailName.EraseAllChars( '>' );
 
