@@ -687,7 +687,7 @@ UserEventQueue::~UserEventQueue()
         clear();
     }
     catch (uno::Exception &) {
-        OSL_ENSURE( false, rtl::OUStringToOString(
+        OSL_FAIL( rtl::OUStringToOString(
                         comphelper::anyToString(
                             cppu::getCaughtException() ),
                         RTL_TEXTENCODING_UTF8 ).getStr() );
