@@ -45,11 +45,9 @@
 using namespace ::com::sun::star::uno;
 using namespace ::rtl;
 
-#define C2U(cChar) OUString::createFromAscii(cChar)
+#define C2U(cChar) OUString(RTL_CONSTASCII_USTRINGPARAM(cChar))
 #define CFG_READONLY_DEFAULT sal_False
-/* -----------------------------10.04.01 12:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 class SvtCJKOptions_Impl : public utl::ConfigItem
 {
     sal_Bool        bIsLoaded;
@@ -99,9 +97,7 @@ public:
     void    SetAll(sal_Bool bSet);
     sal_Bool IsReadOnly(SvtCJKOptions::EOption eOption) const;
 };
-/*-- 10.04.01 12:41:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 namespace
 { 
     struct PropertyNames 
@@ -131,15 +127,11 @@ SvtCJKOptions_Impl::SvtCJKOptions_Impl() :
     bROVerticalCallOut(CFG_READONLY_DEFAULT)
 {
 }
-/*-- 10.04.01 12:41:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SvtCJKOptions_Impl::~SvtCJKOptions_Impl()
 {
 }
-/* -----------------------------20.04.01 14:34--------------------------------
 
- ---------------------------------------------------------------------------*/
 void    SvtCJKOptions_Impl::SetAll(sal_Bool bSet)
 {
     if (
@@ -169,9 +161,7 @@ void    SvtCJKOptions_Impl::SetAll(sal_Bool bSet)
         NotifyListeners(0);
     }
 }
-/*-- 10.04.01 12:41:56---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SvtCJKOptions_Impl::Load()
 {
     Sequence<OUString> &rPropertyNames = PropertyNames::get();
@@ -233,17 +223,13 @@ void SvtCJKOptions_Impl::Load()
     }
     bIsLoaded = sal_True;
 }
-/*-- 10.04.01 12:41:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void    SvtCJKOptions_Impl::Notify( const Sequence< OUString >& )
 {
     Load();
     NotifyListeners(0);
 }
-/*-- 10.04.01 12:41:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void    SvtCJKOptions_Impl::Commit()
 {
     Sequence<OUString> &rPropertyNames = PropertyNames::get();
@@ -366,9 +352,7 @@ void    SvtCJKOptions_Impl::Commit()
     aValues.realloc(nRealCount);
     PutProperties(aNames, aValues);
 }
-/*-- 13.02.2003 12:12---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SvtCJKOptions_Impl::IsReadOnly(SvtCJKOptions::EOption eOption) const
 {
     sal_Bool bReadOnly = CFG_READONLY_DEFAULT;
@@ -478,25 +462,19 @@ sal_Bool SvtCJKOptions::IsVerticalCallOutEnabled() const
     DBG_ASSERT(pCJKOptions->IsLoaded(), "CJK options not loaded");
     return pCJKOptions->IsVerticalCallOutEnabled();
 }
-/*-- 20.04.01 14:32:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void        SvtCJKOptions::SetAll(sal_Bool bSet)
 {
     DBG_ASSERT(pCJKOptions->IsLoaded(), "CJK options not loaded");
     pCJKOptions->SetAll(bSet);
 }
-/*-- 20.04.01 14:32:06---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool    SvtCJKOptions::IsAnyEnabled() const
 {
     DBG_ASSERT(pCJKOptions->IsLoaded(), "CJK options not loaded");
     return pCJKOptions->IsAnyEnabled();
 }
-/*-- 13.02.2003 12:11---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool    SvtCJKOptions::IsReadOnly(EOption eOption) const
 {
     DBG_ASSERT(pCJKOptions->IsLoaded(), "CJK options not loaded");
