@@ -31,7 +31,7 @@
 #include "contentenumeration.hxx"
 #include <svl/urlfilter.hxx>
 #include <svtools/inettbc.hxx>
-#include "imagemgr.hxx"
+#include <svtools/imagemgr.hxx>
 
 /** === begin UNO includes === **/
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -192,18 +192,18 @@ namespace svt
             Reference< XResultSet > xResultSet;
             Sequence< OUString > aProps(12);
 
-            aProps[0] = OUString::createFromAscii( "Title" );
-            aProps[1] = OUString::createFromAscii( "Size" );
-            aProps[2] = OUString::createFromAscii( "DateModified" );
-            aProps[3] = OUString::createFromAscii( "DateCreated" );
-            aProps[4] = OUString::createFromAscii( "IsFolder" );
-            aProps[5] = OUString::createFromAscii( "TargetURL" );
-            aProps[6] = OUString::createFromAscii( "IsHidden" );
-            aProps[7] = OUString::createFromAscii( "IsVolume" );
-            aProps[8] = OUString::createFromAscii( "IsRemote" );
-            aProps[9] = OUString::createFromAscii( "IsRemoveable" );
-            aProps[10] = OUString::createFromAscii( "IsFloppy" );
-            aProps[11] = OUString::createFromAscii( "IsCompactDisc" );
+            aProps[0] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Title" ));
+            aProps[1] = OUString( RTL_CONSTASCII_USTRINGPARAM( "Size" ));
+            aProps[2] = OUString( RTL_CONSTASCII_USTRINGPARAM( "DateModified" ));
+            aProps[3] = OUString( RTL_CONSTASCII_USTRINGPARAM( "DateCreated" ));
+            aProps[4] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsFolder" ));
+            aProps[5] = OUString( RTL_CONSTASCII_USTRINGPARAM( "TargetURL" ));
+            aProps[6] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsHidden" ));
+            aProps[7] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsVolume" ));
+            aProps[8] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsRemote" ));
+            aProps[9] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsRemoveable" ));
+            aProps[10] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsFloppy" ));
+            aProps[11] = OUString( RTL_CONSTASCII_USTRINGPARAM( "IsCompactDisc" ));
 
             Reference< XCommandEnvironment > xEnvironment;
             try
@@ -299,8 +299,8 @@ namespace svt
                                 ::ucbhelper::Content aCnt( aTargetURL, xEnvironment );
                                 try
                                 {
-                                aCnt.getPropertyValue( OUString::createFromAscii( "Size" ) ) >>= pData->maSize;
-                                aCnt.getPropertyValue( OUString::createFromAscii( "DateModified" ) ) >>= aDT;
+                                aCnt.getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "Size" )) ) >>= pData->maSize;
+                                aCnt.getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "DateModified" )) ) >>= aDT;
                                 }
                                 catch (...) {}
                             }
@@ -396,7 +396,7 @@ namespace svt
 
     sal_Bool FileViewContentEnumerator::URLOnBlackList ( const ::rtl::OUString& sRealURL )
     {
-        ::rtl::OUString entryName = sRealURL.copy( sRealURL.lastIndexOf( rtl::OUString::createFromAscii("/")) +1 );
+        ::rtl::OUString entryName = sRealURL.copy( sRealURL.lastIndexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/" ))) +1 );
 
         for (int i = 0; i < m_rBlackList.getLength() ; i++)
         {
@@ -431,7 +431,7 @@ namespace svt
             m_xDocInfo->loadFromURL( _rTargetURL );
             Reference< XPropertySet > xPropSet( m_xDocInfo, UNO_QUERY );
 
-            Any aAny = xPropSet->getPropertyValue( OUString::createFromAscii( "Title" ) );
+            Any aAny = xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "Title" )) );
 
             OUString sTitle;
             if ( ( aAny >>= sTitle ) && sTitle.getLength() > 0 )
