@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -194,7 +194,7 @@ void SAL_CALL EmbedEventListener_Impl::notifyEvent( const document::EventObject&
 {
     SolarMutexGuard aGuard;
 
-    if ( pObject && aEvent.EventName.equalsAscii("OnVisAreaChanged") && pObject->GetViewAspect() != embed::Aspects::MSOLE_ICON && !pObject->IsChart() )
+    if ( pObject && aEvent.EventName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("OnVisAreaChanged")) && pObject->GetViewAspect() != embed::Aspects::MSOLE_ICON && !pObject->IsChart() )
     {
         pObject->UpdateReplacement();
     }
@@ -235,9 +235,8 @@ struct EmbeddedObjectRef_Impl
     ::rtl::OUString                             aMediaType;
     comphelper::EmbeddedObjectContainer*        pContainer;
     Graphic*                                    pGraphic;
-    Graphic*                                    pHCGraphic;
     sal_Int64                                   nViewAspect;
-    BOOL                                        bIsLocked;
+    sal_Bool                                        bIsLocked;
     sal_Bool                                    bNeedUpdate;
 
     // #i104867#
@@ -250,9 +249,8 @@ void EmbeddedObjectRef::Construct_Impl()
     mpImp = new EmbeddedObjectRef_Impl;
     mpImp->pContainer = 0;
     mpImp->pGraphic = 0;
-    mpImp->pHCGraphic = 0;
     mpImp->nViewAspect = embed::Aspects::MSOLE_CONTENT;
-    mpImp->bIsLocked = FALSE;
+    mpImp->bIsLocked = sal_False;
     mpImp->bNeedUpdate = sal_False;
     mpImp->mnGraphicVersion = 0;
     mpImp->aDefaultSizeForChart_In_100TH_MM = awt::Size(8000,7000);
@@ -289,42 +287,15 @@ EmbeddedObjectRef::EmbeddedObjectRef( const EmbeddedObjectRef& rObj )
     else
         mpImp->pGraphic = 0;
 
-    mpImp->pHCGraphic = 0;
     mpImp->mnGraphicVersion = 0;
 }
 
 EmbeddedObjectRef::~EmbeddedObjectRef()
 {
     delete mpImp->pGraphic;
-    if ( mpImp->pHCGraphic ) 
-        DELETEZ( mpImp->pHCGraphic );
     Clear();
 }
-/*
-EmbeddedObjectRef& EmbeddedObjectRef::operator = ( const EmbeddedObjectRef& rObj )
-{
-    DBG_ASSERT( !mxObj.is(), "Never assign an already assigned object!" );
 
-    delete mpImp->pGraphic;
-    if ( mpImp->pHCGraphic ) DELETEZ( mpImp->pHCGraphic );
-    Clear();
-
-    mpImp->nViewAspect = rObj.mpImp->nViewAspect;
-    mpImp->bIsLocked = rObj.mpImp->bIsLocked;
-    mxObj = rObj.mxObj;
-    mpImp->xListener = EmbedEventListener_Impl::Create( this );
-    mpImp->pContainer = rObj.mpImp->pContainer;
-    mpImp->aPersistName = rObj.mpImp->aPersistName;
-    mpImp->aMediaType = rObj.mpImp->aMediaType;
-    mpImp->bNeedUpdate = rObj.mpImp->bNeedUpdate;
-
-    if ( rObj.mpImp->pGraphic && !rObj.mpImp->bNeedUpdate )
-        mpImp->pGraphic = new Graphic( *rObj.mpImp->pGraphic );
-    else
-        mpImp->pGraphic = 0;
-    return *this;
-}
-*/
 void EmbeddedObjectRef::Assign( const NS_UNO::Reference < NS_EMBED::XEmbeddedObject >& xObj, sal_Int64 nAspect )
 {
     DBG_ASSERT( !mxObj.is(), "Never assign an already assigned object!" );
@@ -335,6 +306,7 @@ void EmbeddedObjectRef::Assign( const NS_UNO::Reference < NS_EMBED::XEmbeddedObj
     mpImp->xListener = EmbedEventListener_Impl::Create( this );
 
     //#i103460#
+    if ( IsChart() )
     {
         ::com::sun::star::uno::Reference < ::com::sun::star::chart2::XDefaultSizeTransmitter > xSizeTransmitter( xObj, uno::UNO_QUERY );
         DBG_ASSERT( xSizeTransmitter.is(), "Object does not support XDefaultSizeTransmitter -> will cause #i103460#!" );
@@ -372,7 +344,7 @@ void EmbeddedObjectRef::Clear()
                 }
                 catch ( uno::Exception& )
                 {
-                    OSL_ENSURE( sal_False, "Error on switching of the object to loaded state and closing!\n" );
+                    OSL_FAIL( "Error on switching of the object to loaded state and closing!\n" );
                 }
             }
         }
@@ -389,7 +361,7 @@ void EmbeddedObjectRef::Clear()
     }
 
     mpImp->pContainer = 0;
-    mpImp->bIsLocked = FALSE;
+    mpImp->bIsLocked = sal_False;
     mpImp->bNeedUpdate = sal_False;
 }
 
@@ -431,25 +403,23 @@ void EmbeddedObjectRef::SetViewAspect( sal_Int64 nAspect )
     mpImp->nViewAspect = nAspect;
 }
 
-void EmbeddedObjectRef::Lock( BOOL bLock )
+void EmbeddedObjectRef::Lock( sal_Bool bLock )
 {
     mpImp->bIsLocked = bLock;
 }
 
-BOOL EmbeddedObjectRef::IsLocked() const
+sal_Bool EmbeddedObjectRef::IsLocked() const
 {
     return mpImp->bIsLocked;
 }
 
-void EmbeddedObjectRef::GetReplacement( BOOL bUpdate )
+void EmbeddedObjectRef::GetReplacement( sal_Bool bUpdate )
 {
     if ( bUpdate )
     {
         DELETEZ( mpImp->pGraphic );
         mpImp->aMediaType = ::rtl::OUString();
         mpImp->pGraphic = new Graphic;
-        if ( mpImp->pHCGraphic ) 
-            DELETEZ( mpImp->pHCGraphic );
         mpImp->mnGraphicVersion++;
     }
     else if ( !mpImp->pGraphic )
@@ -459,7 +429,7 @@ void EmbeddedObjectRef::GetReplacement( BOOL bUpdate )
     }
     else
     {
-        DBG_ERROR("No update, but replacement exists already!");
+        OSL_FAIL("No update, but replacement exists already!");
         return;
     }
 
@@ -480,7 +450,7 @@ Graphic* EmbeddedObjectRef::GetGraphic( ::rtl::OUString* pMediaType ) const
         // bNeedUpdate will be set to false while retrieving new replacement
         const_cast < EmbeddedObjectRef* >(this)->GetReplacement( sal_True );
     else if ( !mpImp->pGraphic )
-        const_cast < EmbeddedObjectRef* >(this)->GetReplacement( FALSE );
+        const_cast < EmbeddedObjectRef* >(this)->GetReplacement( sal_False );
 
     if ( mpImp->pGraphic && pMediaType )
         *pMediaType = mpImp->aMediaType;
@@ -518,7 +488,7 @@ Size EmbeddedObjectRef::GetSize( MapMode* pTargetMapMode ) const
             }
             catch( uno::Exception& )
             {
-                OSL_ENSURE( sal_False, "Something went wrong on getting of the size of the object!" );
+                OSL_FAIL( "Something went wrong on getting of the size of the object!" );
             }
 
             try
@@ -527,7 +497,7 @@ Size EmbeddedObjectRef::GetSize( MapMode* pTargetMapMode ) const
             }
             catch( uno::Exception )
             {
-                OSL_ENSURE( sal_False, "Can not get the map mode!" );
+                OSL_FAIL( "Can not get the map mode!" );
             }
         }
 
@@ -546,70 +516,6 @@ Size EmbeddedObjectRef::GetSize( MapMode* pTargetMapMode ) const
     return aResult;
 }
 
-Graphic* EmbeddedObjectRef::GetHCGraphic() const
-{
-    if ( !mpImp->pHCGraphic )
-    {
-        uno::Reference< io::XInputStream > xInStream;
-        try
-        {
-            // if the object needs size on load, that means that it is not our object
-            // currently the HC mode is supported only for OOo own objects so the following
-            // check is used as an optimization
-            // TODO/LATER: shouldn't there be a special status flag to detect alien implementation?
-            if ( mpImp->nViewAspect == embed::Aspects::MSOLE_CONTENT
-              && mxObj.is() && !( mxObj->getStatus( mpImp->nViewAspect ) & embed::EmbedMisc::EMBED_NEEDSSIZEONLOAD ) )
-            {
-                // TODO/LATER: optimization, it makes no sence to do it for OLE objects
-                if ( mxObj->getCurrentState() == embed::EmbedStates::LOADED )
-                    mxObj->changeState( embed::EmbedStates::RUNNING );
-
-                // TODO: return for the aspect of the document
-                embed::VisualRepresentation aVisualRepresentation;
-                uno::Reference< datatransfer::XTransferable > xTransferable( mxObj->getComponent(), uno::UNO_QUERY );
-                if ( !xTransferable.is() )
-                    throw uno::RuntimeException();
-
-                datatransfer::DataFlavor aDataFlavor(
-                        ::rtl::OUString::createFromAscii(
-                                "application/x-openoffice-highcontrast-gdimetafile;windows_formatname=\"GDIMetaFile\"" ),
-                        ::rtl::OUString::createFromAscii( "GDIMetaFile" ),
-                        ::getCppuType( (const uno::Sequence< sal_Int8 >*) NULL ) );
-
-                uno::Sequence < sal_Int8 > aSeq;
-                if ( ( xTransferable->getTransferData( aDataFlavor ) >>= aSeq ) && aSeq.getLength() )
-                    xInStream = new ::comphelper::SequenceInputStream( aSeq );
-            }
-        }
-        catch ( uno::Exception& )
-        {
-        }
-
-        if ( xInStream.is() )
-        {
-            SvStream* pStream = NULL;
-            pStream = ::utl::UcbStreamHelper::CreateStream( xInStream );
-            if ( pStream )
-            {
-                if ( !pStream->GetError() )
-                {
-                    GraphicFilter* pGF = GraphicFilter::GetGraphicFilter();
-                    Graphic* pGraphic = new Graphic(); 
-                    if ( pGF->ImportGraphic( *pGraphic, String(), *pStream, GRFILTER_FORMAT_DONTKNOW ) == 0 )
-                        mpImp->pHCGraphic = pGraphic;
-                    else
-                        delete pGraphic;
-                    mpImp->mnGraphicVersion++;
-                }
-
-                delete pStream;
-            }
-        }
-    }
-
-    return mpImp->pHCGraphic;
-}
-
 void EmbeddedObjectRef::SetGraphicStream( const uno::Reference< io::XInputStream >& xInGrStream,
                                             const ::rtl::OUString& rMediaType )
 {
@@ -617,8 +523,6 @@ void EmbeddedObjectRef::SetGraphicStream( const uno::Reference< io::XInputStream
         delete mpImp->pGraphic;
     mpImp->pGraphic = new Graphic();
     mpImp->aMediaType = rMediaType;
-    if ( mpImp->pHCGraphic ) 
-        DELETEZ( mpImp->pHCGraphic );
     mpImp->mnGraphicVersion++;
 
     SvStream* pGraphicStream = ::utl::UcbStreamHelper::CreateStream( xInGrStream );
@@ -628,7 +532,7 @@ void EmbeddedObjectRef::SetGraphicStream( const uno::Reference< io::XInputStream
         GraphicFilter* pGF = GraphicFilter::GetGraphicFilter();
         pGF->ImportGraphic( *mpImp->pGraphic, String(), *pGraphicStream, GRFILTER_FORMAT_DONTKNOW );
         mpImp->mnGraphicVersion++;
-    
+
         if ( mpImp->pContainer )
         {
             pGraphicStream->Seek( 0 );
@@ -650,8 +554,6 @@ void EmbeddedObjectRef::SetGraphic( const Graphic& rGraphic, const ::rtl::OUStri
         delete mpImp->pGraphic;
     mpImp->pGraphic = new Graphic( rGraphic );
     mpImp->aMediaType = rMediaType;
-    if ( mpImp->pHCGraphic ) 
-        DELETEZ( mpImp->pHCGraphic );
     mpImp->mnGraphicVersion++;
 
     if ( mpImp->pContainer )
@@ -660,7 +562,7 @@ void EmbeddedObjectRef::SetGraphic( const Graphic& rGraphic, const ::rtl::OUStri
     mpImp->bNeedUpdate = sal_False;
 }
 
-SvStream* EmbeddedObjectRef::GetGraphicStream( BOOL bUpdate ) const
+SvStream* EmbeddedObjectRef::GetGraphicStream( sal_Bool bUpdate ) const
 {
     RTL_LOGFILE_CONTEXT( aLog, "svtools (mv76033) svt::EmbeddedObjectRef::GetGraphicStream" );
     DBG_ASSERT( bUpdate || mpImp->pContainer, "Can't retrieve current graphic!" );
@@ -714,7 +616,7 @@ void EmbeddedObjectRef::DrawPaintReplacement( const Rectangle &rRect, const Stri
     MapMode aMM( MAP_APPFONT );
     Size aAppFontSz = pOut->LogicToLogic( Size( 0, 8 ), &aMM, NULL );
     Font aFnt( String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "Helvetica" ) ), aAppFontSz );
-    aFnt.SetTransparent( TRUE );
+    aFnt.SetTransparent( sal_True );
     aFnt.SetColor( Color( COL_LIGHTRED ) );
     aFnt.SetWeight( WEIGHT_BOLD );
     aFnt.SetFamily( FAMILY_SWISS );
@@ -726,14 +628,14 @@ void EmbeddedObjectRef::DrawPaintReplacement( const Rectangle &rRect, const Stri
     Point aPt;
     // Nun den Text so skalieren, dass er in das Rect passt.
     // Wir fangen mit der Defaultsize an und gehen 1-AppFont runter
-    for( USHORT i = 8; i > 2; i-- )
+    for( sal_uInt16 i = 8; i > 2; i-- )
     {
         aPt.X() = (rRect.GetWidth()  - pOut->GetTextWidth( rText )) / 2;
         aPt.Y() = (rRect.GetHeight() - pOut->GetTextHeight()) / 2;
 
-        BOOL bTiny = FALSE;
-        if( aPt.X() < 0 ) bTiny = TRUE, aPt.X() = 0;
-        if( aPt.Y() < 0 ) bTiny = TRUE, aPt.Y() = 0;
+        sal_Bool bTiny = sal_False;
+        if( aPt.X() < 0 ) bTiny = sal_True, aPt.X() = 0;
+        if( aPt.Y() < 0 ) bTiny = sal_True, aPt.Y() = 0;
         if( bTiny )
         {
             // heruntergehen bei kleinen Bildern
@@ -795,8 +697,8 @@ void EmbeddedObjectRef::DrawShading( const Rectangle &rRect, OutputDevice *pOut
     aPixSize.Width() -= 1;
     aPixSize.Height() -= 1;
     Point aPixViewPos = pOut->LogicToPixel( rRect.TopLeft() );
-    INT32 nMax = aPixSize.Width() + aPixSize.Height();
-    for( INT32 i = 5; i < nMax; i += 5 )
+    sal_Int32 nMax = aPixSize.Width() + aPixSize.Height();
+    for( sal_Int32 i = 5; i < nMax; i += 5 )
     {
         Point a1( aPixViewPos ), a2( aPixViewPos );
         if( i > aPixSize.Width() )
@@ -815,15 +717,15 @@ void EmbeddedObjectRef::DrawShading( const Rectangle &rRect, OutputDevice *pOut
 
 }
 
-BOOL EmbeddedObjectRef::TryRunningState()
+sal_Bool EmbeddedObjectRef::TryRunningState()
 {
     return TryRunningState( mxObj );
 }
 
-BOOL EmbeddedObjectRef::TryRunningState( const uno::Reference < embed::XEmbeddedObject >& xEmbObj )
+sal_Bool EmbeddedObjectRef::TryRunningState( const uno::Reference < embed::XEmbeddedObject >& xEmbObj )
 {
     if ( !xEmbObj.is() )
-        return FALSE;
+        return sal_False;
 
     try
     {
@@ -832,10 +734,10 @@ BOOL EmbeddedObjectRef::TryRunningState( const uno::Reference < embed::XEmbedded
     }
     catch ( uno::Exception& )
     {
-        return FALSE;
+        return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 void EmbeddedObjectRef::SetGraphicToContainer( const Graphic& rGraphic,
@@ -853,7 +755,7 @@ void EmbeddedObjectRef::SetGraphicToContainer( const Graphic& rGraphic,
            aContainer.InsertGraphicStream( xStream, aName, aMediaType );
     }
     else
-        OSL_ENSURE( sal_False, "Export of graphic is failed!\n" );
+        OSL_FAIL( "Export of graphic is failed!\n" );
 }
 
 sal_Bool EmbeddedObjectRef::ObjectIsModified( const uno::Reference< embed::XEmbeddedObject >& xObj )
@@ -887,8 +789,6 @@ void EmbeddedObjectRef::UpdateReplacementOnDemand()
 {
     DELETEZ( mpImp->pGraphic );
     mpImp->bNeedUpdate = sal_True;
-    if ( mpImp->pHCGraphic ) 
-        DELETEZ( mpImp->pHCGraphic );
     mpImp->mnGraphicVersion++;
 
     if( mpImp->pContainer )
@@ -898,7 +798,7 @@ void EmbeddedObjectRef::UpdateReplacementOnDemand()
     }
 }
 
-BOOL EmbeddedObjectRef::IsChart() const
+sal_Bool EmbeddedObjectRef::IsChart() const
 {
     //todo maybe for 3.0:
     //if the changes work good for chart
