@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -55,6 +55,7 @@
 
 //////////////////////////////////////////////////////////////////////////////
 
+using editeng::SvxBorderLine;
 using namespace com::sun::star;
 
 //////////////////////////////////////////////////////////////////////////////
@@ -75,7 +76,7 @@ namespace drawinglayer
 
         public:
             SdrCellPrimitive2D(
-                const basegfx::B2DHomMatrix& rTransform, 
+                const basegfx::B2DHomMatrix& rTransform,
                 const attribute::SdrFillTextAttribute& rSdrFTAttribute)
             :	BufferedDecompositionPrimitive2D(),
                 maTransform(rTransform),
@@ -103,11 +104,11 @@ namespace drawinglayer
             // add fill
             if(!getSdrFTAttribute().getFill().isDefault())
             {
-                appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, 
+                appendPrimitive2DReferenceToPrimitive2DSequence(aRetval,
                     createPolyPolygonFillPrimitive(
-                        aUnitPolyPolygon, 
-                        getTransform(), 
-                        getSdrFTAttribute().getFill(), 
+                        aUnitPolyPolygon,
+                        getTransform(),
+                        getSdrFTAttribute().getFill(),
                         getSdrFTAttribute().getFillFloatTransGradient()));
             }
             else
@@ -123,14 +124,14 @@ namespace drawinglayer
             // add text
             if(!getSdrFTAttribute().getText().isDefault())
             {
-                appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, 
+                appendPrimitive2DReferenceToPrimitive2DSequence(aRetval,
                     createTextPrimitive(
-                        aUnitPolyPolygon, 
-                        getTransform(), 
+                        aUnitPolyPolygon,
+                        getTransform(),
                         getSdrFTAttribute().getText(),
                         attribute::SdrLineAttribute(),
-                        true, 
-                        false, 
+                        true,
+                        false,
                         false));
             }
 
@@ -142,7 +143,7 @@ namespace drawinglayer
             if(BufferedDecompositionPrimitive2D::operator==(rPrimitive))
             {
                 const SdrCellPrimitive2D& rCompare = (SdrCellPrimitive2D&)rPrimitive;
-                
+
                 return (getTransform() == rCompare.getTransform()
                     && getSdrFTAttribute() == rCompare.getSdrFTAttribute());
             }
@@ -171,6 +172,16 @@ namespace drawinglayer
             SvxBorderLine								maRightLine;
             SvxBorderLine								maTopLine;
 
+            // Neighbor cells' borders
+            SvxBorderLine								maLeftFromTLine;
+            SvxBorderLine								maLeftFromBLine;
+            SvxBorderLine								maRightFromTLine;
+            SvxBorderLine								maRightFromBLine;
+            SvxBorderLine								maTopFromLLine;
+            SvxBorderLine								maTopFromRLine;
+            SvxBorderLine								maBottomFromLLine;
+            SvxBorderLine								maBottomFromRLine;
+
             // bitfield
             unsigned									mbLeftIsOutside : 1;
             unsigned									mbBottomIsOutside : 1;
@@ -184,11 +195,19 @@ namespace drawinglayer
 
         public:
             SdrBorderlinePrimitive2D(
-                const basegfx::B2DHomMatrix& rTransform, 
+                const basegfx::B2DHomMatrix& rTransform,
                 const SvxBorderLine& rLeftLine,
                 const SvxBorderLine& rBottomLine,
                 const SvxBorderLine& rRightLine,
                 const SvxBorderLine& rTopLine,
+                const SvxBorderLine& rLeftFromTLine,
+                const SvxBorderLine& rLeftFromBLine,
+                const SvxBorderLine& rRightFromTLine,
+                const SvxBorderLine& rRightFromBLine,
+                const SvxBorderLine& rTopFromLLine,
+                const SvxBorderLine& rTopFromRLine,
+                const SvxBorderLine& rBottomFromLLine,
+                const SvxBorderLine& rBottomFromRLine,
                 bool bLeftIsOutside,
                 bool bBottomIsOutside,
                 bool bRightIsOutside,
@@ -200,6 +219,14 @@ namespace drawinglayer
                 maBottomLine(rBottomLine),
                 maRightLine(rRightLine),
                 maTopLine(rTopLine),
+                maLeftFromTLine(rLeftFromTLine),
+                maLeftFromBLine(rLeftFromBLine),
+                maRightFromTLine(rRightFromTLine),
+                maRightFromBLine(rRightFromBLine),
+                maTopFromLLine(rTopFromLLine),
+                maTopFromRLine(rTopFromRLine),
+                maBottomFromLLine(rBottomFromLLine),
+                maBottomFromRLine(rBottomFromRLine),
                 mbLeftIsOutside(bLeftIsOutside),
                 mbBottomIsOutside(bBottomIsOutside),
                 mbRightIsOutside(bRightIsOutside),
@@ -208,7 +235,6 @@ namespace drawinglayer
             {
             }
 
-
             // data access
             const basegfx::B2DHomMatrix& getTransform() const { return maTransform; }
             const SvxBorderLine& getLeftLine() const { return maLeftLine; }
@@ -248,34 +274,20 @@ namespace drawinglayer
             return getBorderLineOutWidth(rLineA) + getBorderLineDistance(rLineA) + getBorderLineInWidth(rLineA);
         }
 
-        double getInnerExtend(const SvxBorderLine& rLineA, bool bSideToUse)
+        double getExtend(const SvxBorderLine& rLineSide, const SvxBorderLine& rLineOpposite)
         {
-            if(!rLineA.isEmpty())
+            double nExtend = 0.0;
+            if(!rLineSide.isEmpty())
             {
-                if(rLineA.isDouble())
-                {
-                    // reduce to inner edge of associated matching line
-                    return -((getBorderLineWidth(rLineA) / 2.0) - (bSideToUse ? getBorderLineOutWidth(rLineA) : getBorderLineInWidth(rLineA)));
-                }
-                else
-                {
-                    // extend to overlap with single line
-                    return getBorderLineWidth(rLineA) / 2.0;
-                }
+                // reduce to inner edge of associated matching line
+                nExtend = -((getBorderLineWidth(rLineSide) / 2.0));
+            }
+            else
+            {
+                nExtend = ((getBorderLineWidth(rLineOpposite) / 2.0));
             }
 
-            return 0.0;
-        }
-
-        double getOuterExtend(const SvxBorderLine& rLineA)
-        {
-            if(!rLineA.isEmpty())
-            {
-                // extend to overlap with single line
-                return getBorderLineWidth(rLineA) / 2.0;
-            }
-
-            return 0.0;
+            return nExtend;
         }
 
         double getChangedValue(sal_uInt16 nValue, bool bChangeToMM)
@@ -303,23 +315,10 @@ namespace drawinglayer
 
                 if(!aStart.equal(aEnd))
                 {
-                    const double fExtendIS(getInnerExtend(getTopLine(), false));
-                    const double fExtendIE(getInnerExtend(getBottomLine(), true));
-                    double fExtendOS(0.0);
-                    double fExtendOE(0.0);
-
-                    if(getLeftIsOutside())
-                    {
-                        if(getTopIsOutside())
-                        {
-                            fExtendOS = getOuterExtend(getTopLine());
-                        }
-
-                        if(getBottomIsOutside())
-                        {
-                            fExtendOE = getOuterExtend(getBottomLine());
-                        }
-                    }
+                    const double fExtendIS(getExtend(getTopLine(), maTopFromLLine));
+                    const double fExtendIE(getExtend(getBottomLine(), maBottomFromLLine));
+                    const double fExtendOS(getExtend(maTopFromLLine, getTopLine()));
+                    const double fExtendOE(getExtend(maBottomFromLLine, getBottomLine()));
 
                     xRetval[nInsert++] = Primitive2DReference(new BorderLinePrimitive2D(
                         aStart,
@@ -331,14 +330,15 @@ namespace drawinglayer
                         fExtendIE * fTwipsToMM,
                         fExtendOS * fTwipsToMM,
                         fExtendOE * fTwipsToMM,
-                        true,
-                        getLeftIsOutside(),
-                        getLeftLine().GetColor().getBColor(),
+                        getLeftLine().GetColorOut(true).getBColor(),
+                        getLeftLine().GetColorIn(true).getBColor(),
+                        getLeftLine().GetColorGap().getBColor(),
+                        getLeftLine().HasGapColor(),
                         getLeftLine().GetStyle()));
                 }
             }
 
-            if(!getBottomLine().isEmpty())
+            if(!getBottomLine().isEmpty() && getBottomIsOutside())
             {
                 // create bottom line from left to right
                 const basegfx::B2DPoint aStart(getTransform() * basegfx::B2DPoint(0.0, 1.0));
@@ -346,23 +346,10 @@ namespace drawinglayer
 
                 if(!aStart.equal(aEnd))
                 {
-                    const double fExtendIS(getInnerExtend(getLeftLine(), true));
-                    const double fExtendIE(getInnerExtend(getRightLine(), false));
-                    double fExtendOS(0.0);
-                    double fExtendOE(0.0);
-
-                    if(getBottomIsOutside())
-                    {
-                        if(getLeftIsOutside())
-                        {
-                            fExtendOS = getOuterExtend(getLeftLine());
-                        }
-
-                        if(getRightIsOutside())
-                        {
-                            fExtendOE = getOuterExtend(getRightLine());
-                        }
-                    }
+                    const double fExtendIS(getExtend(getLeftLine(), maLeftFromBLine ));
+                    const double fExtendIE(getExtend(getRightLine(), maRightFromBLine));
+                    const double fExtendOS(getExtend(maLeftFromBLine, getLeftLine()));
+                    const double fExtendOE(getExtend(maRightFromBLine, getRightLine()));
 
                     xRetval[nInsert++] = Primitive2DReference(new BorderLinePrimitive2D(
                         aStart,
@@ -374,14 +361,15 @@ namespace drawinglayer
                         fExtendIE * fTwipsToMM,
                         fExtendOS * fTwipsToMM,
                         fExtendOE * fTwipsToMM,
-                        true,
-                        getBottomIsOutside(),
-                        getBottomLine().GetColor().getBColor(),
+                        getBottomLine().GetColorOut(false).getBColor(),
+                        getBottomLine().GetColorIn(false).getBColor(),
+                        getBottomLine().GetColorGap().getBColor(),
+                        getBottomLine().HasGapColor(),
                         getBottomLine().GetStyle()));
                 }
             }
 
-            if(!getRightLine().isEmpty())
+            if(!getRightLine().isEmpty() && getRightIsOutside())
             {
                 // create right line from top to bottom
                 const basegfx::B2DPoint aStart(getTransform() * basegfx::B2DPoint(1.0, 0.0));
@@ -389,23 +377,10 @@ namespace drawinglayer
 
                 if(!aStart.equal(aEnd))
                 {
-                    const double fExtendIS(getInnerExtend(getTopLine(), false));
-                    const double fExtendIE(getInnerExtend(getBottomLine(), true));
-                    double fExtendOS(0.0);
-                    double fExtendOE(0.0);
-
-                    if(getRightIsOutside())
-                    {
-                        if(getTopIsOutside())
-                        {
-                            fExtendOS = getOuterExtend(getTopLine());
-                        }
-
-                        if(getBottomIsOutside())
-                        {
-                            fExtendOE = getOuterExtend(getBottomLine());
-                        }
-                    }
+                    const double fExtendIS(getExtend(getTopLine(), maTopFromRLine));
+                    const double fExtendIE(getExtend(getBottomLine(), maBottomFromRLine));
+                    const double fExtendOS(getExtend(maTopFromRLine, getTopLine()));
+                    const double fExtendOE(getExtend(maBottomFromRLine, getBottomLine()));
 
                     xRetval[nInsert++] = Primitive2DReference(new BorderLinePrimitive2D(
                         aStart,
@@ -417,9 +392,10 @@ namespace drawinglayer
                         fExtendOE * fTwipsToMM,
                         fExtendIS * fTwipsToMM,
                         fExtendIE * fTwipsToMM,
-                        getRightIsOutside(),
-                        true,
-                        getRightLine().GetColor().getBColor(),
+                        getRightLine().GetColorOut(true).getBColor(),
+                        getRightLine().GetColorIn(true).getBColor(),
+                        getRightLine().GetColorGap().getBColor(),
+                        getRightLine().HasGapColor(),
                         getRightLine().GetStyle()));
                 }
             }
@@ -432,23 +408,10 @@ namespace drawinglayer
 
                 if(!aStart.equal(aEnd))
                 {
-                    const double fExtendIS(getInnerExtend(getLeftLine(), true));
-                    const double fExtendIE(getInnerExtend(getRightLine(), false));
-                    double fExtendOS(0.0);
-                    double fExtendOE(0.0);
-
-                    if(getTopIsOutside())
-                    {
-                        if(getLeftIsOutside())
-                        {
-                            fExtendOS = getOuterExtend(getLeftLine());
-                        }
-
-                        if(getRightIsOutside())
-                        {
-                            fExtendOE = getOuterExtend(getRightLine());
-                        }
-                    }
+                    const double fExtendIS(getExtend(getLeftLine(), maLeftFromTLine));
+                    const double fExtendIE(getExtend(getRightLine(), maRightFromTLine));
+                    const double fExtendOS(getExtend(maLeftFromTLine, getLeftLine()));
+                    const double fExtendOE(getExtend(maRightFromTLine, getRightLine()));
 
                     xRetval[nInsert++] = Primitive2DReference(new BorderLinePrimitive2D(
                         aStart,
@@ -460,9 +423,10 @@ namespace drawinglayer
                         fExtendOE * fTwipsToMM,
                         fExtendIS * fTwipsToMM,
                         fExtendIE * fTwipsToMM,
-                        getTopIsOutside(),
-                        true,
-                        getTopLine().GetColor().getBColor(),
+                        getTopLine().GetColorOut(false).getBColor(),
+                        getTopLine().GetColorIn(false).getBColor(),
+                        getTopLine().GetColorGap().getBColor(),
+                        getTopLine().HasGapColor(),
                         getTopLine().GetStyle()));
                 }
             }
@@ -476,12 +440,20 @@ namespace drawinglayer
             if(BufferedDecompositionPrimitive2D::operator==(rPrimitive))
             {
                 const SdrBorderlinePrimitive2D& rCompare = (SdrBorderlinePrimitive2D&)rPrimitive;
-                
+
                 return (getTransform() == rCompare.getTransform()
                     && getLeftLine() == rCompare.getLeftLine()
                     && getBottomLine() == rCompare.getBottomLine()
                     && getRightLine() == rCompare.getRightLine()
                     && getTopLine() == rCompare.getTopLine()
+                    && maLeftFromTLine == rCompare.maLeftFromTLine
+                    && maLeftFromBLine == rCompare.maLeftFromBLine
+                    && maRightFromTLine == rCompare.maRightFromTLine
+                    && maRightFromBLine == rCompare.maRightFromBLine
+                    && maTopFromLLine == rCompare.maTopFromLLine
+                    && maTopFromRLine == rCompare.maTopFromRLine
+                    && maBottomFromLLine == rCompare.maBottomFromLLine
+                    && maBottomFromRLine == rCompare.maBottomFromRLine
                     && getLeftIsOutside() == rCompare.getLeftIsOutside()
                     && getBottomIsOutside() == rCompare.getBottomIsOutside()
                     && getRightIsOutside() == rCompare.getRightIsOutside()
@@ -532,11 +504,10 @@ namespace sdr
                             bMirror = (bIsRTL ? 0 != nX : nX != nColCount);
                         }
                     }
-                        
+
                     if(bMirror)
                     {
-                        aLine.SetOutWidth(pLine->GetInWidth());
-                        aLine.SetInWidth(pLine->GetOutWidth());
+                        aLine.SetMirrorWidths( );
                     }
 
                     return;
@@ -580,13 +551,22 @@ namespace sdr
                     drawinglayer::primitive2d::Primitive2DSequence xBorderSequence(nAllCount);
                     sal_uInt32 nCellInsert(0);
                     sal_uInt32 nBorderInsert(0);
-                    
+
                     // variables for border lines
                     SvxBorderLine aLeftLine;
                     SvxBorderLine aBottomLine;
                     SvxBorderLine aRightLine;
                     SvxBorderLine aTopLine;
-                    
+
+                    SvxBorderLine aLeftFromTLine;
+                    SvxBorderLine aLeftFromBLine;
+                    SvxBorderLine aRightFromTLine;
+                    SvxBorderLine aRightFromBLine;
+                    SvxBorderLine aTopFromLLine;
+                    SvxBorderLine aTopFromRLine;
+                    SvxBorderLine aBottomFromLLine;
+                    SvxBorderLine aBottomFromRLine;
+
                     // create single primitives per cell
                     for(aCellPos.mnRow = 0; aCellPos.mnRow < nRowCount; aCellPos.mnRow++)
                     {
@@ -610,7 +590,7 @@ namespace sdr
                                     const sal_uInt32 nTextIndex(nColCount * aCellPos.mnRow + aCellPos.mnCol);
                                     const SdrText* pSdrText = rTableObj.getText(nTextIndex);
                                     drawinglayer::attribute::SdrFillTextAttribute aAttribute;
-                                    
+
                                     if(pSdrText)
                                     {
                                         // #i101508# take cell's local text frame distances into account
@@ -620,7 +600,7 @@ namespace sdr
                                         const sal_Int32 nLower(xCurrentCell->GetTextLowerDistance());
 
                                         aAttribute = drawinglayer::primitive2d::createNewSdrFillTextAttribute(
-                                            rCellItemSet, 
+                                            rCellItemSet,
                                             pSdrText,
                                             &nLeft,
                                             &nUpper,
@@ -630,7 +610,7 @@ namespace sdr
                                     else
                                     {
                                         aAttribute = drawinglayer::primitive2d::createNewSdrFillTextAttribute(
-                                            rCellItemSet, 
+                                            rCellItemSet,
                                             pSdrText);
                                     }
 
@@ -651,21 +631,39 @@ namespace sdr
                                     const sal_Int32 nYSpan(xCurrentCell->getRowSpan());
                                     const sal_Int32 nXRight(bIsRTL ? nX - nXSpan : nX + nXSpan);
                                     const sal_Int32 nYBottom(nY + nYSpan);
-                                    
+
                                     // get basic lines
                                     impGetLine(aLeftLine, rTableLayouter, nX, nY, false, nColCount, nRowCount, bIsRTL);
                                     impGetLine(aBottomLine, rTableLayouter, nX, nYBottom, true, nColCount, nRowCount, bIsRTL);
                                     impGetLine(aRightLine, rTableLayouter, nXRight, nY, false, nColCount, nRowCount, bIsRTL);
                                     impGetLine(aTopLine, rTableLayouter, nX, nY, true, nColCount, nRowCount, bIsRTL);
-                                    
+
+                                    // get the neighbor cells' borders
+                                    impGetLine(aLeftFromTLine, rTableLayouter, nX, nY - 1, false, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aLeftFromBLine, rTableLayouter, nX, nYBottom + 1, false, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aRightFromTLine, rTableLayouter, nXRight, nY - 1, false, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aRightFromBLine, rTableLayouter, nXRight, nYBottom + 1, false, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aTopFromLLine, rTableLayouter, nX - 1, nY, true, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aTopFromRLine, rTableLayouter, nXRight + 1, nY, true, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aBottomFromLLine, rTableLayouter, nX - 1, nYBottom, true, nColCount, nRowCount, bIsRTL);
+                                    impGetLine(aBottomFromRLine, rTableLayouter, nXRight + 1, nYBottom, true, nColCount, nRowCount, bIsRTL);
+
                                     // create the primtive containing all data for one cell with borders
                                     xBorderSequence[nBorderInsert++] = drawinglayer::primitive2d::Primitive2DReference(
                                         new drawinglayer::primitive2d::SdrBorderlinePrimitive2D(
                                             aCellMatrix,
-                                            aLeftLine, 
-                                            aBottomLine, 
-                                            aRightLine, 
+                                            aLeftLine,
+                                            aBottomLine,
+                                            aRightLine,
                                             aTopLine,
+                                            aLeftFromTLine,
+                                            aLeftFromBLine,
+                                            aRightFromTLine,
+                                            aRightFromBLine,
+                                            aTopFromLLine,
+                                            aTopFromRLine,
+                                            aBottomFromLLine,
+                                            aBottomFromRLine,
                                             bIsRTL ? nX == nColCount : 0 == nX,
                                             nRowCount == nYBottom,
                                             bIsRTL ? 0 == nXRight : nXRight == nColCount,
@@ -705,7 +703,7 @@ namespace sdr
                 // take unrotated snap rect (direct model data) for position and size
                 const Rectangle& rRectangle = rTableObj.GetGeoRect();
                 const basegfx::B2DRange aObjectRange(
-                    rRectangle.Left(), rRectangle.Top(), 
+                    rRectangle.Left(), rRectangle.Top(),
                     rRectangle.Right(), rRectangle.Bottom());
 
                 // create object matrix
@@ -719,7 +717,7 @@ namespace sdr
                 // credate an invisible outline for the cases where no visible content exists
                 const drawinglayer::primitive2d::Primitive2DReference xReference(
                     drawinglayer::primitive2d::createHiddenGeometryPrimitives2D(
-                        false, 
+                        false,
                         aObjectMatrix));
 
                 return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
