@@ -59,7 +59,7 @@
 #include "xmloff/ImageStyle.hxx"
 #include "xmloff/MarkerStyle.hxx"
 #include <xmloff/xmlictxt.hxx>
-#include "xmlgrhlp.hxx"
+#include "svx/xmlgrhlp.hxx"
 #include "xmloff/attrlist.hxx"
 
 #include "xmlxtimp.hxx"
@@ -75,12 +75,12 @@ using namespace ::rtl;
 using namespace ::xmloff::token;
 using namespace cppu;
 
-sal_Char __READONLY_DATA sXML_np__office[] = "__office";
-sal_Char __READONLY_DATA sXML_np__office_ooo[] = "___office";
-sal_Char __READONLY_DATA sXML_np__draw[] = "__draw";
-sal_Char __READONLY_DATA sXML_np__draw_ooo[] = "___draw";
-sal_Char __READONLY_DATA sXML_np__ooo[] = "__ooo";
-sal_Char __READONLY_DATA sXML_np__xlink[] = "__xlink";
+sal_Char const sXML_np__office[] = "__office";
+sal_Char const sXML_np__office_ooo[] = "___office";
+sal_Char const sXML_np__draw[] = "__draw";
+sal_Char const sXML_np__draw_ooo[] = "___draw";
+sal_Char const sXML_np__ooo[] = "__ooo";
+sal_Char const sXML_np__xlink[] = "__xlink";
 
 ///////////////////////////////////////////////////////////////////////
 
@@ -91,21 +91,21 @@ enum SvxXMLTableImportContextEnum { stice_unknown, stice_color, stice_marker, st
 class SvxXMLTableImportContext : public SvXMLImportContext
 {
 public:
-    SvxXMLTableImportContext( SvXMLImport& rImport, USHORT nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >& xAttrList, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, 
+    SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >& xAttrList, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, 
         sal_Bool bOOoFormat );
     virtual ~SvxXMLTableImportContext();
 
-    virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList );
+    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList );
 
     SvxXMLXTableImport& getImport() const { return *(SvxXMLXTableImport*)&GetImport(); }
 
 protected:
-    void importColor( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importMarker( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importDash( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importHatch( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importGradient( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importBitmap( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importColor( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importMarker( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importDash( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importHatch( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importGradient( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importBitmap( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
 
 private:
     uno::Reference< XNameContainer > mxTable;
@@ -115,7 +115,7 @@ private:
 
 ///////////////////////////////////////////////////////////////////////
 
-SvxXMLTableImportContext::SvxXMLTableImportContext( SvXMLImport& rImport, USHORT nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >&, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, sal_Bool bOOoFormat )
+SvxXMLTableImportContext::SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >&, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, sal_Bool bOOoFormat )
 : SvXMLImportContext( rImport, nPrfx, rLName ), mxTable( xTable ), meContext( eContext ),
     mbOOoFormat( bOOoFormat )
 {
@@ -125,7 +125,7 @@ SvxXMLTableImportContext::~SvxXMLTableImportContext()
 {
 }
 
-SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( USHORT nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& rAttrList )
+SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& rAttrList )
 {
     if( XML_NAMESPACE_DRAW == nPrefix )
     {
@@ -222,7 +222,7 @@ SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( USHORT nPrefix
     return new SvXMLImportContext( GetImport(), nPrefix, rLocalName );
 }
 
-void SvxXMLTableImportContext::importColor( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importColor( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -251,7 +251,7 @@ void SvxXMLTableImportContext::importColor( USHORT nPrfx, const OUString& rLocal
     }
 }
 
-void SvxXMLTableImportContext::importMarker( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importMarker( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -263,11 +263,11 @@ void SvxXMLTableImportContext::importMarker( USHORT nPrfx, const OUString& rLoca
     }
     catch( Exception& )
     {
-        DBG_ERROR("SvxXMLTableImportContext::importMarker(), exception caught!");
+        OSL_FAIL("SvxXMLTableImportContext::importMarker(), exception caught!");
     }
 }
 
-void SvxXMLTableImportContext::importDash( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importDash( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -279,11 +279,11 @@ void SvxXMLTableImportContext::importDash( USHORT nPrfx, const OUString& rLocalN
     }
     catch( Exception& )
     {
-        DBG_ERROR("SvxXMLTableImportContext::importDash(), exception caught!");
+        OSL_FAIL("SvxXMLTableImportContext::importDash(), exception caught!");
     }
 }
 
-void SvxXMLTableImportContext::importHatch( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importHatch( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -295,11 +295,11 @@ void SvxXMLTableImportContext::importHatch( USHORT nPrfx, const OUString& rLocal
     }
     catch( Exception& )
     {
-        DBG_ERROR("SvxXMLTableImportContext::importHatch(), exception caught!");
+        OSL_FAIL("SvxXMLTableImportContext::importHatch(), exception caught!");
     }
 }
 
-void SvxXMLTableImportContext::importGradient( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importGradient( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -311,11 +311,11 @@ void SvxXMLTableImportContext::importGradient( USHORT nPrfx, const OUString& rLo
     }
     catch( Exception& )
     {
-        DBG_ERROR("SvxXMLTableImportContext::importGradient(), exception caught!");
+        OSL_FAIL("SvxXMLTableImportContext::importGradient(), exception caught!");
     }
 }
 
-void SvxXMLTableImportContext::importBitmap( USHORT nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importBitmap( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
     (void)nPrfx;
     (void)rLocalName;
@@ -327,7 +327,7 @@ void SvxXMLTableImportContext::importBitmap( USHORT nPrfx, const OUString& rLoca
     }
     catch( Exception& )
     {
-        DBG_ERROR("SvxXMLTableImportContext::importBitmap(), exception caught!");
+        OSL_FAIL("SvxXMLTableImportContext::importBitmap(), exception caught!");
     }
 }
 
@@ -372,12 +372,12 @@ sal_Bool SvxXMLXTableImport::load( const OUString& rUrl, const uno::Reference< X
     {
         do
         {
-            SfxMedium aMedium( rUrl, STREAM_READ | STREAM_NOCREATE, TRUE );
+            SfxMedium aMedium( rUrl, STREAM_READ | STREAM_NOCREATE, sal_True );
 
             uno::Reference<lang::XMultiServiceFactory> xServiceFactory( ::comphelper::getProcessServiceFactory() );
             if( !xServiceFactory.is() )
             {
-                DBG_ERROR( "SvxXMLXTableImport::load: got no service manager" );
+                OSL_FAIL( "SvxXMLXTableImport::load: got no service manager" );
                 break;
             }
 
@@ -396,7 +396,7 @@ sal_Bool SvxXMLXTableImport::load( const OUString& rUrl, const uno::Reference< X
                 xIStm.set( xStorage->openStreamElement( aContentStmName, embed::ElementModes::READ ), uno::UNO_QUERY_THROW );
                 if( !xIStm.is() )
                 {
-                    DBG_ERROR( "could not open Content stream" );
+                    OSL_FAIL( "could not open Content stream" );
                     break;
                 }
 
@@ -435,7 +435,7 @@ sal_Bool SvxXMLXTableImport::load( const OUString& rUrl, const uno::Reference< X
 //		    each time you load a document with property tables that are not
 //			on the current machine. Maybe a better fix would be to place
 //		    a file exists check before importing...
-//		DBG_ERROR("svx::SvxXMLXTableImport::load(), exception caught!");
+//		OSL_FAIL("svx::SvxXMLXTableImport::load(), exception caught!");
         bRet = sal_False;
     }
 
