@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -37,6 +37,10 @@
 #include <poolfmt.hxx>
 #include <rcid.hrc>
 #include <tools/debug.hxx>
+#ifdef _NEED_TO_DEBUG_MAPPING
+#include <stdlib.h>
+#endif
+
 extern ResMgr* pSwResMgr;
 // Initialise UI names to 0
 SvStringsDtor	*SwStyleNameMapper::pTextUINameArray = 0,
@@ -484,7 +488,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCOLL_LISTS_BEGIN ; nId < RES_POOLCOLL_LISTS_END ; nId++,nIndex++ )
             {
@@ -496,7 +500,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCOLL_EXTRA_BEGIN ; nId < RES_POOLCOLL_EXTRA_END ; nId++,nIndex++ )
             {
@@ -508,7 +512,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCOLL_REGISTER_BEGIN ; nId < RES_POOLCOLL_REGISTER_END ; nId++,nIndex++ )
             {
@@ -520,7 +524,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCOLL_DOC_BEGIN ; nId < RES_POOLCOLL_DOC_END ; nId++,nIndex++ )
             {
@@ -532,7 +536,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCOLL_HTML_BEGIN ; nId < RES_POOLCOLL_HTML_END ; nId++,nIndex++ )
             {
@@ -544,7 +548,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
         }
         {
@@ -558,7 +562,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
             for ( nIndex = 0, nId = RES_POOLCHR_HTML_BEGIN ; nId < RES_POOLCHR_HTML_END ; nId++,nIndex++ )
             {
@@ -570,7 +574,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
         }
         {
@@ -584,7 +588,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
         }
         {
@@ -598,7 +602,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
         }
         {
@@ -612,7 +616,7 @@ const NameToIdHash & SwStyleNameMapper::getHashTable ( SwGetPoolIdFromName eFlag
                 bString = GetUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 nNewId = GetPoolIdFromUIName ( aString, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if ( nNewId != nId )
-                    *((sal_Int32*)0) = 42;
+                    abort();
             }
         }
     }
@@ -1009,77 +1013,77 @@ SvStringsDtor* SwStyleNameMapper::NewProgNameArray( SvStringsDtor*& pProgNameArr
 const SvStringsDtor& SwStyleNameMapper::GetTextProgNameArray()
 {
     return pTextProgNameArray ? *pTextProgNameArray :
-           *NewProgNameArray( pTextProgNameArray, TextProgNameTable, 
-            sizeof ( TextProgNameTable ) / sizeof ( SwTableEntry ) ); 
+           *NewProgNameArray( pTextProgNameArray, TextProgNameTable,
+            sizeof ( TextProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetListsProgNameArray()
 {
-    return pListsProgNameArray ? *pListsProgNameArray : 
-           *NewProgNameArray( pListsProgNameArray, ListsProgNameTable, 
+    return pListsProgNameArray ? *pListsProgNameArray :
+           *NewProgNameArray( pListsProgNameArray, ListsProgNameTable,
             sizeof ( ListsProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetExtraProgNameArray()
 {
-    return pExtraProgNameArray ? *pExtraProgNameArray : 
-           *NewProgNameArray( pExtraProgNameArray, ExtraProgNameTable, 
+    return pExtraProgNameArray ? *pExtraProgNameArray :
+           *NewProgNameArray( pExtraProgNameArray, ExtraProgNameTable,
             sizeof ( ExtraProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetRegisterProgNameArray()
 {
-    return pRegisterProgNameArray ? *pRegisterProgNameArray : 
-           *NewProgNameArray( pRegisterProgNameArray, RegisterProgNameTable, 
+    return pRegisterProgNameArray ? *pRegisterProgNameArray :
+           *NewProgNameArray( pRegisterProgNameArray, RegisterProgNameTable,
             sizeof ( RegisterProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetDocProgNameArray()
 {
-    return pDocProgNameArray ? *pDocProgNameArray : 
-           *NewProgNameArray( pDocProgNameArray, DocProgNameTable, 
+    return pDocProgNameArray ? *pDocProgNameArray :
+           *NewProgNameArray( pDocProgNameArray, DocProgNameTable,
             sizeof ( DocProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetHTMLProgNameArray()
 {
-    return pHTMLProgNameArray ? *pHTMLProgNameArray : 
-           *NewProgNameArray( pHTMLProgNameArray, HTMLProgNameTable, 
+    return pHTMLProgNameArray ? *pHTMLProgNameArray :
+           *NewProgNameArray( pHTMLProgNameArray, HTMLProgNameTable,
             sizeof ( HTMLProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetFrmFmtProgNameArray()
 {
-    return pFrmFmtProgNameArray ? *pFrmFmtProgNameArray : 
-           *NewProgNameArray( pFrmFmtProgNameArray, FrmFmtProgNameTable, 
+    return pFrmFmtProgNameArray ? *pFrmFmtProgNameArray :
+           *NewProgNameArray( pFrmFmtProgNameArray, FrmFmtProgNameTable,
             sizeof ( FrmFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetChrFmtProgNameArray()
 {
-    return pChrFmtProgNameArray ? *pChrFmtProgNameArray : 
-           *NewProgNameArray( pChrFmtProgNameArray, ChrFmtProgNameTable, 
+    return pChrFmtProgNameArray ? *pChrFmtProgNameArray :
+           *NewProgNameArray( pChrFmtProgNameArray, ChrFmtProgNameTable,
             sizeof ( ChrFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetHTMLChrFmtProgNameArray()
 {
-    return pHTMLChrFmtProgNameArray ? *pHTMLChrFmtProgNameArray : 
-           *NewProgNameArray( pHTMLChrFmtProgNameArray, HTMLChrFmtProgNameTable, 
+    return pHTMLChrFmtProgNameArray ? *pHTMLChrFmtProgNameArray :
+           *NewProgNameArray( pHTMLChrFmtProgNameArray, HTMLChrFmtProgNameTable,
             sizeof ( HTMLChrFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetPageDescProgNameArray()
 {
-    return pPageDescProgNameArray ? *pPageDescProgNameArray : 
-           *NewProgNameArray( pPageDescProgNameArray, PageDescProgNameTable, 
+    return pPageDescProgNameArray ? *pPageDescProgNameArray :
+           *NewProgNameArray( pPageDescProgNameArray, PageDescProgNameTable,
             sizeof ( PageDescProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
 const SvStringsDtor& SwStyleNameMapper::GetNumRuleProgNameArray()
 {
-    return pNumRuleProgNameArray ? *pNumRuleProgNameArray : 
-           *NewProgNameArray( pNumRuleProgNameArray, NumRuleProgNameTable, 
+    return pNumRuleProgNameArray ? *pNumRuleProgNameArray :
+           *NewProgNameArray( pNumRuleProgNameArray, NumRuleProgNameTable,
             sizeof ( NumRuleProgNameTable ) / sizeof ( SwTableEntry ) );
 }
 
@@ -1087,7 +1091,7 @@ const SvStringsDtor& SwStyleNameMapper::GetNumRuleProgNameArray()
 const String SwStyleNameMapper::GetSpecialExtraProgName( const String& rExtraUIName )
 {
     String aRes = rExtraUIName;
-    BOOL bChgName = FALSE;
+    sal_Bool bChgName = sal_False;
     const SvStringsDtor& rExtraArr = GetExtraUINameArray();
     static sal_uInt16 nIds[] =
     {
@@ -1102,7 +1106,7 @@ const String SwStyleNameMapper::GetSpecialExtraProgName( const String& rExtraUIN
     {
         if (aRes == *rExtraArr[ *pIds ])
         {
-            bChgName = TRUE;
+            bChgName = sal_True;
             break;
         }
     }
@@ -1114,7 +1118,7 @@ const String SwStyleNameMapper::GetSpecialExtraProgName( const String& rExtraUIN
 const String SwStyleNameMapper::GetSpecialExtraUIName( const String& rExtraProgName )
 {
     String aRes = rExtraProgName;
-    BOOL bChgName = FALSE;
+    sal_Bool bChgName = sal_False;
     const SvStringsDtor& rExtraArr = GetExtraProgNameArray();
     static sal_uInt16 nIds[] =
     {
@@ -1130,7 +1134,7 @@ const String SwStyleNameMapper::GetSpecialExtraUIName( const String& rExtraProgN
     {
         if (aRes == *rExtraArr[ *pIds ])
         {
-            bChgName = TRUE;
+            bChgName = sal_True;
             break;
         }
     }
