@@ -40,7 +40,6 @@
 #include <docary.hxx>
 #include <xmloff/odffields.hxx>
 #include <editsh.hxx>
-#include <errhdl.hxx>
 #include <fmtanchr.hxx>
 #include <frmfmt.hxx>
 #include <functional>
@@ -59,7 +58,6 @@
 #include <swserv.hxx>
 #include <swundo.hxx>
 #include <tools/pstm.hxx>
-#include <undobj.hxx>
 #include <unocrsr.hxx>
 #include <viscrs.hxx>
 #include <stdio.h>
@@ -248,7 +246,7 @@ namespace
             bind(&::rtl::OUString::equals, bind(&IMark::GetName, _1), rName));
     }
 
-#if FALSE
+#if 0
     static void lcl_DebugMarks(IDocumentMarkAccess::container_t vMarks)
     {
         OSL_TRACE("%d Marks", vMarks.size());
@@ -294,8 +292,7 @@ IDocumentMarkAccess::MarkType IDocumentMarkAccess::GetType(const IMark& rBkmk)
         return NAVIGATOR_REMINDER;
     else
     {
-        OSL_ENSURE(false,
-            "IDocumentMarkAccess::GetType(..)"
+        OSL_FAIL("IDocumentMarkAccess::GetType(..)"
             " - unknown MarkType. This needs to be fixed!");
         return UNO_BOOKMARK;
     }
@@ -322,7 +319,7 @@ namespace sw { namespace mark
         const ::rtl::OUString& rName,
         const IDocumentMarkAccess::MarkType eType)
     {
-#if FALSE
+#if 0
         {
             ::rtl::OString sName = ::rtl::OUStringToOString(rName, RTL_TEXTENCODING_UTF8);
             const SwPosition* const pPos1 = rPaM.GetPoint();
@@ -353,28 +350,28 @@ namespace sw { namespace mark
         switch(eType)
         {
             case IDocumentMarkAccess::TEXT_FIELDMARK:
-                pMark = shared_ptr<IMark>(new TextFieldmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new TextFieldmark(rPaM));
                 break;
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-                pMark = shared_ptr<IMark>(new CheckboxFieldmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new CheckboxFieldmark(rPaM));
                 break;
             case IDocumentMarkAccess::NAVIGATOR_REMINDER:
-                pMark = shared_ptr<IMark>(new NavigatorReminder(rPaM));
+                pMark = boost::shared_ptr<IMark>(new NavigatorReminder(rPaM));
                 break;
             case IDocumentMarkAccess::BOOKMARK:
-                pMark = shared_ptr<IMark>(new Bookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new Bookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::DDE_BOOKMARK:
-                pMark = shared_ptr<IMark>(new DdeBookmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new DdeBookmark(rPaM));
                 break;
             case IDocumentMarkAccess::CROSSREF_HEADING_BOOKMARK:
-                pMark = shared_ptr<IMark>(new CrossRefHeadingBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new CrossRefHeadingBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::CROSSREF_NUMITEM_BOOKMARK:
-                pMark = shared_ptr<IMark>(new CrossRefNumItemBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new CrossRefNumItemBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::UNO_BOOKMARK:
-                pMark = shared_ptr<IMark>(new UnoMark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new UnoMark(rPaM));
                 break;
         }
         OSL_ENSURE(pMark.get(),
@@ -396,12 +393,10 @@ namespace sw { namespace mark
             case IDocumentMarkAccess::BOOKMARK:
             case IDocumentMarkAccess::CROSSREF_NUMITEM_BOOKMARK:
             case IDocumentMarkAccess::CROSSREF_HEADING_BOOKMARK:
-            // if(dynamic_cast<IBookmark*>)
                 lcl_InsertMarkSorted(m_vBookmarks, pMark);
                 break;
             case IDocumentMarkAccess::TEXT_FIELDMARK:
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-            // if(dynamic_cast<IFieldmark*>
                 lcl_InsertMarkSorted(m_vFieldmarks, pMark);
                 break;
             case IDocumentMarkAccess::NAVIGATOR_REMINDER:
@@ -411,7 +406,7 @@ namespace sw { namespace mark
                 break;
         }
         pMarkBase->InitDoc(m_pDoc);
-#if FALSE
+#if 0
         OSL_TRACE("--- makeType ---");
         OSL_TRACE("Marks");
         lcl_DebugMarks(m_vMarks);
@@ -522,7 +517,7 @@ namespace sw { namespace mark
         // restore sorting if needed
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("correctMarksAbsolute");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -562,7 +557,7 @@ namespace sw { namespace mark
         // restore sorting if needed
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("correctMarksRelative");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -612,7 +607,7 @@ namespace sw { namespace mark
             {
                 // completely in range
 
-                // --> OD 2009-08-07 #i92125#
+                // #i92125#
                 bool bKeepCrossRefBkmk( false );
                 {
                     if ( rStt == rEnd &&
@@ -630,7 +625,6 @@ namespace sw { namespace mark
                         pSaveBkmk->push_back(SaveBookmark(true, true, *pMark, rStt, pSttIdx));
                     vMarksToDelete.push_back(ppMark);
                 }
-                // <--
             }
             else if(isPosInRange ^ isOtherPosInRange)
             {
@@ -647,7 +641,7 @@ namespace sw { namespace mark
                         rEnd,
                         isPosInRange ? pMark->GetOtherMarkPos() : pMark->GetMarkPos());
 
-                // --> OD 2009-08-06 #i92125#
+                // #i92125#
                 // no move of position for cross-reference bookmarks,
                 // if move occurs inside a certain node
                 if ( ( IDocumentMarkAccess::GetType(*pMark) !=
@@ -664,23 +658,22 @@ namespace sw { namespace mark
                     // illegal selection? collapse the mark and restore sorting later
                     isSortingNeeded |= lcl_FixCorrectedMark(isPosInRange, isOtherPosInRange, pMark);
                 }
-                // <--
             }
         }
 
         // we just remembered the iterators to delete, so we do not need to search
-        // for the shared_ptr<> (the entry in m_vMarks) again
+        // for the boost::shared_ptr<> (the entry in m_vMarks) again
         // reverse iteration, since erasing an entry invalidates iterators
         // behind it (the iterators in vMarksToDelete are sorted)
         for(vector<const_iterator_t>::reverse_iterator pppMark = vMarksToDelete.rbegin();
             pppMark != vMarksToDelete.rend();
-            pppMark++)
+            ++pppMark)
         {
             deleteMark(*pppMark);
         }
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("deleteMarks");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -706,7 +699,6 @@ namespace sw { namespace mark
             }
             case IDocumentMarkAccess::TEXT_FIELDMARK:
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-            // if(dynamic_cast<IFieldmark*>
             {
                 IDocumentMarkAccess::iterator_t ppFieldmark = lcl_FindMark(m_vFieldmarks, *ppMark);
                 OSL_ENSURE(ppFieldmark != m_vFieldmarks.end(),
@@ -724,7 +716,24 @@ namespace sw { namespace mark
         DdeBookmark* const pDdeBookmark = dynamic_cast<DdeBookmark*>(ppMark->get());
         if(pDdeBookmark)
             pDdeBookmark->DeregisterFromDoc(m_pDoc);
-        m_vMarks.erase(m_vMarks.begin() + (ppMark - m_vMarks.begin())); // clumsy const-cast
+        //Effective STL Item 27, get a non-const iterator aI at the same
+        //position as const iterator ppMark was
+        iterator_t aI = m_vMarks.begin();
+        std::advance(aI, std::distance<const_iterator_t>(aI, ppMark));
+
+        //fdo#37974
+        //a) a mark destructor may callback into this method.
+        //b) vector::erase first calls the destructor of the object, then
+        //removes it from the vector.
+        //So if the only reference to the object is the one
+        //in the vector then we may reenter this method when the mark
+        //is destructed but before it is removed, i.e. findMark still
+        //finds the object whose destructor is being run. Take a temp
+        //extra reference on the shared_ptr, remove the entry from the
+        //vector, and on xHoldPastErase release findMark won't find
+        //it anymore.
+        pMark_t xHoldPastErase = *aI;
+        m_vMarks.erase(aI);
     }
 
     void MarkManager::deleteMark(const IMark* const pMark)
@@ -749,7 +758,7 @@ namespace sw { namespace mark
         iterator_t pMarkHigh = m_vMarks.end();
         iterator_t pMarkFound = find_if(
             pMarkLow, pMarkHigh,
-            bind(equal_to<const IMark*>(), bind(&shared_ptr<IMark>::get, _1), pMark));
+            bind(equal_to<const IMark*>(), bind(&boost::shared_ptr<IMark>::get, _1), pMark));
         if(pMarkFound != pMarkHigh)
             deleteMark(pMarkFound);
     }
@@ -840,10 +849,6 @@ namespace sw { namespace mark
 }} // namespace ::sw::mark
 
 
-// old implementation
-
-//SV_IMPL_OP_PTRARR_SORT(SwBookmarks, SwBookmarkPtr)
-
 #define PCURCRSR (_pCurrCrsr)
 #define FOREACHPAM_START(pSttCrsr) \
     {\
@@ -888,19 +893,19 @@ namespace
     class _SwSaveTypeCountContent
     {
         union {
-            struct { USHORT nType, nCount; } TC;
-            ULONG nTypeCount;
+            struct { sal_uInt16 nType, nCount; } TC;
+            sal_uLong nTypeCount;
             } TYPECOUNT;
         xub_StrLen nContent;
 
     public:
         _SwSaveTypeCountContent() { TYPECOUNT.nTypeCount = 0; nContent = 0; }
-        _SwSaveTypeCountContent( USHORT nType )
+        _SwSaveTypeCountContent( sal_uInt16 nType )
             {
                 SetTypeAndCount( nType, 0 );
                 nContent = 0;
             }
-        _SwSaveTypeCountContent( const SvULongs& rArr, USHORT& rPos )
+        _SwSaveTypeCountContent( const SvULongs& rArr, sal_uInt16& rPos )
             {
                 TYPECOUNT.nTypeCount = rArr[ rPos++ ];
                 nContent = static_cast<xub_StrLen>(rArr[ rPos++ ]);
@@ -911,17 +916,17 @@ namespace
             rArr.Insert( nContent, rArr.Count() );
         }
 
-        void SetType( USHORT n )		{ TYPECOUNT.TC.nType = n; }
-        USHORT GetType() const 			{ return TYPECOUNT.TC.nType; }
+        void SetType( sal_uInt16 n )		{ TYPECOUNT.TC.nType = n; }
+        sal_uInt16 GetType() const 			{ return TYPECOUNT.TC.nType; }
         void IncType() 	 				{ ++TYPECOUNT.TC.nType; }
         void DecType() 	 				{ --TYPECOUNT.TC.nType; }
 
-        void SetCount( USHORT n ) 		{ TYPECOUNT.TC.nCount = n; }
-        USHORT GetCount() const 		{ return TYPECOUNT.TC.nCount; }
-        USHORT IncCount()  				{ return ++TYPECOUNT.TC.nCount; }
-        USHORT DecCount()  				{ return --TYPECOUNT.TC.nCount; }
+        void SetCount( sal_uInt16 n ) 		{ TYPECOUNT.TC.nCount = n; }
+        sal_uInt16 GetCount() const 		{ return TYPECOUNT.TC.nCount; }
+        sal_uInt16 IncCount()  				{ return ++TYPECOUNT.TC.nCount; }
+        sal_uInt16 DecCount()  				{ return --TYPECOUNT.TC.nCount; }
 
-        void SetTypeAndCount( USHORT nT, USHORT nC )
+        void SetTypeAndCount( sal_uInt16 nT, sal_uInt16 nC )
             { TYPECOUNT.TC.nCount = nC; TYPECOUNT.TC.nType = nT; }
 
         void SetContent( xub_StrLen n )		{ nContent = n; }
@@ -937,9 +942,9 @@ namespace
     static const int BEHIND_SAME_NODE = 3;     // Same node index but content index behind given content index
     static const int BEHIND_NODE = 4;          // Position behind the given node index
 
-    static int lcl_RelativePosition( const SwPosition& rPos, ULONG nNode, xub_StrLen nCntnt )
+    static int lcl_RelativePosition( const SwPosition& rPos, sal_uLong nNode, xub_StrLen nCntnt )
     {
-        ULONG nIndex = rPos.nNode.GetIndex();
+        sal_uLong nIndex = rPos.nNode.GetIndex();
         int nReturn = BEFORE_NODE;
         if( nIndex == nNode )
         {
@@ -962,17 +967,17 @@ namespace
         return rPos.nNode > rNdIdx || ( pIdx && rPos.nNode == rNdIdx && rPos.nContent > pIdx->GetIndex() );
     }
 
-    static void lcl_ChkPaM( SvULongs& rSaveArr, ULONG nNode, xub_StrLen nCntnt,
+    static void lcl_ChkPaM( SvULongs& rSaveArr, sal_uLong nNode, xub_StrLen nCntnt,
                     const SwPaM& rPam, _SwSaveTypeCountContent& rSave,
-                    BOOL bChkSelDirection )
+                    sal_Bool bChkSelDirection )
     {
         // SelektionsRichtung beachten
-        bool bBound1IsStart = !bChkSelDirection ? TRUE :
+        bool bBound1IsStart = !bChkSelDirection ? sal_True :
                             ( *rPam.GetPoint() < *rPam.GetMark()
                                 ? rPam.GetPoint() == &rPam.GetBound()
                                 : rPam.GetMark() == &rPam.GetBound());
 
-        const SwPosition* pPos = &rPam.GetBound( TRUE );
+        const SwPosition* pPos = &rPam.GetBound( sal_True );
         if( pPos->nNode.GetIndex() == nNode &&
             ( bBound1IsStart ? pPos->nContent.GetIndex() < nCntnt
                                 : pPos->nContent.GetIndex() <= nCntnt ))
@@ -981,7 +986,7 @@ namespace
             rSave.Add( rSaveArr );
         }
 
-        pPos = &rPam.GetBound( FALSE );
+        pPos = &rPam.GetBound( sal_False );
         if( pPos->nNode.GetIndex() == nNode &&
             ( (bBound1IsStart && bChkSelDirection)
                         ? pPos->nContent.GetIndex() <= nCntnt
@@ -1078,12 +1083,12 @@ void SaveBookmark::SetInDoc(
             if(pIdx && !m_nNode2)
                 aPam.GetMark()->nContent += m_nCntnt2;
             else
-                aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(FALSE), m_nCntnt2);
+                aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(sal_False), m_nCntnt2);
         }
         else
         {
             aPam.GetMark()->nNode = m_nNode2;
-            aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(FALSE), m_nCntnt2);
+            aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(sal_False), m_nCntnt2);
         }
     }
 
@@ -1103,7 +1108,7 @@ void SaveBookmark::SetInDoc(
     }
 
     if(!aPam.HasMark()
-        || CheckNodesRange(aPam.GetPoint()->nNode, aPam.GetMark()->nNode, TRUE))
+        || CheckNodesRange(aPam.GetPoint()->nNode, aPam.GetMark()->nNode, sal_True))
     {
         ::sw::mark::IBookmark* const pBookmark = dynamic_cast< ::sw::mark::IBookmark* >(pDoc->getIDocumentMarkAccess()->makeMark(aPam, m_aName, m_eOrigBkmType));
         if(pBookmark)
@@ -1145,13 +1150,13 @@ void _DelBookmarks(
     // Array, das alle Angaben auf die Position als Offset speichert.
     // Die neue Zuordung erfolgt nach dem Moven.
     SwRedlineTbl& rTbl = (SwRedlineTbl&)pDoc->GetRedlineTbl();
-    for(USHORT nCnt = 0; nCnt < rTbl.Count(); ++nCnt )
+    for(sal_uInt16 nCnt = 0; nCnt < rTbl.Count(); ++nCnt )
     {
         // liegt auf der Position ??
         SwRedline* pRedl = rTbl[ nCnt ];
 
-        SwPosition *pRStt = &pRedl->GetBound(TRUE),
-                   *pREnd = &pRedl->GetBound(FALSE);
+        SwPosition *pRStt = &pRedl->GetBound(sal_True),
+                   *pREnd = &pRedl->GetBound(sal_False);
         if( *pRStt > *pREnd )
         {
             SwPosition *pTmp = pRStt; pRStt = pREnd, pREnd = pTmp;
@@ -1164,11 +1169,11 @@ void _DelBookmarks(
                 pRStt->nContent = *pEndIdx;
             else
             {
-                BOOL bStt = TRUE;
+                sal_Bool bStt = sal_True;
                 SwCntntNode* pCNd = pRStt->nNode.GetNode().GetCntntNode();
                 if( !pCNd && 0 == ( pCNd = pDoc->GetNodes().GoNext( &pRStt->nNode )) )
                 {
-                    bStt = FALSE;
+                    bStt = sal_False;
                     pRStt->nNode = rStt;
                     if( 0 == ( pCNd = pDoc->GetNodes().GoPrevious( &pRStt->nNode )) )
                     {
@@ -1187,11 +1192,11 @@ void _DelBookmarks(
                 pREnd->nContent = *pSttIdx;
             else
             {
-                BOOL bStt = FALSE;
+                sal_Bool bStt = sal_False;
                 SwCntntNode* pCNd = pREnd->nNode.GetNode().GetCntntNode();
                 if( !pCNd && 0 == ( pCNd = pDoc->GetNodes().GoPrevious( &pREnd->nNode )) )
                 {
-                    bStt = TRUE;
+                    bStt = sal_True;
                     pREnd->nNode = rEnd;
                     if( 0 == ( pCNd = pDoc->GetNodes().GoNext( &pREnd->nNode )) )
                     {
@@ -1207,10 +1212,10 @@ void _DelBookmarks(
 }
 
 void _SaveCntntIdx(SwDoc* pDoc,
-    ULONG nNode,
+    sal_uLong nNode,
     xub_StrLen nCntnt,
     SvULongs& rSaveArr,
-    BYTE nSaveFly)
+    sal_uInt8 nSaveFly)
 {
     // 1. Bookmarks
     _SwSaveTypeCountContent aSave;
@@ -1289,9 +1294,9 @@ void _SaveCntntIdx(SwDoc* pDoc,
         if( pNode )
         {
 
-            SwFrm* pFrm = pNode->GetFrm();
+            SwFrm* pFrm = pNode->getLayoutFrm( pDoc->GetCurrentLayout() );
 #if OSL_DEBUG_LEVEL > 1
-            static BOOL bViaDoc = FALSE;
+            static sal_Bool bViaDoc = sal_False;
             if( bViaDoc )
                 pFrm = NULL;
 #endif
@@ -1385,14 +1390,14 @@ void _SaveCntntIdx(SwDoc* pDoc,
                 if( _pStkCrsr )
                 do {
                     lcl_ChkPaM( rSaveArr, nNode, nCntnt, *_pStkCrsr,
-                                aSave, FALSE );
+                                aSave, sal_False );
                     aSave.IncCount();
                 } while ( (_pStkCrsr != 0 ) &&
                     ((_pStkCrsr=(SwPaM *)_pStkCrsr->GetNext()) != PCURSH->GetStkCrsr()) );
 
                 FOREACHPAM_START( PCURSH->_GetCrsr() )
                     lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR,
-                                aSave, FALSE );
+                                aSave, sal_False );
                     aSave.IncCount();
                 FOREACHPAM_END()
 
@@ -1403,10 +1408,10 @@ void _SaveCntntIdx(SwDoc* pDoc,
     {
         aSave.SetTypeAndCount( 0x400, 0 );
         const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-        for( USHORT n = 0; n < rTbl.Count(); ++n )
+        for( sal_uInt16 n = 0; n < rTbl.Count(); ++n )
         {
             FOREACHPAM_START( rTbl[ n ] )
-                lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, FALSE );
+                lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, sal_False );
                 aSave.IncCount();
             FOREACHPAM_END()
 
@@ -1415,7 +1420,7 @@ void _SaveCntntIdx(SwDoc* pDoc,
             if( pUnoTblCrsr )
             {
                 FOREACHPAM_START( &pUnoTblCrsr->GetSelRing() )
-                    lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, FALSE );
+                    lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, sal_False );
                     aSave.IncCount();
                 FOREACHPAM_END()
             }
@@ -1426,15 +1431,15 @@ void _SaveCntntIdx(SwDoc* pDoc,
 
 void _RestoreCntntIdx(SwDoc* pDoc,
     SvULongs& rSaveArr,
-    ULONG nNode,
+    sal_uLong nNode,
     xub_StrLen nOffset,
-    BOOL bAuto)
+    sal_Bool bAuto)
 {
     SwCntntNode* pCNd = pDoc->GetNodes()[ nNode ]->GetCntntNode();
     const SwRedlineTbl& rRedlTbl = pDoc->GetRedlineTbl();
     SwSpzFrmFmts* pSpz = pDoc->GetSpzFrmFmts();
     IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
-    USHORT n = 0;
+    sal_uInt16 n = 0;
     while( n < rSaveArr.Count() )
     {
         _SwSaveTypeCountContent aSave( rSaveArr, n );
@@ -1493,17 +1498,17 @@ void _RestoreCntntIdx(SwDoc* pDoc,
                 {
                     SwFrmFmt *pFrmFmt = (*pSpz)[ aSave.GetCount() ];
                     SfxPoolItem *pAnchor = (SfxPoolItem*)&pFrmFmt->GetAnchor();
-                    pFrmFmt->SwModify::Modify( pAnchor, pAnchor );
+                    pFrmFmt->NotifyClients( pAnchor, pAnchor );
                 }
                 break;
 
             case 0x0800:
             case 0x0801:
                 {
-                    USHORT nCnt = 0;
                     SwCrsrShell* pShell = pDoc->GetEditShell();
                     if( pShell )
                     {
+                        sal_uInt16 nCnt = 0;
                         FOREACHSHELL_START( pShell )
                             SwPaM *_pStkCrsr = PCURSH->GetStkCrsr();
                             if( _pStkCrsr )
@@ -1541,9 +1546,9 @@ void _RestoreCntntIdx(SwDoc* pDoc,
         case 0x0400:
         case 0x0401:
             {
-                USHORT nCnt = 0;
+                sal_uInt16 nCnt = 0;
                 const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-                for( USHORT i = 0; i < rTbl.Count(); ++i )
+                for( sal_uInt16 i = 0; i < rTbl.Count(); ++i )
                 {
                     FOREACHPAM_START( rTbl[ i ] )
                         if( aSave.GetCount() == nCnt )
@@ -1597,7 +1602,7 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
     const IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
     SwCntntNode* pCNd = (SwCntntNode*)rNd.GetCntntNode();
 
-    USHORT n = 0;
+    sal_uInt16 n = 0;
     while( n < rSaveArr.Count() )
     {
         _SwSaveTypeCountContent aSave( rSaveArr, n );
@@ -1660,10 +1665,10 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
             case 0x0800:
             case 0x0801:
                 {
-                    USHORT nCnt = 0;
                     SwCrsrShell* pShell = pDoc->GetEditShell();
                     if( pShell )
                     {
+                        sal_uInt16 nCnt = 0;
                         FOREACHSHELL_START( pShell )
                             SwPaM *_pStkCrsr = PCURSH->GetStkCrsr();
                             if( _pStkCrsr )
@@ -1701,9 +1706,9 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
             case 0x0400:
             case 0x0401:
                 {
-                    USHORT nCnt = 0;
+                    sal_uInt16 nCnt = 0;
                     const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-                    for( USHORT i = 0; i < rTbl.Count(); ++i )
+                    for( sal_uInt16 i = 0; i < rTbl.Count(); ++i )
                     {
                         FOREACHPAM_START( rTbl[ i ] )
                             if( aSave.GetCount() == nCnt )
