@@ -34,6 +34,7 @@
 #include <editsh.hxx>
 #include <edimp.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <ndtxt.hxx>
 #include <paratr.hxx>
 #include <swundo.hxx>
@@ -57,7 +58,7 @@ void SwPamRanges::Insert( const SwNodeIndex& rIdx1, const SwNodeIndex& rIdx2 )
     if( aRg.nEnd < aRg.nStart )
     {	aRg.nStart = aRg.nEnd; aRg.nEnd = rIdx1.GetIndex(); }
 
-    USHORT nPos = 0;
+    sal_uInt16 nPos = 0;
     const SwPamRange* pTmp;
     if( Count() && Seek_Entry( aRg, &nPos ))		// suche Insert Position
     {
@@ -71,9 +72,9 @@ void SwPamRanges::Insert( const SwNodeIndex& rIdx1, const SwNodeIndex& rIdx2 )
             return;		// ende, weil schon alle zusammengefasst waren
     }
 
-    BOOL bEnde;
+    sal_Bool bEnde;
     do {
-        bEnde = TRUE;
+        bEnde = sal_True;
 
         // mit dem Vorgaenger zusammenfassen ??
         if( nPos > 0 )
@@ -82,7 +83,7 @@ void SwPamRanges::Insert( const SwNodeIndex& rIdx1, const SwNodeIndex& rIdx2 )
                 || pTmp->nEnd+1 == aRg.nStart )
             {
                 aRg.nStart = pTmp->nStart;
-                bEnde = FALSE;
+                bEnde = sal_False;
                 Remove( --nPos, 1 );		// zusammenfassen
             }
             // SSelection im Bereich ??
@@ -96,7 +97,7 @@ void SwPamRanges::Insert( const SwNodeIndex& rIdx1, const SwNodeIndex& rIdx2 )
                 pTmp->nStart == aRg.nEnd+1 )
             {
                 aRg.nEnd = pTmp->nEnd;
-                bEnde = FALSE;
+                bEnde = sal_False;
                 Remove( nPos, 1 );		// zusammenfassen
             }
 
@@ -111,9 +112,9 @@ void SwPamRanges::Insert( const SwNodeIndex& rIdx1, const SwNodeIndex& rIdx2 )
 
 
 
-SwPaM& SwPamRanges::SetPam( USHORT nArrPos, SwPaM& rPam )
+SwPaM& SwPamRanges::SetPam( sal_uInt16 nArrPos, SwPaM& rPam )
 {
-    ASSERT_ID( nArrPos < Count(), ERR_VAR_IDX );
+    OSL_ASSERT( nArrPos < Count() );
     const SwPamRange& rTmp = *(GetData() + nArrPos );
     rPam.GetPoint()->nNode = rTmp.nStart;
     rPam.GetPoint()->nContent.Assign( rPam.GetCntntNode(), 0 );
@@ -146,20 +147,20 @@ const SwNumRule* SwEditShell::GetOutlineNumRule() const
 
 // Absaetze ohne Numerierung, aber mit Einzuegen
 
-BOOL SwEditShell::NoNum()
+sal_Bool SwEditShell::NoNum()
 {
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
     StartAllAction();
 
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )			// Mehrfachselektion ?
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
             bRet = bRet && GetDoc()->NoNum( aRangeArr.SetPam( n, aPam ));
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     else
         bRet = GetDoc()->NoNum( *pCrsr );
@@ -170,9 +171,9 @@ BOOL SwEditShell::NoNum()
 // Loeschen, Splitten der Aufzaehlungsliste
 
 // -> #i29560#
-BOOL SwEditShell::HasNumber() const
+sal_Bool SwEditShell::HasNumber() const
 {
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
 
     const SwTxtNode * pTxtNd =
         GetCrsr()->GetPoint()->nNode.GetNode().GetTxtNode();
@@ -181,23 +182,21 @@ BOOL SwEditShell::HasNumber() const
     {
         bResult = pTxtNd->HasNumber();
 
-        // --> OD 2005-10-26 #b6340308#
         // special case: outline numbered, not counted paragraph
         if ( bResult &&
              pTxtNd->GetNumRule() == GetDoc()->GetOutlineNumRule() &&
              !pTxtNd->IsCountedInList() )
         {
-            bResult = FALSE;
+            bResult = sal_False;
         }
-        // <--
     }
 
     return bResult;
 }
 
-BOOL SwEditShell::HasBullet() const
+sal_Bool SwEditShell::HasBullet() const
 {
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
 
     const SwTxtNode * pTxtNd =
         GetCrsr()->GetPoint()->nNode.GetNode().GetTxtNode();
@@ -218,14 +217,14 @@ void SwEditShell::DelNumRules()
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )			// Mehrfachselektion ?
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
         {
             GetDoc()->DelNumRules( aRangeArr.SetPam( n, aPam ) );
         }
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     else
         GetDoc()->DelNumRules( *pCrsr );
@@ -234,10 +233,9 @@ void SwEditShell::DelNumRules()
     // ueberfluessig sein, aber VB hatte darueber eine Bugrep.
     CallChgLnk();
 
-    // --> OD 2005-10-24 #126346# - cursor can not be anymore in
-    // front of a label, because numbering/bullet is deleted.
-    SetInFrontOfLabel( FALSE );
-    // <--
+    // cursor can not be anymore in front of a label,
+    // because numbering/bullet is deleted.
+    SetInFrontOfLabel( sal_False );
 
     GetDoc()->SetModified();
     EndAllAction();
@@ -246,22 +244,22 @@ void SwEditShell::DelNumRules()
 // Hoch-/Runterstufen
 
 
-BOOL SwEditShell::NumUpDown( BOOL bDown )
+sal_Bool SwEditShell::NumUpDown( sal_Bool bDown )
 {
     StartAllAction();
 
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() == pCrsr )			// keine Mehrfachselektion ?
         bRet = GetDoc()->NumUpDown( *pCrsr, bDown );
     else
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
             bRet = bRet && GetDoc()->NumUpDown( aRangeArr.SetPam( n, aPam ), bDown );
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     GetDoc()->SetModified();
 
@@ -276,9 +274,9 @@ BOOL SwEditShell::NumUpDown( BOOL bDown )
     return bRet;
 }
 // -> #i23726#
-BOOL SwEditShell::IsFirstOfNumRule() const
+sal_Bool SwEditShell::IsFirstOfNumRule() const
 {
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
 
     SwPaM * pCrsr = GetCrsr();
     if (pCrsr->GetNext() == pCrsr)
@@ -289,9 +287,9 @@ BOOL SwEditShell::IsFirstOfNumRule() const
     return bResult;
 }
 
-BOOL SwEditShell::IsFirstOfNumRule(const SwPaM & rPaM) const
+sal_Bool SwEditShell::IsFirstOfNumRule(const SwPaM & rPaM) const
 {
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
 
     SwPosition aPos(*rPaM.GetPoint());
     bResult = GetDoc()->IsFirstOfNumRule(aPos);
@@ -317,10 +315,8 @@ void SwEditShell::ChangeIndentOfAllListLevels( short nDiff )
         aRule.ChangeIndent( nDiff );
         // <--
 
-        // --> OD 2008-03-17 #refactorlists#
         // no start of new list
         SetCurNumRule( aRule, false );
-        // <--
     }
 
     EndAllAction();
@@ -341,13 +337,9 @@ void SwEditShell::SetIndent(short nIndent, const SwPosition & rPos)
         SwTxtNode * pTxtNode = aPaM.GetNode()->GetTxtNode();
 
         // --> OD 2008-06-09 #i90078#
-//        int nLevel = -1;
-//        int nReferenceLevel = pTxtNode->GetActualListLevel();
-//        if (! IsFirstOfNumRule(aPaM))
-//            nLevel = nReferenceLevel;
 
         SwNumRule aRule(*pCurNumRule);
-//        aRule.ChangeIndent(nIndent, nLevel, nReferenceLevel, FALSE);
+
         if ( IsFirstOfNumRule() )
         {
             aRule.SetIndentOfFirstListLevelAndChangeOthers( nIndent );
@@ -355,13 +347,12 @@ void SwEditShell::SetIndent(short nIndent, const SwPosition & rPos)
         else if ( pTxtNode->GetActualListLevel() >= 0  )
         {
             aRule.SetIndent( nIndent,
-                             static_cast<USHORT>(pTxtNode->GetActualListLevel()) );
+                             static_cast<sal_uInt16>(pTxtNode->GetActualListLevel()) );
         }
         // <--
 
         // --> OD 2005-02-18 #i42921# - 3rd parameter = false in order to
         // suppress setting of num rule at <aPaM>.
-        // --> OD 2008-03-17 #refactorlists#
         // do not apply any list
         GetDoc()->SetNumRule( aPaM, aRule, false, String(), sal_False );
         // <--
@@ -371,7 +362,7 @@ void SwEditShell::SetIndent(short nIndent, const SwPosition & rPos)
 }
 // <- #i23725#
 
-BOOL SwEditShell::MoveParagraph( long nOffset )
+sal_Bool SwEditShell::MoveParagraph( long nOffset )
 {
     StartAllAction();
 
@@ -383,7 +374,7 @@ BOOL SwEditShell::MoveParagraph( long nOffset )
         pCrsr->DeleteMark();
     }
 
-    BOOL bRet = GetDoc()->MoveParagraph( *pCrsr, nOffset );
+    sal_Bool bRet = GetDoc()->MoveParagraph( *pCrsr, nOffset );
 
     GetDoc()->SetModified();
     EndAllAction();
@@ -410,11 +401,11 @@ void SwEditShell::GetCurrentOutlineLevels( sal_uInt8& rUpper, sal_uInt8& rLower
     aCrsr.SetMark();
     if( pCrsr->HasMark() )
         *aCrsr.GetPoint() = *pCrsr->End();
-    GetDoc()->GotoNextNum( *aCrsr.GetPoint(), FALSE,
+    GetDoc()->GotoNextNum( *aCrsr.GetPoint(), sal_False,
                             &rUpper, &rLower );
 }
 
-BOOL SwEditShell::MoveNumParas( BOOL bUpperLower, BOOL bUpperLeft )
+sal_Bool SwEditShell::MoveNumParas( sal_Bool bUpperLower, sal_Bool bUpperLeft )
 {
     StartAllAction();
 
@@ -426,9 +417,9 @@ BOOL SwEditShell::MoveNumParas( BOOL bUpperLower, BOOL bUpperLeft )
     if( pCrsr->HasMark() )
         *aCrsr.GetPoint() = *pCrsr->End();
 
-    BOOL bRet = FALSE;
-    BYTE nUpperLevel, nLowerLevel;
-    if( GetDoc()->GotoNextNum( *aCrsr.GetPoint(), FALSE,
+    sal_Bool bRet = sal_False;
+    sal_uInt8 nUpperLevel, nLowerLevel;
+    if( GetDoc()->GotoNextNum( *aCrsr.GetPoint(), sal_False,
                                 &nUpperLevel, &nLowerLevel ))
     {
         if( bUpperLower )
@@ -440,12 +431,12 @@ BOOL SwEditShell::MoveNumParas( BOOL bUpperLower, BOOL bUpperLeft )
             if( bUpperLeft )		// verschiebe nach oben
             {
                 SwPosition aPos( *aCrsr.GetMark() );
-                if( GetDoc()->GotoPrevNum( aPos, FALSE ) )
+                if( GetDoc()->GotoPrevNum( aPos, sal_False ) )
                     nOffset = aPos.nNode.GetIndex() -
                             aCrsr.GetMark()->nNode.GetIndex();
                 else
                 {
-                    ULONG nStt = aPos.nNode.GetIndex(), nIdx = nStt - 1;
+                    sal_uLong nStt = aPos.nNode.GetIndex(), nIdx = nStt - 1;
                     while( nIdx && (
                         ( pNd = GetDoc()->GetNodes()[ nIdx ])->IsSectionNode() ||
                         ( pNd->IsEndNode() && pNd->StartOfSectionNode()->IsSectionNode())))
@@ -456,11 +447,11 @@ BOOL SwEditShell::MoveNumParas( BOOL bUpperLower, BOOL bUpperLeft )
             }
             else					// verschiebe nach unten
             {
-                const SwNumRule* pOrig = aCrsr.GetNode(FALSE)->GetTxtNode()->GetNumRule();
+                const SwNumRule* pOrig = aCrsr.GetNode(sal_False)->GetTxtNode()->GetNumRule();
                 if( aCrsr.GetNode()->IsTxtNode() &&
                     pOrig == aCrsr.GetNode()->GetTxtNode()->GetNumRule() )
                 {
-                    ULONG nStt = aCrsr.GetPoint()->nNode.GetIndex(), nIdx = nStt+1;
+                    sal_uLong nStt = aCrsr.GetPoint()->nNode.GetIndex(), nIdx = nStt+1;
 
                     while (nIdx < GetDoc()->GetNodes().Count()-1)
                     {
@@ -508,23 +499,23 @@ BOOL SwEditShell::MoveNumParas( BOOL bUpperLower, BOOL bUpperLeft )
     return bRet;
 }
 
-BOOL SwEditShell::OutlineUpDown( short nOffset )
+sal_Bool SwEditShell::OutlineUpDown( short nOffset )
 {
     StartAllAction();
 
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() == pCrsr )			// keine Mehrfachselektion ?
         bRet = GetDoc()->OutlineUpDown( *pCrsr, nOffset );
     else
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
             bRet = bRet && GetDoc()->OutlineUpDown(
                                     aRangeArr.SetPam( n, aPam ), nOffset );
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     GetDoc()->SetModified();
     EndAllAction();
@@ -532,25 +523,25 @@ BOOL SwEditShell::OutlineUpDown( short nOffset )
 }
 
 
-BOOL SwEditShell::MoveOutlinePara( short nOffset )
+sal_Bool SwEditShell::MoveOutlinePara( short nOffset )
 {
     StartAllAction();
-    BOOL bRet = GetDoc()->MoveOutlinePara( *GetCrsr(), nOffset );
+    sal_Bool bRet = GetDoc()->MoveOutlinePara( *GetCrsr(), nOffset );
     EndAllAction();
     return bRet;
 }
 
 // Outlines and SubOutline are ReadOnly?
-BOOL SwEditShell::IsProtectedOutlinePara() const
+sal_Bool SwEditShell::IsProtectedOutlinePara() const
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     const SwNode& rNd = GetCrsr()->Start()->nNode.GetNode();
     if( rNd.IsTxtNode() )
     {
         const SwOutlineNodes& rOutlNd = GetDoc()->GetNodes().GetOutLineNds();
         SwNodePtr pNd = (SwNodePtr)&rNd;
-        BOOL bFirst = TRUE;
-        USHORT nPos;
+        sal_Bool bFirst = sal_True;
+        sal_uInt16 nPos;
         int nLvl(0);
         if( !rOutlNd.Seek_Entry( pNd, &nPos ) && nPos )
             --nPos;
@@ -559,26 +550,22 @@ BOOL SwEditShell::IsProtectedOutlinePara() const
         {
             SwNodePtr pTmpNd = rOutlNd[ nPos ];
 
-            // --> OD 2008-04-02 #refactorlists#
-//            BYTE nTmpLvl = GetRealLevel( pTmpNd->GetTxtNode()->
-//                                    GetTxtColl()->GetOutlineLevel() );
- //           int nTmpLvl = pTmpNd->GetTxtNode()->GetOutlineLevel();//#outline level,zhaojianwei
             int nTmpLvl = pTmpNd->GetTxtNode()->GetAttrOutlineLevel();
- //           OSL_ENSURE( nTmpLvl >= 0 && nTmpLvl < MAXLEVEL,
-            OSL_ENSURE( nTmpLvl >= 0 && nTmpLvl <= MAXLEVEL,			//<-end,zhaojianwei
+
+            OSL_ENSURE( nTmpLvl >= 0 && nTmpLvl <= MAXLEVEL,
                     "<SwEditShell::IsProtectedOutlinePara()>" );
-            // <--
+
             if( bFirst )
             {
                 nLvl = nTmpLvl;
-                bFirst = FALSE;
+                bFirst = sal_False;
             }
             else if( nLvl >= nTmpLvl )
                 break;
 
             if( pTmpNd->IsProtect() )
             {
-                bRet = TRUE;
+                bRet = sal_True;
                 break;
             }
         }
@@ -599,7 +586,7 @@ BOOL SwEditShell::IsProtectedOutlinePara() const
  * 2) outline must not be within table
  * 3) if bCopy is set, outline must not be write protected
  */
-BOOL lcl_IsOutlineMoveAndCopyable( const SwDoc* pDoc, USHORT nIdx, bool bCopy )
+sal_Bool lcl_IsOutlineMoveAndCopyable( const SwDoc* pDoc, sal_uInt16 nIdx, bool bCopy )
 {
     const SwNodes& rNds = pDoc->GetNodes();
     const SwNode* pNd = rNds.GetOutLineNds()[ nIdx ];
@@ -608,36 +595,35 @@ BOOL lcl_IsOutlineMoveAndCopyable( const SwDoc* pDoc, USHORT nIdx, bool bCopy )
             ( bCopy || !pNd->IsProtect() );                         // 3) write
 }
 
-BOOL SwEditShell::IsOutlineMovable( USHORT nIdx ) const
+sal_Bool SwEditShell::IsOutlineMovable( sal_uInt16 nIdx ) const
 {
     return lcl_IsOutlineMoveAndCopyable( GetDoc(), nIdx, false );
 }
 
-BOOL SwEditShell::IsOutlineCopyable( USHORT nIdx ) const
+sal_Bool SwEditShell::IsOutlineCopyable( sal_uInt16 nIdx ) const
 {
     return lcl_IsOutlineMoveAndCopyable( GetDoc(), nIdx, true );
 }
 
 
-BOOL SwEditShell::NumOrNoNum( BOOL bNumOn, BOOL bChkStart ) // #115901#
+sal_Bool SwEditShell::NumOrNoNum( sal_Bool bNumOn, sal_Bool bChkStart )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() == pCrsr && !pCrsr->HasMark() &&
         ( !bChkStart || !pCrsr->GetPoint()->nContent.GetIndex()) )
     {
         StartAllAction();		// Klammern fuers Updaten !!
-        // #115901#
         bRet = GetDoc()->NumOrNoNum( pCrsr->GetPoint()->nNode, !bNumOn ); // #i29560#
         EndAllAction();
     }
     return bRet;
 }
 
-BOOL SwEditShell::IsNoNum( BOOL bChkStart ) const
+sal_Bool SwEditShell::IsNoNum( sal_Bool bChkStart ) const
 {
     // ein Backspace im Absatz ohne Nummer wird zum Delete
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
     SwPaM* pCrsr = GetCrsr();
 
     if (pCrsr->GetNext() == pCrsr && !pCrsr->HasMark() &&
@@ -654,32 +640,26 @@ BOOL SwEditShell::IsNoNum( BOOL bChkStart ) const
     return bResult;
 }
 
-// --> OD 2008-02-29 #refactorlists# - removed <pHasChilds>
-BYTE SwEditShell::GetNumLevel() const
+sal_uInt8 SwEditShell::GetNumLevel() const
 {
     // gebe die akt. Ebene zurueck, auf der sich der Point vom Cursor befindet
-    //BYTE nLevel = NO_NUMBERING;	//#outline level,zhaojianwei
-    BYTE nLevel = MAXLEVEL;		//end,zhaojianwei
+    sal_uInt8 nLevel = MAXLEVEL;		//end,zhaojianwei
 
     SwPaM* pCrsr = GetCrsr();
     const SwTxtNode* pTxtNd = pCrsr->GetNode()->GetTxtNode();
 
-    // --> FME 2005-09-12 #124972# Made code robust:
     OSL_ENSURE( pTxtNd, "GetNumLevel() without text node" );
     if ( !pTxtNd )
         return nLevel;
-    // <--
 
     const SwNumRule* pRule = pTxtNd->GetNumRule();
     if(pRule)
     {
-        // --> OD 2008-05-09 #refactorlists#
         const int nListLevelOfTxtNode( pTxtNd->GetActualListLevel() );
         if ( nListLevelOfTxtNode >= 0 )
         {
-            nLevel = static_cast<BYTE>( nListLevelOfTxtNode );
+            nLevel = static_cast<sal_uInt8>( nListLevelOfTxtNode );
         }
-        // <--
     }
 
     return nLevel;
@@ -690,8 +670,6 @@ const SwNumRule* SwEditShell::GetCurNumRule() const
     return GetDoc()->GetCurrNumRule( *GetCrsr()->GetPoint() );
 }
 
-// OD 2008-02-08 #newlistlevelattrs# - add handling of parameter <bResetIndentAttrs>
-// --> OD 2008-03-17 #refactorlists#
 void SwEditShell::SetCurNumRule( const SwNumRule& rRule,
                                  const bool bCreateNewList,
                                  const String sContinuedListId,
@@ -699,43 +677,35 @@ void SwEditShell::SetCurNumRule( const SwNumRule& rRule,
 {
     StartAllAction();
 
+    GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
+
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )			// Mehrfachselektion ?
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
           {
             aRangeArr.SetPam( n, aPam );
-            // --> OD 2008-02-08 #newlistlevelattrs#
-            // --> OD 2008-03-17 #refactorlists#
             GetDoc()->SetNumRule( aPam, rRule,
                                   bCreateNewList, sContinuedListId,
                                   sal_True, bResetIndentAttrs );
-            // <--
             GetDoc()->SetCounted( aPam, true );
           }
-        GetDoc()->EndUndo( UNDO_END, NULL );
     }
     else
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
-
-        // --> OD 2008-02-08 #newlistlevelattrs#
-        // --> OD 2008-03-17 #refactorlists#
         GetDoc()->SetNumRule( *pCrsr, rRule,
                               bCreateNewList, sContinuedListId,
                               sal_True, bResetIndentAttrs );
         GetDoc()->SetCounted( *pCrsr, true );
-
-        GetDoc()->EndUndo( UNDO_END, NULL );
     }
+    GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
 
     EndAllAction();
 }
 
-String SwEditShell::GetUniqueNumRuleName( const String* pChkStr, BOOL bAutoNum ) const
+String SwEditShell::GetUniqueNumRuleName( const String* pChkStr, sal_Bool bAutoNum ) const
 {
     return GetDoc()->GetUniqueNumRuleName( pChkStr, bAutoNum );
 }
@@ -747,27 +717,27 @@ void SwEditShell::ChgNumRuleFmts( const SwNumRule& rRule )
     EndAllAction();
 }
 
-BOOL SwEditShell::ReplaceNumRule( const String& rOldRule, const String& rNewRule )
+sal_Bool SwEditShell::ReplaceNumRule( const String& rOldRule, const String& rNewRule )
 {
     StartAllAction();
-    BOOL bRet = GetDoc()->ReplaceNumRule( *GetCrsr()->GetPoint(), rOldRule, rNewRule );
+    sal_Bool bRet = GetDoc()->ReplaceNumRule( *GetCrsr()->GetPoint(), rOldRule, rNewRule );
     EndAllAction();
     return bRet;
 }
 
-void SwEditShell::SetNumRuleStart( BOOL bFlag )
+void SwEditShell::SetNumRuleStart( sal_Bool bFlag )
 {
     StartAllAction();
 
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )			// Mehrfachselektion ?
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
             GetDoc()->SetNumRuleStart( *aRangeArr.SetPam( n, aPam ).GetPoint(), bFlag );
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     else
         GetDoc()->SetNumRuleStart( *pCrsr->GetPoint(), bFlag );
@@ -775,28 +745,28 @@ void SwEditShell::SetNumRuleStart( BOOL bFlag )
     EndAllAction();
 }
 
-BOOL SwEditShell::IsNumRuleStart() const
+sal_Bool SwEditShell::IsNumRuleStart() const
 {
-    BOOL bResult = FALSE;
+    sal_Bool bResult = sal_False;
     const SwTxtNode* pTxtNd = GetCrsr()->GetNode()->GetTxtNode();
     if( pTxtNd )
-        bResult = pTxtNd->IsListRestart() ? TRUE : FALSE;
+        bResult = pTxtNd->IsListRestart() ? sal_True : sal_False;
     return bResult;
 }
 
-void SwEditShell::SetNodeNumStart( USHORT nStt )
+void SwEditShell::SetNodeNumStart( sal_uInt16 nStt )
 {
     StartAllAction();
 
     SwPaM* pCrsr = GetCrsr();
     if( pCrsr->GetNext() != pCrsr )			// Mehrfachselektion ?
     {
-        GetDoc()->StartUndo( UNDO_START, NULL );
+        GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
         SwPamRanges aRangeArr( *pCrsr );
         SwPaM aPam( *pCrsr->GetPoint() );
-        for( USHORT n = 0; n < aRangeArr.Count(); ++n )
+        for( sal_uInt16 n = 0; n < aRangeArr.Count(); ++n )
             GetDoc()->SetNodeNumStart( *aRangeArr.SetPam( n, aPam ).GetPoint(), nStt );
-        GetDoc()->EndUndo( UNDO_END, NULL );
+        GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     }
     else
         GetDoc()->SetNodeNumStart( *pCrsr->GetPoint(), nStt );
@@ -804,25 +774,19 @@ void SwEditShell::SetNodeNumStart( USHORT nStt )
     EndAllAction();
 }
 
-USHORT SwEditShell::GetNodeNumStart() const
+sal_uInt16 SwEditShell::GetNodeNumStart() const
 {
     const SwTxtNode* pTxtNd = GetCrsr()->GetNode()->GetTxtNode();
-    // --> OD 2008-02-28 #refactorlists#
     // correction: check, if list restart value is set at text node and
     // use new method <SwTxtNode::GetAttrListRestartValue()>.
     // return USHRT_MAX, if no list restart value is found.
     if ( pTxtNd && pTxtNd->HasAttrListRestartValue() )
     {
-        return static_cast<USHORT>(pTxtNd->GetAttrListRestartValue());
+        return static_cast<sal_uInt16>(pTxtNd->GetAttrListRestartValue());
     }
     return USHRT_MAX;
-    // <--
 }
 
-/*-- 26.08.2005 14:47:17---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
-// --> OD 2008-03-18 #refactorlists#
 const SwNumRule * SwEditShell::SearchNumRule( const bool bForward,
                                               const bool bNum,
                                               const bool bOutline,
@@ -833,6 +797,5 @@ const SwNumRule * SwEditShell::SearchNumRule( const bool bForward,
                                     bForward, bNum, bOutline, nNonEmptyAllowed,
                                     sListId );
 }
-// <--
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
