@@ -45,7 +45,6 @@
 #include <fmtftn.hxx>
 #include <rowfrm.hxx>
 
-#include "txtcfg.hxx"
 #include "widorp.hxx"
 #include "txtfrm.hxx"
 #include "itrtxt.hxx"
@@ -223,9 +222,17 @@ void SwTxtFrmBreak::SetRstHeight( const SwTxtMargin &rLine )
 {
     // OD, FME 2004-02-27 #106629# - consider bottom margin
     SWRECTFN( pFrm )
+    
     nRstHeight = (pFrm->*fnRect->fnGetBottomMargin)();
+    
     if ( bVert )
-        nRstHeight += nOrigin - pFrm->SwitchHorizontalToVertical( rLine.Y() );
+    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+    {
+           if ( pFrm->IsVertLR() ) 
+              nRstHeight = (*fnRect->fnYDiff)( pFrm->SwitchHorizontalToVertical( rLine.Y() ) , nOrigin );
+           else
+               nRstHeight += nOrigin - pFrm->SwitchHorizontalToVertical( rLine.Y() );	
+    }
     else
         nRstHeight += rLine.Y() - nOrigin;
 }
@@ -487,7 +494,7 @@ sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrame, SwTxtMargin &rLine )
     // --> FME 2008-09-16 #i91421#
     if ( !pMaster->GetIndPrev() )
     {
-        ULONG nLines = pMaster->GetThisLines();
+        sal_uLong nLines = pMaster->GetThisLines();
         if(nLines == 0 && pMaster->HasPara())
         {
             const SwParaPortion *pMasterPara = pMaster->GetPara();
@@ -525,7 +532,6 @@ sal_Bool WidowsAndOrphans::WouldFit( SwTxtMargin &rLine, SwTwips &rMaxHeight, sa
 
     while( nMinLines > rLine.GetLineNr() )
     {
-        DBG_LOOP;
         if( !rLine.NextLine() )
             return sal_False;
         nLineSum += rLine.GetLineHeight();
