@@ -38,6 +38,7 @@
 #include <bookmrk.hxx>
 #include <frmfmt.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <ndtxt.hxx>
 #include <ndnotxt.hxx>
 #include <unocrsr.hxx>
@@ -117,16 +118,13 @@
 #include <dcontact.hxx>
 #include <dflyobj.hxx>
 #include <crsskip.hxx>
-// OD 2004-05-07 #i28701#
 #include <vector>
-// OD 2004-05-24 #i28701#
 #include <sortedobjs.hxx>
 #include <sortopt.hxx>
-
 #include <algorithm>
 #include <iterator>
 #include <boost/bind.hpp>
-
+#include <switerator.hxx>
 
 using namespace ::com::sun::star;
 using ::rtl::OUString;
@@ -154,7 +152,7 @@ GetSupportedServiceNamesImpl(
     uno::Sequence< ::rtl::OUString > ret(nServices);
     for (size_t i = 0; i < nServices; ++i)
     {
-        ret[i] = C2U(pServices[i]);
+        ret[i] = rtl::OUString::createFromAscii(pServices[i]);
     }
     return ret;
 }
@@ -187,7 +185,7 @@ void DeepCopyPaM(SwPaM const & rSource, SwPaM & rTarget)
 struct FrameDependSortListLess
 {
     bool operator() (FrameDependSortListEntry const& r1,
-                     FrameDependSortListEntry const& r2)
+                     FrameDependSortListEntry const& r2) const
     {
         return  (r1.nIndex <  r2.nIndex)
             || ((r1.nIndex == r2.nIndex) && (r1.nOrder < r2.nOrder));
@@ -200,24 +198,24 @@ void CollectFrameAtNode( SwClient& rClnt, const SwNodeIndex& rIdx,
                          const bool _bAtCharAnchoredObjs )
 {
     // _bAtCharAnchoredObjs:
-    // <TRUE>: at-character anchored objects are collected
-    // <FALSE>: at-paragraph anchored objects are collected
+    // <sal_True>: at-character anchored objects are collected
+    // <sal_False>: at-paragraph anchored objects are collected
 
     // alle Rahmen, Grafiken und OLEs suchen, die an diesem Absatz
     // gebunden sind
     SwDoc* pDoc = rIdx.GetNode().GetDoc();
 
-    USHORT nChkType = static_cast< USHORT >((_bAtCharAnchoredObjs)
+    sal_uInt16 nChkType = static_cast< sal_uInt16 >((_bAtCharAnchoredObjs)
             ? FLY_AT_CHAR : FLY_AT_PARA);
     const SwCntntFrm* pCFrm;
     const SwCntntNode* pCNd;
-    if( pDoc->GetRootFrm() &&
+    if( pDoc->GetCurrentViewShell() &&	//swmod 071108//swmod 071225
         0 != (pCNd = rIdx.GetNode().GetCntntNode()) &&
-        0 != (pCFrm = pCNd->GetFrm()) )
+        0 != (pCFrm = pCNd->getLayoutFrm( pDoc->GetCurrentLayout())) )
     {
         const SwSortedObjs *pObjs = pCFrm->GetDrawObjs();
         if( pObjs )
-            for( USHORT i = 0; i < pObjs->Count(); ++i )
+            for( sal_uInt16 i = 0; i < pObjs->Count(); ++i )
             {
                 SwAnchoredObject* pAnchoredObj = (*pObjs)[i];
                 SwFrmFmt& rFmt = pAnchoredObj->GetFrmFmt();
@@ -239,8 +237,8 @@ void CollectFrameAtNode( SwClient& rClnt, const SwNodeIndex& rIdx,
     else
     {
         const SwSpzFrmFmts& rFmts = *pDoc->GetSpzFrmFmts();
-        USHORT nSize = rFmts.Count();
-        for ( USHORT i = 0; i < nSize; i++)
+        sal_uInt16 nSize = rFmts.Count();
+        for ( sal_uInt16 i = 0; i < nSize; i++)
         {
             const SwFrmFmt* pFmt = rFmts[ i ];
             const SwFmtAnchor& rAnchor = pFmt->GetAnchor();
@@ -271,7 +269,7 @@ void CollectFrameAtNode( SwClient& rClnt, const SwNodeIndex& rIdx,
 UnoActionContext::UnoActionContext(SwDoc *const pDoc)
     : m_pDoc(pDoc)
 {
-    SwRootFrm *const pRootFrm = m_pDoc->GetRootFrm();
+    SwRootFrm *const pRootFrm = m_pDoc->GetCurrentLayout();
     if (pRootFrm)
     {
         pRootFrm->StartAllAction();
@@ -283,7 +281,7 @@ UnoActionContext::~UnoActionContext()
     // Doc may already have been removed here
     if (m_pDoc)
     {
-        SwRootFrm *const pRootFrm = m_pDoc->GetRootFrm();
+        SwRootFrm *const pRootFrm = m_pDoc->GetCurrentLayout();
         if (pRootFrm)
         {
             pRootFrm->EndAllAction();
@@ -297,7 +295,7 @@ UnoActionContext::~UnoActionContext()
 UnoActionRemoveContext::UnoActionRemoveContext(SwDoc *const pDoc)
     : m_pDoc(pDoc)
 {
-    SwRootFrm *const pRootFrm = m_pDoc->GetRootFrm();
+    SwRootFrm *const pRootFrm = m_pDoc->GetCurrentLayout();
     if (pRootFrm)
     {
         pRootFrm->UnoRemoveAllActions();
@@ -306,14 +304,14 @@ UnoActionRemoveContext::UnoActionRemoveContext(SwDoc *const pDoc)
 
 UnoActionRemoveContext::~UnoActionRemoveContext()
 {
-    SwRootFrm *const pRootFrm = m_pDoc->GetRootFrm();
+    SwRootFrm *const pRootFrm = m_pDoc->GetCurrentLayout();
     if (pRootFrm)
     {
         pRootFrm->UnoRestoreAllActions();
     }
 }
 
-void ClientModify(SwClient* pClient, SfxPoolItem *pOld, SfxPoolItem *pNew)
+void ClientModify(SwClient* pClient, const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 {
     switch( pOld ? pOld->Which() : 0 )
     {
@@ -342,7 +340,7 @@ void SwUnoCursorHelper::SetCrsrAttr(SwPaM & rPam,
     UnoActionContext aAction(pDoc);
     if (rPam.GetNext() != &rPam)    // Ring of Cursors
     {
-        pDoc->StartUndo(UNDO_INSATTR, NULL);
+        pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_INSATTR, NULL);
 
         SwPaM *pCurrent = &rPam;
         do
@@ -356,7 +354,7 @@ void SwUnoCursorHelper::SetCrsrAttr(SwPaM & rPam,
             pCurrent= static_cast<SwPaM *>(pCurrent->GetNext());
         } while (pCurrent != &rPam);
 
-        pDoc->EndUndo(UNDO_INSATTR, NULL);
+        pDoc->GetIDocumentUndoRedo().EndUndo(UNDO_INSATTR, NULL);
     }
     else
     {
@@ -390,8 +388,8 @@ void SwUnoCursorHelper::GetCrsrAttr(SwPaM & rPam,
     {
         SwPosition const & rStart( *pCurrent->Start() );
         SwPosition const & rEnd( *pCurrent->End() );
-        const ULONG nSttNd = rStart.nNode.GetIndex();
-        const ULONG nEndNd = rEnd  .nNode.GetIndex();
+        const sal_uLong nSttNd = rStart.nNode.GetIndex();
+        const sal_uLong nEndNd = rEnd  .nNode.GetIndex();
 
         if (nEndNd - nSttNd >= nMaxLookup)
         {
@@ -402,7 +400,7 @@ void SwUnoCursorHelper::GetCrsrAttr(SwPaM & rPam,
 
         // the first node inserts the values into the get set
         // all other nodes merge their values into the get set
-        for (ULONG n = nSttNd; n <= nEndNd; ++n)
+        for (sal_uLong n = nSttNd; n <= nEndNd; ++n)
         {
             SwNode *const pNd = rPam.GetDoc()->GetNodes()[ n ];
             switch (pNd->GetNodeType())
@@ -461,7 +459,7 @@ public:
     /// embedded tables.
     SwStartNode const*const m_pOwnStartNode;
     SwTable const*const     m_pOwnTable;
-    const ULONG             m_nEndIndex;
+    const sal_uLong             m_nEndIndex;
     sal_Int32               m_nFirstParaStart;
     sal_Int32               m_nLastParaEnd;
     bool                    m_bFirstParagraph;
@@ -516,13 +514,13 @@ public:
     uno::Reference< text::XTextContent > NextElement_Impl()
         throw (container::NoSuchElementException, lang::WrappedTargetException,
                 uno::RuntimeException);
-
+protected:
     // SwClient
-    virtual void    Modify(SfxPoolItem *pOld, SfxPoolItem *pNew);
+    virtual void Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew);
 
 };
 
-void SwXParagraphEnumeration::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
+void SwXParagraphEnumeration::Impl::Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 {
     ClientModify(this, pOld, pNew);
 }
@@ -785,13 +783,13 @@ public:
     }
 
     const ::sw::mark::IMark * GetBookmark() const { return m_pMark; }
-
+protected:
     // SwClient
-    virtual void    Modify(SfxPoolItem *pOld, SfxPoolItem *pNew);
+    virtual void    Modify(const SfxPoolItem *pOld, const SfxPoolItem *pNew);
 
 };
 
-void SwXTextRange::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
+void SwXTextRange::Impl::Modify(const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 {
     const bool bAlreadyRegistered = 0 != GetRegisteredIn();
     ClientModify(this, pOld, pNew);
@@ -881,7 +879,7 @@ throw (uno::RuntimeException)
     if (GetPositions(aCursor))
     {
         UnoActionContext aAction(& m_pImpl->m_rDoc);
-        m_pImpl->m_rDoc.StartUndo(UNDO_INSERT, NULL);
+        m_pImpl->m_rDoc.GetIDocumentUndoRedo().StartUndo(UNDO_INSERT, NULL);
         if (aCursor.HasMark())
         {
             m_pImpl->m_rDoc.DeleteAndJoin(aCursor);
@@ -893,10 +891,10 @@ throw (uno::RuntimeException)
                     m_pImpl->m_rDoc, aCursor, rText, bForceExpandHints);
 
             SwUnoCursorHelper::SelectPam(aCursor, true);
-            aCursor.Left(rText.getLength(), CRSR_SKIP_CHARS, FALSE, FALSE);
+            aCursor.Left(rText.getLength(), CRSR_SKIP_CHARS, sal_False, sal_False);
         }
         SetPositions(aCursor);
-        m_pImpl->m_rDoc.EndUndo(UNDO_INSERT, NULL);
+        m_pImpl->m_rDoc.GetIDocumentUndoRedo().EndUndo(UNDO_INSERT, NULL);
     }
 }
 
@@ -1150,7 +1148,7 @@ lcl_IsStartNodeInFormat(const bool bHeader, SwStartNode *const pSttNode,
     const SfxItemSet& rSet = pFrmFmt->GetAttrSet();
     const SfxPoolItem* pItem;
     if (SFX_ITEM_SET == rSet.GetItemState(
-            static_cast<USHORT>(bHeader ? RES_HEADER : RES_FOOTER),
+            static_cast<sal_uInt16>(bHeader ? RES_HEADER : RES_FOOTER),
             sal_True, &pItem))
     {
         SfxPoolItem *const pItemNonConst(const_cast<SfxPoolItem *>(pItem));
@@ -1226,8 +1224,7 @@ CreateParentXText(SwDoc & rDoc, const SwPosition& rPos)
             SwFrmFmt *const pFmt = pSttNode->GetFlyFmt();
             if (0 != pFmt)
             {
-                SwXTextFrame* pFrame( static_cast<SwXTextFrame*>(
-                    SwClientIter( *pFmt ).First( TYPE( SwXTextFrame ) ) ) );
+                SwXTextFrame* pFrame = SwIterator<SwXTextFrame,SwFmt>::FirstElement( *pFmt );
                 xParentText = pFrame ? pFrame : new SwXTextFrame( *pFmt );
             }
         }
@@ -1308,7 +1305,7 @@ throw (uno::RuntimeException)
 {
     SolarMutexGuard g;
 
-    if (!rServiceName.equalsAscii("com.sun.star.text.TextContent"))
+    if (!rServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextContent")))
     {
         throw uno::RuntimeException();
     }
@@ -1319,7 +1316,7 @@ throw (uno::RuntimeException)
     }
     const SwPosition aPos(GetDoc()->GetNodes().GetEndOfContent());
     const ::std::auto_ptr<SwUnoCrsr> pNewCrsr(
-            m_pImpl->m_rDoc.CreateUnoCrsr(aPos, FALSE));
+            m_pImpl->m_rDoc.CreateUnoCrsr(aPos, sal_False));
     if (!GetPositions(*pNewCrsr))
     {
         throw uno::RuntimeException();
@@ -1341,7 +1338,7 @@ SwXTextRange::createEnumeration() throw (uno::RuntimeException)
     }
     const SwPosition aPos(GetDoc()->GetNodes().GetEndOfContent());
     ::std::auto_ptr<SwUnoCrsr> pNewCrsr(
-            m_pImpl->m_rDoc.CreateUnoCrsr(aPos, FALSE));
+            m_pImpl->m_rDoc.CreateUnoCrsr(aPos, sal_False));
     if (!GetPositions(*pNewCrsr))
     {
         throw uno::RuntimeException();
@@ -1430,8 +1427,7 @@ SwXTextRange::addPropertyChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXTextRange::addPropertyChangeListener(): not implemented");
+    OSL_FAIL("SwXTextRange::addPropertyChangeListener(): not implemented");
 }
 
 void SAL_CALL
@@ -1441,8 +1437,7 @@ SwXTextRange::removePropertyChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXTextRange::removePropertyChangeListener(): not implemented");
+    OSL_FAIL("SwXTextRange::removePropertyChangeListener(): not implemented");
 }
 
 void SAL_CALL
@@ -1452,8 +1447,7 @@ SwXTextRange::addVetoableChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXTextRange::addVetoableChangeListener(): not implemented");
+    OSL_FAIL("SwXTextRange::addVetoableChangeListener(): not implemented");
 }
 
 void SAL_CALL
@@ -1463,8 +1457,7 @@ SwXTextRange::removeVetoableChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
         uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXTextRange::removeVetoableChangeListener(): not implemented");
+    OSL_FAIL("SwXTextRange::removeVetoableChangeListener(): not implemented");
 }
 
 beans::PropertyState SAL_CALL
@@ -1582,13 +1575,13 @@ public:
     }
 
     void MakeRanges();
-
+protected:
     // SwClient
-    virtual void    Modify(SfxPoolItem *pOld, SfxPoolItem *pNew);
+    virtual void Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew);
 
 };
 
-void SwXTextRanges::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
+void SwXTextRanges::Impl::Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 {
     ClientModify(this, pOld, pNew);
 }
@@ -1715,7 +1708,7 @@ void SwUnoCursorHelper::SetString(SwCursor & rCursor, const OUString& rString)
     // Start/EndAction
     SwDoc *const pDoc = rCursor.GetDoc();
     UnoActionContext aAction(pDoc);
-    pDoc->StartUndo(UNDO_INSERT, NULL);
+    pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_INSERT, NULL);
     if (rCursor.HasMark())
     {
         pDoc->DeleteAndJoin(rCursor);
@@ -1728,9 +1721,9 @@ void SwUnoCursorHelper::SetString(SwCursor & rCursor, const OUString& rString)
         DBG_ASSERT( bSuccess, "DocInsertStringSplitCR" );
         (void) bSuccess;
         SwUnoCursorHelper::SelectPam(rCursor, true);
-        rCursor.Left(rString.getLength(), CRSR_SKIP_CHARS, FALSE, FALSE);
+        rCursor.Left(rString.getLength(), CRSR_SKIP_CHARS, sal_False, sal_False);
     }
-    pDoc->EndUndo(UNDO_INSERT, NULL);
+    pDoc->GetIDocumentUndoRedo().EndUndo(UNDO_INSERT, NULL);
 }
 
 /******************************************************************
@@ -1765,9 +1758,9 @@ public:
         return static_cast<SwUnoCrsr*>(
                 const_cast<SwModify*>(GetRegisteredIn()));
     }
-
+protected:
     // SwClient
-    virtual void    Modify(SfxPoolItem *pOld, SfxPoolItem *pNew);
+    virtual void Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew);
 
 };
 
@@ -1776,7 +1769,7 @@ struct InvalidFrameDepend {
     { return !rEntry->GetRegisteredIn(); }
 };
 
-void SwXParaFrameEnumeration::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
+void SwXParaFrameEnumeration::Impl::Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 {
     ClientModify(this, pOld, pNew);
     if(!GetRegisteredIn())
@@ -1808,9 +1801,7 @@ lcl_CreateNextObject(SwUnoCrsr& i_rUnoCrsr,
     // the format should be valid here, otherwise the client
     // would have been removed in ::Modify
     // check for a shape first
-    SwClientIter aIter(*pFormat);
-    SwDrawContact * const pContact =
-        static_cast<SwDrawContact*>( aIter.First(TYPE(SwDrawContact)) );
+    SwDrawContact* const pContact = SwIterator<SwDrawContact,SwFmt>::FirstElement( *pFormat );
     if (pContact)
     {
         SdrObject * const pSdr = pContact->GetMaster();
@@ -1837,7 +1828,7 @@ lcl_CreateNextObject(SwUnoCrsr& i_rUnoCrsr,
     return o_rNextObject.is();
 }
 
-/* -----------------------------03.04.00 10:15--------------------------------
+/* ---------------------------------------------------------------------------
     Description: Search for a FLYCNT text attribute at the cursor point
                 and fill the frame into the array
  ---------------------------------------------------------------------------*/
@@ -1885,8 +1876,8 @@ SwXParaFrameEnumeration::SwXParaFrameEnumeration(
         {
             SwPosFlyFrms aFlyFrms;
             //get all frames that are bound at paragraph or at character
-            rPaM.GetDoc()->GetAllFlyFmts(aFlyFrms, m_pImpl->GetCursor());
-            for(USHORT i = 0; i < aFlyFrms.Count(); i++)
+            rPaM.GetDoc()->GetAllFlyFmts(aFlyFrms, m_pImpl->GetCursor(), sal_False, sal_True);
+            for(sal_uInt16 i = 0; i < aFlyFrms.Count(); i++)
             {
                 SwPosFlyFrm* pPosFly = aFlyFrms[i];
                 SwFrmFmt *const pFrmFmt =
@@ -1897,20 +1888,6 @@ SwXParaFrameEnumeration::SwXParaFrameEnumeration(
                 m_pImpl->m_Frames.push_back(
                         ::boost::shared_ptr<SwDepend>(pNewDepend) );
             }
-            //created from any text range
-            if (m_pImpl->GetCursor()->HasMark())
-            {
-                m_pImpl->GetCursor()->Normalize();
-                do
-                {
-                    lcl_FillFrame(*m_pImpl.get(), *m_pImpl->GetCursor(),
-                            m_pImpl->m_Frames);
-                    m_pImpl->GetCursor()->Right(
-                            1, CRSR_SKIP_CHARS, FALSE, FALSE);
-                }
-                while (*m_pImpl->GetCursor()->GetPoint() <
-                        *m_pImpl->GetCursor()->GetMark());
-            }
         }
         lcl_FillFrame(*m_pImpl.get(), *m_pImpl->GetCursor(), m_pImpl->m_Frames);
     }
