@@ -67,7 +67,6 @@
 #define CONTEXT_FLAGS_MULTICOL (HTML_CNTXT_STRIP_PARA |  \
                                 HTML_CNTXT_KEEP_NUMRULE | \
                                 HTML_CNTXT_KEEP_ATTRS)
-//#define CONTEXT_FLAGS_HDRFTR (HTML_CNTXT_STRIP_PARA|HTML_CNTXT_PROTECT_STACK)
 #define CONTEXT_FLAGS_HDRFTR (CONTEXT_FLAGS_MULTICOL)
 #define CONTEXT_FLAGS_FTN (CONTEXT_FLAGS_MULTICOL)
 
@@ -205,7 +204,7 @@ void SwHTMLParser::NewDivision( int nToken )
             aDelPam.SetMark();
 
             const SwStartNode *pStNd =
-                (const SwStartNode *)pDoc->GetNodes()[rCntntStIdx];
+                (const SwStartNode *) &rCntntStIdx.GetNode();
             aDelPam.GetPoint()->nNode = pStNd->EndOfSectionIndex() - 1;
 
             pDoc->DelFullPara( aDelPam );
@@ -262,7 +261,7 @@ void SwHTMLParser::NewDivision( int nToken )
         if( !bAppended )
         {
             SwNodeIndex aPrvNdIdx( pPam->GetPoint()->nNode, -1 );
-            if( (pDoc->GetNodes()[aPrvNdIdx])->IsSectionNode() )
+            if (aPrvNdIdx.GetNode().IsSectionNode())
             {
                 AppendTxtNode();
                 bAppended = sal_True;
@@ -351,8 +350,7 @@ void SwHTMLParser::NewDivision( int nToken )
         }
 
         SwTxtNode* pOldTxtNd =
-            bAppended ? 0 : pDoc->GetNodes()[pPam->GetPoint()->nNode]
-                                ->GetTxtNode();
+            (bAppended) ? 0 : pPam->GetPoint()->nNode.GetNode().GetTxtNode();
 
         pPam->Move( fnMoveBackward );
 
@@ -436,10 +434,10 @@ void SwHTMLParser::FixHeaderFooterDistance( sal_Bool bHeader,
     const SwFmtCntnt& rFlyCntnt = pHdFtFmt->GetCntnt();
     const SwNodeIndex& rCntntStIdx = *rFlyCntnt.GetCntntIdx();
 
-    ULONG nPrvNxtIdx;
+    sal_uLong nPrvNxtIdx;
     if( bHeader )
     {
-        nPrvNxtIdx = pDoc->GetNodes()[rCntntStIdx]->EndOfSectionIndex()-1;
+        nPrvNxtIdx = rCntntStIdx.GetNode().EndOfSectionIndex()-1;
     }
     else
     {
@@ -690,7 +688,7 @@ void SwHTMLParser::NewMultiCol()
             // node must be inserted. Otherwise, the new section will be
             // inserted in front of the old one.
             SwNodeIndex aPrvNdIdx( pPam->GetPoint()->nNode, -1 );
-            if( (pDoc->GetNodes()[aPrvNdIdx])->IsSectionNode() )
+            if (aPrvNdIdx.GetNode().IsSectionNode())
             {
                 AppendTxtNode();
                 bAppended = sal_True;
@@ -746,8 +744,7 @@ void SwHTMLParser::NewMultiCol()
         }
 
         SwTxtNode* pOldTxtNd =
-            bAppended ? 0 : pDoc->GetNodes()[pPam->GetPoint()->nNode]
-                                ->GetTxtNode();
+            (bAppended) ? 0 : pPam->GetPoint()->nNode.GetNode().GetTxtNode();
 
         pPam->Move( fnMoveBackward );
 
@@ -811,7 +808,7 @@ void SwHTMLParser::InsertFlyFrame( const SfxItemSet& rItemSet,
 /*  */
 
 void SwHTMLParser::MovePageDescAttrs( SwNode *pSrcNd,
-                                      ULONG nDestIdx,
+                                      sal_uLong nDestIdx,
                                       sal_Bool bFmtBreak )
 {
     SwCntntNode* pDestCntntNd =
