@@ -184,7 +184,7 @@ SfxTabPage*  SwMailConfigPage::Create( Window* pParent, const SfxItemSet& rAttrS
     return new SwMailConfigPage(pParent, rAttrSet);
 }
 
-BOOL SwMailConfigPage::FillItemSet( SfxItemSet& /*rSet*/ )
+sal_Bool SwMailConfigPage::FillItemSet( SfxItemSet& /*rSet*/ )
 {
     if(m_aDisplayNameED.GetText() != m_aDisplayNameED.GetSavedValue())
         m_pConfigItem->SetMailDisplayName(m_aDisplayNameED.GetText());
@@ -268,7 +268,7 @@ SwTestAccountSettingsDialog::SwTestAccountSettingsDialog(SwMailConfigPage* pPare
 #ifdef MSC
 #pragma warning (default : 4355)
 #endif
-    m_aImageList( SW_RES( GetSettings().GetStyleSettings().GetHighContrastMode() ? ILIST_HC : ILIST) ),
+    m_aImageList( SW_RES(ILIST) ),
     m_sTask( SW_RES(        ST_TASK          )),
     m_sStatus( SW_RES(      ST_STATUS        )),
     m_sEstablish( SW_RES(   ST_ESTABLISH     )),
@@ -306,7 +306,7 @@ SwTestAccountSettingsDialog::SwTestAccountSettingsDialog(SwMailConfigPage* pPare
 
     m_aStatusLB.SetHelpId(HID_MM_TESTACCOUNTSETTINGS_TLB);
     static long nTabs[] = {2, 0, aSz.Width()/2 };
-    m_aStatusLB.SetWindowBits( WB_SORT | WB_HSCROLL | WB_CLIPCHILDREN | WB_TABSTOP );
+    m_aStatusLB.SetStyle( m_aStatusLB.GetStyle() | WB_SORT | WB_HSCROLL | WB_CLIPCHILDREN | WB_TABSTOP );
     m_aStatusLB.SetSelectionMode( SINGLE_SELECTION );
     m_aStatusLB.SetTabs(&nTabs[0], MAP_PIXEL);
     short nEntryHeight = m_aStatusLB.GetEntryHeight();
@@ -337,6 +337,8 @@ void SwTestAccountSettingsDialog::Test()
 {
     uno::Reference<XMultiServiceFactory> rMgr = ::comphelper::getProcessServiceFactory();
 
+    rtl::OUString sException;
+
     bool bIsLoggedIn = false;
     bool bIsServer = false;
     if (rMgr.is())
@@ -404,8 +406,7 @@ void SwTestAccountSettingsDialog::Test()
                     new SwConnectionContext(
                         m_pParent->m_aServerED.GetText(),
                         sal::static_int_cast< sal_Int16, sal_Int64 >(m_pParent->m_aPortNF.GetValue()),
-                        ::rtl::OUString::createFromAscii(
-                                m_pParent->m_aSecureCB.IsChecked() ? "Ssl" : "Insecure"));
+                        m_pParent->m_aSecureCB.IsChecked() ? OUString(RTL_CONSTASCII_USTRINGPARAM("Ssl")) : OUString(RTL_CONSTASCII_USTRINGPARAM("Insecure")));
             xMailService->connect(xConnectionContext, xAuthenticator);
             bIsLoggedIn = xMailService->isConnected();
             if( xInMailService.is() )
@@ -413,9 +414,9 @@ void SwTestAccountSettingsDialog::Test()
             if( xMailService->isConnected())
                 xMailService->disconnect();
         }
-        catch(uno::Exception&)
+        catch (const uno::Exception& e)
         {
-            OSL_ENSURE(false, "exception caught");
+            sException = e.Message;
         }
     }
 
@@ -438,14 +439,17 @@ void SwTestAccountSettingsDialog::Test()
 
     if(!bIsServer || !bIsLoggedIn )
     {
-        m_eErrorsED.SetText( m_sErrorServer );
+        rtl::OUStringBuffer aErrorMessage(m_sErrorServer);
+        if (!sException.isEmpty())
+            aErrorMessage.appendAscii(RTL_CONSTASCII_STRINGPARAM("\n--\n")).append(sException);
+        m_eErrorsED.SetText(aErrorMessage.makeStringAndClear());
     }
 }
 
 SwMailConfigDlg::SwMailConfigDlg(Window* pParent, SfxItemSet& rSet ) :
     SfxSingleTabDialog(pParent, rSet, 0)
 {
-    // TabPage erzeugen
+    // create TabPage
     SetTabPage(SwMailConfigPage::Create( this, rSet ));
 }
 
