@@ -84,7 +84,7 @@ using namespace svt;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-String lcl_GetExtensionForDocType(ULONG nDocType)
+String lcl_GetExtensionForDocType(sal_uLong nDocType)
 {
     String sExtension;
     switch( nDocType )
@@ -447,7 +447,7 @@ IMPL_LINK(SwMailMergeOutputPage, OutputTypeHdl_Impl, RadioButton*, pButton)
         &m_aSendAllRB, &m_aSendDocumentsPB,
         0
     };
-    SetUpdateMode(TRUE);
+    SetUpdateMode(sal_True);
     Control** pControl = aControls;
     do
     {
@@ -518,7 +518,7 @@ IMPL_LINK(SwMailMergeOutputPage, OutputTypeHdl_Impl, RadioButton*, pButton)
         aPos = m_aFromNF.GetPosPixel();     aPos.Y() = nNewRBXPos + nRB_FT_Offset; m_aFromNF.SetPosPixel(aPos);
         aPos = m_aToNF.GetPosPixel();       aPos.Y() = nNewRBXPos + nRB_FT_Offset; m_aToNF.SetPosPixel(aPos);
     }
-    else /*if(&m_aSendMailRB == pButton)*/
+    else
     {
         Control* aMailControls[] =
         {
@@ -543,7 +543,7 @@ IMPL_LINK(SwMailMergeOutputPage, OutputTypeHdl_Impl, RadioButton*, pButton)
             String sAttach( m_sDefaultAttachmentST );
             sAttach += '.';
             sAttach += lcl_GetExtensionForDocType(
-                        (ULONG)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos()));
+                        (sal_uLong)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos()));
             m_aAttachmentED.SetText( sAttach );
 
         }
@@ -589,7 +589,7 @@ IMPL_LINK(SwMailMergeOutputPage, OutputTypeHdl_Impl, RadioButton*, pButton)
     }
     m_aFromRB.GetClickHdl().Call(m_aFromRB.IsChecked() ? &m_aFromRB : 0);
 
-    SetUpdateMode(FALSE);
+    SetUpdateMode(sal_False);
     return 0;
 }
 
@@ -647,9 +647,9 @@ IMPL_LINK(SwMailMergeOutputPage, SaveStartHdl_Impl, PushButton*, pButton)
 
             rConfigItem.AddSavedDocument(
                     aURL.GetMainURL(INetURLObject::DECODE_TO_IURI));
-            pButton->Enable(FALSE);
+            pButton->Enable(sal_False);
             m_pWizard->enableButtons(WZB_FINISH, sal_True);
-            pButton->Enable(FALSE);
+            pButton->Enable(sal_False);
 
         }
     }
@@ -782,10 +782,10 @@ IMPL_LINK(SwMailMergeOutputPage, SaveOutputHdl_Impl, PushButton*, pButton)
             aSaveMonitor.aPrintInfo.SetText(sStat);
 
             //now extract a document from the target document
-            SfxObjectShellRef xTempDocShell( new SwDocShell( SFX_CREATE_MODE_STANDARD ) );
+            // the shell will be closed at the end, but it is more safe to use SfxObjectShellLock here
+            SfxObjectShellLock xTempDocShell( new SwDocShell( SFX_CREATE_MODE_STANDARD ) );
             xTempDocShell->DoInitNew( 0 );
             SfxViewFrame* pTempFrame = SfxViewFrame::LoadHiddenDocument( *xTempDocShell, 0 );
-//            pTempFrame->GetFrame().Appear();
             SwView* pTempView = static_cast<SwView*>( pTempFrame->GetViewShell() );
             pTargetView->GetWrtShell().StartAction();
             SwgReaderOption aOpt;
@@ -798,15 +798,13 @@ IMPL_LINK(SwMailMergeOutputPage, SaveOutputHdl_Impl, PushButton*, pButton)
                     sTargetTempURL, aOpt, sal_True );
 
             pTargetView->GetWrtShell().PastePages(pTempView->GetWrtShell(),
-                    (USHORT)rInfo.nStartPageInTarget, (USHORT)rInfo.nEndPageInTarget );
+                    (sal_uInt16)rInfo.nStartPageInTarget, (sal_uInt16)rInfo.nEndPageInTarget );
             pTargetView->GetWrtShell().EndAction();
             //then save it
             String sOutPath = aURL.GetMainURL(INetURLObject::DECODE_TO_IURI);
             String sCounter('_');
             sCounter += String::CreateFromInt32(nDoc);
             sOutPath.Insert(sCounter, sOutPath.Len() - sExtension.Len() - 1);
-            //SfxStringItem aName(SID_FILE_NAME, sOutPath);
-            //SfxStringItem aFilter(SID_FILTER_NAME, sFilter);
 
             while(true)
             {
@@ -885,7 +883,6 @@ IMPL_LINK(SwMailMergeOutputPage, PrinterChangeHdl_Impl, ListBox*, pBox)
         m_aPrinterSettingsPB.Disable();
     m_pWizard->GetConfigItem().SetSelectedPrinter( pBox->GetSelectEntry() );
 
-//    return m_pTempPrinter;
     return 0;
 }
 
@@ -911,7 +908,7 @@ IMPL_LINK(SwMailMergeOutputPage, PrintHdl_Impl, PushButton*, EMPTYARG)
         if(nEnd > rConfigItem.GetMergedDocumentCount())
             nEnd = rConfigItem.GetMergedDocumentCount();
     }
-    rConfigItem.SetPrintRange( (USHORT)nBegin, (USHORT)nEnd );
+    rConfigItem.SetPrintRange( (sal_uInt16)nBegin, (sal_uInt16)nEnd );
     SwDocMergeInfo& rStartInfo = rConfigItem.GetDocumentMergeInfo(nBegin);
     SwDocMergeInfo& rEndInfo = rConfigItem.GetDocumentMergeInfo(nEnd - 1);
     
@@ -930,7 +927,6 @@ IMPL_LINK(SwMailMergeOutputPage, PrintHdl_Impl, PushButton*, EMPTYARG)
     SfxObjectShell* pObjSh = pTargetView->GetViewFrame()->GetObjectShell();
     SFX_APP()->NotifyEvent(SfxEventHint(SW_EVENT_MAIL_MERGE, SwDocShell::GetEventName(STR_SW_EVENT_MAIL_MERGE), pObjSh));
     rSh.GetNewDBMgr()->SetMergeType( DBMGR_MERGE_DOCUMENTS );
-    //SfxDispatcher *pDis = pTargetView->GetViewFrame()->GetDispatcher();
     SfxBoolItem aMergeSilent(SID_SILENT, sal_False);
     m_pWizard->enableButtons(WZB_CANCEL, sal_False);
 
@@ -960,7 +956,7 @@ IMPL_LINK(SwMailMergeOutputPage, PrinterSetupHdl_Impl, PushButton*, pButton)
 
 IMPL_LINK(SwMailMergeOutputPage, SendTypeHdl_Impl, ListBox*, pBox)
 {
-    ULONG nDocType = (ULONG)pBox->GetEntryData(pBox->GetSelectEntryPos());
+    sal_uLong nDocType = (sal_uLong)pBox->GetEntryData(pBox->GetSelectEntryPos());
     sal_Bool bEnable = MM_DOCTYPE_HTML != nDocType && MM_DOCTYPE_TEXT != nDocType;
     m_aSendAsPB.Enable( bEnable );
     m_aAttachmentFT.Enable( bEnable );
@@ -996,7 +992,7 @@ IMPL_LINK(SwMailMergeOutputPage, SendAsHdl_Impl, PushButton*, pButton)
     return 0;
 }
 
-/*-- 21.05.2004 12:03:25---------------------------------------------------
+/*-------------------------------------------------------------------------
     Send documents as e-mail
   -----------------------------------------------------------------------*/
 IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
@@ -1013,7 +1009,7 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
             !SwMailMergeHelper::CheckMailAddress(rConfigItem.GetMailAddress()) )
     {
         QueryBox aQuery(pButton, WB_YES_NO_CANCEL, m_sConfigureMail);
-        USHORT nRet = aQuery.Execute();
+        sal_uInt16 nRet = aQuery.Execute();
         if(RET_YES == nRet )
         {
             SfxAllItemSet aSet(pTargetView->GetPool());
@@ -1025,8 +1021,6 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
         if(nRet != RET_OK && nRet != RET_YES)
             return 0;
     }
-    //create the send dialog
-    SwSendMailDialog* pDlg = new SwSendMailDialog( pButton, rConfigItem );
     //add the documents
     sal_uInt32 nBegin = 0;
     sal_uInt32 nEnd = 0;
@@ -1043,16 +1037,29 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
             nEnd = rConfigItem.GetMergedDocumentCount();
     }
     bool bAsBody = false;
-    bool bIsPDF = false;
     rtl_TextEncoding eEncoding = ::gsl_getSystemTextEncoding();
     SfxFilterContainer* pFilterContainer = SwDocShell::Factory().GetFilterContainer();
     const SfxFilter *pSfxFlt = 0;
-    ULONG nDocType = (ULONG)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos());
+    sal_uLong nDocType = (sal_uLong)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos());
     String sExtension = lcl_GetExtensionForDocType(nDocType);
     switch( nDocType )
     {
-        case MM_DOCTYPE_OOO : break;
-        case MM_DOCTYPE_PDF : bIsPDF = true; break;
+        case MM_DOCTYPE_OOO:
+        {
+            //Make sure we don't pick e.g. the flat xml filter
+            //for this format
+            pSfxFlt = SwIoSystem::GetFilterOfFormat(
+                String::CreateFromAscii( FILTER_XML ),
+                SwDocShell::Factory().GetFilterContainer() );
+        }
+        break;
+        case MM_DOCTYPE_PDF:
+        {
+            pSfxFlt = pFilterContainer->GetFilter4FilterName(
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("writer_pdf_Export")),
+                SFX_FILTER_EXPORT);
+        }
+        break;
         case MM_DOCTYPE_WORD:
         {
             //the method SwIOSystemGetFilterOfFormat( ) returns the template filter
@@ -1118,7 +1125,7 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
                 ++nTokenCount;
             }
             sAttach.SetToken( nTokenCount - 1, '.', lcl_GetExtensionForDocType(
-                     (ULONG)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos())));
+                     (sal_uLong)m_aSendAsLB.GetEntryData(m_aSendAsLB.GetSelectEntryPos())));
             m_aAttachmentED.SetText(sAttach);
         }
         else
@@ -1136,8 +1143,8 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
     if(MM_DOCTYPE_TEXT == nDocType)
     {
         SwAsciiOptions aOpt;
-        USHORT nAppScriptType = GetI18NScriptTypeOfLanguage( (USHORT)GetAppLanguage() );
-        USHORT nWhich = GetWhichOfScript( RES_CHRATR_LANGUAGE, nAppScriptType);
+        sal_uInt16 nAppScriptType = GetI18NScriptTypeOfLanguage( (sal_uInt16)GetAppLanguage() );
+        sal_uInt16 nWhich = GetWhichOfScript( RES_CHRATR_LANGUAGE, nAppScriptType);
         aOpt.SetLanguage( ((SvxLanguageItem&)pTargetView->GetWrtShell().
                             GetDefault( nWhich )).GetLanguage());
         aOpt.SetParaFlags( LINEEND_CR );
@@ -1158,11 +1165,13 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
     uno::Reference< frame::XStorable > xStore( pTargetView->GetDocShell()->GetModel(), uno::UNO_QUERY);
     xStore->storeToURL( sTargetTempURL, aValues   );
 
+    //create the send dialog
+    SwSendMailDialog* pDlg = new SwSendMailDialog( pButton, rConfigItem );
     pDlg->SetDocumentCount( nEnd );
     pDlg->ShowDialog();
     //help to force painting the dialog
     //TODO/CLEANUP
-    //Sollbruchstelle
+    //predetermined breaking point
     for ( sal_Int16 i = 0; i < 25; i++)
         Application::Reschedule();
     for(sal_uInt32 nDoc = nBegin; nDoc < nEnd; ++nDoc)
@@ -1171,10 +1180,10 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
         SwDocMergeInfo& rInfo = rConfigItem.GetDocumentMergeInfo(nDoc);
 
         //now extract a document from the target document
-        SfxObjectShellRef xTempDocShell( new SwDocShell( SFX_CREATE_MODE_STANDARD ) );
+        // the shell will be closed at the end, but it is more safe to use SfxObjectShellLock here
+        SfxObjectShellLock xTempDocShell( new SwDocShell( SFX_CREATE_MODE_STANDARD ) );
         xTempDocShell->DoInitNew( 0 );
         SfxViewFrame* pTempFrame = SfxViewFrame::LoadHiddenDocument( *xTempDocShell, 0 );
-//        pTempFrame->GetFrame().Appear();
         SwView* pTempView = static_cast<SwView*>( pTempFrame->GetViewShell() );
         pTargetView->GetWrtShell().StartAction();
         SwgReaderOption aOpt;
@@ -1186,7 +1195,7 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
         pTempView->GetDocShell()->LoadStylesFromFile(
                 sTargetTempURL, aOpt, sal_True );
         pTargetView->GetWrtShell().PastePages(pTempView->GetWrtShell(),
-                (USHORT)rInfo.nStartPageInTarget, (USHORT)rInfo.nEndPageInTarget );
+                (sal_uInt16)rInfo.nStartPageInTarget, (sal_uInt16)rInfo.nEndPageInTarget );
         pTargetView->GetWrtShell().EndAction();
 
         //then save it
@@ -1195,14 +1204,6 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
                     INetURLObject(), utl::TempFile::CreateTempName(0),
                     URIHelper::GetMaybeFileHdl()) );
 
-/*        if(bIsPDF)
-        {
-            SfxDispatcher* pSfxDispatcher = pTempView->GetViewFrame()->GetDispatcher();
-            pSfxDispatcher->Execute(
-                            SID_DIRECTEXPORTDOCASPDF,
-                                  SFX_CALLMODE_SYNCHRON, &aName, &aFilterName, 0L );
-        }
-        else*/
         {
             uno::Sequence< beans::PropertyValue > aFilterValues(MM_DOCTYPE_TEXT == nDocType ? 2 : 1);
             beans::PropertyValue* pFilterValues = aFilterValues.getArray();
@@ -1219,11 +1220,9 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
         }
         xTempDocShell->DoClose();
 
-#if OSL_DEBUG_LEVEL > 1
-        sal_Int32 nTarget =
-#endif
-            rConfigItem.MoveResultSet(rInfo.nDBRow);
+        sal_Int32 nTarget = rConfigItem.MoveResultSet(rInfo.nDBRow);
         OSL_ENSURE( nTarget == rInfo.nDBRow, "row of current document could not be selected");
+        (void)nTarget;
         OSL_ENSURE( sEMailColumn.Len(), "No email column selected");
         ::rtl::OUString sEMail = lcl_GetColumnValueOf(sEMailColumn, xColAccess);
         SwMailDescriptor aDesc;
@@ -1233,13 +1232,13 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
         {
             {
                 //read in the temporary file and use it as mail body
-                SfxMedium aMedium( aName.GetValue(),    STREAM_READ, TRUE);
+                SfxMedium aMedium( aName.GetValue(),    STREAM_READ, sal_True);
                 SvStream* pInStream = aMedium.GetInStream();
                 if(pInStream)
                     pInStream->SetStreamCharSet( eEncoding );
                 else
                 {
-                    OSL_ENSURE(false, "no output file created?");
+                    OSL_FAIL("no output file created?");
                     continue;
                 }
                 ByteString sLine;
