@@ -126,7 +126,7 @@ SwLabDlg::SwLabDlg(Window* pParent, const SfxItemSet& rSet,
 
     GetOKButton().SetText(String(SW_RES(STR_BTN_NEW_DOC)));
     GetOKButton().SetHelpId(HID_LABEL_INSERT);
-    GetOKButton().SetHelpText(aEmptyStr);	// Damit generierter Hilfetext verwendet wird
+    GetOKButton().SetHelpText(aEmptyStr);	// in order for generated help text to get used
 
     AddTabPage(TP_LAB_LAB, m_bLabel ? sFormat : sMedium ,SwLabPage   ::Create, 0, sal_False, 0);
     AddTabPage(TP_VISITING_CARDS, SwVisitingCardPage::Create, 0);
@@ -197,7 +197,7 @@ void SwLabDlg::GetLabItem(SwLabItem &rItem)
 
     if (rActItem != rOldItem)
     {
-        // Wurde schon mal mit (hoffentlich) korrektem Inhalt "geputtet"
+        // Was already "put" with (hopefully) correct content
         rItem = rActItem;
     }
     else
@@ -246,7 +246,8 @@ SwLabPage::SwLabPage(Window* pParent, const SfxItemSet& rSet) :
     SfxTabPage(pParent, SW_RES(TP_LAB_LAB), rSet),
     pNewDBMgr(NULL),
     aItem          ((const SwLabItem&) rSet.Get(FN_LABEL)),
-
+    
+    aWritingFL     (this, SW_RES(FL_WRITING)),
     aWritingText   (this, SW_RES(TXT_WRITING)),
     aAddrBox       (this, SW_RES(BOX_ADDR   )),
     aWritingEdit   (this, SW_RES(EDT_WRITING)),
@@ -257,7 +258,7 @@ SwLabPage::SwLabPage(Window* pParent, const SfxItemSet& rSet) :
     aInsertBT      (this, SW_RES(BTN_INSERT )),
     aDBFieldFT     (this, SW_RES(FT_DBFIELD )),
     aDBFieldLB     (this, SW_RES(LB_DBFIELD )),
-    aWritingFL     (this, SW_RES(FL_WRITING)),
+    aFormatFL      (this, SW_RES(FL_FORMAT )),
     aContButton    (this, SW_RES(BTN_CONT   )),
     aSheetButton   (this, SW_RES(BTN_SHEET  )),
     aMakeText      (this, SW_RES(TXT_MAKE   )),
@@ -265,9 +266,8 @@ SwLabPage::SwLabPage(Window* pParent, const SfxItemSet& rSet) :
     aTypeText      (this, SW_RES(TXT_TYPE   )),
     aTypeBox       (this, SW_RES(BOX_TYPE   )),
     aHiddenSortTypeBox(this, WB_SORT|WB_HIDE),
-    aFormatInfo    (this, SW_RES(INF_FORMAT )),
-    aFormatFL      (this, SW_RES(FL_FORMAT ))
-{
+    aFormatInfo    (this, SW_RES(INF_FORMAT ))
+   {
     WaitObject aWait( pParent );
 
     FreeResource();
@@ -427,17 +427,17 @@ IMPL_LINK( SwLabPage, MakeHdl, ListBox *, EMPTYARG )
     for ( sal_uInt16 i = 0; i < nCount; ++i )
     {
         const String aType ( GetParent()->Recs()[i]->aType );
-        BOOL bInsert = FALSE;
+        sal_Bool bInsert = sal_False;
         if ( GetParent()->Recs()[i]->aType == sCustom )
         {
-            bInsert = TRUE;
+            bInsert = sal_True;
             aTypeBox.InsertEntry(aType );
         }
         else if ( GetParent()->Recs()[i]->bCont == bCont )
         {
             if ( aHiddenSortTypeBox.GetEntryPos(aType) == LISTBOX_ENTRY_NOTFOUND )
             {
-                bInsert = TRUE;
+                bInsert = sal_True;
                 aHiddenSortTypeBox.InsertEntry( aType );
             }
         }
@@ -471,7 +471,7 @@ IMPL_LINK_INLINE_END( SwLabPage, TypeHdl, ListBox *, EMPTYARG )
 void SwLabPage::DisplayFormat()
 {
     MetricField aField(this, WinBits(0));
-    FieldUnit aMetric = ::GetDfltMetric(FALSE);
+    FieldUnit aMetric = ::GetDfltMetric(sal_False);
     SetMetric(aField, aMetric);
     aField.SetDecimalDigits(2);
     aField.SetMin		  (0);
@@ -636,16 +636,16 @@ void SwVisitingCardPage::SetUserData( sal_uInt32 nCnt,
 
 SwVisitingCardPage::SwVisitingCardPage(Window* pParent, const SfxItemSet& rSet) :
     SfxTabPage(pParent, SW_RES(TP_VISITING_CARDS), rSet),
+    aContentFL(this,        SW_RES( FL_CONTENT           )),
     aAutoTextLB(this, 		SW_RES( LB_AUTO_TEXT			)),
     aAutoTextGroupFT(this, 	SW_RES( FT_AUTO_TEXT_GROUP	)),
     aAutoTextGroupLB(this, 	SW_RES( LB_AUTO_TEXT_GROUP	)),
-    aContentFL(this,        SW_RES( FL_CONTENT           )),
     aExampleWIN(this, 		SW_RES( WIN_EXAMPLE			)),
     sVisCardGroup(SW_RES(ST_VISCARD_GROUP)),
     pExampleFrame(0)
 {
     FreeResource();
-    aAutoTextLB.SetWindowBits( WB_HSCROLL );
+    aAutoTextLB.SetStyle( aAutoTextLB.GetStyle() | WB_HSCROLL );
     aAutoTextLB.SetSpaceBetweenEntries(0);
     aAutoTextLB.SetSelectionMode( SINGLE_SELECTION );
     aAutoTextLB.SetHelpId(HID_BUSINESS_CARD_CONTENT);
