@@ -50,7 +50,7 @@ static const long MY_MINSHORT = -MY_MAXSHORT;
  * sind diese Algorithmen im Kapitel 4.3.1. The Classical Algorithms.
  */
 
-// Muss auf UINT16/INT16/UINT32/INT32 umgestellt werden !!! W.P.
+// Muss auf sal_uInt16/INT16/sal_uInt32/sal_Int32 umgestellt werden !!! W.P.
 
 // -----------------------------------------------------------------------
 
@@ -78,12 +78,7 @@ void BigInt::MakeBigInt( const BigInt& rVal )
 
         nNum[0] = (sal_uInt16)(nTmp & 0xffffL);
         nNum[1] = (sal_uInt16)(nTmp >> 16);
-#ifndef _WIN16
         if ( nTmp & 0xffff0000L )
-#else
-        long l = 0xffff0000L;
-        if ( nTmp & l )
-#endif
             nLen = 2;
         else
             nLen = 1;
@@ -650,7 +645,7 @@ BigInt::BigInt( sal_uInt32 nValue )
 
 // -----------------------------------------------------------------------
 
-BigInt::operator ULONG() const
+BigInt::operator sal_uIntPtr() const
 {
     if ( !bIsBig )
         return (sal_uInt32)nVal;
@@ -876,7 +871,7 @@ BigInt& BigInt::operator/=( const BigInt& rVal )
     {
         if ( rVal.nVal == 0 )
         {
-            DBG_ERROR( "BigInt::operator/ --> divide by zero" );
+            OSL_FAIL( "BigInt::operator/ --> divide by zero" );
             return *this;
         }
 
@@ -937,7 +932,7 @@ void BigInt::DivMod( const BigInt& rVal, BigInt& rMod )
     {
         if ( rVal.nVal == 0 )
         {
-            DBG_ERROR( "BigInt::operator/ --> divide by zero" );
+            OSL_FAIL( "BigInt::operator/ --> divide by zero" );
             return;
         }
 
@@ -1006,7 +1001,7 @@ BigInt& BigInt::operator%=( const BigInt& rVal )
     {
         if ( rVal.nVal == 0 )
         {
-            DBG_ERROR( "BigInt::operator/ --> divide by zero" );
+            OSL_FAIL( "BigInt::operator/ --> divide by zero" );
             return *this;
         }
 
