@@ -41,24 +41,13 @@
 
 #include "boost/static_assert.hpp"
 
-/*
-#if defined( DBG_UTIL ) && (OSL_DEBUG_LEVEL > 1)
-// prueft Synchronisation des Buffers nach allen Read, Write, Seek
-#define OV_DEBUG
-#endif
-*/
-
 #include <tools/solar.h>
 
-#if defined(BLC)
-#define SWAPNIBBLES(c) c=_crotl(c,4);
-#else
 #define SWAPNIBBLES(c)      \
 unsigned char nSwapTmp=c;   \
 nSwapTmp <<= 4;             \
 c >>= 4;                    \
 c |= nSwapTmp;
-#endif
 
 #include <tools/debug.hxx>
 #define ENABLE_BYTESTRING_STREAM_OPERATORS
@@ -93,6 +82,24 @@ inline static void SwapLongInt( int& r )
     {   r = SWAPLONG(r);   }
 inline static void SwapLongUInt( unsigned int& r )
     {   r = SWAPLONG(r);   }
+
+inline static void SwapUInt64( sal_uInt64& r )
+    {
+        union
+        {
+            sal_uInt64 n;
+            sal_uInt32 c[2];
+        } s;
+
+        s.n = r;
+        s.c[0] ^= s.c[1]; // swap the 32 bit words
+        s.c[1] ^= s.c[0];
+        s.c[0] ^= s.c[1];
+        // swap the bytes in the words
+        s.c[0] = SWAPLONG(s.c[0]);
+        s.c[1] = SWAPLONG(s.c[1]);
+        r = s.n;
+    }
 #ifdef UNX
 inline static void SwapFloat( float& r )
     {
@@ -106,11 +113,12 @@ inline static void SwapFloat( float& r )
         s.c = SWAPLONG( s.c );
         r = s.f;
     }
+
 inline static void SwapDouble( double& r )
     {
         if( sizeof(double) != 8 )
         {
-          DBG_ASSERT( FALSE, "Can only swap 8-Byte-doubles\n" );
+          DBG_ASSERT( sal_False, "Can only swap 8-Byte-doubles\n" );
         }
         else
         {
@@ -160,7 +168,7 @@ if( (tmp==STREAM_IO_WRITE) && sizeof(datatype) <= nBufFree)\
     if( nBufActualPos > nBufActualLen )\
         nBufActualLen = nBufActualPos;\
     pBufPos += sizeof(datatype);\
-    bIsDirty = TRUE;\
+    bIsDirty = sal_True;\
 }\
 else\
     Write( (char*)&value, sizeof(datatype) );\
@@ -189,7 +197,7 @@ ErrCode SvLockBytes::ReadAt(sal_Size nPos, void * pBuffer, sal_Size nCount,
 {
     if (!m_pStream)
     {
-        DBG_ERROR("SvLockBytes::ReadAt(): Bad stream");
+        OSL_FAIL("SvLockBytes::ReadAt(): Bad stream");
         return ERRCODE_NONE;
     }
 
@@ -207,7 +215,7 @@ ErrCode SvLockBytes::WriteAt(sal_Size nPos, const void * pBuffer, sal_Size nCoun
 {
     if (!m_pStream)
     {
-        DBG_ERROR("SvLockBytes::WriteAt(): Bad stream");
+        OSL_FAIL("SvLockBytes::WriteAt(): Bad stream");
         return ERRCODE_NONE;
     }
 
@@ -224,7 +232,7 @@ ErrCode SvLockBytes::Flush() const
 {
     if (!m_pStream)
     {
-        DBG_ERROR("SvLockBytes::Flush(): Bad stream");
+        OSL_FAIL("SvLockBytes::Flush(): Bad stream");
         return ERRCODE_NONE;
     }
 
@@ -238,7 +246,7 @@ ErrCode SvLockBytes::SetSize(sal_Size nSize)
 {
     if (!m_pStream)
     {
-        DBG_ERROR("SvLockBytes::SetSize(): Bad stream");
+        OSL_FAIL("SvLockBytes::SetSize(): Bad stream");
         return ERRCODE_NONE;
     }
 
@@ -249,7 +257,7 @@ ErrCode SvLockBytes::SetSize(sal_Size nSize)
 //============================================================================
 ErrCode SvLockBytes::LockRegion(sal_Size, sal_Size, LockType)
 {
-    DBG_ERROR("SvLockBytes::LockRegion(): Not implemented");
+    OSL_FAIL("SvLockBytes::LockRegion(): Not implemented");
     return ERRCODE_NONE;
 }
 
@@ -257,7 +265,7 @@ ErrCode SvLockBytes::LockRegion(sal_Size, sal_Size, LockType)
 
 ErrCode SvLockBytes::UnlockRegion(sal_Size, sal_Size, LockType)
 {
-    DBG_ERROR("SvLockBytes::UnlockRegion(): Not implemented");
+    OSL_FAIL("SvLockBytes::UnlockRegion(): Not implemented");
     return ERRCODE_NONE;
 }
 
@@ -266,7 +274,7 @@ ErrCode SvLockBytes::Stat(SvLockBytesStat * pStat, SvLockBytesStatFlag) const
 {
     if (!m_pStream)
     {
-        DBG_ERROR("SvLockBytes::Stat(): Bad stream");
+        OSL_FAIL("SvLockBytes::Stat(): Bad stream");
         return ERRCODE_NONE;
     }
 
@@ -436,7 +444,7 @@ void SvStream::ImpInit()
     eStreamCharSet      = osl_getThreadTextEncoding();
 //  eTargetCharSet      = osl_getThreadTextEncoding();
     nCryptMask          = 0;
-    bIsEof              = FALSE;
+    bIsEof              = sal_False;
 #if defined UNX
     eLineDelimiter      = LINEEND_LF;   // UNIX-Format
 #else
@@ -447,9 +455,9 @@ void SvStream::ImpInit()
 
     nBufFilePos         = 0;
     nBufActualPos       = 0;
-    bIsDirty            = FALSE;
-    bIsConsistent       = TRUE;
-    bIsWritable         = TRUE;
+    bIsDirty            = sal_False;
+    bIsConsistent       = sal_True;
+    bIsWritable         = sal_True;
 
     pRWBuf              = 0;
     pBufPos             = 0;
@@ -475,10 +483,6 @@ void SvStream::ImpInit()
 |*
 |*    Stream::Stream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 SvStream::SvStream( SvLockBytes* pLockBytesP )
@@ -508,10 +512,6 @@ SvStream::SvStream()
 |*
 |*    Stream::~Stream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 SvStream::~SvStream()
@@ -529,10 +529,6 @@ SvStream::~SvStream()
 |*
 |*    Stream::IsA()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_uInt16 SvStream::IsA() const
@@ -544,15 +540,11 @@ sal_uInt16 SvStream::IsA() const
 |*
 |*    Stream::ClearError()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::ClearError()
 {
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     nError = SVSTREAM_OK;
 }
 
@@ -560,10 +552,6 @@ void SvStream::ClearError()
 |*
 |*    Stream::SetError()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::SetError( sal_uInt32 nErrorCode )
@@ -577,22 +565,18 @@ void SvStream::SetError( sal_uInt32 nErrorCode )
 |*
 |*    Stream::SetNumberFormatInt()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::SetNumberFormatInt( sal_uInt16 nNewFormat )
 {
     nNumberFormatInt = nNewFormat;
-    bSwap = FALSE;
+    bSwap = sal_False;
 #ifdef OSL_BIGENDIAN
     if( nNumberFormatInt == NUMBERFORMAT_INT_LITTLEENDIAN )
-        bSwap = TRUE;
+        bSwap = sal_True;
 #else
     if( nNumberFormatInt == NUMBERFORMAT_INT_BIGENDIAN )
-        bSwap = TRUE;
+        bSwap = sal_True;
 #endif
 }
 
@@ -600,10 +584,6 @@ void SvStream::SetNumberFormatInt( sal_uInt16 nNewFormat )
 |*
 |*    Stream::SetBufferSize()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::SetBufferSize( sal_uInt16 nBufferSize )
@@ -625,8 +605,8 @@ void SvStream::SetBufferSize( sal_uInt16 nBufferSize )
     nBufActualPos   = 0;
     nBufSize        = nBufferSize;
     if( nBufSize )
-        pRWBuf = new BYTE[ nBufSize ];
-    bIsConsistent   = TRUE;
+        pRWBuf = new sal_uInt8[ nBufSize ];
+    bIsConsistent   = sal_True;
     pBufPos         = pRWBuf;
     eIOMode = STREAM_IO_DONTKNOW;
     if( !bDontSeek )
@@ -637,10 +617,6 @@ void SvStream::SetBufferSize( sal_uInt16 nBufferSize )
 |*
 |*    Stream::ClearBuffer()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::ClearBuffer()
@@ -649,21 +625,17 @@ void SvStream::ClearBuffer()
     nBufActualPos   = 0;
     nBufFilePos     = 0;
     pBufPos         = pRWBuf;
-    bIsDirty        = FALSE;
-    bIsConsistent   = TRUE;
+    bIsDirty        = sal_False;
+    bIsConsistent   = sal_True;
     eIOMode         = STREAM_IO_DONTKNOW;
 
-    bIsEof          = FALSE;
+    bIsEof          = sal_False;
 }
 
 /*************************************************************************
 |*
 |*    Stream::ResetError()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::ResetError()
@@ -675,10 +647,6 @@ void SvStream::ResetError()
 |*
 |*    Stream::ReadLine()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvStream::ReadByteStringLine( String& rStr, rtl_TextEncoding eSrcCharSet )
@@ -694,7 +662,7 @@ sal_Bool SvStream::ReadByteStringLine( String& rStr, rtl_TextEncoding eSrcCharSe
 sal_Bool SvStream::ReadLine( ByteString& rStr )
 {
     sal_Char    buf[256+1];
-    sal_Bool        bEnd        = FALSE;
+    sal_Bool        bEnd        = sal_False;
     sal_Size       nOldFilePos = Tell();
     sal_Char    c           = 0;
     sal_Size       nTotalLen   = 0;
@@ -710,8 +678,8 @@ sal_Bool SvStream::ReadLine( ByteString& rStr )
             if ( rStr.Len() == 0 )
             {
                 // der allererste Blockread hat fehlgeschlagen -> Abflug
-                bIsEof = TRUE;
-                return FALSE;
+                bIsEof = sal_True;
+                return sal_False;
             }
             else
                 break;
@@ -723,7 +691,7 @@ sal_Bool SvStream::ReadLine( ByteString& rStr )
             c = buf[j];
             if ( c == '\n' || c == '\r' )
             {
-                bEnd = TRUE;
+                bEnd = sal_True;
                 break;
             }
             // erAck 26.02.01: Old behavior was no special treatment of '\0'
@@ -743,7 +711,7 @@ sal_Bool SvStream::ReadLine( ByteString& rStr )
     }
 
     if ( !bEnd && !GetError() && rStr.Len() )
-        bEnd = TRUE;
+        bEnd = sal_True;
 
     nOldFilePos += nTotalLen;
     if( Tell() > nOldFilePos )
@@ -761,14 +729,14 @@ sal_Bool SvStream::ReadLine( ByteString& rStr )
     }
 
     if ( bEnd )
-        bIsEof = FALSE;
+        bIsEof = sal_False;
     return bEnd;
 }
 
 sal_Bool SvStream::ReadUniStringLine( String& rStr )
 {
     sal_Unicode buf[256+1];
-    sal_Bool        bEnd        = FALSE;
+    sal_Bool        bEnd        = sal_False;
     sal_Size       nOldFilePos = Tell();
     sal_Unicode c           = 0;
     sal_Size       nTotalLen   = 0;
@@ -787,8 +755,8 @@ sal_Bool SvStream::ReadUniStringLine( String& rStr )
             if ( rStr.Len() == 0 )
             {
                 // der allererste Blockread hat fehlgeschlagen -> Abflug
-                bIsEof = TRUE;
-                return FALSE;
+                bIsEof = sal_True;
+                return sal_False;
             }
             else
                 break;
@@ -802,7 +770,7 @@ sal_Bool SvStream::ReadUniStringLine( String& rStr )
             c = buf[j];
             if ( c == '\n' || c == '\r' )
             {
-                bEnd = TRUE;
+                bEnd = sal_True;
                 break;
             }
             // erAck 26.02.01: Old behavior was no special treatment of '\0'
@@ -822,7 +790,7 @@ sal_Bool SvStream::ReadUniStringLine( String& rStr )
     }
 
     if ( !bEnd && !GetError() && rStr.Len() )
-        bEnd = TRUE;
+        bEnd = sal_True;
 
     nOldFilePos += nTotalLen * sizeof(sal_Unicode);
     if( Tell() > nOldFilePos )
@@ -840,7 +808,7 @@ sal_Bool SvStream::ReadUniStringLine( String& rStr )
     }
 
     if ( bEnd )
-        bIsEof = FALSE;
+        bIsEof = sal_False;
     return bEnd;
 }
 
@@ -864,7 +832,7 @@ sal_Bool SvStream::ReadCString( ByteString& rStr )
         rStr.Erase();
 
     sal_Char buf[ 256 + 1 ];
-    sal_Bool bEnd = FALSE;
+    sal_Bool bEnd = sal_False;
     sal_Size nFilePos = Tell();
 
     while( !bEnd && !GetError() )
@@ -949,10 +917,6 @@ sal_Bool SvStream::WriteUnicodeOrByteText( const String& rStr, rtl_TextEncoding
 |*
 |*    Stream::WriteLine()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvStream::WriteByteStringLine( const String& rStr, rtl_TextEncoding eDestCharSet )
@@ -986,10 +950,6 @@ sal_Bool SvStream::WriteUniOrByteStringLine( const String& rStr, rtl_TextEncodin
 |*
 |*    Stream::WriteLines()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 17.07.95
-|*    Letzte Aenderung  OV 17.07.95
-|*
 *************************************************************************/
 
 sal_Bool SvStream::WriteByteStringLines( const String& rStr, rtl_TextEncoding eDestCharSet )
@@ -1048,7 +1008,7 @@ sal_Bool SvStream::WriteUniOrByteChar( sal_Unicode ch, rtl_TextEncoding eDestCha
 
 sal_Bool SvStream::StartWritingUnicodeText()
 {
-    SetEndianSwap( FALSE );     // write native format
+    SetEndianSwap( sal_False );     // write native format
     // BOM, Byte Order Mark, U+FEFF, see
     // http://www.unicode.org/faq/utf_bom.html#BOM
     // Upon read: 0xfeff(-257) => no swap; 0xfffe(-2) => swap
@@ -1062,21 +1022,59 @@ sal_Bool SvStream::StartWritingUnicodeText()
 |*
 *************************************************************************/
 
-sal_Bool SvStream::StartReadingUnicodeText()
+sal_Bool SvStream::StartReadingUnicodeText( rtl_TextEncoding eReadBomCharSet )
 {
+    if (!(  eReadBomCharSet == RTL_TEXTENCODING_DONTKNOW ||
+            eReadBomCharSet == RTL_TEXTENCODING_UNICODE ||
+            eReadBomCharSet == RTL_TEXTENCODING_UTF8))
+        return sal_True;    // nothing to read
+
+    bool bTryUtf8 = false;
     sal_uInt16 nFlag;
+    sal_sSize nBack = sizeof(nFlag);
     *this >> nFlag;
     switch ( nFlag )
     {
         case 0xfeff :
-            // native
+            // native UTF-16
+            if (    eReadBomCharSet == RTL_TEXTENCODING_DONTKNOW ||
+                    eReadBomCharSet == RTL_TEXTENCODING_UNICODE)
+                nBack = 0;
         break;
         case 0xfffe :
-            SetEndianSwap( !bSwap );
+            // swapped UTF-16
+            if (    eReadBomCharSet == RTL_TEXTENCODING_DONTKNOW ||
+                    eReadBomCharSet == RTL_TEXTENCODING_UNICODE)
+            {
+                SetEndianSwap( !bSwap );
+                nBack = 0;
+            }
+        break;
+        case 0xefbb :
+            if (nNumberFormatInt == NUMBERFORMAT_INT_BIGENDIAN &&
+                    (eReadBomCharSet == RTL_TEXTENCODING_DONTKNOW ||
+                     eReadBomCharSet == RTL_TEXTENCODING_UTF8))
+                bTryUtf8 = true;
+        break;
+        case 0xbbef :
+            if (nNumberFormatInt == NUMBERFORMAT_INT_LITTLEENDIAN &&
+                    (eReadBomCharSet == RTL_TEXTENCODING_DONTKNOW ||
+                     eReadBomCharSet == RTL_TEXTENCODING_UTF8))
+                bTryUtf8 = true;
         break;
         default:
-            SeekRel( -((sal_sSize)sizeof(nFlag)) );      // no BOM, pure data
+            ;   // nothing
     }
+    if (bTryUtf8)
+    {
+        sal_uChar nChar;
+        nBack += sizeof(nChar);
+        *this >> nChar;
+        if (nChar == 0xbf)
+            nBack = 0;      // it is UTF-8
+    }
+    if (nBack)
+        SeekRel( -nBack );      // no BOM, pure data
     return nError == SVSTREAM_OK;
 }
 
@@ -1109,6 +1107,10 @@ sal_Bool SvStream::ReadCsvLine( String& rStr, sal_Bool bEmbeddedLineBreak,
     if (bEmbeddedLineBreak)
     {
         const sal_Unicode* pSeps = rFieldSeparators.GetBuffer();
+
+        // See if the separator(s) include tab.
+        bool bTabSep = lcl_UnicodeStrChr(pSeps, '\t') != NULL;
+
         xub_StrLen nLastOffset = 0;
         xub_StrLen nQuotes = 0;
         while (!IsEof() && rStr.Len() < STRING_MAXLEN)
@@ -1121,6 +1123,16 @@ sal_Bool SvStream::ReadCsvLine( String& rStr, sal_Bool bEmbeddedLineBreak,
             {
                 if (nQuotes)
                 {
+                    if (bTabSep && *p == '\t')
+                    {
+                        // When tab-delimited, tab char ends quoted sequence
+                        // even if we haven't reached the end quote.  Doing
+                        // this helps keep mal-formed rows from damaging
+                        // other, well-formed rows.
+                        nQuotes = 0;
+                        break;
+                    }
+
                     if (*p == cFieldQuote && !bBackslashEscaped)
                         ++nQuotes;
                     else if (bAllowBackslashEscape)
@@ -1158,10 +1170,6 @@ sal_Bool SvStream::ReadCsvLine( String& rStr, sal_Bool bEmbeddedLineBreak,
 |*
 |*    Stream::SeekRel()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Size SvStream::SeekRel( sal_sSize nPos )
@@ -1188,10 +1196,6 @@ sal_Size SvStream::SeekRel( sal_sSize nPos )
 |*
 |*    Stream::operator>>()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 SvStream& SvStream::operator >> ( sal_uInt16& r )
@@ -1210,6 +1214,15 @@ SvStream& SvStream::operator>> ( sal_uInt32& r )
     return *this;
 }
 
+
+SvStream& SvStream::operator>> ( sal_uInt64& r )
+{
+    READNUMBER_WITHOUT_SWAP(sal_uInt64,r)
+    if( bSwap )
+        SwapUInt64(r);
+    return *this;
+}
+
 SvStream& SvStream::operator >> ( long& r )
 {
 #if(SAL_TYPES_SIZEOFLONG != 4)
@@ -1328,10 +1341,6 @@ SvStream& SvStream::operator>> ( SvStream& rStream )
 |*
 |*    Stream::operator<<()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 SvStream& SvStream::operator<< ( sal_uInt16 v )
@@ -1350,6 +1359,14 @@ SvStream& SvStream::operator<<  ( sal_uInt32 v )
     return *this;
 }
 
+SvStream& SvStream::operator<<  ( sal_uInt64 v )
+{
+    if( bSwap )
+        SwapUInt64(v);
+    WRITENUMBER_WITHOUT_SWAP(sal_uInt64,v)
+    return *this;
+}
+
 SvStream& SvStream::operator<< ( long v )
 {
 #if(SAL_TYPES_SIZEOFLONG != 4)
@@ -1391,7 +1408,7 @@ SvStream& SvStream::operator<<  ( signed char v )
         if( nBufActualPos > nBufActualLen )  // Append ?
             nBufActualLen = nBufActualPos;
         nBufFree--; // = sizeof(char);
-        bIsDirty = TRUE;
+        bIsDirty = sal_True;
     }
     else
         Write( (char*)&v, sizeof(signed char) );
@@ -1412,7 +1429,7 @@ SvStream& SvStream::operator<<  ( char v )
         if( nBufActualPos > nBufActualLen )  // Append ?
             nBufActualLen = nBufActualPos;
         nBufFree--; // = sizeof(char);
-        bIsDirty = TRUE;
+        bIsDirty = sal_True;
     }
     else
         Write( (char*)&v, sizeof(char) );
@@ -1431,7 +1448,7 @@ SvStream& SvStream::operator<<  ( unsigned char v )
         if( nBufActualPos > nBufActualLen )  // Append ?
             nBufActualLen = nBufActualPos;
         nBufFree--;
-        bIsDirty = TRUE;
+        bIsDirty = sal_True;
     }
     else
         Write( (char*)&v, sizeof(char) );
@@ -1592,10 +1609,6 @@ SvStream& SvStream::WriteByteString( const ByteString& rStr)
 |*
 |*    Stream::Read()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Size SvStream::Read( void* pData, sal_Size nCount )
@@ -1632,7 +1645,7 @@ sal_Size SvStream::Read( void* pData, sal_Size nCount )
                     CryptAndWriteBuffer(pRWBuf, nBufActualLen);
                 else
                     PutData( pRWBuf, nBufActualLen );
-                bIsDirty = FALSE;
+                bIsDirty = sal_False;
             }
 
             // passt der Datenblock in den Puffer ?
@@ -1677,10 +1690,10 @@ sal_Size SvStream::Read( void* pData, sal_Size nCount )
             }
         }
     }
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     nBufFree = nBufActualLen - nBufActualPos;
     if( nCount != nSaveCount && nError != ERRCODE_IO_PENDING )
-        bIsEof = TRUE;
+        bIsEof = sal_True;
     if( nCount == nSaveCount && nError == ERRCODE_IO_PENDING )
         nError = ERRCODE_NONE;
     return nCount;
@@ -1690,10 +1703,6 @@ sal_Size SvStream::Read( void* pData, sal_Size nCount )
 |*
 |*    Stream::Write()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Size SvStream::Write( const void* pData, sal_Size nCount )
@@ -1728,7 +1737,7 @@ sal_Size SvStream::Write( const void* pData, sal_Size nCount )
             nBufActualLen = nBufActualPos;
 
         pBufPos += nCount;
-        bIsDirty = TRUE;
+        bIsDirty = sal_True;
     }
     else
     {
@@ -1740,7 +1749,7 @@ sal_Size SvStream::Write( const void* pData, sal_Size nCount )
                 CryptAndWriteBuffer( pRWBuf, (sal_Size)nBufActualLen );
             else
                 PutData( pRWBuf, nBufActualLen );
-            bIsDirty = FALSE;
+            bIsDirty = sal_False;
         }
 
         // passt der Block in den Puffer ?
@@ -1768,7 +1777,7 @@ sal_Size SvStream::Write( const void* pData, sal_Size nCount )
             nBufActualPos = (sal_uInt16)nCount;
             pBufPos = pRWBuf + nCount;
             nBufActualLen = (sal_uInt16)nCount;
-            bIsDirty = TRUE;
+            bIsDirty = sal_True;
         }
     }
     nBufFree = nBufSize - nBufActualPos;
@@ -1780,17 +1789,13 @@ sal_Size SvStream::Write( const void* pData, sal_Size nCount )
 |*
 |*    Stream::Seek()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Size SvStream::Seek( sal_Size nFilePos )
 {
     eIOMode = STREAM_IO_DONTKNOW;
 
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     if( !pRWBuf )
     {
         nBufFilePos = SeekPos( nFilePos );
@@ -1816,7 +1821,7 @@ sal_Size SvStream::Seek( sal_Size nFilePos )
                 CryptAndWriteBuffer( pRWBuf, nBufActualLen );
             else
                 PutData( pRWBuf, nBufActualLen );
-            bIsDirty = FALSE;
+            bIsDirty = sal_False;
         }
         nBufActualLen = 0;
         nBufActualPos = 0;
@@ -1836,10 +1841,6 @@ sal_Size SvStream::Seek( sal_Size nFilePos )
 |*
 |*    Stream::Flush()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::Flush()
@@ -1852,7 +1853,7 @@ void SvStream::Flush()
         else
             if( PutData( pRWBuf, nBufActualLen ) != nBufActualLen )
                 SetError( SVSTREAM_WRITE_ERROR );
-        bIsDirty = FALSE;
+        bIsDirty = sal_False;
     }
     if( bIsWritable )
         FlushData();
@@ -1863,10 +1864,6 @@ void SvStream::Flush()
 |*
 |*    Stream::PutBack()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 01.08.94
-|*    Letzte Aenderung  OV 01.08.94
-|*
 *************************************************************************/
 
 /*
@@ -1896,9 +1893,9 @@ SvStream& SvStream::PutBack( char aCh )
             CryptAndWriteBuffer( pRWBuf, nBufActualLen );
         else
             PutData( pRWBuf, nBufActualLen );
-        bIsDirty = FALSE;
+        bIsDirty = sal_False;
     }
-    bIsConsistent = FALSE;  // Puffer enthaelt jetzt TRASH
+    bIsConsistent = sal_False;  // Puffer enthaelt jetzt TRASH
     if( nBufActualPos )
     {
         // 1. Fall
@@ -1927,7 +1924,7 @@ SvStream& SvStream::PutBack( char aCh )
         *pRWBuf = aCh;
     }
     eIOMode = STREAM_IO_DONTKNOW;
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     return *this;
 }
 
@@ -1935,10 +1932,6 @@ SvStream& SvStream::PutBack( char aCh )
 |*
 |*    Stream::EatWhite()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 01.08.94
-|*    Letzte Aenderung  OV 01.08.94
-|*
 *************************************************************************/
 
 void SvStream::EatWhite()
@@ -1955,10 +1948,6 @@ void SvStream::EatWhite()
 |*
 |*    Stream::RefreshBuffer()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 01.08.94
-|*    Letzte Aenderung  OV 01.08.94
-|*
 *************************************************************************/
 
 void SvStream::RefreshBuffer()
@@ -1970,7 +1959,7 @@ void SvStream::RefreshBuffer()
             CryptAndWriteBuffer( pRWBuf, (sal_Size)nBufActualLen );
         else
             PutData( pRWBuf, nBufActualLen );
-        bIsDirty = FALSE;
+        bIsDirty = sal_False;
     }
     SeekPos( nBufFilePos );
     nBufActualLen = (sal_uInt16)GetData( pRWBuf, nBufSize );
@@ -1978,7 +1967,7 @@ void SvStream::RefreshBuffer()
         nError = ERRCODE_NONE;
     if( nCryptMask )
         EncryptBuffer(pRWBuf, (sal_Size)nBufActualLen);
-    bIsConsistent = TRUE;
+    bIsConsistent = sal_True;
     eIOMode = STREAM_IO_DONTKNOW;
 }
 
@@ -1988,8 +1977,6 @@ void SvStream::RefreshBuffer()
 |*    Stream::CreateFormatString()
 |*
 |*    Beschreibung      Baut Formatstring zusammen
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
 |*
 *************************************************************************/
 
@@ -2025,10 +2012,6 @@ void SvStream::CreateFormatString()
 |*
 |*    Stream::ReadNumber()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 #define BUFSIZE_LONG 21  // log( 2 hoch 64 ) + 1
@@ -2054,7 +2037,7 @@ SvStream& SvStream::ReadNumber( long& rLong )
     rLong = strtol( buf, &pEndPtr, (int)nRadix );
     nFPtr += ( (sal_Size)pEndPtr - (sal_Size)(&(buf[0])) );
     Seek( nFPtr );
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     return *this;
 }
 
@@ -2079,7 +2062,7 @@ SvStream& SvStream::ReadNumber( sal_uInt32& rUInt32 )
     rUInt32 = strtoul( buf, &pEndPtr, (int)nRadix );
     nFPtr += ( (sal_uIntPtr)pEndPtr - (sal_uIntPtr)buf );
     Seek( nFPtr );
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     return *this;
 }
 
@@ -2104,7 +2087,7 @@ SvStream& SvStream::ReadNumber( double& rDouble )
     rDouble = strtod( buf, &pEndPtr );
     nFPtr += ( (sal_Size)pEndPtr - (sal_Size)buf );
     Seek( nFPtr );
-    bIsEof = FALSE;
+    bIsEof = sal_False;
     return *this;
 }
 
@@ -2113,10 +2096,6 @@ SvStream& SvStream::ReadNumber( double& rDouble )
 |*
 |*    Stream::WriteNumber()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 SvStream& SvStream::WriteNumber( long nLong )
@@ -2207,8 +2186,6 @@ SvStream& SvStream::WriteNumber( const double& rDouble )
 |*    Stream::CryptAndWriteBuffer()
 |*
 |*    Beschreibung      Verschluesseln und Schreiben
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
 |*
 *************************************************************************/
 
@@ -2250,8 +2227,6 @@ sal_Size SvStream::CryptAndWriteBuffer( const void* pStart, sal_Size nLen)
 |*    Stream::EncryptBuffer()
 |*
 |*    Beschreibung      Buffer entschluesseln
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
 |*
 *************************************************************************/
 
@@ -2267,17 +2242,13 @@ sal_Bool SvStream::EncryptBuffer(void* pStart, sal_Size nLen)
         aCh ^= nMask;
         *pTemp = aCh;
     }
-    return TRUE;
+    return sal_True;
 }
 
 /*************************************************************************
 |*
 |*    Stream::SetKey()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 unsigned char implGetCryptMask(const sal_Char* pStr, sal_Int32 nLen, long nVersion)
@@ -2325,10 +2296,6 @@ void SvStream::SetKey( const ByteString& rKey )
 |*
 |*    Stream::SyncSvStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::SyncSvStream( sal_Size nNewStreamPos )
@@ -2341,10 +2308,6 @@ void SvStream::SyncSvStream( sal_Size nNewStreamPos )
 |*
 |*    Stream::SyncSysStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 void SvStream::SyncSysStream()
@@ -2357,10 +2320,6 @@ void SvStream::SyncSysStream()
 |*
 |*    Stream::SetStreamSize()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  OV 08.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvStream::SetStreamSize( sal_Size nSize )
@@ -2392,10 +2351,6 @@ void SvStream::RemoveMark( sal_Size )
 |*
 |*    endl()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 08.06.94
-|*    Letzte Aenderung  TH 13.11.96
-|*
 *************************************************************************/
 
 SvStream& endl( SvStream& rStr )
@@ -2438,22 +2393,18 @@ SvStream& endlub( SvStream& rStrm )
 |*
 |*    SvMemoryStream::SvMemoryStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 SvMemoryStream::SvMemoryStream( void* pBuffer, sal_Size bufSize,
                                 StreamMode eMode )
 {
     if( eMode & STREAM_WRITE )
-        bIsWritable = TRUE;
+        bIsWritable = sal_True;
     else
-        bIsWritable = FALSE;
+        bIsWritable = sal_False;
     nEndOfData  = bufSize;
-    bOwnsData   = FALSE;
-    pBuf        = (BYTE *) pBuffer;
+    bOwnsData   = sal_False;
+    pBuf        = (sal_uInt8 *) pBuffer;
     nResize     = 0L;
     nSize       = bufSize;
     nPos        = 0L;
@@ -2464,16 +2415,12 @@ SvMemoryStream::SvMemoryStream( void* pBuffer, sal_Size bufSize,
 |*
 |*    SvMemoryStream::SvMemoryStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 SvMemoryStream::SvMemoryStream( sal_Size nInitSize, sal_Size nResizeOffset )
 {
-    bIsWritable = TRUE;
-    bOwnsData   = TRUE;
+    bIsWritable = sal_True;
+    bOwnsData   = sal_True;
     nEndOfData  = 0L;
     nResize     = nResizeOffset;
     nPos        = 0;
@@ -2494,10 +2441,6 @@ SvMemoryStream::SvMemoryStream( sal_Size nInitSize, sal_Size nResizeOffset )
 |*
 |*    SvMemoryStream::~SvMemoryStream()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 SvMemoryStream::~SvMemoryStream()
@@ -2515,10 +2458,6 @@ SvMemoryStream::~SvMemoryStream()
 |*
 |*    SvMemoryStream::IsA()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 sal_uInt16 SvMemoryStream::IsA() const
@@ -2530,10 +2469,6 @@ sal_uInt16 SvMemoryStream::IsA() const
 |*
 |*    SvMemoryStream::SetBuffer()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 void* SvMemoryStream::SetBuffer( void* pNewBuf, sal_Size nCount,
@@ -2551,7 +2486,7 @@ void* SvMemoryStream::SetBuffer( void* pNewBuf, sal_Size nCount,
     else
         pResult = pBuf;
 
-    pBuf        = (BYTE *) pNewBuf;
+    pBuf        = (sal_uInt8 *) pNewBuf;
     nPos        = 0;
     nSize       = nCount;
     nResize     = 0;
@@ -2571,10 +2506,6 @@ void* SvMemoryStream::SetBuffer( void* pNewBuf, sal_Size nCount,
 |*
 |*    SvMemoryStream::GetData()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 sal_Size SvMemoryStream::GetData( void* pData, sal_Size nCount )
@@ -2591,10 +2522,6 @@ sal_Size SvMemoryStream::GetData( void* pData, sal_Size nCount )
 |*
 |*    SvMemoryStream::PutData()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 sal_Size SvMemoryStream::PutData( const void* pData, sal_Size nCount )
@@ -2656,10 +2583,6 @@ sal_Size SvMemoryStream::PutData( const void* pData, sal_Size nCount )
 |*
 |*    SvMemoryStream::SeekPos()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 // nEndOfData: Erste Position im Stream, die nicht gelesen werden darf
@@ -2702,10 +2625,6 @@ sal_Size SvMemoryStream::SeekPos( sal_Size nNewPos )
 |*
 |*    SvMemoryStream::FlushData()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 void SvMemoryStream::FlushData()
@@ -2716,10 +2635,6 @@ void SvMemoryStream::FlushData()
 |*
 |*    SvMemoryStream::ResetError()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 void SvMemoryStream::ResetError()
@@ -2731,15 +2646,11 @@ void SvMemoryStream::ResetError()
 |*
 |*    SvMemoryStream::AllocateMemory()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvMemoryStream::AllocateMemory( sal_Size nNewSize )
 {
-    pBuf = new BYTE[nNewSize];
+    pBuf = new sal_uInt8[nNewSize];
     return( pBuf != 0 );
 }
 
@@ -2747,26 +2658,22 @@ sal_Bool SvMemoryStream::AllocateMemory( sal_Size nNewSize )
 |*
 |*    SvMemoryStream::ReAllocateMemory()   (Bozo-Algorithmus)
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 20.06.94
-|*    Letzte Aenderung  OV 20.06.94
-|*
 *************************************************************************/
 
 sal_Bool SvMemoryStream::ReAllocateMemory( long nDiff )
 {
-    sal_Bool bRetVal    = FALSE;
+    sal_Bool bRetVal    = sal_False;
     long nTemp      = (long)nSize;
     nTemp           += nDiff;
     sal_Size nNewSize  = (sal_Size)nTemp;
 
     if( nNewSize )
     {
-        BYTE* pNewBuf   = new BYTE[nNewSize];
+        sal_uInt8* pNewBuf   = new sal_uInt8[nNewSize];
 
         if( pNewBuf )
         {
-            bRetVal = TRUE; // Success!
+            bRetVal = sal_True; // Success!
             if( nNewSize < nSize )      // Verkleinern ?
             {
                 memcpy( pNewBuf, pBuf, (size_t)nNewSize );
@@ -2788,7 +2695,7 @@ sal_Bool SvMemoryStream::ReAllocateMemory( long nDiff )
     }
     else
     {
-        bRetVal = TRUE;
+        bRetVal = sal_True;
         FreeMemory();
         pBuf = 0;
         nSize = 0;
@@ -2808,10 +2715,6 @@ void SvMemoryStream::FreeMemory()
 |*
 |*    SvMemoryStream::SwitchBuffer()
 |*
-|*    Beschreibung      STREAM.SDW
-|*    Ersterstellung    OV 26.07.94
-|*    Letzte Aenderung  OV 26.07.94
-|*
 *************************************************************************/
 
 void* SvMemoryStream::SwitchBuffer( sal_Size nInitSize, sal_Size nResizeOffset)
