@@ -118,7 +118,6 @@ class UcbStreamer_Impl : public ::cppu::WeakImplHelper2< XActiveDataStreamer, XA
     UcbLockBytesRef         m_xLockBytes;
 
 public:
-
                             UcbStreamer_Impl( UcbLockBytes* pLockBytes )
                                 : m_xLockBytes( pLockBytes )
                             {}
@@ -170,7 +169,6 @@ public:
                                 , m_xProgressHandler( rxProgressHandler )
                             {}
 
-
     virtual Reference<XInteractionHandler> SAL_CALL getInteractionHandler() throw (RuntimeException)
     { return m_xInteractionHandler; }
 
@@ -201,7 +199,7 @@ void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequenc
     for (i = 0; i < n; i++)
     {
         PropertyChangeEvent evt (rEvent[i]);
-        if (evt.PropertyName == ::rtl::OUString::createFromAscii ("DocumentHeader"))
+        if (evt.PropertyName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM ("DocumentHeader")))
         {
             Sequence<DocumentHeaderField> aHead;
             if (evt.NewValue >>= aHead)
@@ -226,12 +224,12 @@ void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequenc
 
             m_xLockBytes->SetStreamValid_Impl();
         }
-        else if (evt.PropertyName == rtl::OUString::createFromAscii ("PresentationURL"))
+        else if (evt.PropertyName == rtl::OUString(RTL_CONSTASCII_USTRINGPARAM ("PresentationURL")))
         {
             ::rtl::OUString aUrl;
             if (evt.NewValue >>= aUrl)
             {
-                ::rtl::OUString aBad (::rtl::OUString::createFromAscii ("private:"));
+                ::rtl::OUString aBad (RTL_CONSTASCII_USTRINGPARAM ("private:"));
                 if (!(aUrl.compareTo (aBad, aBad.getLength()) == 0))
                 {
                     // URL changed (Redirection).
@@ -239,7 +237,7 @@ void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequenc
                 }
             }
         }
-        else if (evt.PropertyName == ::rtl::OUString::createFromAscii ("MediaType"))
+        else if (evt.PropertyName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM ("MediaType")))
         {
             ::rtl::OUString aContentType;
             if (evt.NewValue >>= aContentType)
@@ -259,7 +257,6 @@ class Moderator
     // returns. This would imply that these class must be refcounted !!!
 
 public:
-
     Moderator(
         Reference < XContent >& xContent,
         Reference < XInteractionHandler >& xInteract,
@@ -300,7 +297,6 @@ public:
         : public salhelper::Condition
     {
     public:
-
         ConditionRes(osl::Mutex& aMutex,Moderator& aModerator)
             : salhelper::Condition(aMutex),
               m_aModerator(aModerator)
@@ -308,13 +304,11 @@ public:
         }
 
     protected:
-
         bool applies() const {
             return m_aModerator.m_aResultType != NORESULT;
         }
 
     private:
-
         Moderator& m_aModerator;
     };
 
@@ -325,10 +319,8 @@ public:
         sal_Int32         ioErrorCode;
     };
 
-
     Result getResult(const sal_uInt32 milliSec);
 
-
     enum ReplyType {
         NOREPLY,
         EXIT,
@@ -336,12 +328,10 @@ public:
         REQUESTHANDLED
     };
 
-
     class ConditionRep
         : public salhelper::Condition
     {
     public:
-
         ConditionRep(osl::Mutex& aMutex,Moderator& aModerator)
             : salhelper::Condition(aMutex),
               m_aModerator(aModerator)
@@ -349,40 +339,30 @@ public:
         }
 
     protected:
-
         bool applies() const {
             return m_aModerator.m_aReplyType != NOREPLY;
         }
 
     private:
-
         Moderator& m_aModerator;
     };
 
     void setReply(ReplyType);
 
-
     void handle( const Reference<XInteractionRequest >& Request );
-
     void push( const Any& Status );
-
     void update( const Any& Status );
-
     void pop(  );
 
     void setStream(const Reference< XStream >& aStream);
-
     void setInputStream(const Reference<XInputStream> &rxInputStream);
 
 
 protected:
-
     virtual void SAL_CALL run();
-
     virtual void SAL_CALL onTerminated();
 
 private:
-
     osl::Mutex        m_aMutex;
 
     friend class ConditionRes;
@@ -433,7 +413,6 @@ public:
 
 
 private:
-
     Moderator& m_aModerator;
 
     osl::Mutex m_aMutex;
@@ -441,7 +420,6 @@ private:
 };
 
 
-
 class ModeratorsActiveDataSink
     : public ::cppu::WeakImplHelper1<XActiveDataSink>
 {
@@ -473,7 +451,6 @@ public:
 
 
 private:
-
     Moderator& m_aModerator;
     osl::Mutex m_aMutex;
     Reference<XInputStream> m_xStream;
@@ -557,7 +534,6 @@ class ModeratorsProgressHandler
     : public ::cppu::WeakImplHelper1<XProgressHandler>
 {
 public:
-
     ModeratorsProgressHandler(Moderator &theModerator);
 
     ~ModeratorsProgressHandler();
@@ -574,7 +550,6 @@ public:
 
 
 private:
-
     Moderator& m_aModerator;
 };
 
@@ -611,8 +586,6 @@ void SAL_CALL ModeratorsProgressHandler::pop(  )
 }
 
 
-
-
 ModeratorsInteractionHandler::ModeratorsInteractionHandler(
     Moderator &aModerator)
     : m_aModerator(aModerator)
@@ -776,7 +749,6 @@ void Moderator::handle( const Reference<XInteractionRequest >& Request )
 }
 
 
-
 void Moderator::push( const Any& Status )
 {
     {
@@ -866,7 +838,6 @@ void Moderator::setInputStream(const Reference<XInputStream> &rxInputStream)
 }
 
 
-
 void SAL_CALL Moderator::run()
 {
     ResultType aResultType;
@@ -908,8 +879,6 @@ void SAL_CALL Moderator::run()
     }
 }
 
-
-
 void SAL_CALL Moderator::onTerminated()
 {
     {
@@ -918,12 +887,10 @@ void SAL_CALL Moderator::onTerminated()
      delete this;
 }
 
-
 /**
    Function for opening UCB contents synchronously,
    but with handled timeout;
 */
-
 static sal_Bool _UCBOpenContentSync(
     UcbLockBytesRef xLockBytes,
     Reference < XContent > xContent,
@@ -956,10 +923,10 @@ static sal_Bool UCBOpenContentSync(
         aScheme = xContId->getContentProviderScheme();
 
     // now determine wether we use a timeout or not;
-    if( ! aScheme.equalsIgnoreAsciiCaseAscii("http")                &&
-        ! aScheme.equalsIgnoreAsciiCaseAscii("https")                &&
-        ! aScheme.equalsIgnoreAsciiCaseAscii("vnd.sun.star.webdav") &&
-        ! aScheme.equalsIgnoreAsciiCaseAscii("ftp"))
+    if( ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("http"))                &&
+        ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("https"))               &&
+        ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("vnd.sun.star.webdav")) &&
+        ! aScheme.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("ftp")))
         return _UCBOpenContentSync(
             xLockBytes,xContent,rArg,xSink,xInteract,xProgress,xHandler);
 
@@ -1271,7 +1238,6 @@ static sal_Bool _UCBOpenContentSync(
     return ( bAborted || bException );
 }
 
-
 //----------------------------------------------------------------------------
 UcbLockBytes::UcbLockBytes( UcbLockBytesHandler* pHandler )
     : m_xInputStream (NULL)
@@ -1282,7 +1248,7 @@ UcbLockBytes::UcbLockBytes( UcbLockBytesHandler* pHandler )
     , m_bDontClose( sal_False )
     , m_bStreamValid  (sal_False)
 {
-    SetSynchronMode( TRUE );
+    SetSynchronMode( sal_True );
 }
 
 //----------------------------------------------------------------------------
@@ -1372,7 +1338,7 @@ sal_Bool UcbLockBytes::setInputStream_Impl( const Reference<XInputStream> &rxInp
             {
                 Reference < XMultiServiceFactory > xFactory = ::comphelper::getProcessServiceFactory();
                 Reference< XOutputStream > rxTempOut = Reference < XOutputStream > (
-                                    xFactory->createInstance ( ::rtl::OUString::createFromAscii( "com.sun.star.io.TempFile" ) ),
+                                    xFactory->createInstance ( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.io.TempFile")) ),
                                     UNO_QUERY );
 
                 if( rxTempOut.is() )
@@ -1411,7 +1377,7 @@ void UcbLockBytes::terminate_Impl()
 
     if ( GetError() == ERRCODE_NONE && !m_xInputStream.is() )
     {
-        DBG_ERROR("No InputStream, but no error set!" );
+        OSL_FAIL("No InputStream, but no error set!" );
         SetError( ERRCODE_IO_NOTEXISTS );
     }
 
@@ -1420,13 +1386,13 @@ void UcbLockBytes::terminate_Impl()
 }
 
 //----------------------------------------------------------------------------
-void UcbLockBytes::SetSynchronMode (BOOL bSynchron)
+void UcbLockBytes::SetSynchronMode (sal_Bool bSynchron)
 {
     SvLockBytes::SetSynchronMode (bSynchron);
 }
 
 //----------------------------------------------------------------------------
-ErrCode UcbLockBytes::ReadAt ( ULONG nPos, void *pBuffer, ULONG nCount, ULONG *pRead) const
+ErrCode UcbLockBytes::ReadAt ( sal_uLong nPos, void *pBuffer, sal_uLong nCount, sal_uLong *pRead) const
 {
     if ( IsSynchronMode() )
     {
@@ -1485,13 +1451,13 @@ ErrCode UcbLockBytes::ReadAt ( ULONG nPos, void *pBuffer, ULONG nCount, ULONG *p
 
     rtl_copyMemory (pBuffer, aData.getConstArray(), nSize);
     if (pRead)
-        *pRead = ULONG(nSize);
+        *pRead = sal_uLong(nSize);
 
     return ERRCODE_NONE;
 }
 
 //----------------------------------------------------------------------------
-ErrCode UcbLockBytes::WriteAt ( ULONG nPos, const void *pBuffer, ULONG nCount, ULONG *pWritten)
+ErrCode UcbLockBytes::WriteAt ( sal_uLong nPos, const void *pBuffer, sal_uLong nCount, sal_uLong *pWritten)
 {
     if ( pWritten )
         *pWritten = 0;
@@ -1535,16 +1501,25 @@ ErrCode UcbLockBytes::Flush() const
     Reference <XOutputStream > xOutputStream = getOutputStream_Impl();
     if ( !xOutputStream.is() )
         return ERRCODE_IO_CANTWRITE;
-    xOutputStream->flush();
+
+    try
+    {
+        xOutputStream->flush();
+    }
+    catch( Exception )
+    {
+        return ERRCODE_IO_CANTWRITE;
+    }
+
     return ERRCODE_NONE;
 }
 
 //----------------------------------------------------------------------------
-ErrCode UcbLockBytes::SetSize (ULONG nNewSize)
+ErrCode UcbLockBytes::SetSize (sal_uLong nNewSize)
 {
     SvLockBytesStat aStat;
     Stat( &aStat, (SvLockBytesStatFlag) 0 );
-    ULONG nSize = aStat.nSize;
+    sal_uLong nSize = aStat.nSize;
 
     if ( nSize > nNewSize )
     {
@@ -1561,8 +1536,8 @@ ErrCode UcbLockBytes::SetSize (ULONG nNewSize)
 
     if ( nSize < nNewSize )
     {
-        ULONG nDiff = nNewSize-nSize, nCount=0;
-        BYTE* pBuffer = new BYTE[ nDiff ];
+        sal_uLong nDiff = nNewSize-nSize, nCount=0;
+        sal_uInt8* pBuffer = new sal_uInt8[ nDiff ];
         memset(pBuffer, 0, nDiff); // initialize for enhanced security
         WriteAt( nSize, pBuffer, nDiff, &nCount );
         delete[] pBuffer;
@@ -1600,7 +1575,7 @@ ErrCode UcbLockBytes::Stat( SvLockBytesStat *pStat, SvLockBytesStatFlag) const
 
     try
     {
-        pStat->nSize = ULONG(xSeekable->getLength());
+        pStat->nSize = sal_uLong(xSeekable->getLength());
     }
     catch (IOException)
     {
@@ -1667,7 +1642,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     aArgument.Referer = rReferer;
 
     Command aCommand;
-    aCommand.Name = ::rtl::OUString::createFromAscii ("post");
+    aCommand.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM ("post"));
     aCommand.Argument <<= aArgument;
 
     Reference< XProgressHandler > xProgressHdl = new ProgressHandler_Impl( LINK( &xLockBytes, UcbLockBytes, DataAvailHdl ) );
@@ -1682,7 +1657,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
 
        if ( xLockBytes->GetError() == ERRCODE_NONE && ( bError || !xLockBytes->getInputStream().is() ) )
     {
-        DBG_ERROR("No InputStream, but no error set!" );
+        OSL_FAIL("No InputStream, but no error set!" );
            xLockBytes->SetError( ERRCODE_IO_GENERAL );
     }
 
@@ -1707,7 +1682,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     {
         Reference < XCommandProcessor > xProcessor( xContent, UNO_QUERY );
         Command aCommand;
-        aCommand.Name     = ::rtl::OUString::createFromAscii("setPropertyValues");
+        aCommand.Name     = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("setPropertyValues"));
         aCommand.Handle   = -1; /* unknown */
         aCommand.Argument <<= rProps;
         xProcessor->execute( aCommand, 0, Reference < XCommandEnvironment >() );
@@ -1733,7 +1708,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
 
     if ( xLockBytes->GetError() == ERRCODE_NONE && ( bError || !xLockBytes->getInputStream().is() ) )
     {
-        DBG_ERROR("No InputStream, but no error set!" );
+        OSL_FAIL("No InputStream, but no error set!" );
            xLockBytes->SetError( ERRCODE_IO_GENERAL );
     }
 
