@@ -48,7 +48,7 @@ using namespace vcl;
 
 void Control::ImplInitControlData()
 {
-    mbHasFocus	    = FALSE;
+    mbHasFocus	    = sal_False;
     mpControlData   = new ImplControlData;
 }
 
@@ -304,10 +304,10 @@ long Control::Notify( NotifyEvent& rNEvt )
     {
         if ( !mbHasFocus )
         {
-            mbHasFocus = TRUE;
+            mbHasFocus = sal_True;
             if ( ImplCallEventListenersAndHandler( VCLEVENT_CONTROL_GETFOCUS, maGetFocusHdl, this ) )
                 // been destroyed within the handler
-                return TRUE;
+                return sal_True;
         }
     }
     else
@@ -317,10 +317,10 @@ long Control::Notify( NotifyEvent& rNEvt )
             Window* pFocusWin = Application::GetFocusWindow();
             if ( !pFocusWin || !ImplIsWindowOrChild( pFocusWin ) )
             {
-                mbHasFocus = FALSE;
+                mbHasFocus = sal_False;
                 if ( ImplCallEventListenersAndHandler( VCLEVENT_CONTROL_LOSEFOCUS, maLoseFocusHdl, this ) )
                     // been destroyed within the handler
-                    return TRUE;
+                    return sal_True;
             }
         }
     }
@@ -373,7 +373,7 @@ void Control::AppendLayoutData( const Control& rSubControl ) const
 
 // -----------------------------------------------------------------
 
-BOOL Control::ImplCallEventListenersAndHandler(  ULONG nEvent, const Link& rHandler, void* pCaller )
+sal_Bool Control::ImplCallEventListenersAndHandler(  sal_uLong nEvent, const Link& rHandler, void* pCaller )
 {
     ImplDelData aCheckDelete;
     ImplAddDel( &aCheckDelete );
@@ -386,10 +386,10 @@ BOOL Control::ImplCallEventListenersAndHandler(  ULONG nEvent, const Link& rHand
         if ( !aCheckDelete.IsDelete() )
         {
             ImplRemoveDel( &aCheckDelete );
-            return FALSE;
+            return sal_False;
         }
     }
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------
@@ -448,8 +448,8 @@ void Control::DataChanged( const DataChangedEvent& rDCEvt)
     {
         AllSettings     aSettings = GetSettings();
         StyleSettings   aStyleSettings = aSettings.GetStyleSettings();
-        ULONG           nOldOptions = rDCEvt.GetOldSettings()->GetStyleSettings().GetOptions();
-        ULONG           nNewOptions = aStyleSettings.GetOptions();
+        sal_uLong           nOldOptions = rDCEvt.GetOldSettings()->GetStyleSettings().GetOptions();
+        sal_uLong           nNewOptions = aStyleSettings.GetOptions();
 
         if ( !(nNewOptions & STYLE_OPTION_MONO) && ( nOldOptions & STYLE_OPTION_MONO ) )
         {
@@ -518,7 +518,7 @@ const Color& Control::GetCanonicalTextColor( const StyleSettings& _rStyle ) cons
 }
 
 // -----------------------------------------------------------------
-void Control::ImplInitSettings( const BOOL _bFont, const BOOL _bForeground )
+void Control::ImplInitSettings( const sal_Bool _bFont, const sal_Bool _bForeground )
 {
     const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
 
@@ -545,7 +545,7 @@ void Control::ImplInitSettings( const BOOL _bFont, const BOOL _bForeground )
 // -----------------------------------------------------------------
 
 void Control::DrawControlText( OutputDevice& _rTargetDevice, Rectangle& _io_rRect, const XubString& _rStr,
-    USHORT _nStyle, MetricVector* _pVector, String* _pDisplayText ) const
+    sal_uInt16 _nStyle, MetricVector* _pVector, String* _pDisplayText ) const
 {
 #ifdef FS_DEBUG
     if ( !_pVector )
