@@ -52,8 +52,6 @@
 
 using namespace ::com::sun::star;
 
-static ResStringArray *strAllUnits = NULL;
-
 // -----------------------------------------------------------------------
 
 #define FORMAT_NUMERIC       1
@@ -62,9 +60,9 @@ static ResStringArray *strAllUnits = NULL;
 
 // -----------------------------------------------------------------------
 
-static sal_Int64 ImplPower10( USHORT n )
+static sal_Int64 ImplPower10( sal_uInt16 n )
 {
-    USHORT i;
+    sal_uInt16 i;
     sal_Int64   nValue = 1;
 
     for ( i=0; i < n; i++ )
@@ -75,16 +73,16 @@ static sal_Int64 ImplPower10( USHORT n )
 
 // -----------------------------------------------------------------------
 
-static BOOL ImplNumericProcessKeyInput( Edit*, const KeyEvent& rKEvt,
-                                        BOOL bStrictFormat, BOOL bThousandSep,
+static sal_Bool ImplNumericProcessKeyInput( Edit*, const KeyEvent& rKEvt,
+                                        sal_Bool bStrictFormat, sal_Bool bThousandSep,
                                         const LocaleDataWrapper& rLocaleDataWrappper )
 {
     if ( !bStrictFormat )
-        return FALSE;
+        return sal_False;
     else
     {
         xub_Unicode cChar = rKEvt.GetCharCode();
-        USHORT      nGroup = rKEvt.GetKeyCode().GetGroup();
+        sal_uInt16      nGroup = rKEvt.GetKeyCode().GetGroup();
 
         if ( (nGroup == KEYGROUP_FKEYS) || (nGroup == KEYGROUP_CURSOR) ||
              (nGroup == KEYGROUP_MISC) ||
@@ -92,28 +90,28 @@ static BOOL ImplNumericProcessKeyInput( Edit*, const KeyEvent& rKEvt,
              (cChar == rLocaleDataWrappper.getNumDecimalSep() ) ||
              (bThousandSep && (cChar == rLocaleDataWrappper.getNumThousandSep())) ||
              (cChar == '-') )
-            return FALSE;
+            return sal_False;
         else
-            return TRUE;
+            return sal_True;
     }
 }
 
 // -----------------------------------------------------------------------
 
-static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
-                                 USHORT nDecDigits, const LocaleDataWrapper& rLocaleDataWrappper,
-                                 BOOL bCurrency = FALSE )
+static sal_Bool ImplNumericGetValue( const XubString& rStr, double& rValue,
+                                 sal_uInt16 nDecDigits, const LocaleDataWrapper& rLocaleDataWrappper,
+                                 sal_Bool bCurrency = sal_False )
 {
     XubString   aStr = rStr;
     XubString   aStr1;
     XubString   aStr2;
-    BOOL        bNegative = FALSE;
+    sal_Bool        bNegative = sal_False;
     xub_StrLen  nDecPos;
     xub_StrLen  i;
 
     // Reaktion auf leeren String
     if ( !rStr.Len() )
-        return FALSE;
+        return sal_False;
 
     // Fuehrende und nachfolgende Leerzeichen entfernen
     aStr.EraseLeadingAndTrailingChars( ' ' );
@@ -132,7 +130,7 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
     if ( bCurrency )
     {
         if ( (aStr.GetChar( 0 ) == '(') && (aStr.GetChar( aStr.Len()-1 ) == ')') )
-            bNegative = TRUE;
+            bNegative = sal_True;
         if ( !bNegative )
         {
             for ( i=0; i < aStr.Len(); i++ )
@@ -141,14 +139,14 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
                     break;
                 else if ( aStr.GetChar( i ) == '-' )
                 {
-                    bNegative = TRUE;
+                    bNegative = sal_True;
                     break;
                 }
             }
         }
         if ( !bNegative && bCurrency && aStr.Len() )
         {
-            USHORT nFormat = rLocaleDataWrappper.getCurrNegativeFormat();
+            sal_uInt16 nFormat = rLocaleDataWrappper.getCurrNegativeFormat();
             if ( (nFormat == 3) || (nFormat == 6)  ||
                  (nFormat == 7) || (nFormat == 10) )
             {
@@ -158,7 +156,7 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
                         break;
                     else if ( aStr.GetChar( i ) == '-' )
                     {
-                        bNegative = TRUE;
+                        bNegative = sal_True;
                         break;
                     }
                 }
@@ -168,7 +166,7 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
     else
     {
         if ( aStr1.GetChar( 0 ) == '-' )
-            bNegative = TRUE;
+            bNegative = sal_True;
     }
 
     // Alle unerwuenschten Zeichen rauswerfen
@@ -188,7 +186,7 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
     }
 
     if ( !aStr1.Len() && !aStr2.Len() )
-        return FALSE;
+        return sal_False;
 
     if ( !aStr1.Len() )
         aStr1.Insert( '0' );
@@ -196,11 +194,11 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
         aStr1.Insert( '-', 0 );
 
     // Nachkommateil zurechtstutzen und dabei runden
-    BOOL bRound = FALSE;
+    sal_Bool bRound = sal_False;
     if ( aStr2.Len() > nDecDigits )
     {
         if ( aStr2.GetChar( nDecDigits ) >= '5' )
-            bRound = TRUE;
+            bRound = sal_True;
         aStr2.Erase( nDecDigits );
     }
     if ( aStr2.Len() < nDecDigits )
@@ -221,7 +219,43 @@ static BOOL ImplNumericGetValue( const XubString& rStr, double& rValue,
 
     rValue = nValue;
 
-    return TRUE;
+    return sal_True;
+}
+
+static void ImplUpdateSeparatorString( String& io_rText, 
+                                       const String& rOldDecSep, const String& rNewDecSep,
+                                       const String& rOldThSep, const String& rNewThSep )
+{
+    rtl::OUStringBuffer aBuf( io_rText.Len() );
+    xub_StrLen nIndexDec = 0, nIndexTh = 0, nIndex = 0;
+    
+    const sal_Unicode* pBuffer = io_rText.GetBuffer();
+    while( nIndex != STRING_NOTFOUND )
+    {
+        nIndexDec = io_rText.Search( rOldDecSep, nIndex );
+        nIndexTh = io_rText.Search( rOldThSep, nIndex );
+        if(   (nIndexTh != STRING_NOTFOUND && nIndexDec != STRING_NOTFOUND && nIndexTh < nIndexDec )
+           || (nIndexTh != STRING_NOTFOUND && nIndexDec == STRING_NOTFOUND)
+           )
+        {
+            aBuf.append( pBuffer + nIndex, nIndexTh - nIndex );
+            aBuf.append( rNewThSep );
+            nIndex = nIndexTh + rOldThSep.Len();
+        }
+        else if( nIndexDec != STRING_NOTFOUND )
+        {
+            aBuf.append( pBuffer + nIndex, nIndexDec - nIndex );
+            aBuf.append( rNewDecSep );
+            nIndex = nIndexDec + rOldDecSep.Len();
+        }
+        else
+        {
+            aBuf.append( pBuffer + nIndex );
+            nIndex = STRING_NOTFOUND;
+        }
+    }
+    
+    io_rText = aBuf.makeStringAndClear();    
 }
 
 static void ImplUpdateSeparators( const String& rOldDecSep, const String& rNewDecSep,
@@ -233,29 +267,25 @@ static void ImplUpdateSeparators( const String& rOldDecSep, const String& rNewDe
 
     if( bChangeDec || bChangeTh )
     {
-        BOOL bUpdateMode = pEdit->IsUpdateMode();
-        pEdit->SetUpdateMode( FALSE );
+        sal_Bool bUpdateMode = pEdit->IsUpdateMode();
+        pEdit->SetUpdateMode( sal_False );
         String aText = pEdit->GetText();
-        if( bChangeDec )
-            aText.SearchAndReplaceAll( rNewDecSep, rOldDecSep );
-        if( bChangeTh )
-            aText.SearchAndReplaceAll( rNewThSep, rOldThSep );
+        ImplUpdateSeparatorString( aText, rOldDecSep, rNewDecSep, rOldThSep, rNewThSep );
         pEdit->SetText( aText );
 
         ComboBox* pCombo = dynamic_cast<ComboBox*>(pEdit);
         if( pCombo )
         {
             // update box entries
-            USHORT nEntryCount = pCombo->GetEntryCount();
-            for ( USHORT i=0; i < nEntryCount; i++ )
+            sal_uInt16 nEntryCount = pCombo->GetEntryCount();
+            for ( sal_uInt16 i=0; i < nEntryCount; i++ )
             {
                 aText = pCombo->GetEntry( i );
-                if( bChangeDec )
-                    aText.SearchAndReplaceAll( rNewDecSep, rOldDecSep );
-                if( bChangeTh )
-                    aText.SearchAndReplaceAll( rNewThSep, rOldThSep );
+                void* pEntryData = pCombo->GetEntryData( i );
+                ImplUpdateSeparatorString( aText, rOldDecSep, rNewDecSep, rOldThSep, rNewThSep );
                 pCombo->RemoveEntry( i );
                 pCombo->InsertEntry( aText, i );
+                pCombo->SetEntryData( i, pEntryData );
             }
         }
         if( bUpdateMode )
@@ -269,11 +299,11 @@ FormatterBase::FormatterBase( Edit* pField )
 {
     mpField                     = pField;
     mpLocaleDataWrapper         = NULL;
-    mbReformat                  = FALSE;
-    mbStrictFormat              = FALSE;
-    mbEmptyFieldValue           = FALSE;
-    mbEmptyFieldValueEnabled    = FALSE;
-    mbDefaultLocale             = TRUE;
+    mbReformat                  = sal_False;
+    mbStrictFormat              = sal_False;
+    mbEmptyFieldValue           = sal_False;
+    mbEmptyFieldValueEnabled    = sal_False;
+    mbDefaultLocale             = sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -314,7 +344,7 @@ void FormatterBase::ReformatAll()
 
 // -----------------------------------------------------------------------
 
-void FormatterBase::SetStrictFormat( BOOL bStrict )
+void FormatterBase::SetStrictFormat( sal_Bool bStrict )
 {
     if ( bStrict != mbStrictFormat )
     {
@@ -329,7 +359,7 @@ void FormatterBase::SetStrictFormat( BOOL bStrict )
 void FormatterBase::SetLocale( const lang::Locale& rLocale )
 {
     ImplGetLocaleDataWrapper().setLocale( rLocale );
-    mbDefaultLocale = FALSE;
+    mbDefaultLocale = sal_False;
     ReformatAll();
 }
 
@@ -360,7 +390,7 @@ const AllSettings& FormatterBase::GetFieldSettings() const
 
 // -----------------------------------------------------------------------
 
-void FormatterBase::SetFieldText( const XubString& rText, BOOL bKeepSelection )
+void FormatterBase::SetFieldText( const XubString& rText, sal_Bool bKeepSelection )
 {
     if ( mpField )
     {
@@ -387,7 +417,7 @@ void FormatterBase::ImplSetText( const XubString& rText, Selection* pNewSelectio
             mpField->SetText( rText, aSel );
         }
 
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     }
 }
 
@@ -397,23 +427,23 @@ void FormatterBase::SetEmptyFieldValue()
 {
     if ( mpField )
         mpField->SetText( ImplGetSVEmptyStr() );
-    mbEmptyFieldValue = TRUE;
+    mbEmptyFieldValue = sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL FormatterBase::IsEmptyFieldValue() const
+sal_Bool FormatterBase::IsEmptyFieldValue() const
 {
     return (!mpField || !mpField->GetText().Len());
 }
 
 // -----------------------------------------------------------------------
 
-BOOL NumericFormatter::ImplNumericReformat( const XubString& rStr, double& rValue,
+sal_Bool NumericFormatter::ImplNumericReformat( const XubString& rStr, double& rValue,
                                             XubString& rOutStr )
 {
     if ( !ImplNumericGetValue( rStr, rValue, GetDecimalDigits(), ImplGetLocaleDataWrapper() ) )
-        return TRUE;
+        return sal_True;
     else
     {
         double nTempVal = rValue;
@@ -429,14 +459,14 @@ BOOL NumericFormatter::ImplNumericReformat( const XubString& rStr, double& rValu
             if ( !GetErrorHdl().Call( this ) )
             {
                 mnCorrectedValue = 0;
-                return FALSE;
+                return sal_False;
             }
             else
                 mnCorrectedValue = 0;
         }
 
         rOutStr = CreateFieldText( (sal_Int64)nTempVal );
-        return TRUE;
+        return sal_True;
     }
 }
 
@@ -451,8 +481,8 @@ void NumericFormatter::ImplInit()
     mnCorrectedValue    = 0;
     mnDecimalDigits     = 2;
     mnType              = FORMAT_NUMERIC;
-    mbThousandSep       = TRUE;
-    mbShowTrailingZeros = TRUE;
+    mbThousandSep       = sal_True;
+    mbShowTrailingZeros = sal_True;
 
     // for fields
     mnSpinSize          = 1;
@@ -477,7 +507,7 @@ void NumericFormatter::ImplLoadRes( const ResId& rResId )
 
     if( pMgr )
     {
-        ULONG nMask = pMgr->ReadLong();
+        sal_uLong nMask = pMgr->ReadLong();
 
         if ( NUMERICFORMATTER_MIN & nMask )
             mnMin = pMgr->ReadLong();
@@ -486,7 +516,7 @@ void NumericFormatter::ImplLoadRes( const ResId& rResId )
             mnMax = pMgr->ReadLong();
 
         if ( NUMERICFORMATTER_STRICTFORMAT & nMask )
-            SetStrictFormat( (BOOL)pMgr->ReadShort() );
+            SetStrictFormat( (sal_Bool)pMgr->ReadShort() );
 
         if ( NUMERICFORMATTER_DECIMALDIGITS & nMask )
             SetDecimalDigits( pMgr->ReadShort() );
@@ -502,7 +532,7 @@ void NumericFormatter::ImplLoadRes( const ResId& rResId )
         }
 
         if ( NUMERICFORMATTER_NOTHOUSANDSEP & nMask )
-            SetUseThousandSep( !(BOOL)pMgr->ReadShort() );
+            SetUseThousandSep( !(sal_Bool)pMgr->ReadShort() );
     }
 }
 
@@ -532,7 +562,7 @@ void NumericFormatter::SetMax( sal_Int64 nNewMax )
 
 // -----------------------------------------------------------------------
 
-void NumericFormatter::SetUseThousandSep( BOOL b )
+void NumericFormatter::SetUseThousandSep( sal_Bool b )
 {
     mbThousandSep = b;
     ReformatAll();
@@ -540,7 +570,7 @@ void NumericFormatter::SetUseThousandSep( BOOL b )
 
 // -----------------------------------------------------------------------
 
-void NumericFormatter::SetDecimalDigits( USHORT nDigits )
+void NumericFormatter::SetDecimalDigits( sal_uInt16 nDigits )
 {
     mnDecimalDigits = nDigits;
     ReformatAll();
@@ -548,7 +578,7 @@ void NumericFormatter::SetDecimalDigits( USHORT nDigits )
 
 // -----------------------------------------------------------------------
 
-void NumericFormatter::SetShowTrailingZeros( BOOL bShowTrailingZeros )
+void NumericFormatter::SetShowTrailingZeros( sal_Bool bShowTrailingZeros )
 {
     if ( mbShowTrailingZeros != bShowTrailingZeros )
     {
@@ -559,7 +589,7 @@ void NumericFormatter::SetShowTrailingZeros( BOOL bShowTrailingZeros )
 
 // -----------------------------------------------------------------------
 
-USHORT NumericFormatter::GetDecimalDigits() const
+sal_uInt16 NumericFormatter::GetDecimalDigits() const
 {
     return mnDecimalDigits;
 }
@@ -570,7 +600,7 @@ void NumericFormatter::SetValue( sal_Int64 nNewValue )
 {
     SetUserValue( nNewValue );
     mnFieldValue = mnLastValue;
-    SetEmptyFieldValueData( FALSE );
+    SetEmptyFieldValueData( sal_False );
 }
 
 // -----------------------------------------------------------------------
@@ -626,14 +656,14 @@ sal_Int64 NumericFormatter::GetValue() const
 
 // -----------------------------------------------------------------------
 
-BOOL NumericFormatter::IsValueModified() const
+sal_Bool NumericFormatter::IsValueModified() const
 {
     if ( ImplGetEmptyFieldValue() )
         return !IsEmptyFieldValue();
     else if ( GetValue() != mnFieldValue )
-        return TRUE;
+        return sal_True;
     else
-        return FALSE;
+        return sal_False;
 }
 
 // -----------------------------------------------------------------------
@@ -690,7 +720,7 @@ void NumericFormatter::Reformat()
     XubString aStr;
     // caution: precision loss in double cast
     double nTemp = (double)mnLastValue;
-    BOOL bOK = ImplNumericReformat( GetField()->GetText(), nTemp, aStr );
+    sal_Bool bOK = ImplNumericReformat( GetField()->GetText(), nTemp, aStr );
     mnLastValue = (sal_Int64)nTemp;
     if ( !bOK )
         return;
@@ -810,7 +840,7 @@ void NumericField::ImplLoadRes( const ResId& rResId )
     SpinField::ImplLoadRes( rResId );
     NumericFormatter::ImplLoadRes( ResId( (RSHEADER_TYPE *)GetClassRes(), *rResId.GetResMgr() ) );
 
-    ULONG      nMask = ReadLongRes();
+    sal_uLong      nMask = ReadLongRes();
 
     if ( NUMERICFIELD_FIRST & nMask )
         mnFirst = ReadLongRes();
@@ -846,7 +876,7 @@ long NumericField::PreNotify( NotifyEvent& rNEvt )
 long NumericField::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -879,7 +909,7 @@ void NumericField::DataChanged( const DataChangedEvent& rDCEvt )
 
 void NumericField::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     SpinField::Modify();
 }
 
@@ -965,7 +995,7 @@ long NumericBox::PreNotify( NotifyEvent& rNEvt )
 long NumericBox::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -998,7 +1028,7 @@ void NumericBox::DataChanged( const DataChangedEvent& rDCEvt )
 
 void NumericBox::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     ComboBox::Modify();
 }
 
@@ -1008,21 +1038,21 @@ void NumericBox::ReformatAll()
 {
     double nValue;
     XubString aStr;
-    SetUpdateMode( FALSE );
-    USHORT nEntryCount = GetEntryCount();
-    for ( USHORT i=0; i < nEntryCount; i++ )
+    SetUpdateMode( sal_False );
+    sal_uInt16 nEntryCount = GetEntryCount();
+    for ( sal_uInt16 i=0; i < nEntryCount; i++ )
     {
         ImplNumericReformat( GetEntry( i ), nValue, aStr );
         RemoveEntry( i );
         InsertEntry( aStr, i );
     }
     NumericFormatter::Reformat();
-    SetUpdateMode( TRUE );
+    SetUpdateMode( sal_True );
 }
 
 // -----------------------------------------------------------------------
 
-void NumericBox::InsertValue( sal_Int64 nValue, USHORT nPos )
+void NumericBox::InsertValue( sal_Int64 nValue, sal_uInt16 nPos )
 {
     ComboBox::InsertEntry( CreateFieldText( nValue ), nPos );
 }
@@ -1036,7 +1066,7 @@ void NumericBox::RemoveValue( sal_Int64 nValue )
 
 // -----------------------------------------------------------------------
 
-sal_Int64 NumericBox::GetValue( USHORT nPos ) const
+sal_Int64 NumericBox::GetValue( sal_uInt16 nPos ) const
 {
     double nValue = 0;
     ImplNumericGetValue( ComboBox::GetEntry( nPos ), nValue, GetDecimalDigits(), ImplGetLocaleDataWrapper() );
@@ -1045,19 +1075,19 @@ sal_Int64 NumericBox::GetValue( USHORT nPos ) const
 
 // -----------------------------------------------------------------------
 
-USHORT NumericBox::GetValuePos( sal_Int64 nValue ) const
+sal_uInt16 NumericBox::GetValuePos( sal_Int64 nValue ) const
 {
     return ComboBox::GetEntryPos( CreateFieldText( nValue ) );
 }
 
 // -----------------------------------------------------------------------
 
-static BOOL ImplMetricProcessKeyInput( Edit* pEdit, const KeyEvent& rKEvt,
-                                       BOOL, BOOL bUseThousandSep, const LocaleDataWrapper& rWrapper )
+static sal_Bool ImplMetricProcessKeyInput( Edit* pEdit, const KeyEvent& rKEvt,
+                                       sal_Bool, sal_Bool bUseThousandSep, const LocaleDataWrapper& rWrapper )
 {
     // Es gibt hier kein sinnvolles StrictFormat, also alle
     // Zeichen erlauben
-    return ImplNumericProcessKeyInput( pEdit, rKEvt, FALSE, bUseThousandSep, rWrapper );
+    return ImplNumericProcessKeyInput( pEdit, rKEvt, sal_False, bUseThousandSep, rWrapper );
 }
 
 // -----------------------------------------------------------------------
@@ -1083,7 +1113,7 @@ static XubString ImplMetricGetUnitText( const XubString& rStr )
 /*
     // MT: #90545# Preparation for translated strings...
     String aMetricText;
-    for ( USHORT n = rStr.Len(); n; )
+    for ( sal_uInt16 n = rStr.Len(); n; )
     {
         sal_Unicode c = rStr.GetChar( --n );
         sal_Int32 nType = xCharClass->getStringType( rStr, n, 1, rLocale );
@@ -1105,38 +1135,37 @@ static XubString ImplMetricGetUnitText( const XubString& rStr )
 
 // #104355# support localized mesaurements
 
-static String ImplMetricToString( FieldUnit rUnit )
+static const String& ImplMetricToString( FieldUnit rUnit )
 {
-    if( !strAllUnits )
+    FieldUnitStringList* pList = ImplGetFieldUnits();
+    if( pList )
     {
-        ResMgr* pResMgr = ImplGetResMgr();
-        strAllUnits = new ResStringArray( ResId (SV_FUNIT_STRINGS, *pResMgr) );
+        // return unit's default string (ie, the first one )
+        for( FieldUnitStringList::const_iterator it = pList->begin(); it != pList->end(); ++it )
+        {
+            if ( it->second == rUnit )
+                return it->first;
+        }
     }
-    // return unit's default string (ie, the first one )
-    for( USHORT i=0; i < strAllUnits->Count(); i++ )
-        if( (FieldUnit) strAllUnits->GetValue( i ) == rUnit )
-            return strAllUnits->GetString( i );
 
-    return String();
+    return String::EmptyString();
 }
 
 static FieldUnit ImplStringToMetric( const String &rMetricString )
 {
-    if( !strAllUnits )
+    FieldUnitStringList* pList = ImplGetCleanedFieldUnits();
+    if( pList )
     {
-        ResMgr* pResMgr = ImplGetResMgr();
-        strAllUnits = new ResStringArray( ResId (SV_FUNIT_STRINGS, *pResMgr) );
+        // return FieldUnit
+        String aStr( rMetricString );
+        aStr.ToLowerAscii();
+        aStr.EraseAllChars( sal_Unicode( ' ' ) );
+        for( FieldUnitStringList::const_iterator it = pList->begin(); it != pList->end(); ++it )
+        {
+            if ( it->first.Equals( aStr ) )
+                return it->second;
+        }
     }
-    // return FieldUnit
-    String aStr( rMetricString );
-    aStr.ToLowerAscii();
-    for( USHORT i=0; i < strAllUnits->Count(); i++ )
-        if ( strAllUnits->GetString( i ).Equals( aStr ) )
-            return (FieldUnit) strAllUnits->GetValue( i );
-
-    // Amelia : about character unit
-    if (aStr.EqualsIgnoreCaseAscii("cm"))
-        return FUNIT_CM;
 
     return FUNIT_NONE;
 }
@@ -1212,7 +1241,7 @@ static FieldUnit ImplMap2FieldUnit( MapUnit meUnit, long& nDecDigits )
         case MAP_TWIP :
             return FUNIT_TWIP;
         default:
-            DBG_ERROR( "default eInUnit" );
+            OSL_FAIL( "default eInUnit" );
             break;
     }
     return FUNIT_NONE;
@@ -1225,7 +1254,7 @@ static double nonValueDoubleToValueDouble( double nValue )
     return rtl::math::isFinite( nValue ) ? nValue : 0.0;
 }
 
-sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, sal_Int64 mnBaseValue, USHORT nDecDigits,
+sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, sal_Int64 mnBaseValue, sal_uInt16 nDecDigits,
                                      FieldUnit eInUnit, FieldUnit eOutUnit )
 {
     double nDouble = nonValueDoubleToValueDouble( ConvertDoubleValue(
@@ -1244,7 +1273,7 @@ sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, sal_Int64 mnBaseValue, US
 
 // -----------------------------------------------------------------------
 
-sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, USHORT nDigits,
+sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, sal_uInt16 nDigits,
                                      MapUnit eInUnit, FieldUnit eOutUnit )
 {
     return static_cast<sal_Int64>(
@@ -1254,7 +1283,7 @@ sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, USHORT nDigits,
 
 // -----------------------------------------------------------------------
 
-sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, USHORT nDigits,
+sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, sal_uInt16 nDigits,
                                      FieldUnit eInUnit, MapUnit eOutUnit )
 {
     return static_cast<sal_Int64>(
@@ -1264,7 +1293,7 @@ sal_Int64 MetricField::ConvertValue( sal_Int64 nValue, USHORT nDigits,
 
 // -----------------------------------------------------------------------
 
-double MetricField::ConvertDoubleValue( double nValue, sal_Int64 mnBaseValue, USHORT nDecDigits,
+double MetricField::ConvertDoubleValue( double nValue, sal_Int64 mnBaseValue, sal_uInt16 nDecDigits,
                                         FieldUnit eInUnit, FieldUnit eOutUnit )
 {
     if ( eInUnit != eOutUnit )
@@ -1276,7 +1305,7 @@ double MetricField::ConvertDoubleValue( double nValue, sal_Int64 mnBaseValue, US
             if ( (mnBaseValue <= 0) || (nValue <= 0) )
                 return nValue;
             nDiv = 100;
-            for ( USHORT i=0; i < nDecDigits; i++ )
+            for ( sal_uInt16 i=0; i < nDecDigits; i++ )
                 nDiv *= 10;
 
             nMult = mnBaseValue;
@@ -1315,7 +1344,7 @@ double MetricField::ConvertDoubleValue( double nValue, sal_Int64 mnBaseValue, US
 
 // -----------------------------------------------------------------------
 
-double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
+double MetricField::ConvertDoubleValue( double nValue, sal_uInt16 nDigits,
                                         MapUnit eInUnit, FieldUnit eOutUnit )
 {
     if ( eOutUnit == FUNIT_PERCENT ||
@@ -1326,7 +1355,7 @@ double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
          eInUnit == MAP_APPFONT ||
          eInUnit == MAP_RELATIVE )
     {
-        DBG_ERROR( "invalid parameters" );
+        OSL_FAIL( "invalid parameters" );
         return nValue;
     }
 
@@ -1372,7 +1401,7 @@ double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
 
 // -----------------------------------------------------------------------
 
-double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
+double MetricField::ConvertDoubleValue( double nValue, sal_uInt16 nDigits,
                                         FieldUnit eInUnit, MapUnit eOutUnit )
 {
     if ( eInUnit == FUNIT_PERCENT ||
@@ -1383,7 +1412,7 @@ double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
          eOutUnit == MAP_APPFONT ||
          eOutUnit == MAP_RELATIVE )
     {
-        DBG_ERROR( "invalid parameters" );
+        OSL_FAIL( "invalid parameters" );
         return nValue;
     }
 
@@ -1402,7 +1431,6 @@ double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
     {
         while ( nDecDigits )
         {
-            nValue += 5;
             nValue /= 10;
             nDecDigits--;
         }
@@ -1429,12 +1457,12 @@ double MetricField::ConvertDoubleValue( double nValue, USHORT nDigits,
 
 // -----------------------------------------------------------------------
 
-static BOOL ImplMetricGetValue( const XubString& rStr, double& rValue, sal_Int64 nBaseValue,
-                                USHORT nDecDigits, const LocaleDataWrapper& rLocaleDataWrapper, FieldUnit eUnit )
+static sal_Bool ImplMetricGetValue( const XubString& rStr, double& rValue, sal_Int64 nBaseValue,
+                                sal_uInt16 nDecDigits, const LocaleDataWrapper& rLocaleDataWrapper, FieldUnit eUnit )
 {
     // Zahlenwert holen
     if ( !ImplNumericGetValue( rStr, rValue, nDecDigits, rLocaleDataWrapper ) )
-        return FALSE;
+        return sal_False;
 
     // Einheit rausfinden
     FieldUnit eEntryUnit = ImplMetricGetUnit( rStr );
@@ -1442,15 +1470,15 @@ static BOOL ImplMetricGetValue( const XubString& rStr, double& rValue, sal_Int64
     // Einheiten umrechnen
     rValue = MetricField::ConvertDoubleValue( rValue, nBaseValue, nDecDigits, eEntryUnit, eUnit );
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL MetricFormatter::ImplMetricReformat( const XubString& rStr, double& rValue, XubString& rOutStr )
+sal_Bool MetricFormatter::ImplMetricReformat( const XubString& rStr, double& rValue, XubString& rOutStr )
 {
     if ( !ImplMetricGetValue( rStr, rValue, mnBaseValue, GetDecimalDigits(), ImplGetLocaleDataWrapper(), meUnit ) )
-        return TRUE;
+        return sal_True;
     else
     {
         double nTempVal = rValue;
@@ -1466,14 +1494,14 @@ BOOL MetricFormatter::ImplMetricReformat( const XubString& rStr, double& rValue,
             if ( !GetErrorHdl().Call( this ) )
             {
                 mnCorrectedValue = 0;
-                return FALSE;
+                return sal_False;
             }
             else
                 mnCorrectedValue = 0;
         }
 
         rOutStr = CreateFieldText( (sal_Int64)nTempVal );
-        return TRUE;
+        return sal_True;
     }
 }
 
@@ -1502,7 +1530,7 @@ void MetricFormatter::ImplLoadRes( const ResId& rResId )
     ResMgr*     pMgr = rResId.GetResMgr();
     if( pMgr )
     {
-        ULONG       nMask = pMgr->ReadLong();
+        sal_uLong       nMask = pMgr->ReadLong();
 
         if ( METRICFORMATTER_UNIT & nMask )
             meUnit = (FieldUnit)pMgr->ReadLong();
@@ -1676,7 +1704,7 @@ void MetricFormatter::Reformat()
     XubString aStr;
     // caution: precision loss in double cast
     double nTemp = (double)mnLastValue;
-    BOOL bOK = ImplMetricReformat( aText, nTemp, aStr );
+    sal_Bool bOK = ImplMetricReformat( aText, nTemp, aStr );
     mnLastValue = (sal_Int64)nTemp;
 
     if ( !bOK )
@@ -1733,7 +1761,7 @@ void MetricField::ImplLoadRes( const ResId& rResId )
     SpinField::ImplLoadRes( rResId );
     MetricFormatter::ImplLoadRes( ResId( (RSHEADER_TYPE *)GetClassRes(), *rResId.GetResMgr() ) );
 
-    ULONG      nMask = ReadLongRes();
+    sal_uLong      nMask = ReadLongRes();
 
     if ( METRICFIELD_FIRST & nMask )
         mnFirst = ReadLongRes();
@@ -1825,7 +1853,7 @@ long MetricField::PreNotify( NotifyEvent& rNEvt )
 long MetricField::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -1858,7 +1886,7 @@ void MetricField::DataChanged( const DataChangedEvent& rDCEvt )
 
 void MetricField::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     SpinField::Modify();
 }
 
@@ -1951,7 +1979,7 @@ long MetricBox::PreNotify( NotifyEvent& rNEvt )
 long MetricBox::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -1984,7 +2012,7 @@ void MetricBox::DataChanged( const DataChangedEvent& rDCEvt )
 
 void MetricBox::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     ComboBox::Modify();
 }
 
@@ -1994,16 +2022,16 @@ void MetricBox::ReformatAll()
 {
     double nValue;
     XubString aStr;
-    SetUpdateMode( FALSE );
-    USHORT nEntryCount = GetEntryCount();
-    for ( USHORT i=0; i < nEntryCount; i++ )
+    SetUpdateMode( sal_False );
+    sal_uInt16 nEntryCount = GetEntryCount();
+    for ( sal_uInt16 i=0; i < nEntryCount; i++ )
     {
         ImplMetricReformat( GetEntry( i ), nValue, aStr );
         RemoveEntry( i );
         InsertEntry( aStr, i );
     }
     MetricFormatter::Reformat();
-    SetUpdateMode( TRUE );
+    SetUpdateMode( sal_True );
 }
 
 // -----------------------------------------------------------------------
@@ -2015,7 +2043,7 @@ void MetricBox::CustomConvert()
 
 // -----------------------------------------------------------------------
 
-void MetricBox::InsertValue( sal_Int64 nValue, FieldUnit eInUnit, USHORT nPos )
+void MetricBox::InsertValue( sal_Int64 nValue, FieldUnit eInUnit, sal_uInt16 nPos )
 {
     // Umrechnen auf eingestellte Einheiten
     nValue = MetricField::ConvertValue( nValue, mnBaseValue, GetDecimalDigits(),
@@ -2035,7 +2063,7 @@ void MetricBox::RemoveValue( sal_Int64 nValue, FieldUnit eInUnit )
 
 // -----------------------------------------------------------------------
 
-sal_Int64 MetricBox::GetValue( USHORT nPos, FieldUnit eOutUnit ) const
+sal_Int64 MetricBox::GetValue( sal_uInt16 nPos, FieldUnit eOutUnit ) const
 {
     double nValue = 0;
     ImplMetricGetValue( ComboBox::GetEntry( nPos ), nValue, mnBaseValue,
@@ -2050,7 +2078,7 @@ sal_Int64 MetricBox::GetValue( USHORT nPos, FieldUnit eOutUnit ) const
 
 // -----------------------------------------------------------------------
 
-USHORT MetricBox::GetValuePos( sal_Int64 nValue, FieldUnit eInUnit ) const
+sal_uInt16 MetricBox::GetValuePos( sal_Int64 nValue, FieldUnit eInUnit ) const
 {
     // Umrechnen auf eingestellte Einheiten
     nValue = MetricField::ConvertValue( nValue, mnBaseValue, GetDecimalDigits(),
@@ -2076,31 +2104,31 @@ sal_Int64 MetricBox::GetValue() const
 
 // -----------------------------------------------------------------------
 
-static BOOL ImplCurrencyProcessKeyInput( Edit* pEdit, const KeyEvent& rKEvt,
-                                         BOOL, BOOL bUseThousandSep, const LocaleDataWrapper& rWrapper )
+static sal_Bool ImplCurrencyProcessKeyInput( Edit* pEdit, const KeyEvent& rKEvt,
+                                         sal_Bool, sal_Bool bUseThousandSep, const LocaleDataWrapper& rWrapper )
 {
     // Es gibt hier kein sinnvolles StrictFormat, also alle
     // Zeichen erlauben
-    return ImplNumericProcessKeyInput( pEdit, rKEvt, FALSE, bUseThousandSep, rWrapper );
+    return ImplNumericProcessKeyInput( pEdit, rKEvt, sal_False, bUseThousandSep, rWrapper );
 }
 
 // -----------------------------------------------------------------------
 
-inline BOOL ImplCurrencyGetValue( const XubString& rStr, double& rValue,
-                                  USHORT nDecDigits, const LocaleDataWrapper& rWrapper )
+inline sal_Bool ImplCurrencyGetValue( const XubString& rStr, double& rValue,
+                                  sal_uInt16 nDecDigits, const LocaleDataWrapper& rWrapper )
 {
     // Zahlenwert holen
-    return ImplNumericGetValue( rStr, rValue, nDecDigits, rWrapper, TRUE );
+    return ImplNumericGetValue( rStr, rValue, nDecDigits, rWrapper, sal_True );
 }
 
 // -----------------------------------------------------------------------
 
-BOOL CurrencyFormatter::ImplCurrencyReformat( const XubString& rStr,
+sal_Bool CurrencyFormatter::ImplCurrencyReformat( const XubString& rStr,
                                               XubString& rOutStr )
 {
     double nValue;
-    if ( !ImplNumericGetValue( rStr, nValue, GetDecimalDigits(), ImplGetLocaleDataWrapper(), TRUE ) )
-        return TRUE;
+    if ( !ImplNumericGetValue( rStr, nValue, GetDecimalDigits(), ImplGetLocaleDataWrapper(), sal_True ) )
+        return sal_True;
     else
     {
         double nTempVal = nValue;
@@ -2116,14 +2144,14 @@ BOOL CurrencyFormatter::ImplCurrencyReformat( const XubString& rStr,
             if ( !GetErrorHdl().Call( this ) )
             {
                 mnCorrectedValue = 0;
-                return FALSE;
+                return sal_False;
             }
             else
                 mnCorrectedValue = 0;
         }
 
         rOutStr = CreateFieldText( (long)nTempVal );
-        return TRUE;
+        return sal_True;
     }
 }
 
@@ -2168,7 +2196,7 @@ void CurrencyFormatter::SetValue( sal_Int64 nNewValue )
 {
     SetUserValue( nNewValue );
     mnFieldValue = mnLastValue;
-    SetEmptyFieldValueData( FALSE );
+    SetEmptyFieldValueData( sal_False );
 }
 
 // -----------------------------------------------------------------------
@@ -2207,7 +2235,7 @@ void CurrencyFormatter::Reformat()
         return;
 
     XubString aStr;
-    BOOL bOK = ImplCurrencyReformat( GetField()->GetText(), aStr );
+    sal_Bool bOK = ImplCurrencyReformat( GetField()->GetText(), aStr );
     if ( !bOK )
         return;
 
@@ -2254,7 +2282,7 @@ void CurrencyField::ImplLoadRes( const ResId& rResId )
     SpinField::ImplLoadRes( rResId );
     CurrencyFormatter::ImplLoadRes( ResId( (RSHEADER_TYPE *)GetClassRes(), *rResId.GetResMgr() ) );
 
-    ULONG      nMask = ReadLongRes();
+    sal_uLong      nMask = ReadLongRes();
 
     if ( CURRENCYFIELD_FIRST & nMask )
         mnFirst = ReadLongRes();
@@ -2292,7 +2320,7 @@ long CurrencyField::PreNotify( NotifyEvent& rNEvt )
 long CurrencyField::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -2325,7 +2353,7 @@ void CurrencyField::DataChanged( const DataChangedEvent& rDCEvt )
 
 void CurrencyField::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     SpinField::Modify();
 }
 
@@ -2411,7 +2439,7 @@ long CurrencyBox::PreNotify( NotifyEvent& rNEvt )
 long CurrencyBox::Notify( NotifyEvent& rNEvt )
 {
     if ( rNEvt.GetType() == EVENT_GETFOCUS )
-        MarkToBeReformatted( FALSE );
+        MarkToBeReformatted( sal_False );
     else if ( rNEvt.GetType() == EVENT_LOSEFOCUS )
     {
         if ( MustBeReformatted() && (GetText().Len() || !IsEmptyFieldValueEnabled()) )
@@ -2444,7 +2472,7 @@ void CurrencyBox::DataChanged( const DataChangedEvent& rDCEvt )
 
 void CurrencyBox::Modify()
 {
-    MarkToBeReformatted( TRUE );
+    MarkToBeReformatted( sal_True );
     ComboBox::Modify();
 }
 
@@ -2453,21 +2481,21 @@ void CurrencyBox::Modify()
 void CurrencyBox::ReformatAll()
 {
     XubString aStr;
-    SetUpdateMode( FALSE );
-    USHORT nEntryCount = GetEntryCount();
-    for ( USHORT i=0; i < nEntryCount; i++ )
+    SetUpdateMode( sal_False );
+    sal_uInt16 nEntryCount = GetEntryCount();
+    for ( sal_uInt16 i=0; i < nEntryCount; i++ )
     {
         ImplCurrencyReformat( GetEntry( i ), aStr );
         RemoveEntry( i );
         InsertEntry( aStr, i );
     }
     CurrencyFormatter::Reformat();
-    SetUpdateMode( TRUE );
+    SetUpdateMode( sal_True );
 }
 
 // -----------------------------------------------------------------------
 
-void CurrencyBox::InsertValue( sal_Int64 nValue, USHORT nPos )
+void CurrencyBox::InsertValue( sal_Int64 nValue, sal_uInt16 nPos )
 {
     ComboBox::InsertEntry( CreateFieldText( nValue ), nPos );
 }
@@ -2481,7 +2509,7 @@ void CurrencyBox::RemoveValue( sal_Int64 nValue )
 
 // -----------------------------------------------------------------------
 
-sal_Int64 CurrencyBox::GetValue( USHORT nPos ) const
+sal_Int64 CurrencyBox::GetValue( sal_uInt16 nPos ) const
 {
     double nValue = 0;
     ImplCurrencyGetValue( ComboBox::GetEntry( nPos ), nValue, GetDecimalDigits(), ImplGetLocaleDataWrapper() );
@@ -2490,7 +2518,7 @@ sal_Int64 CurrencyBox::GetValue( USHORT nPos ) const
 
 // -----------------------------------------------------------------------
 
-USHORT CurrencyBox::GetValuePos( sal_Int64 nValue ) const
+sal_uInt16 CurrencyBox::GetValuePos( sal_Int64 nValue ) const
 {
     return ComboBox::GetEntryPos( CreateFieldText( nValue ) );
 }
