@@ -3,7 +3,7 @@
 #define vertcurs_curs_height 16
 #define vertcurs_curs_x_hot 8 
 #define vertcurs_curs_y_hot 8
-static char vertcurs_curs_bits[] = {
+static unsigned char vertcurs_curs_bits[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x40, 0x02, 0x40,
    0x06, 0x60, 0xfc, 0x3f, 0x06, 0x60, 0x02, 0x40, 0x02, 0x40, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
