@@ -68,7 +68,7 @@
 #include "sdxmlexp_impl.hxx"
 #include "sdpropls.hxx"
 #include <xmloff/xmltoken.hxx>
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmluconv.hxx>
 #include <xmloff/xmlexp.hxx>
 #include <xmloff/xmlement.hxx>
@@ -476,7 +476,7 @@ SvXMLEnumMapEntry* getAnimationsEnumMap( sal_uInt16 nMap )
         }
     }
 
-    DBG_ERROR( "xmloff::getAnimationsEnumMap(), invalid map!" );
+    OSL_FAIL( "xmloff::getAnimationsEnumMap(), invalid map!" );
     return NULL;
 }
 
@@ -526,11 +526,11 @@ public:
 
     Reference< XInterface > getParagraphTarget( const ParagraphTarget* pTarget ) const;
 
-    void convertPath( OUStringBuffer& sTmp, const Any& rPath );
-    void convertValue( XMLTokenEnum eAttributeName, OUStringBuffer& sTmp, const Any& rValue );
-    void convertTiming( OUStringBuffer& sTmp, const Any& rTiming );
-    void convertSource( OUStringBuffer& sTmp, const Any& rSource );
-    void convertTarget( OUStringBuffer& sTmp, const Any& rTarget );
+    void convertPath( OUStringBuffer& sTmp, const Any& rPath ) const;
+    void convertValue( XMLTokenEnum eAttributeName, OUStringBuffer& sTmp, const Any& rValue ) const;
+    void convertTiming( OUStringBuffer& sTmp, const Any& rTiming ) const;
+    void convertSource( OUStringBuffer& sTmp, const Any& rSource ) const;
+    void convertTarget( OUStringBuffer& sTmp, const Any& rTarget ) const;
 
     void prepareValue( const Any& rValue );
 
@@ -555,7 +555,7 @@ AnimationsExporterImpl::AnimationsExporterImpl( SvXMLExport& rExport, const Refe
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::AnimationsExporterImpl(), RuntimeException catched!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::AnimationsExporterImpl(), RuntimeException catched!" );
     }
 }
 
@@ -603,12 +603,12 @@ void AnimationsExporterImpl::exportTransitionNode()
                 sTmp.append( sal_Unicode('s'));
                 mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_DUR, sTmp.makeStringAndClear() );
 
-                SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTransition, getAnimationsEnumMap(Animations_EnumMap_TransitionType) );
+                SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTransition, getAnimationsEnumMap(Animations_EnumMap_TransitionType) );
                 mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_TYPE, sTmp.makeStringAndClear() );
 
                 if( nSubtype != TransitionSubType::DEFAULT )
                 {
-                    SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nSubtype, getAnimationsEnumMap(Animations_EnumMap_TransitionSubType) );
+                    SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nSubtype, getAnimationsEnumMap(Animations_EnumMap_TransitionSubType) );
                     mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_SUBTYPE, sTmp.makeStringAndClear() );
                 }
 
@@ -671,7 +671,7 @@ void AnimationsExporterImpl::prepareTransitionNode()
     }
     catch( Exception& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::prepareNode(), Exception caught!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::prepareNode(), Exception caught!" );
     }
     
 }
@@ -752,7 +752,7 @@ void AnimationsExporterImpl::prepareNode( const Reference< XAnimationNode >& xNo
     }
     catch( Exception& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::prepareNode(), RuntimeException catched!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::prepareNode(), RuntimeException catched!" );
     }
 }
 
@@ -806,28 +806,28 @@ void AnimationsExporterImpl::exportNode( const Reference< XAnimationNode >& xNod
         nTemp = xNode->getFill();
         if( nTemp != AnimationFill::DEFAULT )
         {
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_Fill) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_Fill) );
             mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_FILL, sTmp.makeStringAndClear() );
         }
 
         nTemp = xNode->getFillDefault();
         if( nTemp != AnimationFill::INHERIT )
         {
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_FillDefault) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_FillDefault) );
             mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_FILLDEFAULT, sTmp.makeStringAndClear() );
         }
 
         nTemp = xNode->getRestart();
         if( nTemp != AnimationRestart::DEFAULT )
         {
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_Restart) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_Restart) );
             mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_RESTART, sTmp.makeStringAndClear() );
         }
 
         nTemp = xNode->getRestartDefault();
         if( nTemp != AnimationRestart::INHERIT )
         {
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_RestartDefault) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_RestartDefault) );
             mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_RESTARTDEFAULT, sTmp.makeStringAndClear() );
         }
 
@@ -885,7 +885,7 @@ void AnimationsExporterImpl::exportNode( const Reference< XAnimationNode >& xNod
         {
             if( aTemp >>= nTemp )
             {
-                SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_Endsync) );
+                SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_Endsync) );
                 mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_ENDSYNC, sTmp.makeStringAndClear() );
             }
         }
@@ -904,7 +904,7 @@ void AnimationsExporterImpl::exportNode( const Reference< XAnimationNode >& xNod
                 {
                     if( (pValue->Value >>= nContainerNodeType) && (nContainerNodeType != EffectNodeType::DEFAULT) )
                     {
-                        SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nContainerNodeType, getAnimationsEnumMap(Animations_EnumMap_EffectNodeType) );
+                        SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nContainerNodeType, getAnimationsEnumMap(Animations_EnumMap_EffectNodeType) );
                         mrExport.AddAttribute( XML_NAMESPACE_PRESENTATION, XML_NODE_TYPE, sTmp.makeStringAndClear() );
                     }
                 }
@@ -928,7 +928,7 @@ void AnimationsExporterImpl::exportNode( const Reference< XAnimationNode >& xNod
                     sal_Int16 nEffectPresetClass = sal_Int16();
                     if( pValue->Value >>= nEffectPresetClass )
                     {
-                        SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nEffectPresetClass, getAnimationsEnumMap(Animations_EnumMap_EffectPresetClass) );
+                        SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nEffectPresetClass, getAnimationsEnumMap(Animations_EnumMap_EffectPresetClass) );
                         mrExport.AddAttribute( XML_NAMESPACE_PRESENTATION, XML_PRESET_CLASS, sTmp.makeStringAndClear() );
                     }
                 }
@@ -994,12 +994,12 @@ void AnimationsExporterImpl::exportNode( const Reference< XAnimationNode >& xNod
         }
         break;
         default:
-            DBG_ERROR( "xmloff::AnimationsExporterImpl::exportNode(), invalid AnimationNodeType!" );
+            OSL_FAIL( "xmloff::AnimationsExporterImpl::exportNode(), invalid AnimationNodeType!" );
         }
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::exportNode(), RuntimeException catched!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::exportNode(), RuntimeException catched!" );
     }
 
     // if something goes wrong, its always a good idea to clear the attribute list
@@ -1027,14 +1027,14 @@ void AnimationsExporterImpl::exportContainer( const Reference< XTimeContainer >&
             sal_Int16 nTemp = xIter->getSubItem();
             if( nTemp )
             {
-                SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_SubItem) );
+                SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_SubItem) );
                 mrExport.AddAttribute( XML_NAMESPACE_ANIMATION, XML_SUB_ITEM, sTmp.makeStringAndClear() );
             }
 
             nTemp = xIter->getIterateType();
             if( nTemp )
             {
-                SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_IterateType) );
+                SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_IterateType) );
                 mrExport.AddAttribute( XML_NAMESPACE_ANIMATION, XML_ITERATE_TYPE, sTmp.makeStringAndClear() );
             }
 
@@ -1064,7 +1064,7 @@ void AnimationsExporterImpl::exportContainer( const Reference< XTimeContainer >&
         case AnimationNodeType::SEQ:	eElementToken = XML_SEQ; break;
         case AnimationNodeType::ITERATE:eElementToken = XML_ITERATE; break;
         default:
-            DBG_ERROR( "xmloff::AnimationsExporterImpl::exportContainer(), invalid TimeContainerType!" );
+            OSL_FAIL( "xmloff::AnimationsExporterImpl::exportContainer(), invalid TimeContainerType!" );
             return;
         }
         SvXMLElementExport aElement( mrExport, XML_NAMESPACE_ANIMATION, eElementToken, sal_True, sal_True );
@@ -1082,7 +1082,7 @@ void AnimationsExporterImpl::exportContainer( const Reference< XTimeContainer >&
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::exportContainer(), RuntimeException catched!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::exportContainer(), RuntimeException catched!" );
     }
 }
 
@@ -1106,7 +1106,7 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
         nTemp = xAnimate->getSubItem();
         if( nTemp )
         {
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_SubItem) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_SubItem) );
             mrExport.AddAttribute( XML_NAMESPACE_ANIMATION, XML_SUB_ITEM, sTmp.makeStringAndClear() );
         }
 
@@ -1212,7 +1212,7 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
                 if( ((nNodeType == AnimationNodeType::ANIMATEMOTION ) && (nTemp != AnimationCalcMode::PACED)) || 
                     ((nNodeType != AnimationNodeType::ANIMATEMOTION ) && (nTemp != AnimationCalcMode::LINEAR)) )
                 {
-                    SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_CalcMode) );
+                    SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_CalcMode) );
                     mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_CALCMODE, sTmp.makeStringAndClear() );
                 }
                     
@@ -1223,7 +1223,7 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
                 nTemp = xAnimate->getAdditive();
                 if( nTemp != AnimationAdditiveMode::REPLACE )
                 {
-                    SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_AdditiveMode) );
+                    SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_AdditiveMode) );
                     mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_ADDITIVE, sTmp.makeStringAndClear() );
                 }
             }
@@ -1302,7 +1302,7 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
 
             Reference< XAnimateTransform > xTransform( xAnimate, UNO_QUERY_THROW );
             nTemp = xTransform->getTransformType();
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTemp, getAnimationsEnumMap(Animations_EnumMap_TransformType) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTemp, getAnimationsEnumMap(Animations_EnumMap_TransformType) );
             mrExport.AddAttribute( XML_NAMESPACE_SVG, XML_TYPE, sTmp.makeStringAndClear() );
         }
         break;
@@ -1313,13 +1313,13 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
             eElementToken = XML_TRANSITIONFILTER;
 
             sal_Int16 nTransition = xTransitionFilter->getTransition();
-            SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nTransition, getAnimationsEnumMap(Animations_EnumMap_TransitionType) );
+            SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nTransition, getAnimationsEnumMap(Animations_EnumMap_TransitionType) );
             mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_TYPE, sTmp.makeStringAndClear() );
 
             sal_Int16 nSubtype = xTransitionFilter->getSubtype();
             if( nSubtype != TransitionSubType::DEFAULT )
             {
-                SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nSubtype, getAnimationsEnumMap(Animations_EnumMap_TransitionSubType) );
+                SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nSubtype, getAnimationsEnumMap(Animations_EnumMap_TransitionSubType) );
                 mrExport.AddAttribute( XML_NAMESPACE_SMIL, XML_SUBTYPE, sTmp.makeStringAndClear() );
             }
 
@@ -1347,7 +1347,7 @@ void AnimationsExporterImpl::exportAnimate( const Reference< XAnimate >& xAnimat
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::exportAnimate(), Exception cought!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::exportAnimate(), Exception cought!" );
     }
 }
 
@@ -1380,7 +1380,7 @@ void AnimationsExporterImpl::exportAudio( const Reference< XAudio >& xAudio )
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::exportAudio(), exception caught!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::exportAudio(), exception caught!" );
     }
 }
 
@@ -1397,7 +1397,7 @@ void AnimationsExporterImpl::exportCommand( const Reference< XCommand >& xComman
         }
 
         sal_Int16 nCommand = xCommand->getCommand();
-        SvXMLUnitConverter::convertEnum( sTmp, (USHORT)nCommand, getAnimationsEnumMap(Animations_EnumMap_Command) );
+        SvXMLUnitConverter::convertEnum( sTmp, (sal_uInt16)nCommand, getAnimationsEnumMap(Animations_EnumMap_Command) );
         mrExport.AddAttribute( XML_NAMESPACE_ANIMATION, XML_COMMAND, sTmp.makeStringAndClear() );
 
 // todo virtual ::com::sun::star::uno::Any SAL_CALL getParameter() throw (::com::sun::star::uno::RuntimeException) = 0;
@@ -1408,7 +1408,7 @@ void AnimationsExporterImpl::exportCommand( const Reference< XCommand >& xComman
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::exportCommand(), exception caught!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::exportCommand(), exception caught!" );
     }
 }
 
@@ -1430,14 +1430,14 @@ Reference< XInterface > AnimationsExporterImpl::getParagraphTarget( const Paragr
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::getParagraphTarget(), RuntimeException catched!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::getParagraphTarget(), RuntimeException catched!" );
     }
 
     Reference< XInterface > xRef;
     return xRef;
 }
 
-void AnimationsExporterImpl::convertPath( OUStringBuffer& sTmp, const Any& rPath )
+void AnimationsExporterImpl::convertPath( OUStringBuffer& sTmp, const Any& rPath ) const
 {
     OUString aStr;
     rPath >>= aStr;
@@ -1445,7 +1445,7 @@ void AnimationsExporterImpl::convertPath( OUStringBuffer& sTmp, const Any& rPath
     sTmp = aStr;
 }
 
-void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUStringBuffer& sTmp, const Any& rValue )
+void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUStringBuffer& sTmp, const Any& rValue ) const
 {
     if( !rValue.hasValue() )
         return;
@@ -1492,37 +1492,6 @@ void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUString
         {
             if( rValue >>= aString )
             {
-                /*
-                const sal_Char* pSource[] = { "$X", "$Y", "$Width", "$Height", NULL };
-                const sal_Char* pDest[] = { "$x", "$y", "$width", "$height", NULL };
-                const sal_Int32 nLength[] = { 2, 2, 6, 7, 0 };
-
-                sal_Int32 nIndex = 0;
-                while( (nIndex = aString.indexOf( (sal_Unicode)'$', nIndex )) != -1  )
-                {
-                    const sal_Char** ps = pSource;
-                    const sal_Char** pd = pDest;
-                    const sal_Int32* pl = nLength;
-
-                    while( *ps )
-                    {
-                        if( aString.matchAsciiL( *ps, *pl, nIndex ) )
-                        {
-                            const OUString aNew( OUString::createFromAscii( *pd ) );
-                            aString = aString.replaceAt( nIndex, *pl, aNew );
-                            nIndex += aNew.getLength();
-                            break;
-                        }
-
-                        ps++;
-                        pd++;
-                        pl++;
-                    }
-
-                    if( *ps == 0 )
-                        nIndex++;
-                }
-                */
                 sTmp.append( aString );
             }
             else if( rValue.getValueType() == ::getCppuType((const double*)0) )
@@ -1531,7 +1500,7 @@ void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUString
             }
             else
             {
-                DBG_ERROR( "xmloff::AnimationsExporterImpl::convertValue(), invalid value type!" );
+                OSL_FAIL( "xmloff::AnimationsExporterImpl::convertValue(), invalid value type!" );
             }
             return;
         }
@@ -1553,7 +1522,7 @@ void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUString
         case XML_OPACITY:
         case XML_TRANSITIONFILTER:	nType = XML_TYPE_DOUBLE;					break;
         default:
-            DBG_ERROR( "xmloff::AnimationsExporterImpl::convertValue(), invalid AttributeName!" );
+            OSL_FAIL( "xmloff::AnimationsExporterImpl::convertValue(), invalid AttributeName!" );
             nType = XML_TYPE_STRING;
         }
 
@@ -1564,24 +1533,9 @@ void AnimationsExporterImpl::convertValue( XMLTokenEnum eAttributeName, OUString
             sTmp.append( aString );
         }
     }
-
-/*	
-    if( rValue.getValueType() == ::getCppuType((const double*)0) )
-    {
-        sTmp.append( *(static_cast< const double* >( rValue.getValue() )) );
-    }
-    else if( rValue.getValueType() == ::getCppuType((const OUString*)0) )
-    {
-        sTmp.append( *(static_cast< const OUString* >( rValue.getValue() )) );
-    }
-    else
-    {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::convertValue(), invalid value type!" );
-    }
-*/
 }
 
-void AnimationsExporterImpl::convertTiming( OUStringBuffer& sTmp, const Any& rValue )
+void AnimationsExporterImpl::convertTiming( OUStringBuffer& sTmp, const Any& rValue ) const
 {
     if( !rValue.hasValue() )
         return;
@@ -1627,7 +1581,7 @@ void AnimationsExporterImpl::convertTiming( OUStringBuffer& sTmp, const Any& rVa
                 sTmp.append( (sal_Unicode)'.' );
             }
 
-            SvXMLUnitConverter::convertEnum( sTmp2, (USHORT)pEvent->Trigger, getAnimationsEnumMap(Animations_EnumMap_EventTrigger) );
+            SvXMLUnitConverter::convertEnum( sTmp2, (sal_uInt16)pEvent->Trigger, getAnimationsEnumMap(Animations_EnumMap_EventTrigger) );
             
             sTmp.append( sTmp2.makeStringAndClear() );
         }
@@ -1644,16 +1598,16 @@ void AnimationsExporterImpl::convertTiming( OUStringBuffer& sTmp, const Any& rVa
     }
     else
     {
-        DBG_ERROR( "xmloff::AnimationsExporterImpl::convertTiming(), invalid value type!" );
+        OSL_FAIL( "xmloff::AnimationsExporterImpl::convertTiming(), invalid value type!" );
     }	
 }
 
-void AnimationsExporterImpl::convertSource( OUStringBuffer& sTmp, const Any& rSource )
+void AnimationsExporterImpl::convertSource( OUStringBuffer& sTmp, const Any& rSource ) const
 {
     convertTarget( sTmp, rSource );
 }
 
-void AnimationsExporterImpl::convertTarget( OUStringBuffer& sTmp, const Any& rTarget )
+void AnimationsExporterImpl::convertTarget( OUStringBuffer& sTmp, const Any& rTarget ) const
 {
     if( !rTarget.hasValue() )
         return;
@@ -1740,7 +1694,7 @@ void AnimationsExporter::prepare( Reference< XAnimationNode > xRootNode )
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporter::prepare(), exception catched" );
+        OSL_FAIL( "xmloff::AnimationsExporter::prepare(), exception catched" );
     }
 }
 
@@ -1776,7 +1730,7 @@ void AnimationsExporter::exportAnimations( Reference< XAnimationNode > xRootNode
     }
     catch( RuntimeException& )
     {
-        DBG_ERROR( "xmloff::AnimationsExporter::exportAnimations(), exception catched" );
+        OSL_FAIL( "xmloff::AnimationsExporter::exportAnimations(), exception catched" );
     }
 }
 
