@@ -231,7 +231,7 @@ sal_Bool DocumentDigitalSignatures::ImplViewSignatures(
         {
             if ( aSignaturesDialog.SignaturesChanged() )
             {
-                bChanges = TRUE;
+                bChanges = sal_True;
                 // If we have a storage and no stream, we are responsible for commit
                 if ( rxStorage.is() && !xSignStream.is() )
                 {
@@ -320,7 +320,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
             if (!rSigInfo.Signer.is())
                 rSigInfo.Signer = xSecEnv->getCertificate( rInfo.ouX509IssuerName, xSerialNumberAdapter->toSequence( rInfo.ouX509SerialNumber ) );
 
-            // --> PB 2004-12-14 #i38744# time support again
+            // Time support again (#i38744#)
             Date aDate( rInfo.stDateTime.Day, rInfo.stDateTime.Month, rInfo.stDateTime.Year );
             Time aTime( rInfo.stDateTime.Hours, rInfo.stDateTime.Minutes,
                         rInfo.stDateTime.Seconds, rInfo.stDateTime.HundredthSeconds );
@@ -340,7 +340,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
                     rSigInfo.CertificateStatus = xSecEnv->verifyCertificate(rSigInfo.Signer,
                         Sequence<Reference<css::security::XCertificate> >());
                 } catch (SecurityException& ) {
-                    OSL_ENSURE(0, "Verification of certificate failed");
+                    OSL_FAIL("Verification of certificate failed");
                     rSigInfo.CertificateStatus = css::security::CertificateValidity::INVALID;
                 }
             }
@@ -398,7 +398,7 @@ void DocumentDigitalSignatures::showCertificate(
 
     if ( bInit )
     {
-        CertificateViewer aViewer( NULL, aSignatureHelper.GetSecurityEnvironment(), _Certificate, FALSE );
+        CertificateViewer aViewer( NULL, aSignatureHelper.GetSecurityEnvironment(), _Certificate, sal_False );
         aViewer.Execute();
     }
 
